-- Version: 7.3 7.3.0.29

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity NVM_sys is

    port( INIT_CLK      : in    std_logic;
          SYS_RESET     : in    std_logic;
          INIT_POWER_UP : in    std_logic;
          INIT_DONE     : out   std_logic;
          INIT_DATA     : out   std_logic_vector(8 downto 0);
          INIT_ADDR     : out   std_logic_vector(8 downto 0);
          INIT_ACM_WEN  : out   std_logic;
          INIT_ASSC_WEN : out   std_logic;
          INIT_EV_WEN   : out   std_logic;
          INIT_TR_WEN   : out   std_logic
        );

end NVM_sys;

architecture DEF_ARCH of NVM_sys is 

  component NVM
    generic (MEMORYFILE:string := "");

    port( RD               : out   std_logic_vector(31 downto 0);
          BUSY             : out   std_logic;
          STATUS           : out   std_logic_vector(1 downto 0);
          ADDR             : in    std_logic_vector(17 downto 0) := (others => 'U');
          WD               : in    std_logic_vector(31 downto 0) := (others => 'U');
          DATAWIDTH        : in    std_logic_vector(1 downto 0) := (others => 'U');
          REN              : in    std_logic := 'U';
          WEN              : in    std_logic := 'U';
          PROGRAM          : in    std_logic := 'U';
          SPAREPAGE        : in    std_logic := 'U';
          AUXBLOCK         : in    std_logic := 'U';
          READNEXT         : in    std_logic := 'U';
          ERASEPAGE        : in    std_logic := 'U';
          UNPROTECTPAGE    : in    std_logic := 'U';
          DISCARDPAGE      : in    std_logic := 'U';
          OVERWRITEPROTECT : in    std_logic := 'U';
          PAGELOSSPROTECT  : in    std_logic := 'U';
          CLK              : in    std_logic := 'U';
          RESET            : in    std_logic := 'U';
          PAGESTATUS       : in    std_logic := 'U';
          OVERWRITEPAGE    : in    std_logic := 'U';
          PIPE             : in    std_logic := 'U';
          LOCKREQUEST      : in    std_logic := 'U'
        );
  end component;

  component NVM_sys_init_wrapper
    port( CLK                 : in    std_logic := 'U';
          USER_CLK            : in    std_logic := 'U';
          NRESET              : in    std_logic := 'U';
          CLIENT_DIN          : in    std_logic_vector(35 downto 0) := (others => 'U');
          CLIENT_AVAIL        : in    std_logic_vector(3 downto 0) := (others => 'U');
          USER_ADD            : in    std_logic_vector(17 downto 0) := (others => 'U');
          USER_AUX_BLOCK      : in    std_logic := 'U';
          USER_DATA           : in    std_logic_vector(31 downto 0) := (others => 'U');
          USER_DISCARD_PAGE   : in    std_logic := 'U';
          USER_ERASE_PAGE     : in    std_logic := 'U';
          USER_OVERWRITE_PAGE : in    std_logic := 'U';
          USER_OVERWRITE_PROT : in    std_logic := 'U';
          USER_PAGE_STATUS    : in    std_logic := 'U';
          USER_PAGELOSS_PROT  : in    std_logic := 'U';
          USER_PROGRAM        : in    std_logic := 'U';
          USER_READ           : in    std_logic := 'U';
          USER_READ_NEXT      : in    std_logic := 'U';
          USER_LOCK           : in    std_logic := 'U';
          USER_SPARE_PAGE     : in    std_logic := 'U';
          USER_UNPROT_PAGE    : in    std_logic := 'U';
          USER_WIDTH          : in    std_logic_vector(1 downto 0) := (others => 'U');
          USER_WRITE          : in    std_logic := 'U';
          USER_SIX_CYCLE      : in    std_logic := 'U';
          CLIENT_UPDATE       : in    std_logic := 'U';
          POWER_UP            : in    std_logic := 'U';
          NVM_BUSY            : in    std_logic := 'U';
          NVM_DAT_FROM        : in    std_logic_vector(31 downto 0) := (others => 'U');
          NVM_STATUS          : in    std_logic_vector(1 downto 0) := (others => 'U');
          NVM_ADD             : out   std_logic_vector(17 downto 0);
          NVM_AUX_BLOCK       : out   std_logic;
          NVM_DAT_TO          : out   std_logic_vector(31 downto 0);
          NVM_DISCARD_PAGE    : out   std_logic;
          NVM_ERASE_PAGE      : out   std_logic;
          NVM_OVERWRITE_PAGE  : out   std_logic;
          NVM_OVERWRITE_PROT  : out   std_logic;
          NVM_PAGE_STATUS     : out   std_logic;
          NVM_PAGELOSS_PROT   : out   std_logic;
          NVM_PROGRAM         : out   std_logic;
          NVM_READ            : out   std_logic;
          NVM_READ_NEXT       : out   std_logic;
          NVM_LOCK            : out   std_logic;
          NVM_SPARE_PAGE      : out   std_logic;
          NVM_UNPROT_PAGE     : out   std_logic;
          NVM_WIDTH           : out   std_logic_vector(1 downto 0);
          NVM_WRITE           : out   std_logic;
          NVM_SIX_CYCLE       : out   std_logic;
          WORD_COUNT          : out   std_logic_vector(8 downto 0);
          CLIENT_DOUT         : out   std_logic_vector(8 downto 0);
          CLIENT_DAT_VAL      : out   std_logic_vector(3 downto 0);
          SAVE_COMPLETE       : out   std_logic;
          INIT_DONE           : out   std_logic;
          USER_DOUT           : out   std_logic_vector(31 downto 0);
          USER_DAT_VAL        : out   std_logic;
          USER_NVM_STATUS     : out   std_logic_vector(1 downto 0);
          NVM_CLK             : out   std_logic
        );
  end component;

  component GND
    port(Y : out std_logic); 
  end component;

  component VCC
    port(Y : out std_logic); 
  end component;

    signal GND_net, VCC_net, NVM_LOCK_net, NVM_AUX_BLOCK_net, 
        NVM_DAT_TO_net_busnet_31, NVM_DAT_TO_net_busnet_30, 
        NVM_DAT_TO_net_busnet_29, NVM_DAT_TO_net_busnet_28, 
        NVM_DAT_TO_net_busnet_27, NVM_DAT_TO_net_busnet_26, 
        NVM_DAT_TO_net_busnet_25, NVM_DAT_TO_net_busnet_24, 
        NVM_DAT_TO_net_busnet_23, NVM_DAT_TO_net_busnet_22, 
        NVM_DAT_TO_net_busnet_21, NVM_DAT_TO_net_busnet_20, 
        NVM_DAT_TO_net_busnet_19, NVM_DAT_TO_net_busnet_18, 
        NVM_DAT_TO_net_busnet_17, NVM_DAT_TO_net_busnet_16, 
        NVM_DAT_TO_net_busnet_15, NVM_DAT_TO_net_busnet_14, 
        NVM_DAT_TO_net_busnet_13, NVM_DAT_TO_net_busnet_12, 
        NVM_DAT_TO_net_busnet_11, NVM_DAT_TO_net_busnet_10, 
        NVM_DAT_TO_net_busnet_9, NVM_DAT_TO_net_busnet_8, 
        NVM_DAT_TO_net_busnet_7, NVM_DAT_TO_net_busnet_6, 
        NVM_DAT_TO_net_busnet_5, NVM_DAT_TO_net_busnet_4, 
        NVM_DAT_TO_net_busnet_3, NVM_DAT_TO_net_busnet_2, 
        NVM_DAT_TO_net_busnet_1, NVM_DAT_TO_net_busnet_0, 
        NVM_ADD_net_busnet_17, NVM_ADD_net_busnet_16, 
        NVM_ADD_net_busnet_15, NVM_ADD_net_busnet_14, 
        NVM_ADD_net_busnet_13, NVM_ADD_net_busnet_12, 
        NVM_ADD_net_busnet_11, NVM_ADD_net_busnet_10, 
        NVM_ADD_net_busnet_9, NVM_ADD_net_busnet_8, 
        NVM_ADD_net_busnet_7, NVM_ADD_net_busnet_6, 
        NVM_ADD_net_busnet_5, NVM_ADD_net_busnet_4, 
        NVM_ADD_net_busnet_3, NVM_ADD_net_busnet_2, 
        NVM_ADD_net_busnet_1, NVM_ADD_net_busnet_0, 
        NVM_WIDTH_net_busnet_1, NVM_WIDTH_net_busnet_0, 
        NVM_REN_net, NVM_READ_NEXT_net, NVM_WRITE_net, 
        NVM_SPARE_PAGE_net, NVM_PROGRAM_net, NVM_ERASE_PAGE_net, 
        NVM_UNPROT_PAGE_net, NVM_DISCARD_PAGE_net, 
        NVM_OVERWRITE_PROT_net, NVM_PAGELOSS_PROT_net, 
        NVM_PAGE_STATUS_net, NVM_OVERWRITE_PAGE_net, 
        NVM_DAT_FROM_net_busnet_31, NVM_DAT_FROM_net_busnet_30, 
        NVM_DAT_FROM_net_busnet_29, NVM_DAT_FROM_net_busnet_28, 
        NVM_DAT_FROM_net_busnet_27, NVM_DAT_FROM_net_busnet_26, 
        NVM_DAT_FROM_net_busnet_25, NVM_DAT_FROM_net_busnet_24, 
        NVM_DAT_FROM_net_busnet_23, NVM_DAT_FROM_net_busnet_22, 
        NVM_DAT_FROM_net_busnet_21, NVM_DAT_FROM_net_busnet_20, 
        NVM_DAT_FROM_net_busnet_19, NVM_DAT_FROM_net_busnet_18, 
        NVM_DAT_FROM_net_busnet_17, NVM_DAT_FROM_net_busnet_16, 
        NVM_DAT_FROM_net_busnet_15, NVM_DAT_FROM_net_busnet_14, 
        NVM_DAT_FROM_net_busnet_13, NVM_DAT_FROM_net_busnet_12, 
        NVM_DAT_FROM_net_busnet_11, NVM_DAT_FROM_net_busnet_10, 
        NVM_DAT_FROM_net_busnet_9, NVM_DAT_FROM_net_busnet_8, 
        NVM_DAT_FROM_net_busnet_7, NVM_DAT_FROM_net_busnet_6, 
        NVM_DAT_FROM_net_busnet_5, NVM_DAT_FROM_net_busnet_4, 
        NVM_DAT_FROM_net_busnet_3, NVM_DAT_FROM_net_busnet_2, 
        NVM_DAT_FROM_net_busnet_1, NVM_DAT_FROM_net_busnet_0, 
        NVM_BUSY_net, NVM_STATUS_net_busnet_1, 
        NVM_STATUS_net_busnet_0, NVM_CLK_net : std_logic;
    signal GND_power_net1 : std_logic;
    signal VCC_power_net1 : std_logic;
    signal nc34, nc9, nc13, nc23, nc33, nc16, nc26, nc27, nc17, 
        nc5, nc4, nc25, nc15, nc28, nc18, nc1, nc2, nc22, nc12, 
        nc21, nc11, nc3, nc32, nc31, nc7, nc6, nc19, nc29, nc8, 
        nc20, nc10, nc24, nc14, nc30 : std_logic;

begin 

    GND_net <= GND_power_net1;
    VCC_net <= VCC_power_net1;

    NVM_INST : NVM
      generic map(MEMORYFILE => "NVM_sys.mem")

      port map(RD(31) => NVM_DAT_FROM_net_busnet_31, RD(30) => 
        NVM_DAT_FROM_net_busnet_30, RD(29) => 
        NVM_DAT_FROM_net_busnet_29, RD(28) => 
        NVM_DAT_FROM_net_busnet_28, RD(27) => 
        NVM_DAT_FROM_net_busnet_27, RD(26) => 
        NVM_DAT_FROM_net_busnet_26, RD(25) => 
        NVM_DAT_FROM_net_busnet_25, RD(24) => 
        NVM_DAT_FROM_net_busnet_24, RD(23) => 
        NVM_DAT_FROM_net_busnet_23, RD(22) => 
        NVM_DAT_FROM_net_busnet_22, RD(21) => 
        NVM_DAT_FROM_net_busnet_21, RD(20) => 
        NVM_DAT_FROM_net_busnet_20, RD(19) => 
        NVM_DAT_FROM_net_busnet_19, RD(18) => 
        NVM_DAT_FROM_net_busnet_18, RD(17) => 
        NVM_DAT_FROM_net_busnet_17, RD(16) => 
        NVM_DAT_FROM_net_busnet_16, RD(15) => 
        NVM_DAT_FROM_net_busnet_15, RD(14) => 
        NVM_DAT_FROM_net_busnet_14, RD(13) => 
        NVM_DAT_FROM_net_busnet_13, RD(12) => 
        NVM_DAT_FROM_net_busnet_12, RD(11) => 
        NVM_DAT_FROM_net_busnet_11, RD(10) => 
        NVM_DAT_FROM_net_busnet_10, RD(9) => 
        NVM_DAT_FROM_net_busnet_9, RD(8) => 
        NVM_DAT_FROM_net_busnet_8, RD(7) => 
        NVM_DAT_FROM_net_busnet_7, RD(6) => 
        NVM_DAT_FROM_net_busnet_6, RD(5) => 
        NVM_DAT_FROM_net_busnet_5, RD(4) => 
        NVM_DAT_FROM_net_busnet_4, RD(3) => 
        NVM_DAT_FROM_net_busnet_3, RD(2) => 
        NVM_DAT_FROM_net_busnet_2, RD(1) => 
        NVM_DAT_FROM_net_busnet_1, RD(0) => 
        NVM_DAT_FROM_net_busnet_0, BUSY => NVM_BUSY_net, 
        STATUS(1) => NVM_STATUS_net_busnet_1, STATUS(0) => 
        NVM_STATUS_net_busnet_0, ADDR(17) => 
        NVM_ADD_net_busnet_17, ADDR(16) => NVM_ADD_net_busnet_16, 
        ADDR(15) => NVM_ADD_net_busnet_15, ADDR(14) => 
        NVM_ADD_net_busnet_14, ADDR(13) => NVM_ADD_net_busnet_13, 
        ADDR(12) => NVM_ADD_net_busnet_12, ADDR(11) => 
        NVM_ADD_net_busnet_11, ADDR(10) => NVM_ADD_net_busnet_10, 
        ADDR(9) => NVM_ADD_net_busnet_9, ADDR(8) => 
        NVM_ADD_net_busnet_8, ADDR(7) => NVM_ADD_net_busnet_7, 
        ADDR(6) => NVM_ADD_net_busnet_6, ADDR(5) => 
        NVM_ADD_net_busnet_5, ADDR(4) => NVM_ADD_net_busnet_4, 
        ADDR(3) => NVM_ADD_net_busnet_3, ADDR(2) => 
        NVM_ADD_net_busnet_2, ADDR(1) => NVM_ADD_net_busnet_1, 
        ADDR(0) => NVM_ADD_net_busnet_0, WD(31) => 
        NVM_DAT_TO_net_busnet_31, WD(30) => 
        NVM_DAT_TO_net_busnet_30, WD(29) => 
        NVM_DAT_TO_net_busnet_29, WD(28) => 
        NVM_DAT_TO_net_busnet_28, WD(27) => 
        NVM_DAT_TO_net_busnet_27, WD(26) => 
        NVM_DAT_TO_net_busnet_26, WD(25) => 
        NVM_DAT_TO_net_busnet_25, WD(24) => 
        NVM_DAT_TO_net_busnet_24, WD(23) => 
        NVM_DAT_TO_net_busnet_23, WD(22) => 
        NVM_DAT_TO_net_busnet_22, WD(21) => 
        NVM_DAT_TO_net_busnet_21, WD(20) => 
        NVM_DAT_TO_net_busnet_20, WD(19) => 
        NVM_DAT_TO_net_busnet_19, WD(18) => 
        NVM_DAT_TO_net_busnet_18, WD(17) => 
        NVM_DAT_TO_net_busnet_17, WD(16) => 
        NVM_DAT_TO_net_busnet_16, WD(15) => 
        NVM_DAT_TO_net_busnet_15, WD(14) => 
        NVM_DAT_TO_net_busnet_14, WD(13) => 
        NVM_DAT_TO_net_busnet_13, WD(12) => 
        NVM_DAT_TO_net_busnet_12, WD(11) => 
        NVM_DAT_TO_net_busnet_11, WD(10) => 
        NVM_DAT_TO_net_busnet_10, WD(9) => 
        NVM_DAT_TO_net_busnet_9, WD(8) => NVM_DAT_TO_net_busnet_8, 
        WD(7) => NVM_DAT_TO_net_busnet_7, WD(6) => 
        NVM_DAT_TO_net_busnet_6, WD(5) => NVM_DAT_TO_net_busnet_5, 
        WD(4) => NVM_DAT_TO_net_busnet_4, WD(3) => 
        NVM_DAT_TO_net_busnet_3, WD(2) => NVM_DAT_TO_net_busnet_2, 
        WD(1) => NVM_DAT_TO_net_busnet_1, WD(0) => 
        NVM_DAT_TO_net_busnet_0, DATAWIDTH(1) => 
        NVM_WIDTH_net_busnet_1, DATAWIDTH(0) => 
        NVM_WIDTH_net_busnet_0, REN => NVM_REN_net, WEN => 
        NVM_WRITE_net, PROGRAM => NVM_PROGRAM_net, SPAREPAGE => 
        NVM_SPARE_PAGE_net, AUXBLOCK => NVM_AUX_BLOCK_net, 
        READNEXT => NVM_READ_NEXT_net, ERASEPAGE => 
        NVM_ERASE_PAGE_net, UNPROTECTPAGE => NVM_UNPROT_PAGE_net, 
        DISCARDPAGE => NVM_DISCARD_PAGE_net, OVERWRITEPROTECT => 
        NVM_OVERWRITE_PROT_net, PAGELOSSPROTECT => 
        NVM_PAGELOSS_PROT_net, CLK => NVM_CLK_net, RESET => 
        SYS_RESET, PAGESTATUS => NVM_PAGE_STATUS_net, 
        OVERWRITEPAGE => NVM_OVERWRITE_PAGE_net, PIPE => GND_net, 
        LOCKREQUEST => NVM_LOCK_net);
    
    NVM_sys_init_wrapper_inst : NVM_sys_init_wrapper
      port map(CLK => INIT_CLK, USER_CLK => INIT_CLK, NRESET => 
        SYS_RESET, CLIENT_DIN(35) => GND_net, CLIENT_DIN(34) => 
        GND_net, CLIENT_DIN(33) => GND_net, CLIENT_DIN(32) => 
        GND_net, CLIENT_DIN(31) => GND_net, CLIENT_DIN(30) => 
        GND_net, CLIENT_DIN(29) => GND_net, CLIENT_DIN(28) => 
        GND_net, CLIENT_DIN(27) => GND_net, CLIENT_DIN(26) => 
        GND_net, CLIENT_DIN(25) => GND_net, CLIENT_DIN(24) => 
        GND_net, CLIENT_DIN(23) => GND_net, CLIENT_DIN(22) => 
        GND_net, CLIENT_DIN(21) => GND_net, CLIENT_DIN(20) => 
        GND_net, CLIENT_DIN(19) => GND_net, CLIENT_DIN(18) => 
        GND_net, CLIENT_DIN(17) => GND_net, CLIENT_DIN(16) => 
        GND_net, CLIENT_DIN(15) => GND_net, CLIENT_DIN(14) => 
        GND_net, CLIENT_DIN(13) => GND_net, CLIENT_DIN(12) => 
        GND_net, CLIENT_DIN(11) => GND_net, CLIENT_DIN(10) => 
        GND_net, CLIENT_DIN(9) => GND_net, CLIENT_DIN(8) => 
        GND_net, CLIENT_DIN(7) => GND_net, CLIENT_DIN(6) => 
        GND_net, CLIENT_DIN(5) => GND_net, CLIENT_DIN(4) => 
        GND_net, CLIENT_DIN(3) => GND_net, CLIENT_DIN(2) => 
        GND_net, CLIENT_DIN(1) => GND_net, CLIENT_DIN(0) => 
        GND_net, CLIENT_AVAIL(3) => GND_net, CLIENT_AVAIL(2) => 
        GND_net, CLIENT_AVAIL(1) => GND_net, CLIENT_AVAIL(0) => 
        GND_net, USER_ADD(17) => GND_net, USER_ADD(16) => GND_net, 
        USER_ADD(15) => GND_net, USER_ADD(14) => GND_net, 
        USER_ADD(13) => GND_net, USER_ADD(12) => GND_net, 
        USER_ADD(11) => GND_net, USER_ADD(10) => GND_net, 
        USER_ADD(9) => GND_net, USER_ADD(8) => GND_net, 
        USER_ADD(7) => GND_net, USER_ADD(6) => GND_net, 
        USER_ADD(5) => GND_net, USER_ADD(4) => GND_net, 
        USER_ADD(3) => GND_net, USER_ADD(2) => GND_net, 
        USER_ADD(1) => GND_net, USER_ADD(0) => GND_net, 
        USER_AUX_BLOCK => GND_net, USER_DATA(31) => GND_net, 
        USER_DATA(30) => GND_net, USER_DATA(29) => GND_net, 
        USER_DATA(28) => GND_net, USER_DATA(27) => GND_net, 
        USER_DATA(26) => GND_net, USER_DATA(25) => GND_net, 
        USER_DATA(24) => GND_net, USER_DATA(23) => GND_net, 
        USER_DATA(22) => GND_net, USER_DATA(21) => GND_net, 
        USER_DATA(20) => GND_net, USER_DATA(19) => GND_net, 
        USER_DATA(18) => GND_net, USER_DATA(17) => GND_net, 
        USER_DATA(16) => GND_net, USER_DATA(15) => GND_net, 
        USER_DATA(14) => GND_net, USER_DATA(13) => GND_net, 
        USER_DATA(12) => GND_net, USER_DATA(11) => GND_net, 
        USER_DATA(10) => GND_net, USER_DATA(9) => GND_net, 
        USER_DATA(8) => GND_net, USER_DATA(7) => GND_net, 
        USER_DATA(6) => GND_net, USER_DATA(5) => GND_net, 
        USER_DATA(4) => GND_net, USER_DATA(3) => GND_net, 
        USER_DATA(2) => GND_net, USER_DATA(1) => GND_net, 
        USER_DATA(0) => GND_net, USER_DISCARD_PAGE => GND_net, 
        USER_ERASE_PAGE => GND_net, USER_OVERWRITE_PAGE => 
        GND_net, USER_OVERWRITE_PROT => GND_net, USER_PAGE_STATUS
         => GND_net, USER_PAGELOSS_PROT => GND_net, USER_PROGRAM
         => GND_net, USER_READ => GND_net, USER_READ_NEXT => 
        GND_net, USER_LOCK => GND_net, USER_SPARE_PAGE => GND_net, 
        USER_UNPROT_PAGE => GND_net, USER_WIDTH(1) => GND_net, 
        USER_WIDTH(0) => GND_net, USER_WRITE => GND_net, 
        USER_SIX_CYCLE => GND_net, CLIENT_UPDATE => GND_net, 
        POWER_UP => INIT_POWER_UP, NVM_BUSY => NVM_BUSY_net, 
        NVM_DAT_FROM(31) => NVM_DAT_FROM_net_busnet_31, 
        NVM_DAT_FROM(30) => NVM_DAT_FROM_net_busnet_30, 
        NVM_DAT_FROM(29) => NVM_DAT_FROM_net_busnet_29, 
        NVM_DAT_FROM(28) => NVM_DAT_FROM_net_busnet_28, 
        NVM_DAT_FROM(27) => NVM_DAT_FROM_net_busnet_27, 
        NVM_DAT_FROM(26) => NVM_DAT_FROM_net_busnet_26, 
        NVM_DAT_FROM(25) => NVM_DAT_FROM_net_busnet_25, 
        NVM_DAT_FROM(24) => NVM_DAT_FROM_net_busnet_24, 
        NVM_DAT_FROM(23) => NVM_DAT_FROM_net_busnet_23, 
        NVM_DAT_FROM(22) => NVM_DAT_FROM_net_busnet_22, 
        NVM_DAT_FROM(21) => NVM_DAT_FROM_net_busnet_21, 
        NVM_DAT_FROM(20) => NVM_DAT_FROM_net_busnet_20, 
        NVM_DAT_FROM(19) => NVM_DAT_FROM_net_busnet_19, 
        NVM_DAT_FROM(18) => NVM_DAT_FROM_net_busnet_18, 
        NVM_DAT_FROM(17) => NVM_DAT_FROM_net_busnet_17, 
        NVM_DAT_FROM(16) => NVM_DAT_FROM_net_busnet_16, 
        NVM_DAT_FROM(15) => NVM_DAT_FROM_net_busnet_15, 
        NVM_DAT_FROM(14) => NVM_DAT_FROM_net_busnet_14, 
        NVM_DAT_FROM(13) => NVM_DAT_FROM_net_busnet_13, 
        NVM_DAT_FROM(12) => NVM_DAT_FROM_net_busnet_12, 
        NVM_DAT_FROM(11) => NVM_DAT_FROM_net_busnet_11, 
        NVM_DAT_FROM(10) => NVM_DAT_FROM_net_busnet_10, 
        NVM_DAT_FROM(9) => NVM_DAT_FROM_net_busnet_9, 
        NVM_DAT_FROM(8) => NVM_DAT_FROM_net_busnet_8, 
        NVM_DAT_FROM(7) => NVM_DAT_FROM_net_busnet_7, 
        NVM_DAT_FROM(6) => NVM_DAT_FROM_net_busnet_6, 
        NVM_DAT_FROM(5) => NVM_DAT_FROM_net_busnet_5, 
        NVM_DAT_FROM(4) => NVM_DAT_FROM_net_busnet_4, 
        NVM_DAT_FROM(3) => NVM_DAT_FROM_net_busnet_3, 
        NVM_DAT_FROM(2) => NVM_DAT_FROM_net_busnet_2, 
        NVM_DAT_FROM(1) => NVM_DAT_FROM_net_busnet_1, 
        NVM_DAT_FROM(0) => NVM_DAT_FROM_net_busnet_0, 
        NVM_STATUS(1) => NVM_STATUS_net_busnet_1, NVM_STATUS(0)
         => NVM_STATUS_net_busnet_0, NVM_ADD(17) => 
        NVM_ADD_net_busnet_17, NVM_ADD(16) => 
        NVM_ADD_net_busnet_16, NVM_ADD(15) => 
        NVM_ADD_net_busnet_15, NVM_ADD(14) => 
        NVM_ADD_net_busnet_14, NVM_ADD(13) => 
        NVM_ADD_net_busnet_13, NVM_ADD(12) => 
        NVM_ADD_net_busnet_12, NVM_ADD(11) => 
        NVM_ADD_net_busnet_11, NVM_ADD(10) => 
        NVM_ADD_net_busnet_10, NVM_ADD(9) => NVM_ADD_net_busnet_9, 
        NVM_ADD(8) => NVM_ADD_net_busnet_8, NVM_ADD(7) => 
        NVM_ADD_net_busnet_7, NVM_ADD(6) => NVM_ADD_net_busnet_6, 
        NVM_ADD(5) => NVM_ADD_net_busnet_5, NVM_ADD(4) => 
        NVM_ADD_net_busnet_4, NVM_ADD(3) => NVM_ADD_net_busnet_3, 
        NVM_ADD(2) => NVM_ADD_net_busnet_2, NVM_ADD(1) => 
        NVM_ADD_net_busnet_1, NVM_ADD(0) => NVM_ADD_net_busnet_0, 
        NVM_AUX_BLOCK => NVM_AUX_BLOCK_net, NVM_DAT_TO(31) => 
        NVM_DAT_TO_net_busnet_31, NVM_DAT_TO(30) => 
        NVM_DAT_TO_net_busnet_30, NVM_DAT_TO(29) => 
        NVM_DAT_TO_net_busnet_29, NVM_DAT_TO(28) => 
        NVM_DAT_TO_net_busnet_28, NVM_DAT_TO(27) => 
        NVM_DAT_TO_net_busnet_27, NVM_DAT_TO(26) => 
        NVM_DAT_TO_net_busnet_26, NVM_DAT_TO(25) => 
        NVM_DAT_TO_net_busnet_25, NVM_DAT_TO(24) => 
        NVM_DAT_TO_net_busnet_24, NVM_DAT_TO(23) => 
        NVM_DAT_TO_net_busnet_23, NVM_DAT_TO(22) => 
        NVM_DAT_TO_net_busnet_22, NVM_DAT_TO(21) => 
        NVM_DAT_TO_net_busnet_21, NVM_DAT_TO(20) => 
        NVM_DAT_TO_net_busnet_20, NVM_DAT_TO(19) => 
        NVM_DAT_TO_net_busnet_19, NVM_DAT_TO(18) => 
        NVM_DAT_TO_net_busnet_18, NVM_DAT_TO(17) => 
        NVM_DAT_TO_net_busnet_17, NVM_DAT_TO(16) => 
        NVM_DAT_TO_net_busnet_16, NVM_DAT_TO(15) => 
        NVM_DAT_TO_net_busnet_15, NVM_DAT_TO(14) => 
        NVM_DAT_TO_net_busnet_14, NVM_DAT_TO(13) => 
        NVM_DAT_TO_net_busnet_13, NVM_DAT_TO(12) => 
        NVM_DAT_TO_net_busnet_12, NVM_DAT_TO(11) => 
        NVM_DAT_TO_net_busnet_11, NVM_DAT_TO(10) => 
        NVM_DAT_TO_net_busnet_10, NVM_DAT_TO(9) => 
        NVM_DAT_TO_net_busnet_9, NVM_DAT_TO(8) => 
        NVM_DAT_TO_net_busnet_8, NVM_DAT_TO(7) => 
        NVM_DAT_TO_net_busnet_7, NVM_DAT_TO(6) => 
        NVM_DAT_TO_net_busnet_6, NVM_DAT_TO(5) => 
        NVM_DAT_TO_net_busnet_5, NVM_DAT_TO(4) => 
        NVM_DAT_TO_net_busnet_4, NVM_DAT_TO(3) => 
        NVM_DAT_TO_net_busnet_3, NVM_DAT_TO(2) => 
        NVM_DAT_TO_net_busnet_2, NVM_DAT_TO(1) => 
        NVM_DAT_TO_net_busnet_1, NVM_DAT_TO(0) => 
        NVM_DAT_TO_net_busnet_0, NVM_DISCARD_PAGE => 
        NVM_DISCARD_PAGE_net, NVM_ERASE_PAGE => 
        NVM_ERASE_PAGE_net, NVM_OVERWRITE_PAGE => 
        NVM_OVERWRITE_PAGE_net, NVM_OVERWRITE_PROT => 
        NVM_OVERWRITE_PROT_net, NVM_PAGE_STATUS => 
        NVM_PAGE_STATUS_net, NVM_PAGELOSS_PROT => 
        NVM_PAGELOSS_PROT_net, NVM_PROGRAM => NVM_PROGRAM_net, 
        NVM_READ => NVM_REN_net, NVM_READ_NEXT => 
        NVM_READ_NEXT_net, NVM_LOCK => NVM_LOCK_net, 
        NVM_SPARE_PAGE => NVM_SPARE_PAGE_net, NVM_UNPROT_PAGE => 
        NVM_UNPROT_PAGE_net, NVM_WIDTH(1) => 
        NVM_WIDTH_net_busnet_1, NVM_WIDTH(0) => 
        NVM_WIDTH_net_busnet_0, NVM_WRITE => NVM_WRITE_net, 
        NVM_SIX_CYCLE => OPEN, WORD_COUNT(8) => INIT_ADDR(8), 
        WORD_COUNT(7) => INIT_ADDR(7), WORD_COUNT(6) => 
        INIT_ADDR(6), WORD_COUNT(5) => INIT_ADDR(5), 
        WORD_COUNT(4) => INIT_ADDR(4), WORD_COUNT(3) => 
        INIT_ADDR(3), WORD_COUNT(2) => INIT_ADDR(2), 
        WORD_COUNT(1) => INIT_ADDR(1), WORD_COUNT(0) => 
        INIT_ADDR(0), CLIENT_DOUT(8) => INIT_DATA(8), 
        CLIENT_DOUT(7) => INIT_DATA(7), CLIENT_DOUT(6) => 
        INIT_DATA(6), CLIENT_DOUT(5) => INIT_DATA(5), 
        CLIENT_DOUT(4) => INIT_DATA(4), CLIENT_DOUT(3) => 
        INIT_DATA(3), CLIENT_DOUT(2) => INIT_DATA(2), 
        CLIENT_DOUT(1) => INIT_DATA(1), CLIENT_DOUT(0) => 
        INIT_DATA(0), CLIENT_DAT_VAL(3) => INIT_TR_WEN, 
        CLIENT_DAT_VAL(2) => INIT_EV_WEN, CLIENT_DAT_VAL(1) => 
        INIT_ASSC_WEN, CLIENT_DAT_VAL(0) => INIT_ACM_WEN, 
        SAVE_COMPLETE => OPEN, INIT_DONE => INIT_DONE, 
        USER_DOUT(31) => nc34, USER_DOUT(30) => nc9, 
        USER_DOUT(29) => nc13, USER_DOUT(28) => nc23, 
        USER_DOUT(27) => nc33, USER_DOUT(26) => nc16, 
        USER_DOUT(25) => nc26, USER_DOUT(24) => nc27, 
        USER_DOUT(23) => nc17, USER_DOUT(22) => nc5, 
        USER_DOUT(21) => nc4, USER_DOUT(20) => nc25, 
        USER_DOUT(19) => nc15, USER_DOUT(18) => nc28, 
        USER_DOUT(17) => nc18, USER_DOUT(16) => nc1, 
        USER_DOUT(15) => nc2, USER_DOUT(14) => nc22, 
        USER_DOUT(13) => nc12, USER_DOUT(12) => nc21, 
        USER_DOUT(11) => nc11, USER_DOUT(10) => nc3, USER_DOUT(9)
         => nc32, USER_DOUT(8) => nc31, USER_DOUT(7) => nc7, 
        USER_DOUT(6) => nc6, USER_DOUT(5) => nc19, USER_DOUT(4)
         => nc29, USER_DOUT(3) => nc8, USER_DOUT(2) => nc20, 
        USER_DOUT(1) => nc10, USER_DOUT(0) => nc24, USER_DAT_VAL
         => OPEN, USER_NVM_STATUS(1) => nc14, USER_NVM_STATUS(0)
         => nc30, NVM_CLK => NVM_CLK_net);
    
    GND_power_inst1 : GND
      port map( Y => GND_power_net1);

    VCC_power_inst1 : VCC
      port map( Y => VCC_power_net1);


end DEF_ARCH; 

-- _Disclaimer: Please leave the following comments in the file, they are for internal purposes only._

-- _CFG_File_Contents_

-- nvm_set_engine \
--    -toplevel "NVM_sys" \
--    -HDL VHDL \
--    -die AFS250 \
--    -package "256 FBGA" \
--    -workdir {.} \
--    -commondir {./common} \
--    -verbosity 0
-- nvm_set_system \
--    -pipe 0
-- nvm_set_analogsystem_config -config_file {Analog}

-- _GEN_File_Contents_

-- DESIGN:NVM_sys
-- DESDIR:D:/Actelprj/VT_Mon_vhd/smartgen\.\NVM_sys
-- FAM:Fusion
-- MGNCMPL:F
-- MGNTIMER:F
-- OUTFORMAT:VHDL
-- LPMTYPE:LPM_NVM
-- LPMHINT:NONE
-- CONFIGFILE:NVM_sys.cfg

-- _End_Comments_

