-- Version: 7.3 7.3.0.29

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity NGM is

    port( INIT_DONE_net_i : in    std_logic;
          CLK10M          : in    std_logic;
          PLL_CLK40M      : in    std_logic;
          SYS_CLK_int     : out   std_logic
        );

end NGM;

architecture DEF_ARCH of NGM is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component NGMUX
    port( CLK0 : in    std_logic := 'U';
          CLK1 : in    std_logic := 'U';
          S    : in    std_logic := 'U';
          GL   : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    Inst1 : NGMUX
      port map(CLK0 => PLL_CLK40M, CLK1 => CLK10M, S => 
        INIT_DONE_net_i, GL => SYS_CLK_int);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity PLL_40_10 is

    port( PLL_40_10_VCC : in    std_logic;
          PLL_40_10_GND : in    std_logic;
          PLL_CLK40M    : out   std_logic;
          CLK40M_c      : in    std_logic;
          CLK10M        : out   std_logic
        );

end PLL_40_10;

architecture DEF_ARCH of PLL_40_10 is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component PLL
    generic (VCOFREQUENCY:real := 0.0);

    port( CLKA      : in    std_logic := 'U';
          EXTFB     : in    std_logic := 'U';
          POWERDOWN : in    std_logic := 'U';
          GLA       : out   std_logic;
          LOCK      : out   std_logic;
          GLB       : out   std_logic;
          YB        : out   std_logic;
          GLC       : out   std_logic;
          YC        : out   std_logic;
          OADIV0    : in    std_logic := 'U';
          OADIV1    : in    std_logic := 'U';
          OADIV2    : in    std_logic := 'U';
          OADIV3    : in    std_logic := 'U';
          OADIV4    : in    std_logic := 'U';
          OADIVHALF : in    std_logic := 'U';
          OADIVRST  : in    std_logic := 'U';
          OAMUX0    : in    std_logic := 'U';
          OAMUX1    : in    std_logic := 'U';
          OAMUX2    : in    std_logic := 'U';
          DLYGLA0   : in    std_logic := 'U';
          DLYGLA1   : in    std_logic := 'U';
          DLYGLA2   : in    std_logic := 'U';
          DLYGLA3   : in    std_logic := 'U';
          DLYGLA4   : in    std_logic := 'U';
          OBDIV0    : in    std_logic := 'U';
          OBDIV1    : in    std_logic := 'U';
          OBDIV2    : in    std_logic := 'U';
          OBDIV3    : in    std_logic := 'U';
          OBDIV4    : in    std_logic := 'U';
          OBMUX0    : in    std_logic := 'U';
          OBMUX1    : in    std_logic := 'U';
          OBMUX2    : in    std_logic := 'U';
          DLYYB0    : in    std_logic := 'U';
          DLYYB1    : in    std_logic := 'U';
          DLYYB2    : in    std_logic := 'U';
          DLYYB3    : in    std_logic := 'U';
          DLYYB4    : in    std_logic := 'U';
          DLYGLB0   : in    std_logic := 'U';
          DLYGLB1   : in    std_logic := 'U';
          DLYGLB2   : in    std_logic := 'U';
          DLYGLB3   : in    std_logic := 'U';
          DLYGLB4   : in    std_logic := 'U';
          OCDIV0    : in    std_logic := 'U';
          OCDIV1    : in    std_logic := 'U';
          OCDIV2    : in    std_logic := 'U';
          OCDIV3    : in    std_logic := 'U';
          OCDIV4    : in    std_logic := 'U';
          OCMUX0    : in    std_logic := 'U';
          OCMUX1    : in    std_logic := 'U';
          OCMUX2    : in    std_logic := 'U';
          DLYYC0    : in    std_logic := 'U';
          DLYYC1    : in    std_logic := 'U';
          DLYYC2    : in    std_logic := 'U';
          DLYYC3    : in    std_logic := 'U';
          DLYYC4    : in    std_logic := 'U';
          DLYGLC0   : in    std_logic := 'U';
          DLYGLC1   : in    std_logic := 'U';
          DLYGLC2   : in    std_logic := 'U';
          DLYGLC3   : in    std_logic := 'U';
          DLYGLC4   : in    std_logic := 'U';
          FINDIV0   : in    std_logic := 'U';
          FINDIV1   : in    std_logic := 'U';
          FINDIV2   : in    std_logic := 'U';
          FINDIV3   : in    std_logic := 'U';
          FINDIV4   : in    std_logic := 'U';
          FINDIV5   : in    std_logic := 'U';
          FINDIV6   : in    std_logic := 'U';
          FBDIV0    : in    std_logic := 'U';
          FBDIV1    : in    std_logic := 'U';
          FBDIV2    : in    std_logic := 'U';
          FBDIV3    : in    std_logic := 'U';
          FBDIV4    : in    std_logic := 'U';
          FBDIV5    : in    std_logic := 'U';
          FBDIV6    : in    std_logic := 'U';
          FBDLY0    : in    std_logic := 'U';
          FBDLY1    : in    std_logic := 'U';
          FBDLY2    : in    std_logic := 'U';
          FBDLY3    : in    std_logic := 'U';
          FBDLY4    : in    std_logic := 'U';
          FBSEL0    : in    std_logic := 'U';
          FBSEL1    : in    std_logic := 'U';
          XDLYSEL   : in    std_logic := 'U';
          VCOSEL0   : in    std_logic := 'U';
          VCOSEL1   : in    std_logic := 'U';
          VCOSEL2   : in    std_logic := 'U'
        );
  end component;

  component PLLINT
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

    signal CLKAP, Core_GLB, Core_LOCK, Core_YB, Core_YC, \GND\, 
        \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    Core : PLL
      generic map(VCOFREQUENCY => 40)

      port map(CLKA => CLKAP, EXTFB => PLL_40_10_GND, POWERDOWN
         => PLL_40_10_VCC, GLA => PLL_CLK40M, LOCK => Core_LOCK, 
        GLB => Core_GLB, YB => Core_YB, GLC => CLK10M, YC => 
        Core_YC, OADIV0 => PLL_40_10_GND, OADIV1 => PLL_40_10_GND, 
        OADIV2 => PLL_40_10_GND, OADIV3 => PLL_40_10_GND, OADIV4
         => PLL_40_10_GND, OADIVHALF => PLL_40_10_GND, OADIVRST
         => PLL_40_10_VCC, OAMUX0 => PLL_40_10_GND, OAMUX1 => 
        PLL_40_10_GND, OAMUX2 => PLL_40_10_VCC, DLYGLA0 => 
        PLL_40_10_GND, DLYGLA1 => PLL_40_10_GND, DLYGLA2 => 
        PLL_40_10_GND, DLYGLA3 => PLL_40_10_GND, DLYGLA4 => 
        PLL_40_10_GND, OBDIV0 => PLL_40_10_GND, OBDIV1 => 
        PLL_40_10_GND, OBDIV2 => PLL_40_10_GND, OBDIV3 => 
        PLL_40_10_GND, OBDIV4 => PLL_40_10_GND, OBMUX0 => 
        PLL_40_10_GND, OBMUX1 => PLL_40_10_GND, OBMUX2 => 
        PLL_40_10_GND, DLYYB0 => PLL_40_10_GND, DLYYB1 => 
        PLL_40_10_GND, DLYYB2 => PLL_40_10_GND, DLYYB3 => 
        PLL_40_10_GND, DLYYB4 => PLL_40_10_GND, DLYGLB0 => 
        PLL_40_10_GND, DLYGLB1 => PLL_40_10_GND, DLYGLB2 => 
        PLL_40_10_GND, DLYGLB3 => PLL_40_10_GND, DLYGLB4 => 
        PLL_40_10_GND, OCDIV0 => PLL_40_10_VCC, OCDIV1 => 
        PLL_40_10_VCC, OCDIV2 => PLL_40_10_GND, OCDIV3 => 
        PLL_40_10_GND, OCDIV4 => PLL_40_10_GND, OCMUX0 => 
        PLL_40_10_GND, OCMUX1 => PLL_40_10_GND, OCMUX2 => 
        PLL_40_10_VCC, DLYYC0 => PLL_40_10_GND, DLYYC1 => 
        PLL_40_10_GND, DLYYC2 => PLL_40_10_GND, DLYYC3 => 
        PLL_40_10_GND, DLYYC4 => PLL_40_10_GND, DLYGLC0 => 
        PLL_40_10_GND, DLYGLC1 => PLL_40_10_GND, DLYGLC2 => 
        PLL_40_10_GND, DLYGLC3 => PLL_40_10_GND, DLYGLC4 => 
        PLL_40_10_GND, FINDIV0 => PLL_40_10_VCC, FINDIV1 => 
        PLL_40_10_VCC, FINDIV2 => PLL_40_10_VCC, FINDIV3 => 
        PLL_40_10_GND, FINDIV4 => PLL_40_10_GND, FINDIV5 => 
        PLL_40_10_GND, FINDIV6 => PLL_40_10_GND, FBDIV0 => 
        PLL_40_10_VCC, FBDIV1 => PLL_40_10_VCC, FBDIV2 => 
        PLL_40_10_VCC, FBDIV3 => PLL_40_10_GND, FBDIV4 => 
        PLL_40_10_GND, FBDIV5 => PLL_40_10_GND, FBDIV6 => 
        PLL_40_10_GND, FBDLY0 => PLL_40_10_GND, FBDLY1 => 
        PLL_40_10_VCC, FBDLY2 => PLL_40_10_VCC, FBDLY3 => 
        PLL_40_10_GND, FBDLY4 => PLL_40_10_GND, FBSEL0 => 
        PLL_40_10_GND, FBSEL1 => PLL_40_10_VCC, XDLYSEL => 
        PLL_40_10_GND, VCOSEL0 => PLL_40_10_GND, VCOSEL1 => 
        PLL_40_10_GND, VCOSEL2 => PLL_40_10_GND);
    
    pllint1 : PLLINT
      port map(A => CLK40M_c, Y => CLKAP);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_smev_ram is

    port( INIT_DATA_net              : in    std_logic_vector(8 downto 0);
          SYS_RESET_c                : in    std_logic;
          EV_RAM_DI_B_net_busnet_8   : in    std_logic;
          EV_RAM_DI_B_net_busnet_7   : in    std_logic;
          EV_RAM_DI_B_net_busnet_6   : in    std_logic;
          EV_RAM_DI_B_net_busnet_5   : in    std_logic;
          EV_RAM_DI_B_net_busnet_4   : in    std_logic;
          EV_RAM_DI_B_net_busnet_3   : in    std_logic;
          EV_RAM_DI_B_net_busnet_2   : in    std_logic;
          EV_RAM_DI_B_net_busnet_1   : in    std_logic;
          EV_RAM_DI_B_net_busnet_0   : in    std_logic;
          SYS_CLK_int                : in    std_logic;
          EV_RAM_WR_BUSY_B_net       : in    std_logic;
          EV_RAM_CSN_B_net           : in    std_logic;
          Analog_smev_ram_VCC        : in    std_logic;
          EV_RAM_RW_A_net            : in    std_logic;
          EV_RAM_CSN_A_net           : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_8 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_2 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_1 : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_0 : in    std_logic;
          Analog_smev_ram_GND        : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_8 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_7 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_6 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_5 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_4 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_3 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_2 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_1 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_0 : in    std_logic;
          EV_RAM_DO_B_net_busnet_8   : out   std_logic;
          EV_RAM_DO_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_B_net_busnet_5   : out   std_logic;
          EV_RAM_DO_B_net_busnet_4   : out   std_logic;
          EV_RAM_DO_B_net_busnet_3   : out   std_logic;
          EV_RAM_DO_B_net_busnet_2   : out   std_logic;
          EV_RAM_DO_B_net_busnet_1   : out   std_logic;
          EV_RAM_DO_B_net_busnet_0   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : out   std_logic;
          EV_RAM_DO_B_net_busnet_7   : out   std_logic;
          EV_RAM_DO_B_net_busnet_7_0 : out   std_logic
        );

end Analog_smev_ram;

architecture DEF_ARCH of Analog_smev_ram is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component RAM4K9
    generic (MEMORYFILE:string := "");

    port( ADDRA11 : in    std_logic := 'U';
          ADDRA10 : in    std_logic := 'U';
          ADDRA9  : in    std_logic := 'U';
          ADDRA8  : in    std_logic := 'U';
          ADDRA7  : in    std_logic := 'U';
          ADDRA6  : in    std_logic := 'U';
          ADDRA5  : in    std_logic := 'U';
          ADDRA4  : in    std_logic := 'U';
          ADDRA3  : in    std_logic := 'U';
          ADDRA2  : in    std_logic := 'U';
          ADDRA1  : in    std_logic := 'U';
          ADDRA0  : in    std_logic := 'U';
          ADDRB11 : in    std_logic := 'U';
          ADDRB10 : in    std_logic := 'U';
          ADDRB9  : in    std_logic := 'U';
          ADDRB8  : in    std_logic := 'U';
          ADDRB7  : in    std_logic := 'U';
          ADDRB6  : in    std_logic := 'U';
          ADDRB5  : in    std_logic := 'U';
          ADDRB4  : in    std_logic := 'U';
          ADDRB3  : in    std_logic := 'U';
          ADDRB2  : in    std_logic := 'U';
          ADDRB1  : in    std_logic := 'U';
          ADDRB0  : in    std_logic := 'U';
          DINA8   : in    std_logic := 'U';
          DINA7   : in    std_logic := 'U';
          DINA6   : in    std_logic := 'U';
          DINA5   : in    std_logic := 'U';
          DINA4   : in    std_logic := 'U';
          DINA3   : in    std_logic := 'U';
          DINA2   : in    std_logic := 'U';
          DINA1   : in    std_logic := 'U';
          DINA0   : in    std_logic := 'U';
          DINB8   : in    std_logic := 'U';
          DINB7   : in    std_logic := 'U';
          DINB6   : in    std_logic := 'U';
          DINB5   : in    std_logic := 'U';
          DINB4   : in    std_logic := 'U';
          DINB3   : in    std_logic := 'U';
          DINB2   : in    std_logic := 'U';
          DINB1   : in    std_logic := 'U';
          DINB0   : in    std_logic := 'U';
          WIDTHA0 : in    std_logic := 'U';
          WIDTHA1 : in    std_logic := 'U';
          WIDTHB0 : in    std_logic := 'U';
          WIDTHB1 : in    std_logic := 'U';
          PIPEA   : in    std_logic := 'U';
          PIPEB   : in    std_logic := 'U';
          WMODEA  : in    std_logic := 'U';
          WMODEB  : in    std_logic := 'U';
          BLKA    : in    std_logic := 'U';
          BLKB    : in    std_logic := 'U';
          WENA    : in    std_logic := 'U';
          WENB    : in    std_logic := 'U';
          CLKA    : in    std_logic := 'U';
          CLKB    : in    std_logic := 'U';
          RESET   : in    std_logic := 'U';
          DOUTA8  : out   std_logic;
          DOUTA7  : out   std_logic;
          DOUTA6  : out   std_logic;
          DOUTA5  : out   std_logic;
          DOUTA4  : out   std_logic;
          DOUTA3  : out   std_logic;
          DOUTA2  : out   std_logic;
          DOUTA1  : out   std_logic;
          DOUTA0  : out   std_logic;
          DOUTB8  : out   std_logic;
          DOUTB7  : out   std_logic;
          DOUTB6  : out   std_logic;
          DOUTB5  : out   std_logic;
          DOUTB4  : out   std_logic;
          DOUTB3  : out   std_logic;
          DOUTB2  : out   std_logic;
          DOUTB1  : out   std_logic;
          DOUTB0  : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component BUFF
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal EV_RAM_DO_A_net_busnet_1, EV_RAM_DO_A_net_busnet_2, 
        EV_RAM_DO_A_net_busnet_3, EV_RAM_DO_A_net_busnet_4, 
        EV_RAM_DO_A_net_busnet_5, EV_RAM_DO_A_net_busnet_6, 
        EV_RAM_DO_A_net_busnet_7, EV_RAM_DO_A_net_busnet_8, 
        \EV_RAM_DO_B_net_busnet_7\, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

begin 

    EV_RAM_DO_B_net_busnet_7 <= \EV_RAM_DO_B_net_busnet_7\;

    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    Analog_smev_ram_R0C0 : RAM4K9
      port map(ADDRA11 => Analog_smev_ram_GND, ADDRA10 => 
        Analog_smev_ram_GND, ADDRA9 => Analog_smev_ram_GND, 
        ADDRA8 => EV_RAM_ADDR_A_net_busnet_8, ADDRA7 => 
        EV_RAM_ADDR_A_net_busnet_7, ADDRA6 => 
        EV_RAM_ADDR_A_net_busnet_6, ADDRA5 => 
        EV_RAM_ADDR_A_net_busnet_5, ADDRA4 => 
        EV_RAM_ADDR_A_net_busnet_4, ADDRA3 => 
        EV_RAM_ADDR_A_net_busnet_3, ADDRA2 => 
        EV_RAM_ADDR_A_net_busnet_2, ADDRA1 => 
        EV_RAM_ADDR_A_net_busnet_1, ADDRA0 => 
        EV_RAM_ADDR_A_net_busnet_0, ADDRB11 => 
        Analog_smev_ram_GND, ADDRB10 => Analog_smev_ram_GND, 
        ADDRB9 => Analog_smev_ram_GND, ADDRB8 => 
        EV_RAM_ADDR_B_net_busnet_8, ADDRB7 => 
        EV_RAM_ADDR_B_net_busnet_7, ADDRB6 => 
        EV_RAM_ADDR_B_net_busnet_6, ADDRB5 => 
        EV_RAM_ADDR_B_net_busnet_5, ADDRB4 => 
        EV_RAM_ADDR_B_net_busnet_4, ADDRB3 => 
        EV_RAM_ADDR_B_net_busnet_3, ADDRB2 => 
        EV_RAM_ADDR_B_net_busnet_2, ADDRB1 => 
        EV_RAM_ADDR_B_net_busnet_1, ADDRB0 => 
        EV_RAM_ADDR_B_net_busnet_0, DINA8 => INIT_DATA_net(8), 
        DINA7 => INIT_DATA_net(7), DINA6 => INIT_DATA_net(6), 
        DINA5 => INIT_DATA_net(5), DINA4 => INIT_DATA_net(4), 
        DINA3 => INIT_DATA_net(3), DINA2 => INIT_DATA_net(2), 
        DINA1 => INIT_DATA_net(1), DINA0 => INIT_DATA_net(0), 
        DINB8 => EV_RAM_DI_B_net_busnet_8, DINB7 => 
        EV_RAM_DI_B_net_busnet_7, DINB6 => 
        EV_RAM_DI_B_net_busnet_6, DINB5 => 
        EV_RAM_DI_B_net_busnet_5, DINB4 => 
        EV_RAM_DI_B_net_busnet_4, DINB3 => 
        EV_RAM_DI_B_net_busnet_3, DINB2 => 
        EV_RAM_DI_B_net_busnet_2, DINB1 => 
        EV_RAM_DI_B_net_busnet_1, DINB0 => 
        EV_RAM_DI_B_net_busnet_0, WIDTHA0 => Analog_smev_ram_VCC, 
        WIDTHA1 => Analog_smev_ram_VCC, WIDTHB0 => 
        Analog_smev_ram_VCC, WIDTHB1 => Analog_smev_ram_VCC, 
        PIPEA => Analog_smev_ram_GND, PIPEB => 
        Analog_smev_ram_GND, WMODEA => Analog_smev_ram_VCC, 
        WMODEB => Analog_smev_ram_VCC, BLKA => EV_RAM_CSN_A_net, 
        BLKB => EV_RAM_CSN_B_net, WENA => EV_RAM_RW_A_net, WENB
         => EV_RAM_WR_BUSY_B_net, CLKA => SYS_CLK_int, CLKB => 
        SYS_CLK_int, RESET => SYS_RESET_c, DOUTA8 => 
        EV_RAM_DO_A_net_busnet_8, DOUTA7 => 
        EV_RAM_DO_A_net_busnet_7, DOUTA6 => 
        EV_RAM_DO_A_net_busnet_6, DOUTA5 => 
        EV_RAM_DO_A_net_busnet_5, DOUTA4 => 
        EV_RAM_DO_A_net_busnet_4, DOUTA3 => 
        EV_RAM_DO_A_net_busnet_3, DOUTA2 => 
        EV_RAM_DO_A_net_busnet_2, DOUTA1 => 
        EV_RAM_DO_A_net_busnet_1, DOUTA0 => 
        EV_RAM_DO_A_net_busnet_0, DOUTB8 => 
        EV_RAM_DO_B_net_busnet_8, DOUTB7 => 
        \EV_RAM_DO_B_net_busnet_7\, DOUTB6 => 
        EV_RAM_DO_B_net_busnet_6, DOUTB5 => 
        EV_RAM_DO_B_net_busnet_5, DOUTB4 => 
        EV_RAM_DO_B_net_busnet_4, DOUTB3 => 
        EV_RAM_DO_B_net_busnet_3, DOUTB2 => 
        EV_RAM_DO_B_net_busnet_2, DOUTB1 => 
        EV_RAM_DO_B_net_busnet_1, DOUTB0 => 
        EV_RAM_DO_B_net_busnet_0);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    Analog_smev_ram_R0C0_0 : BUFF
      port map(A => \EV_RAM_DO_B_net_busnet_7\, Y => 
        EV_RAM_DO_B_net_busnet_7_0);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_smtr_ram is

    port( INIT_DATA_net              : in    std_logic_vector(8 downto 0);
          INIT_ADDR_net              : in    std_logic_vector(8 downto 0);
          SYS_RESET_c                : in    std_logic;
          TR_RAM_DI_B_net_busnet_8   : in    std_logic;
          TR_RAM_DI_B_net_busnet_7   : in    std_logic;
          TR_RAM_DI_B_net_busnet_6   : in    std_logic;
          TR_RAM_DI_B_net_busnet_5   : in    std_logic;
          TR_RAM_DI_B_net_busnet_4   : in    std_logic;
          TR_RAM_DI_B_net_busnet_3   : in    std_logic;
          TR_RAM_DI_B_net_busnet_2   : in    std_logic;
          TR_RAM_DI_B_net_busnet_1   : in    std_logic;
          TR_RAM_DI_B_net_busnet_0   : in    std_logic;
          SYS_CLK_int                : in    std_logic;
          xgnmbzmtzbb_0              : in    std_logic;
          TR_RAM_CSN_B_net           : in    std_logic;
          Analog_smtr_ram_VCC        : in    std_logic;
          TR_RAM_RW_A_net            : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : in    std_logic;
          Analog_smtr_ram_GND        : in    std_logic;
          TR_RAM_DO_B_net_busnet_8   : out   std_logic;
          TR_RAM_DO_B_net_busnet_7   : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : out   std_logic;
          TR_RAM_DO_B_net_busnet_2   : out   std_logic;
          TR_RAM_DO_B_net_busnet_1   : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : out   std_logic
        );

end Analog_smtr_ram;

architecture DEF_ARCH of Analog_smtr_ram is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component RAM4K9
    generic (MEMORYFILE:string := "");

    port( ADDRA11 : in    std_logic := 'U';
          ADDRA10 : in    std_logic := 'U';
          ADDRA9  : in    std_logic := 'U';
          ADDRA8  : in    std_logic := 'U';
          ADDRA7  : in    std_logic := 'U';
          ADDRA6  : in    std_logic := 'U';
          ADDRA5  : in    std_logic := 'U';
          ADDRA4  : in    std_logic := 'U';
          ADDRA3  : in    std_logic := 'U';
          ADDRA2  : in    std_logic := 'U';
          ADDRA1  : in    std_logic := 'U';
          ADDRA0  : in    std_logic := 'U';
          ADDRB11 : in    std_logic := 'U';
          ADDRB10 : in    std_logic := 'U';
          ADDRB9  : in    std_logic := 'U';
          ADDRB8  : in    std_logic := 'U';
          ADDRB7  : in    std_logic := 'U';
          ADDRB6  : in    std_logic := 'U';
          ADDRB5  : in    std_logic := 'U';
          ADDRB4  : in    std_logic := 'U';
          ADDRB3  : in    std_logic := 'U';
          ADDRB2  : in    std_logic := 'U';
          ADDRB1  : in    std_logic := 'U';
          ADDRB0  : in    std_logic := 'U';
          DINA8   : in    std_logic := 'U';
          DINA7   : in    std_logic := 'U';
          DINA6   : in    std_logic := 'U';
          DINA5   : in    std_logic := 'U';
          DINA4   : in    std_logic := 'U';
          DINA3   : in    std_logic := 'U';
          DINA2   : in    std_logic := 'U';
          DINA1   : in    std_logic := 'U';
          DINA0   : in    std_logic := 'U';
          DINB8   : in    std_logic := 'U';
          DINB7   : in    std_logic := 'U';
          DINB6   : in    std_logic := 'U';
          DINB5   : in    std_logic := 'U';
          DINB4   : in    std_logic := 'U';
          DINB3   : in    std_logic := 'U';
          DINB2   : in    std_logic := 'U';
          DINB1   : in    std_logic := 'U';
          DINB0   : in    std_logic := 'U';
          WIDTHA0 : in    std_logic := 'U';
          WIDTHA1 : in    std_logic := 'U';
          WIDTHB0 : in    std_logic := 'U';
          WIDTHB1 : in    std_logic := 'U';
          PIPEA   : in    std_logic := 'U';
          PIPEB   : in    std_logic := 'U';
          WMODEA  : in    std_logic := 'U';
          WMODEB  : in    std_logic := 'U';
          BLKA    : in    std_logic := 'U';
          BLKB    : in    std_logic := 'U';
          WENA    : in    std_logic := 'U';
          WENB    : in    std_logic := 'U';
          CLKA    : in    std_logic := 'U';
          CLKB    : in    std_logic := 'U';
          RESET   : in    std_logic := 'U';
          DOUTA8  : out   std_logic;
          DOUTA7  : out   std_logic;
          DOUTA6  : out   std_logic;
          DOUTA5  : out   std_logic;
          DOUTA4  : out   std_logic;
          DOUTA3  : out   std_logic;
          DOUTA2  : out   std_logic;
          DOUTA1  : out   std_logic;
          DOUTA0  : out   std_logic;
          DOUTB8  : out   std_logic;
          DOUTB7  : out   std_logic;
          DOUTB6  : out   std_logic;
          DOUTB5  : out   std_logic;
          DOUTB4  : out   std_logic;
          DOUTB3  : out   std_logic;
          DOUTB2  : out   std_logic;
          DOUTB1  : out   std_logic;
          DOUTB0  : out   std_logic
        );
  end component;

    signal Analog_smtr_ram_R0C0_DOUTA0, 
        Analog_smtr_ram_R0C0_DOUTA1, Analog_smtr_ram_R0C0_DOUTA2, 
        Analog_smtr_ram_R0C0_DOUTA3, Analog_smtr_ram_R0C0_DOUTA4, 
        Analog_smtr_ram_R0C0_DOUTA5, Analog_smtr_ram_R0C0_DOUTA6, 
        Analog_smtr_ram_R0C0_DOUTA7, Analog_smtr_ram_R0C0_DOUTA8, 
        \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    Analog_smtr_ram_R0C0 : RAM4K9
      port map(ADDRA11 => Analog_smtr_ram_GND, ADDRA10 => 
        Analog_smtr_ram_GND, ADDRA9 => Analog_smtr_ram_GND, 
        ADDRA8 => INIT_ADDR_net(8), ADDRA7 => INIT_ADDR_net(7), 
        ADDRA6 => INIT_ADDR_net(6), ADDRA5 => INIT_ADDR_net(5), 
        ADDRA4 => INIT_ADDR_net(4), ADDRA3 => INIT_ADDR_net(3), 
        ADDRA2 => INIT_ADDR_net(2), ADDRA1 => INIT_ADDR_net(1), 
        ADDRA0 => INIT_ADDR_net(0), ADDRB11 => 
        Analog_smtr_ram_GND, ADDRB10 => Analog_smtr_ram_GND, 
        ADDRB9 => Analog_smtr_ram_GND, ADDRB8 => 
        TR_RAM_ADDR_B_net_busnet_8, ADDRB7 => 
        TR_RAM_ADDR_B_net_busnet_7, ADDRB6 => 
        TR_RAM_ADDR_B_net_busnet_6, ADDRB5 => 
        TR_RAM_ADDR_B_net_busnet_5, ADDRB4 => 
        TR_RAM_ADDR_B_net_busnet_4, ADDRB3 => 
        TR_RAM_ADDR_B_net_busnet_3, ADDRB2 => 
        TR_RAM_ADDR_B_net_busnet_2, ADDRB1 => 
        TR_RAM_ADDR_B_net_busnet_1, ADDRB0 => 
        TR_RAM_ADDR_B_net_busnet_0, DINA8 => INIT_DATA_net(8), 
        DINA7 => INIT_DATA_net(7), DINA6 => INIT_DATA_net(6), 
        DINA5 => INIT_DATA_net(5), DINA4 => INIT_DATA_net(4), 
        DINA3 => INIT_DATA_net(3), DINA2 => INIT_DATA_net(2), 
        DINA1 => INIT_DATA_net(1), DINA0 => INIT_DATA_net(0), 
        DINB8 => TR_RAM_DI_B_net_busnet_8, DINB7 => 
        TR_RAM_DI_B_net_busnet_7, DINB6 => 
        TR_RAM_DI_B_net_busnet_6, DINB5 => 
        TR_RAM_DI_B_net_busnet_5, DINB4 => 
        TR_RAM_DI_B_net_busnet_4, DINB3 => 
        TR_RAM_DI_B_net_busnet_3, DINB2 => 
        TR_RAM_DI_B_net_busnet_2, DINB1 => 
        TR_RAM_DI_B_net_busnet_1, DINB0 => 
        TR_RAM_DI_B_net_busnet_0, WIDTHA0 => Analog_smtr_ram_VCC, 
        WIDTHA1 => Analog_smtr_ram_VCC, WIDTHB0 => 
        Analog_smtr_ram_VCC, WIDTHB1 => Analog_smtr_ram_VCC, 
        PIPEA => Analog_smtr_ram_GND, PIPEB => 
        Analog_smtr_ram_GND, WMODEA => Analog_smtr_ram_VCC, 
        WMODEB => Analog_smtr_ram_VCC, BLKA => TR_RAM_RW_A_net, 
        BLKB => TR_RAM_CSN_B_net, WENA => TR_RAM_RW_A_net, WENB
         => xgnmbzmtzbb_0, CLKA => SYS_CLK_int, CLKB => 
        SYS_CLK_int, RESET => SYS_RESET_c, DOUTA8 => 
        Analog_smtr_ram_R0C0_DOUTA8, DOUTA7 => 
        Analog_smtr_ram_R0C0_DOUTA7, DOUTA6 => 
        Analog_smtr_ram_R0C0_DOUTA6, DOUTA5 => 
        Analog_smtr_ram_R0C0_DOUTA5, DOUTA4 => 
        Analog_smtr_ram_R0C0_DOUTA4, DOUTA3 => 
        Analog_smtr_ram_R0C0_DOUTA3, DOUTA2 => 
        Analog_smtr_ram_R0C0_DOUTA2, DOUTA1 => 
        Analog_smtr_ram_R0C0_DOUTA1, DOUTA0 => 
        Analog_smtr_ram_R0C0_DOUTA0, DOUTB8 => 
        TR_RAM_DO_B_net_busnet_8, DOUTB7 => 
        TR_RAM_DO_B_net_busnet_7, DOUTB6 => 
        TR_RAM_DO_B_net_busnet_6, DOUTB5 => 
        TR_RAM_DO_B_net_busnet_5, DOUTB4 => 
        TR_RAM_DO_B_net_busnet_4, DOUTB3 => 
        TR_RAM_DO_B_net_busnet_3, DOUTB2 => 
        TR_RAM_DO_B_net_busnet_2, DOUTB1 => 
        TR_RAM_DO_B_net_busnet_1, DOUTB0 => 
        TR_RAM_DO_B_net_busnet_0);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity ccfdxrhchsz is

    port( TR_EV_ADDR_net_busnet_8    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : in    std_logic;
          EV_DONE_net                : in    std_logic;
          xgnmbzmtzbb_0              : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_3     : in    std_logic;
          EV_CHHOLD_net_busnet_4     : in    std_logic;
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic;
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          N_10                       : in    std_logic;
          N_4                        : in    std_logic;
          TR_RAM_RW_A_net            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          EV_CHHOLD_net_busnet_1     : in    std_logic;
          EV_CHHOLD_net_busnet_0     : in    std_logic;
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : in    std_logic;
          TR_RAM_DO_B_net_busnet_8   : in    std_logic;
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : in    std_logic;
          TR_RAM_DO_B_net_busnet_7   : in    std_logic;
          TR_EV_RD_net               : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          AV5V_over5p25_net          : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : in    std_logic;
          TR_RAM_DO_B_net_busnet_1   : in    std_logic;
          TR_RAM_DO_B_net_busnet_2   : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : in    std_logic;
          INIT_DONE_net              : in    std_logic;
          SYS_RESET_c                : in    std_logic;
          SYS_CLK_int                : in    std_logic
        );

end ccfdxrhchsz;

architecture DEF_ARCH of ccfdxrhchsz is 

  component NOR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component XAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AND2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1E1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component NOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AOI1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1P0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          PRE : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component AX1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component INV
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NAND2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal \frcskdnwvmx_0[0]_net_1\, 
        \frcskdnwvmx_ns_i[11]_net_1\, \frcskdnwvmx_i[0]_net_1\, 
        \frcskdnwvmx_ns[0]_net_1\, N_269_i, un1_frcskdnwvmx_3_1, 
        \znjtscvsvcs_iv_0_a2_0\, N_315, \jnfrmfqggmk\, 
        \frcskdnwvmx_ns_a3_4[0]_net_1\, N_291, N_357, 
        cpwfrthtnfr_13_sqmuxa_1, znjtscvsvcs, 
        \znjtscvsvcs_iv_0_0\, \qgnzcpmbksd_7_0_iv_0[4]\, 
        qgnzcpmbksd_0_sqmuxa, \kpffvbpxmsf_m[3]_net_1\, 
        ADD_9x9_medium_I8_Y_1, N105, \qgnzcpmbksd_7_0_iv_0[2]\, 
        \kpffvbpxmsf_m[1]_net_1\, \qgnzcpmbksd_7_0_iv_0[1]\, 
        \kpffvbpxmsf_m[0]_net_1\, \qgnzcpmbksd_7_iv_0[0]\, N_278, 
        \mwzbqqvzwjt_12_iv_0_0[0]_net_1\, mwzbqqvzwjt_1_sqmuxa_1, 
        N_346, \mwzbqqvzwjt_12_iv_0_0[1]_net_1\, N_350, 
        un1_xjrbtnwdszs_0_sqmuxa_0, \frcskdnwvmx[2]_net_1\, 
        \dvqzjxhqhrh\, N_358_1, un1_xjrbtnwdszs_1_sqmuxa_0, 
        N_181_1, \qxzrwpjhcww_m[0]\, N_358, \dttrrgvsnmg_iv_0_0\, 
        N_205, \dttrrgvsnmg_iv_0_a2_1_0\, 
        \dttrrgvsnmg_iv_0_a2_0_0\, \hnbsspwxkpd\, 
        \mwzbqqvzwjt_12_iv_0_a2_0_0[0]_net_1\, N_60, 
        \mwzbqqvzwjt_12_iv_0_a2_0_0[1]_net_1\, N_91_i, N_381, 
        \un1_qgnzcpmbksd15_i_0\, un1_wjpccrvpdms, 
        \frcskdnwvmx[8]_net_1\, \svpbmqwvncp_0_1\, 
        \frcskdnwvmx[11]_net_1\, \un1_frcskdnwvmx_5_0_a2_0\, 
        \frcskdnwvmx[6]_net_1\, \frcskdnwvmx_ns_a3_2[0]_net_1\, 
        \frcskdnwvmx[4]_net_1\, \frcskdnwvmx_ns_a3_0[0]_net_1\, 
        \frcskdnwvmx[9]_net_1\, \TR_EV_RD_net\, 
        \mwzbqqvzwjt_12_iv_0_o2_0[16]_net_1\, N124, N107, N108, 
        N_287, \frcskdnwvmx[5]_net_1\, \frcskdnwvmx[7]_net_1\, 
        \qgnzcpmbksd_7[2]\, N_230_i_0, \un1_jvxfmjbzjmc[3]\, 
        \qgnzcpmbksd_7[1]\, \un1_jvxfmjbzjmc[2]\, 
        \qgnzcpmbksd_7[0]\, \un1_jvxfmjbzjmc[1]\, 
        \frcskdnwvmx_ns_i[5]_net_1\, N_274, N_273, N_234_i_0, 
        N_263, N_247, N_348, cpwfrthtnfr_4_sqmuxa_i, N_314, N_484, 
        N_419, \rhjxdmgzftc[0]_net_1\, \rhjxdmgzftc[1]_net_1\, 
        \mwzbqqvzwjt_12[1]\, N_352, N_349, \mwzbqqvzwjt_12[0]\, 
        N_345, \mwzbqqvzwjt_12[2]\, N_177_i, N_176, N_175, N_426, 
        N_238, N_285, \qgnzcpmbksd_7[3]\, 
        \kpffvbpxmsf_m[2]_net_1\, \tpxkpvnpvvn_m_0[3]_net_1\, 
        \un1_jvxfmjbzjmc_m[4]_net_1\, \qgnzcpmbksd_7[4]\, 
        \un1_jvxfmjbzjmc[5]\, \qgnzcpmbksd_7[5]\, 
        \kpffvbpxmsf_m[4]_net_1\, \tpxkpvnpvvn_m_0[5]_net_1\, 
        \un1_jvxfmjbzjmc_m[6]_net_1\, N_264, N_289, N_235_i_0, 
        N121, N127, un1_xjrbtnwdszs_1_sqmuxa, 
        cpwfrthtnfr_13_sqmuxa, cpwfrthtnfr_14_sqmuxa, dttrrgvsnmg, 
        N_181_i, N_182, N_272, N_233, \frcskdnwvmx_ns_i[4]_net_1\, 
        N_271, N_288, N_117_i, N_201, un1_xjrbtnwdszs_0_sqmuxa, 
        cpwfrthtnfr_12_sqmuxa_i, 
        \mwzbqqvzwjt_12_iv_0_o3_0[2]_net_1\, 
        \mwzbqqvzwjt_12_iv_0_o3_0_tz[2]_net_1\, N_262, 
        \TR_RAM_ADDR_B_net_busnet_0\, 
        \TR_RAM_ADDR_B_net_busnet_1\, 
        \TR_RAM_ADDR_B_net_busnet_2\, N_282, 
        \frcskdnwvmx[10]_net_1\, \frcskdnwvmx_ns_i[2]_net_1\, 
        N_310, un1_frcskdnwvmx_3, N_243, \qgnzcpmbksd_7[7]\, 
        \un1_jvxfmjbzjmc_m[8]_net_1\, \frcskdnwvmx_ns_i[9]_net_1\, 
        \frcskdnwvmx_ns_i[1]_net_1\, \frcskdnwvmx_ns_i[8]_net_1\, 
        un1_frcskdnwvmx_5, \AV5V_over5p25_net\, 
        \AV5V_under4p75_net\, \frcskdnwvmx[0]_net_1\, 
        \frcskdnwvmx_ns_i[3]_net_1\, N_248, 
        \TR_RAM_ADDR_B_net_busnet_5\, cpwfrthtnfr_7_sqmuxa, 
        cpwfrthtnfr_6_sqmuxa, \frcskdnwvmx_ns[7]\, 
        \frcskdnwvmx_ns[6]\, \TR_RAM_ADDR_B_net_busnet_3\, 
        \TR_RAM_ADDR_B_net_busnet_4\, \frcskdnwvmx[1]_net_1\, 
        N_203, \qgnzcpmbksd_7[8]\, \un1_jvxfmjbzjmc[9]\, 
        \tpxkpvnpvvn_m[8]_net_1\, \qgnzcpmbksd_7[6]\, 
        \un1_jvxfmjbzjmc[7]\, \tpxkpvnpvvn_m_0[6]_net_1\, 
        \frcskdnwvmx_ns[10]\, \TR_RAM_ADDR_B_net_busnet_7\, 
        \TR_RAM_ADDR_B_net_busnet_6\, \Temp_over70C_net\, 
        \TR_RAM_ADDR_B_net_busnet_8\, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

begin 

    TR_RAM_ADDR_B_net_busnet_8 <= \TR_RAM_ADDR_B_net_busnet_8\;
    TR_RAM_ADDR_B_net_busnet_4 <= \TR_RAM_ADDR_B_net_busnet_4\;
    TR_RAM_ADDR_B_net_busnet_3 <= \TR_RAM_ADDR_B_net_busnet_3\;
    Temp_over70C_net <= \Temp_over70C_net\;
    TR_RAM_ADDR_B_net_busnet_7 <= \TR_RAM_ADDR_B_net_busnet_7\;
    TR_RAM_ADDR_B_net_busnet_0 <= \TR_RAM_ADDR_B_net_busnet_0\;
    TR_RAM_ADDR_B_net_busnet_1 <= \TR_RAM_ADDR_B_net_busnet_1\;
    TR_RAM_ADDR_B_net_busnet_2 <= \TR_RAM_ADDR_B_net_busnet_2\;
    TR_EV_RD_net <= \TR_EV_RD_net\;
    AV5V_under4p75_net <= \AV5V_under4p75_net\;
    AV5V_over5p25_net <= \AV5V_over5p25_net\;
    TR_RAM_ADDR_B_net_busnet_6 <= \TR_RAM_ADDR_B_net_busnet_6\;
    TR_RAM_ADDR_B_net_busnet_5 <= \TR_RAM_ADDR_B_net_busnet_5\;

    \mwzbqqvzwjt_12_iv_0_a2[0]\ : NOR2B
      port map(A => N_314, B => \AV5V_over5p25_net\, Y => N_345);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I3_Y : NOR3A
      port map(A => \TR_RAM_ADDR_B_net_busnet_0\, B => N_262, C
         => N_263, Y => N108);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I9_Y : NOR3C
      port map(A => N105, B => N107, C => N108, Y => N124);
    
    \jfkkdmfhcdn_0_a3[8]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_8, B => 
        \frcskdnwvmx[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_8);
    
    \jfkkdmfhcdn_0_a3[6]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_6, B => 
        \frcskdnwvmx[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_6);
    
    cpwfrthtnfr_6_sqmuxa_0_a2_0 : OR3B
      port map(A => TR_RAM_DO_B_net_busnet_8, B => N_235_i_0, C
         => TR_RAM_DO_B_net_busnet_6, Y => N_289);
    
    \qgnzcpmbksd[1]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_1\);
    
    \mwzbqqvzwjt_12_iv_0_a2_0[0]\ : NOR3C
      port map(A => N_238, B => N_285, C => 
        \mwzbqqvzwjt_12_iv_0_a2_0_0[0]_net_1\, Y => N_346);
    
    \un1_jvxfmjbzjmc_m[8]\ : XAI1
      port map(A => N121, B => \TR_RAM_ADDR_B_net_busnet_7\, C
         => N_230_i_0, Y => \un1_jvxfmjbzjmc_m[8]_net_1\);
    
    znjtscvsvcs_iv_0_a2_0_2 : AND2
      port map(A => N_315, B => \jnfrmfqggmk\, Y => 
        \znjtscvsvcs_iv_0_a2_0\);
    
    \jfkkdmfhcdn_0_a3[7]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_7, B => 
        \frcskdnwvmx_0[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_7);
    
    \jfkkdmfhcdn[1]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_1, B => 
        \frcskdnwvmx[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_1);
    
    \frcskdnwvmx_ns_a3[6]\ : NOR2B
      port map(A => INIT_DONE_net, B => cpwfrthtnfr_6_sqmuxa, Y
         => \frcskdnwvmx_ns[6]\);
    
    cpwfrthtnfr_5_sqmuxa_0_o2 : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_6, B => 
        TR_RAM_DO_B_net_busnet_8, Y => N_238);
    
    znjtscvsvcs_iv_0_0 : OR2A
      port map(A => \qxzrwpjhcww_m[0]\, B => N_358, Y => 
        \znjtscvsvcs_iv_0_0\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[4]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[5]\, C => 
        \qgnzcpmbksd_7_0_iv_0[4]\, Y => \qgnzcpmbksd_7[4]\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_iv[0]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[1]\, C => 
        \qgnzcpmbksd_7_iv_0[0]\, Y => \qgnzcpmbksd_7[0]\);
    
    \mwzbqqvzwjt_12_iv_0[0]\ : OR3
      port map(A => N_348, B => \mwzbqqvzwjt_12_iv_0_0[0]_net_1\, 
        C => N_345, Y => \mwzbqqvzwjt_12[0]\);
    
    dttrrgvsnmg_iv_0_a2_0_0 : OA1
      port map(A => TR_RAM_DO_B_net_busnet_0, B => 
        TR_RAM_DO_B_net_busnet_1, C => \hnbsspwxkpd\, Y => 
        \dttrrgvsnmg_iv_0_a2_0_0\);
    
    \kpffvbpxmsf_m[2]\ : OR2B
      port map(A => EV_CHHOLD_net_busnet_2, B => N_310, Y => 
        \kpffvbpxmsf_m[2]_net_1\);
    
    cpwfrthtnfr_14_sqmuxa_0_a2_0_a2 : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_1, B => 
        cpwfrthtnfr_13_sqmuxa_1, Y => cpwfrthtnfr_14_sqmuxa);
    
    svpbmqwvncp_0_a3 : OR3A
      port map(A => N_235_i_0, B => TR_RAM_DO_B_net_busnet_8, C
         => TR_RAM_DO_B_net_busnet_6, Y => N_264);
    
    \frcskdnwvmx_ns_i[3]\ : OA1
      port map(A => N_248, B => \frcskdnwvmx[9]_net_1\, C => 
        INIT_DONE_net, Y => \frcskdnwvmx_ns_i[3]_net_1\);
    
    \rjhhzsggrtr[5]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_5, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_5);
    
    \qgnzcpmbksd[8]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[8]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_8\);
    
    dttrrgvsnmg_iv_0_a2_1_0_0 : NOR2B
      port map(A => \jnfrmfqggmk\, B => N_91_i, Y => 
        \dttrrgvsnmg_iv_0_a2_1_0\);
    
    \mwzbqqvzwjt_12_iv_0_o3_0_tz[2]\ : NOR3
      port map(A => TR_RAM_DO_B_net_busnet_2, B => 
        TR_RAM_DO_B_net_busnet_3, C => N_426, Y => 
        \mwzbqqvzwjt_12_iv_0_o3_0_tz[2]_net_1\);
    
    \brxxctcvrmh_qgnzcpmbksd_7[5]\ : OR2B
      port map(A => un1_wjpccrvpdms, B => N_278, Y => N_310);
    
    \frcskdnwvmx_ns_i_a3_0[5]\ : NOR3
      port map(A => TR_RAM_DO_B_net_busnet_7, B => N_287, C => 
        N_234_i_0, Y => N_274);
    
    vnjtgtptszx_un1_xjrbtnwdszs_1_sqmuxa : OR3
      port map(A => cpwfrthtnfr_13_sqmuxa, B => 
        un1_xjrbtnwdszs_1_sqmuxa_0, C => cpwfrthtnfr_14_sqmuxa, Y
         => un1_xjrbtnwdszs_1_sqmuxa);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I6_Y : NOR2B
      port map(A => N108, B => N107, Y => N127);
    
    \jfkkdmfhcdn[4]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_4, B => 
        \frcskdnwvmx_0[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_4);
    
    jvxfmjbzjmc_i_a3 : OA1C
      port map(A => \frcskdnwvmx[6]_net_1\, B => N_282, C => 
        N_291, Y => N_262);
    
    \frcskdnwvmx_ns_i[4]\ : NOR3A
      port map(A => INIT_DONE_net, B => N_272, C => N_271, Y => 
        \frcskdnwvmx_ns_i[4]_net_1\);
    
    \frcskdnwvmx_ns_i[11]\ : NOR2B
      port map(A => INIT_DONE_net, B => \frcskdnwvmx[1]_net_1\, Y
         => \frcskdnwvmx_ns_i[11]_net_1\);
    
    qgtkpxrgqqs_un1_xjrbtnwdszs_0_sqmuxa : OR3B
      port map(A => cpwfrthtnfr_12_sqmuxa_i, B => 
        un1_xjrbtnwdszs_0_sqmuxa_0, C => cpwfrthtnfr_14_sqmuxa, Y
         => un1_xjrbtnwdszs_0_sqmuxa);
    
    \rhjxdmgzftc[1]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => cpwfrthtnfr_6_sqmuxa, Q => 
        \rhjxdmgzftc[1]_net_1\);
    
    \frcskdnwvmx[7]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[4]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[7]_net_1\);
    
    svpbmqwvncp_0_1 : NOR3
      port map(A => \TR_EV_RD_net\, B => \frcskdnwvmx[11]_net_1\, 
        C => \frcskdnwvmx[8]_net_1\, Y => \svpbmqwvncp_0_1\);
    
    un1_frcskdnwvmx_3_0_1 : NOR2A
      port map(A => INIT_DONE_net, B => \frcskdnwvmx_0[0]_net_1\, 
        Y => un1_frcskdnwvmx_3_1);
    
    \frcskdnwvmx_ns_i[2]\ : NOR2B
      port map(A => INIT_DONE_net, B => \frcskdnwvmx[10]_net_1\, 
        Y => \frcskdnwvmx_ns_i[2]_net_1\);
    
    \rjhhzsggrtr[3]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_3, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_3);
    
    \frcskdnwvmx_ns_i[1]\ : NOR2A
      port map(A => INIT_DONE_net, B => N_243, Y => 
        \frcskdnwvmx_ns_i[1]_net_1\);
    
    \frcskdnwvmx[5]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \frcskdnwvmx[5]_net_1\);
    
    \frcskdnwvmx[8]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[3]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[8]_net_1\);
    
    \frcskdnwvmx[1]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns[10]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \frcskdnwvmx[1]_net_1\);
    
    un1_frcskdnwvmx_5_0 : AO1
      port map(A => N_238, B => \un1_frcskdnwvmx_5_0_a2_0\, C => 
        \frcskdnwvmx[5]_net_1\, Y => un1_frcskdnwvmx_5);
    
    \mwzbqqvzwjt_12_iv_0_a2_0[1]\ : NOR3C
      port map(A => N_238, B => N_285, C => 
        \mwzbqqvzwjt_12_iv_0_a2_0_0[1]_net_1\, Y => N_350);
    
    dttrrgvsnmg_iv_0_0 : AOI1B
      port map(A => N_205, B => \dttrrgvsnmg_iv_0_a2_1_0\, C => 
        \qxzrwpjhcww_m[0]\, Y => \dttrrgvsnmg_iv_0_0\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv_0[2]\ : AOI1B
      port map(A => qgnzcpmbksd_0_sqmuxa, B => 
        TR_RAM_DO_B_net_busnet_2, C => \kpffvbpxmsf_m[1]_net_1\, 
        Y => \qgnzcpmbksd_7_0_iv_0[2]\);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    un1_txjjszxznxd_1_0_a3 : OR2
      port map(A => EV_DONE_net, B => N_288, Y => N_278);
    
    znjtscvsvcs_iv_0_o2 : AO1A
      port map(A => TR_RAM_DO_B_net_busnet_0, B => \hnbsspwxkpd\, 
        C => TR_RAM_DO_B_net_busnet_1, Y => N_315);
    
    un1_qgnzcpmbksd15_i_0 : NOR2A
      port map(A => un1_wjpccrvpdms, B => \frcskdnwvmx[8]_net_1\, 
        Y => \un1_qgnzcpmbksd15_i_0\);
    
    \frcskdnwvmx_ns_i_a3_0[4]\ : NOR3B
      port map(A => TR_RAM_DO_B_net_busnet_6, B => N_233, C => 
        \frcskdnwvmx[8]_net_1\, Y => N_272);
    
    un1_qgnzcpmbksd15_i : NOR2B
      port map(A => \un1_qgnzcpmbksd15_i_0\, B => N_288, Y => 
        N_230_i_0);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[8]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[9]\, C => 
        \tpxkpvnpvvn_m[8]_net_1\, Y => \qgnzcpmbksd_7[8]\);
    
    \frcskdnwvmx[11]\ : DFN1P0
      port map(D => \frcskdnwvmx_ns[0]_net_1\, CLK => SYS_CLK_int, 
        PRE => SYS_RESET_c, Q => \frcskdnwvmx[11]_net_1\);
    
    \frcskdnwvmx_ns_i_a2[5]\ : OR3
      port map(A => \frcskdnwvmx[5]_net_1\, B => 
        \frcskdnwvmx[7]_net_1\, C => \frcskdnwvmx[2]_net_1\, Y
         => N_287);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[1]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[2]\, C => 
        \qgnzcpmbksd_7_0_iv_0[1]\, Y => \qgnzcpmbksd_7[1]\);
    
    cpwfrthtnfr_13_sqmuxa_0_i3_0_a2 : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_0, B => 
        TR_RAM_DO_B_net_busnet_1, Y => N_91_i);
    
    vnjtgtptszx_un1_xjrbtnwdszs_1_sqmuxa_0 : AO1
      port map(A => \dvqzjxhqhrh\, B => \frcskdnwvmx[2]_net_1\, C
         => N_181_1, Y => un1_xjrbtnwdszs_1_sqmuxa_0);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I2_Y : NOR2B
      port map(A => \TR_RAM_ADDR_B_net_busnet_2\, B => 
        \TR_RAM_ADDR_B_net_busnet_1\, Y => N107);
    
    \frcskdnwvmx[6]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[5]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[6]_net_1\);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I1_Y : NOR2B
      port map(A => \TR_RAM_ADDR_B_net_busnet_4\, B => 
        \TR_RAM_ADDR_B_net_busnet_3\, Y => N105);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv_0[4]\ : AOI1B
      port map(A => qgnzcpmbksd_0_sqmuxa, B => 
        TR_RAM_DO_B_net_busnet_4, C => \kpffvbpxmsf_m[3]_net_1\, 
        Y => \qgnzcpmbksd_7_0_iv_0[4]\);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I22_Y : AX1C
      port map(A => N108, B => \TR_RAM_ADDR_B_net_busnet_1\, C
         => \TR_RAM_ADDR_B_net_busnet_2\, Y => 
        \un1_jvxfmjbzjmc[3]\);
    
    \frcskdnwvmx_i[0]\ : INV
      port map(A => \frcskdnwvmx_0[0]_net_1\, Y => 
        \frcskdnwvmx_i[0]_net_1\);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I28_Y : AX1C
      port map(A => N121, B => \TR_RAM_ADDR_B_net_busnet_7\, C
         => \TR_RAM_ADDR_B_net_busnet_8\, Y => 
        \un1_jvxfmjbzjmc[9]\);
    
    \jfkkdmfhcdn[0]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_0, B => 
        \frcskdnwvmx[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_0);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    \mwzbqqvzwjt_12_iv_0_a2_0_0[0]\ : NOR2B
      port map(A => \AV5V_over5p25_net\, B => N_60, Y => 
        \mwzbqqvzwjt_12_iv_0_a2_0_0[0]_net_1\);
    
    \mwzbqqvzwjt[0]\ : DFN1E1C0
      port map(D => \mwzbqqvzwjt_12[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => un1_frcskdnwvmx_5, Q => 
        \AV5V_over5p25_net\);
    
    \frcskdnwvmx_ns_i[5]\ : NOR3A
      port map(A => INIT_DONE_net, B => N_274, C => N_273, Y => 
        \frcskdnwvmx_ns_i[5]_net_1\);
    
    \frcskdnwvmx_ns_a3[7]\ : NOR2B
      port map(A => INIT_DONE_net, B => cpwfrthtnfr_7_sqmuxa, Y
         => \frcskdnwvmx_ns[7]\);
    
    \frcskdnwvmx_ns_a3[0]\ : OR2A
      port map(A => \frcskdnwvmx_ns_a3_4[0]_net_1\, B => N_291, Y
         => N_269_i);
    
    un1_frcskdnwvmx_3_0 : OR3B
      port map(A => INIT_DONE_net, B => N_243, C => 
        \frcskdnwvmx_0[0]_net_1\, Y => un1_frcskdnwvmx_3);
    
    \tpxkpvnpvvn_m[8]\ : OR2B
      port map(A => TR_RAM_DO_B_net_busnet_8, B => 
        qgnzcpmbksd_0_sqmuxa, Y => \tpxkpvnpvvn_m[8]_net_1\);
    
    \rjhhzsggrtr[1]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_1);
    
    \brxxctcvrmh_qgnzcpmbksd_7_iv_0[0]\ : AOI1B
      port map(A => qgnzcpmbksd_0_sqmuxa, B => 
        TR_RAM_DO_B_net_busnet_0, C => N_278, Y => 
        \qgnzcpmbksd_7_iv_0[0]\);
    
    \mwzbqqvzwjt_12_iv_0_a2_0_0[1]\ : OA1A
      port map(A => N_91_i, B => N_381, C => \AV5V_under4p75_net\, 
        Y => \mwzbqqvzwjt_12_iv_0_a2_0_0[1]_net_1\);
    
    dttrrgvsnmg_iv_0 : OR3C
      port map(A => N_181_i, B => \dttrrgvsnmg_iv_0_0\, C => 
        N_182, Y => dttrrgvsnmg);
    
    znjtscvsvcs_iv_0_a2 : NOR2A
      port map(A => \znjtscvsvcs_iv_0_a2_0\, B => 
        cpwfrthtnfr_13_sqmuxa_1, Y => N_357);
    
    \qgnzcpmbksd[2]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_2\);
    
    \mwzbqqvzwjt_12_iv_0_o2[0]\ : OR3C
      port map(A => N_484, B => N_419, C => 
        cpwfrthtnfr_4_sqmuxa_i, Y => N_314);
    
    \mwzbqqvzwjt_12_iv_0[1]\ : OR3
      port map(A => N_352, B => \mwzbqqvzwjt_12_iv_0_0[1]_net_1\, 
        C => N_349, Y => \mwzbqqvzwjt_12[1]\);
    
    \mwzbqqvzwjt_12_iv_0_a2[1]\ : AOI1B
      port map(A => N_419, B => cpwfrthtnfr_4_sqmuxa_i, C => 
        \AV5V_under4p75_net\, Y => N_349);
    
    \mwzbqqvzwjt_12_iv_0_o2_0[16]\ : NOR3
      port map(A => TR_RAM_DO_B_net_busnet_2, B => 
        TR_RAM_DO_B_net_busnet_3, C => TR_RAM_DO_B_net_busnet_0, 
        Y => \mwzbqqvzwjt_12_iv_0_o2_0[16]_net_1\);
    
    \jfkkdmfhcdn[2]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_2, B => 
        \frcskdnwvmx_0[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_2);
    
    \mwzbqqvzwjt_12_iv_0_a2_0[2]\ : OR2A
      port map(A => TR_RAM_DO_B_net_busnet_2, B => 
        mwzbqqvzwjt_1_sqmuxa_1, Y => N_176);
    
    \qgnzcpmbksd[4]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_4\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv_0[1]\ : AOI1B
      port map(A => qgnzcpmbksd_0_sqmuxa, B => 
        TR_RAM_DO_B_net_busnet_1, C => \kpffvbpxmsf_m[0]_net_1\, 
        Y => \qgnzcpmbksd_7_0_iv_0[1]\);
    
    \mwzbqqvzwjt[1]\ : DFN1E1C0
      port map(D => \mwzbqqvzwjt_12[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => un1_frcskdnwvmx_5, Q => 
        \AV5V_under4p75_net\);
    
    jvxfmjbzjmc_i_o2_0 : OR2B
      port map(A => N_238, B => N_233, Y => N_247);
    
    \rjhhzsggrtr[7]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_7, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_7);
    
    qgnzcpmbksd_0_sqmuxa_0_a3 : NOR2A
      port map(A => \frcskdnwvmx[8]_net_1\, B => EV_DONE_net, Y
         => qgnzcpmbksd_0_sqmuxa);
    
    \frcskdnwvmx_0[0]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[11]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx_0[0]_net_1\);
    
    cpwfrthtnfr_7_sqmuxa_0_a2 : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_5, B => N_289, Y => 
        cpwfrthtnfr_7_sqmuxa);
    
    \jfkkdmfhcdn_0_a3[5]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_5, B => 
        \frcskdnwvmx[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_5);
    
    \qgnzcpmbksd[5]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[5]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_5\);
    
    \mwzbqqvzwjt_12_iv_0_a2_1[2]\ : OR3
      port map(A => N_381, B => N_426, C => 
        cpwfrthtnfr_4_sqmuxa_i, Y => N_177_i);
    
    \mwzbqqvzwjt_12_iv_0_a2_2[8]\ : OR3C
      port map(A => N_238, B => N_285, C => 
        TR_RAM_DO_B_net_busnet_4, Y => N_484);
    
    cpwfrthtnfr_11_sqmuxa_0_a3_0_a2_0 : NOR2B
      port map(A => TR_RAM_DO_B_net_busnet_7, B => N_201, Y => 
        N_203);
    
    dttrrgvsnmg_iv_0_a2 : AO1C
      port map(A => \jnfrmfqggmk\, B => N_117_i, C => N_181_1, Y
         => N_181_i);
    
    \mwzbqqvzwjt_12_iv_0[2]\ : OR3C
      port map(A => N_177_i, B => N_176, C => N_175, Y => 
        \mwzbqqvzwjt_12[2]\);
    
    jvxfmjbzjmc_i_a2_0 : OR2
      port map(A => \frcskdnwvmx[10]_net_1\, B => N_287, Y => 
        N_291);
    
    jnfrmfqggmk : DFN1E1C0
      port map(D => dttrrgvsnmg, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => un1_xjrbtnwdszs_1_sqmuxa, Q => 
        \jnfrmfqggmk\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[3]\ : OR3C
      port map(A => \kpffvbpxmsf_m[2]_net_1\, B => 
        \tpxkpvnpvvn_m_0[3]_net_1\, C => 
        \un1_jvxfmjbzjmc_m[4]_net_1\, Y => \qgnzcpmbksd_7[3]\);
    
    \mwzbqqvzwjt_12_iv_0_a2[2]\ : OAI1
      port map(A => N_314, B => 
        \mwzbqqvzwjt_12_iv_0_o3_0[2]_net_1\, C => 
        \Temp_over70C_net\, Y => N_175);
    
    cpwfrthtnfr_13_sqmuxa_1_0_a2_0_a3 : OR2B
      port map(A => TR_RAM_DO_B_net_busnet_6, B => N_205, Y => 
        cpwfrthtnfr_13_sqmuxa_1);
    
    \xgnmbzmtzbb_0\ : NOR2
      port map(A => \frcskdnwvmx[1]_net_1\, B => 
        \frcskdnwvmx[0]_net_1\, Y => xgnmbzmtzbb_0);
    
    \rjhhzsggrtr[0]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_0, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_0);
    
    \un1_jvxfmjbzjmc_m[4]\ : XAI1
      port map(A => N127, B => \TR_RAM_ADDR_B_net_busnet_3\, C
         => N_230_i_0, Y => \un1_jvxfmjbzjmc_m[4]_net_1\);
    
    cpwfrthtnfr_4_sqmuxa_0_a3 : OR3B
      port map(A => N_238, B => \un1_frcskdnwvmx_5_0_a2_0\, C => 
        TR_RAM_DO_B_net_busnet_5, Y => cpwfrthtnfr_4_sqmuxa_i);
    
    cpwfrthtnfr_9_sqmuxa_0_a3_0_a3_0_a2 : NOR2B
      port map(A => TR_RAM_DO_B_net_busnet_8, B => 
        \frcskdnwvmx[6]_net_1\, Y => N_201);
    
    \qgnzcpmbksd[7]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[7]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_7\);
    
    dttrrgvsnmg_iv_0_a2_0 : OR2A
      port map(A => \dttrrgvsnmg_iv_0_a2_0_0\, B => 
        cpwfrthtnfr_13_sqmuxa_1, Y => N_182);
    
    \mwzbqqvzwjt_12_iv_0_a2_2[0]\ : NOR3
      port map(A => N_60, B => TR_RAM_DO_B_net_busnet_4, C => 
        cpwfrthtnfr_4_sqmuxa_i, Y => N_348);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[7]\ : AO1B
      port map(A => qgnzcpmbksd_0_sqmuxa, B => 
        TR_RAM_DO_B_net_busnet_7, C => 
        \un1_jvxfmjbzjmc_m[8]_net_1\, Y => \qgnzcpmbksd_7[7]\);
    
    \rjhhzsggrtr[6]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_6, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_6);
    
    cpwfrthtnfr_13_sqmuxa_0_a2 : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_0, B => 
        cpwfrthtnfr_13_sqmuxa_1, Y => cpwfrthtnfr_13_sqmuxa);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[5]\ : OR3C
      port map(A => \kpffvbpxmsf_m[4]_net_1\, B => 
        \tpxkpvnpvvn_m_0[5]_net_1\, C => 
        \un1_jvxfmjbzjmc_m[6]_net_1\, Y => \qgnzcpmbksd_7[5]\);
    
    N_235_i_0_a2 : NOR2A
      port map(A => \frcskdnwvmx[6]_net_1\, B => 
        TR_RAM_DO_B_net_busnet_7, Y => N_235_i_0);
    
    znjtscvsvcs_iv_0_a2_0_1 : OR3B
      port map(A => TR_RAM_DO_B_net_busnet_6, B => N_201, C => 
        TR_RAM_DO_B_net_busnet_7, Y => N_358_1);
    
    \frcskdnwvmx_ns_i_a3[5]\ : OA1C
      port map(A => \frcskdnwvmx[6]_net_1\, B => N_282, C => 
        N_287, Y => N_273);
    
    brxxctcvrmh_un1_wjpccrvpdms_0_o3 : NOR2
      port map(A => EV_DONE_net, B => \frcskdnwvmx[1]_net_1\, Y
         => un1_wjpccrvpdms);
    
    \frcskdnwvmx[10]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[10]_net_1\);
    
    \frcskdnwvmx[4]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns[7]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \frcskdnwvmx[4]_net_1\);
    
    qgtkpxrgqqs_un1_xjrbtnwdszs_0_sqmuxa_0 : OA1A
      port map(A => \frcskdnwvmx[2]_net_1\, B => \dvqzjxhqhrh\, C
         => N_358_1, Y => un1_xjrbtnwdszs_0_sqmuxa_0);
    
    \kpffvbpxmsf_m[0]\ : OR2B
      port map(A => EV_CHHOLD_net_busnet_0, B => N_310, Y => 
        \kpffvbpxmsf_m[0]_net_1\);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I21_Y : XOR2
      port map(A => \TR_RAM_ADDR_B_net_busnet_1\, B => N108, Y
         => \un1_jvxfmjbzjmc[2]\);
    
    \qgnzcpmbksd[0]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_0\);
    
    \qgnzcpmbksd[6]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_6\);
    
    cpwfrthtnfr_6_sqmuxa_0_a2 : NOR2
      port map(A => TR_RAM_DO_B_net_busnet_5, B => N_289, Y => 
        cpwfrthtnfr_6_sqmuxa);
    
    mwzbqqvzwjt_1_sqmuxa_1_0_a2_0_a3_0_a3 : OR3A
      port map(A => \frcskdnwvmx[5]_net_1\, B => 
        \rhjxdmgzftc[0]_net_1\, C => \rhjxdmgzftc[1]_net_1\, Y
         => mwzbqqvzwjt_1_sqmuxa_1);
    
    jvxfmjbzjmc_i_a2 : NOR3C
      port map(A => TR_RAM_DO_B_net_busnet_5, B => 
        TR_RAM_DO_B_net_busnet_7, C => N_234_i_0, Y => N_282);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I8_Y : NOR2B
      port map(A => ADD_9x9_medium_I8_Y_1, B => N127, Y => N121);
    
    cpwfrthtnfr_10_sqmuxa_0_a3_0_a2_0 : NOR2A
      port map(A => N_203, B => TR_RAM_DO_B_net_busnet_5, Y => 
        N_205);
    
    thrxvbszptn : DFN1P0
      port map(D => \frcskdnwvmx_i[0]_net_1\, CLK => SYS_CLK_int, 
        PRE => SYS_RESET_c, Q => TR_DONE_net_i_0);
    
    \qxzrwpjhcww_m_0[0]\ : OR2B
      port map(A => EV_RAM_DO_A_net_busnet_0, B => 
        \frcskdnwvmx[2]_net_1\, Y => \qxzrwpjhcww_m[0]\);
    
    znjtscvsvcs_iv_0 : OR2
      port map(A => N_357, B => \znjtscvsvcs_iv_0_0\, Y => 
        znjtscvsvcs);
    
    \frcskdnwvmx_ns_a3_4[0]\ : NOR3B
      port map(A => \frcskdnwvmx_ns_a3_2[0]_net_1\, B => 
        un1_wjpccrvpdms, C => \frcskdnwvmx[4]_net_1\, Y => 
        \frcskdnwvmx_ns_a3_4[0]_net_1\);
    
    \frcskdnwvmx_ns[0]\ : NAND2
      port map(A => N_269_i, B => un1_frcskdnwvmx_3_1, Y => 
        \frcskdnwvmx_ns[0]_net_1\);
    
    \mwzbqqvzwjt_12_iv_0_o2[16]\ : OR2A
      port map(A => \mwzbqqvzwjt_12_iv_0_o2_0[16]_net_1\, B => 
        TR_RAM_DO_B_net_busnet_1, Y => N_60);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    \frcskdnwvmx_ns_a3[10]\ : NOR2A
      port map(A => INIT_DONE_net, B => N_288, Y => 
        \frcskdnwvmx_ns[10]\);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I26_Y : AX1C
      port map(A => N124, B => \TR_RAM_ADDR_B_net_busnet_5\, C
         => \TR_RAM_ADDR_B_net_busnet_6\, Y => 
        \un1_jvxfmjbzjmc[7]\);
    
    svpbmqwvncp_0 : OR3B
      port map(A => \svpbmqwvncp_0_1\, B => N_264, C => 
        \frcskdnwvmx[4]_net_1\, Y => TR_RAM_CSN_B_net);
    
    \kpffvbpxmsf_m[4]\ : OR2B
      port map(A => EV_CHHOLD_net_busnet_4, B => N_310, Y => 
        \kpffvbpxmsf_m[4]_net_1\);
    
    \frcskdnwvmx[0]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[11]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[0]_net_1\);
    
    \un1_jvxfmjbzjmc_m[6]\ : XAI1
      port map(A => N124, B => \TR_RAM_ADDR_B_net_busnet_5\, C
         => N_230_i_0, Y => \un1_jvxfmjbzjmc_m[6]_net_1\);
    
    \rjhhzsggrtr[4]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_4, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_4);
    
    \mwzbqqvzwjt_12_iv_0_o3_0[2]\ : NOR3B
      port map(A => N_238, B => N_285, C => 
        \mwzbqqvzwjt_12_iv_0_o3_0_tz[2]_net_1\, Y => 
        \mwzbqqvzwjt_12_iv_0_o3_0[2]_net_1\);
    
    cpwfrthtnfr_12_sqmuxa_0_a2 : OR3
      port map(A => TR_RAM_DO_B_net_busnet_0, B => 
        TR_RAM_DO_B_net_busnet_1, C => cpwfrthtnfr_13_sqmuxa_1, Y
         => cpwfrthtnfr_12_sqmuxa_i);
    
    \kpffvbpxmsf_m[3]\ : OR2B
      port map(A => EV_CHHOLD_net_busnet_3, B => N_310, Y => 
        \kpffvbpxmsf_m[3]_net_1\);
    
    \frcskdnwvmx_ns_i_o2[3]\ : NOR2A
      port map(A => N_235_i_0, B => N_247, Y => N_248);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[6]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[7]\, C => 
        \tpxkpvnpvvn_m_0[6]_net_1\, Y => \qgnzcpmbksd_7[6]\);
    
    N_234_i_0_a2 : NOR2B
      port map(A => TR_RAM_DO_B_net_busnet_8, B => 
        TR_RAM_DO_B_net_busnet_6, Y => N_234_i_0);
    
    znjtscvsvcs_iv_0_a2_0 : NOR3A
      port map(A => \hnbsspwxkpd\, B => N_358_1, C => N_117_i, Y
         => N_358);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I8_Y_1 : NOR3C
      port map(A => \TR_RAM_ADDR_B_net_busnet_5\, B => 
        \TR_RAM_ADDR_B_net_busnet_6\, C => N105, Y => 
        ADD_9x9_medium_I8_Y_1);
    
    dvqzjxhqhrh : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_4, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => cpwfrthtnfr_7_sqmuxa, Q => 
        \dvqzjxhqhrh\);
    
    \frcskdnwvmx[9]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[2]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[9]_net_1\);
    
    dttrrgvsnmg_iv_0_a2_1_0 : NOR2A
      port map(A => N_203, B => TR_RAM_DO_B_net_busnet_6, Y => 
        N_181_1);
    
    \jfkkdmfhcdn[3]\ : NOR2A
      port map(A => TR_RAM_DO_B_net_busnet_3, B => 
        \frcskdnwvmx_0[0]_net_1\, Y => TR_RAM_DI_B_net_busnet_3);
    
    \tpxkpvnpvvn_m_0[6]\ : OR2B
      port map(A => TR_RAM_DO_B_net_busnet_6, B => 
        qgnzcpmbksd_0_sqmuxa, Y => \tpxkpvnpvvn_m_0[6]_net_1\);
    
    \qgnzcpmbksd[3]\ : DFN1C0
      port map(D => \qgnzcpmbksd_7[3]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \TR_RAM_ADDR_B_net_busnet_3\);
    
    \frcskdnwvmx_ns_i[9]\ : NOR2B
      port map(A => INIT_DONE_net, B => \TR_EV_RD_net\, Y => 
        \frcskdnwvmx_ns_i[9]_net_1\);
    
    \rjhhzsggrtr[8]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_8, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_8);
    
    \mwzbqqvzwjt_12_iv_0_a2_2[1]\ : NOR3A
      port map(A => N_91_i, B => N_381, C => 
        cpwfrthtnfr_4_sqmuxa_i, Y => N_352);
    
    \mwzbqqvzwjt[2]\ : DFN1E1C0
      port map(D => \mwzbqqvzwjt_12[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => un1_frcskdnwvmx_5, Q => 
        \Temp_over70C_net\);
    
    \frcskdnwvmx[3]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[8]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => \TR_EV_RD_net\);
    
    \frcskdnwvmx_ns_a3_2[0]\ : NOR3A
      port map(A => \frcskdnwvmx_ns_a3_0[0]_net_1\, B => 
        \frcskdnwvmx[6]_net_1\, C => \frcskdnwvmx[8]_net_1\, Y
         => \frcskdnwvmx_ns_a3_2[0]_net_1\);
    
    hnbsspwxkpd : DFN1E1C0
      port map(D => znjtscvsvcs, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => un1_xjrbtnwdszs_0_sqmuxa, Q => 
        \hnbsspwxkpd\);
    
    mwzbqqvzwjt_0_sqmuxa_0_0_i : OAI1
      port map(A => \rhjxdmgzftc[0]_net_1\, B => 
        \rhjxdmgzftc[1]_net_1\, C => \frcskdnwvmx[5]_net_1\, Y
         => N_419);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I24_Y : AX1C
      port map(A => N127, B => \TR_RAM_ADDR_B_net_busnet_3\, C
         => \TR_RAM_ADDR_B_net_busnet_4\, Y => 
        \un1_jvxfmjbzjmc[5]\);
    
    \tpxkpvnpvvn_m_0[3]\ : OR2B
      port map(A => TR_RAM_DO_B_net_busnet_3, B => 
        qgnzcpmbksd_0_sqmuxa, Y => \tpxkpvnpvvn_m_0[3]_net_1\);
    
    \rjhhzsggrtr[2]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_2, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \frcskdnwvmx[4]_net_1\, Q => 
        TR_EV_ADDR_net_busnet_2);
    
    \mwzbqqvzwjt_12_iv_0_0[1]\ : AO1A
      port map(A => mwzbqqvzwjt_1_sqmuxa_1, B => 
        TR_RAM_DO_B_net_busnet_1, C => N_350, Y => 
        \mwzbqqvzwjt_12_iv_0_0[1]_net_1\);
    
    un1_frcskdnwvmx_5_0_a2_0 : NOR2B
      port map(A => \frcskdnwvmx[6]_net_1\, B => 
        TR_RAM_DO_B_net_busnet_7, Y => \un1_frcskdnwvmx_5_0_a2_0\);
    
    \rhjxdmgzftc[0]\ : DFN1E1C0
      port map(D => TR_RAM_DO_B_net_busnet_0, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => cpwfrthtnfr_6_sqmuxa, Q => 
        \rhjxdmgzftc[0]_net_1\);
    
    jvxfmjbzjmc_i_a3_0 : NOR3
      port map(A => N_291, B => TR_RAM_DO_B_net_busnet_7, C => 
        N_247, Y => N_263);
    
    \frcskdnwvmx[2]\ : DFN1C0
      port map(D => \frcskdnwvmx_ns_i[9]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \frcskdnwvmx[2]_net_1\);
    
    dttrrgvsnmg_iv_0_x2 : AX1A
      port map(A => N_381, B => N_91_i, C => 
        TR_RAM_DO_B_net_busnet_5, Y => N_117_i);
    
    cnwzzrhdsqv : OR3B
      port map(A => N_4, B => N_10, C => INIT_DONE_net, Y => 
        TR_RAM_RW_A_net);
    
    \frcskdnwvmx_ns_i_a3[4]\ : OA1C
      port map(A => N_235_i_0, B => TR_RAM_DO_B_net_busnet_8, C
         => \frcskdnwvmx[8]_net_1\, Y => N_271);
    
    \mwzbqqvzwjt_12_iv_0_o3[22]\ : OR2A
      port map(A => TR_RAM_DO_B_net_busnet_1, B => 
        TR_RAM_DO_B_net_busnet_0, Y => N_426);
    
    un7_nwjvqqsgrjz_i_o3 : OR2B
      port map(A => EV_DONE_net, B => \frcskdnwvmx[11]_net_1\, Y
         => N_243);
    
    \mwzbqqvzwjt_12_iv_0_o2[2]\ : OR3
      port map(A => TR_RAM_DO_B_net_busnet_2, B => 
        TR_RAM_DO_B_net_busnet_3, C => TR_RAM_DO_B_net_busnet_4, 
        Y => N_381);
    
    cpwfrthtnfr_11_sqmuxa_0_a2_0_a2 : NOR3C
      port map(A => TR_RAM_DO_B_net_busnet_5, B => 
        TR_RAM_DO_B_net_busnet_7, C => \frcskdnwvmx[6]_net_1\, Y
         => N_285);
    
    \kpffvbpxmsf_m[1]\ : OR2B
      port map(A => EV_CHHOLD_net_busnet_1, B => N_310, Y => 
        \kpffvbpxmsf_m[1]_net_1\);
    
    un1_qgnzcpmbksd15_i_a2 : OR2B
      port map(A => N_285, B => N_234_i_0, Y => N_288);
    
    \frcskdnwvmx_ns_i[8]\ : NOR2B
      port map(A => INIT_DONE_net, B => \frcskdnwvmx[4]_net_1\, Y
         => \frcskdnwvmx_ns_i[8]_net_1\);
    
    \frcskdnwvmx_ns_a3_0[0]\ : NOR2
      port map(A => \frcskdnwvmx[9]_net_1\, B => \TR_EV_RD_net\, 
        Y => \frcskdnwvmx_ns_a3_0[0]_net_1\);
    
    \brxxctcvrmh_qgnzcpmbksd_7_0_iv[2]\ : AO1B
      port map(A => N_230_i_0, B => \un1_jvxfmjbzjmc[3]\, C => 
        \qgnzcpmbksd_7_0_iv_0[2]\, Y => \qgnzcpmbksd_7[2]\);
    
    \mwzbqqvzwjt_12_iv_0_0[0]\ : AO1A
      port map(A => mwzbqqvzwjt_1_sqmuxa_1, B => 
        TR_RAM_DO_B_net_busnet_0, C => N_346, Y => 
        \mwzbqqvzwjt_12_iv_0_0[0]_net_1\);
    
    \frcskdnwvmx_ns_i_m2[4]\ : MX2A
      port map(A => \hnbsspwxkpd\, B => \jnfrmfqggmk\, S => 
        TR_RAM_DO_B_net_busnet_5, Y => N_233);
    
    un1_jvxfmjbzjmc_ADD_9x9_medium_I20_Y : AX1B
      port map(A => N_262, B => N_263, C => 
        \TR_RAM_ADDR_B_net_busnet_0\, Y => \un1_jvxfmjbzjmc[1]\);
    
    zzzxtvvjqhf : DFN1E1C0
      port map(D => \frcskdnwvmx_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => un1_frcskdnwvmx_3, 
        Q => TR_TRFLAG_net);
    
    \tpxkpvnpvvn_m_0[5]\ : OR2B
      port map(A => TR_RAM_DO_B_net_busnet_5, B => 
        qgnzcpmbksd_0_sqmuxa, Y => \tpxkpvnpvvn_m_0[5]_net_1\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity SMTR is

    port( SYS_CLK_int                : in    std_logic;
          SYS_RESET_c                : in    std_logic;
          INIT_DONE_net              : in    std_logic;
          TR_RAM_DO_B_net_busnet_4   : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_DO_B_net_busnet_2   : in    std_logic;
          TR_RAM_DO_B_net_busnet_1   : in    std_logic;
          TR_RAM_DO_B_net_busnet_0   : in    std_logic;
          AV5V_over5p25_net          : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          TR_EV_RD_net               : out   std_logic;
          TR_RAM_DO_B_net_busnet_7   : in    std_logic;
          TR_RAM_DO_B_net_busnet_3   : in    std_logic;
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_8   : in    std_logic;
          TR_RAM_DO_B_net_busnet_6   : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          EV_CHHOLD_net_busnet_0     : in    std_logic;
          EV_CHHOLD_net_busnet_1     : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          TR_RAM_RW_A_net            : out   std_logic;
          N_4                        : in    std_logic;
          N_10                       : in    std_logic;
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic;
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          EV_CHHOLD_net_busnet_4     : in    std_logic;
          EV_CHHOLD_net_busnet_3     : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic;
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          xgnmbzmtzbb_0              : out   std_logic;
          EV_DONE_net                : in    std_logic;
          EV_RAM_DO_A_net_busnet_0   : in    std_logic;
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_8    : out   std_logic
        );

end SMTR;

architecture DEF_ARCH of SMTR is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component ccfdxrhchsz
    port( TR_EV_ADDR_net_busnet_8    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          EV_DONE_net                : in    std_logic := 'U';
          xgnmbzmtzbb_0              : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_3     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_4     : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          N_10                       : in    std_logic := 'U';
          N_4                        : in    std_logic := 'U';
          TR_RAM_RW_A_net            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          EV_CHHOLD_net_busnet_1     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_0     : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          TR_EV_RD_net               : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          AV5V_over5p25_net          : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          INIT_DONE_net              : in    std_logic := 'U';
          SYS_RESET_c                : in    std_logic := 'U';
          SYS_CLK_int                : in    std_logic := 'U'
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : ccfdxrhchsz
	Use entity work.ccfdxrhchsz(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_ccfdxrhchsz : ccfdxrhchsz
      port map(TR_EV_ADDR_net_busnet_8 => TR_EV_ADDR_net_busnet_8, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        TR_EV_ADDR_net_busnet_6 => TR_EV_ADDR_net_busnet_6, 
        TR_EV_ADDR_net_busnet_5 => TR_EV_ADDR_net_busnet_5, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        TR_EV_ADDR_net_busnet_2 => TR_EV_ADDR_net_busnet_2, 
        TR_EV_ADDR_net_busnet_1 => TR_EV_ADDR_net_busnet_1, 
        TR_EV_ADDR_net_busnet_0 => TR_EV_ADDR_net_busnet_0, 
        TR_TRFLAG_net => TR_TRFLAG_net, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, TR_RAM_ADDR_B_net_busnet_8 => 
        TR_RAM_ADDR_B_net_busnet_8, TR_RAM_DI_B_net_busnet_6 => 
        TR_RAM_DI_B_net_busnet_6, EV_RAM_DO_A_net_busnet_0 => 
        EV_RAM_DO_A_net_busnet_0, EV_DONE_net => EV_DONE_net, 
        xgnmbzmtzbb_0 => xgnmbzmtzbb_0, TR_RAM_DI_B_net_busnet_8
         => TR_RAM_DI_B_net_busnet_8, TR_RAM_ADDR_B_net_busnet_4
         => TR_RAM_ADDR_B_net_busnet_4, TR_RAM_DI_B_net_busnet_5
         => TR_RAM_DI_B_net_busnet_5, EV_CHHOLD_net_busnet_2 => 
        EV_CHHOLD_net_busnet_2, TR_RAM_ADDR_B_net_busnet_3 => 
        TR_RAM_ADDR_B_net_busnet_3, EV_CHHOLD_net_busnet_3 => 
        EV_CHHOLD_net_busnet_3, EV_CHHOLD_net_busnet_4 => 
        EV_CHHOLD_net_busnet_4, TR_RAM_DI_B_net_busnet_1 => 
        TR_RAM_DI_B_net_busnet_1, TR_RAM_DI_B_net_busnet_0 => 
        TR_RAM_DI_B_net_busnet_0, Temp_over70C_net => 
        Temp_over70C_net, TR_RAM_DO_B_net_busnet_5 => 
        TR_RAM_DO_B_net_busnet_5, TR_RAM_DI_B_net_busnet_2 => 
        TR_RAM_DI_B_net_busnet_2, TR_RAM_DI_B_net_busnet_3 => 
        TR_RAM_DI_B_net_busnet_3, TR_RAM_DI_B_net_busnet_4 => 
        TR_RAM_DI_B_net_busnet_4, N_10 => N_10, N_4 => N_4, 
        TR_RAM_RW_A_net => TR_RAM_RW_A_net, 
        TR_RAM_ADDR_B_net_busnet_7 => TR_RAM_ADDR_B_net_busnet_7, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        EV_CHHOLD_net_busnet_0 => EV_CHHOLD_net_busnet_0, 
        TR_RAM_DI_B_net_busnet_7 => TR_RAM_DI_B_net_busnet_7, 
        TR_RAM_ADDR_B_net_busnet_0 => TR_RAM_ADDR_B_net_busnet_0, 
        TR_RAM_ADDR_B_net_busnet_1 => TR_RAM_ADDR_B_net_busnet_1, 
        TR_RAM_ADDR_B_net_busnet_2 => TR_RAM_ADDR_B_net_busnet_2, 
        TR_RAM_DO_B_net_busnet_6 => TR_RAM_DO_B_net_busnet_6, 
        TR_RAM_DO_B_net_busnet_8 => TR_RAM_DO_B_net_busnet_8, 
        TR_RAM_CSN_B_net => TR_RAM_CSN_B_net, 
        TR_RAM_DO_B_net_busnet_3 => TR_RAM_DO_B_net_busnet_3, 
        TR_RAM_DO_B_net_busnet_7 => TR_RAM_DO_B_net_busnet_7, 
        TR_EV_RD_net => TR_EV_RD_net, AV5V_under4p75_net => 
        AV5V_under4p75_net, AV5V_over5p25_net => 
        AV5V_over5p25_net, TR_RAM_DO_B_net_busnet_0 => 
        TR_RAM_DO_B_net_busnet_0, TR_RAM_DO_B_net_busnet_1 => 
        TR_RAM_DO_B_net_busnet_1, TR_RAM_DO_B_net_busnet_2 => 
        TR_RAM_DO_B_net_busnet_2, TR_RAM_ADDR_B_net_busnet_6 => 
        TR_RAM_ADDR_B_net_busnet_6, TR_RAM_ADDR_B_net_busnet_5
         => TR_RAM_ADDR_B_net_busnet_5, TR_RAM_DO_B_net_busnet_4
         => TR_RAM_DO_B_net_busnet_4, INIT_DONE_net => 
        INIT_DONE_net, SYS_RESET_c => SYS_RESET_c, SYS_CLK_int
         => SYS_CLK_int);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_smtr_wrapper is

    port( TR_EV_ADDR_net_busnet_8    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : in    std_logic;
          EV_DONE_net                : in    std_logic;
          xgnmbzmtzbb_0              : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_3     : in    std_logic;
          EV_CHHOLD_net_busnet_4     : in    std_logic;
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic;
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          N_10                       : in    std_logic;
          N_4                        : in    std_logic;
          TR_RAM_RW_A_net            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          EV_CHHOLD_net_busnet_1     : in    std_logic;
          EV_CHHOLD_net_busnet_0     : in    std_logic;
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : in    std_logic;
          TR_RAM_DO_B_net_busnet_8   : in    std_logic;
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : in    std_logic;
          TR_RAM_DO_B_net_busnet_7   : in    std_logic;
          TR_EV_RD_net               : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          AV5V_over5p25_net          : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : in    std_logic;
          TR_RAM_DO_B_net_busnet_1   : in    std_logic;
          TR_RAM_DO_B_net_busnet_2   : in    std_logic;
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : in    std_logic;
          INIT_DONE_net              : in    std_logic;
          SYS_RESET_c                : in    std_logic;
          SYS_CLK_int                : in    std_logic
        );

end Analog_smtr_wrapper;

architecture DEF_ARCH of Analog_smtr_wrapper is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component SMTR
    port( SYS_CLK_int                : in    std_logic := 'U';
          SYS_RESET_c                : in    std_logic := 'U';
          INIT_DONE_net              : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          AV5V_over5p25_net          : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          TR_EV_RD_net               : out   std_logic;
          TR_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          EV_CHHOLD_net_busnet_0     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_1     : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          TR_RAM_RW_A_net            : out   std_logic;
          N_4                        : in    std_logic := 'U';
          N_10                       : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          EV_CHHOLD_net_busnet_4     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_3     : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          xgnmbzmtzbb_0              : out   std_logic;
          EV_DONE_net                : in    std_logic := 'U';
          EV_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_8    : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : SMTR
	Use entity work.SMTR(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    U0 : SMTR
      port map(SYS_CLK_int => SYS_CLK_int, SYS_RESET_c => 
        SYS_RESET_c, INIT_DONE_net => INIT_DONE_net, 
        TR_RAM_DO_B_net_busnet_4 => TR_RAM_DO_B_net_busnet_4, 
        TR_RAM_ADDR_B_net_busnet_5 => TR_RAM_ADDR_B_net_busnet_5, 
        TR_RAM_ADDR_B_net_busnet_6 => TR_RAM_ADDR_B_net_busnet_6, 
        TR_RAM_DO_B_net_busnet_2 => TR_RAM_DO_B_net_busnet_2, 
        TR_RAM_DO_B_net_busnet_1 => TR_RAM_DO_B_net_busnet_1, 
        TR_RAM_DO_B_net_busnet_0 => TR_RAM_DO_B_net_busnet_0, 
        AV5V_over5p25_net => AV5V_over5p25_net, 
        AV5V_under4p75_net => AV5V_under4p75_net, TR_EV_RD_net
         => TR_EV_RD_net, TR_RAM_DO_B_net_busnet_7 => 
        TR_RAM_DO_B_net_busnet_7, TR_RAM_DO_B_net_busnet_3 => 
        TR_RAM_DO_B_net_busnet_3, TR_RAM_CSN_B_net => 
        TR_RAM_CSN_B_net, TR_RAM_DO_B_net_busnet_8 => 
        TR_RAM_DO_B_net_busnet_8, TR_RAM_DO_B_net_busnet_6 => 
        TR_RAM_DO_B_net_busnet_6, TR_RAM_ADDR_B_net_busnet_2 => 
        TR_RAM_ADDR_B_net_busnet_2, TR_RAM_ADDR_B_net_busnet_1
         => TR_RAM_ADDR_B_net_busnet_1, 
        TR_RAM_ADDR_B_net_busnet_0 => TR_RAM_ADDR_B_net_busnet_0, 
        TR_RAM_DI_B_net_busnet_7 => TR_RAM_DI_B_net_busnet_7, 
        EV_CHHOLD_net_busnet_0 => EV_CHHOLD_net_busnet_0, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        TR_RAM_ADDR_B_net_busnet_7 => TR_RAM_ADDR_B_net_busnet_7, 
        TR_RAM_RW_A_net => TR_RAM_RW_A_net, N_4 => N_4, N_10 => 
        N_10, TR_RAM_DI_B_net_busnet_4 => 
        TR_RAM_DI_B_net_busnet_4, TR_RAM_DI_B_net_busnet_3 => 
        TR_RAM_DI_B_net_busnet_3, TR_RAM_DI_B_net_busnet_2 => 
        TR_RAM_DI_B_net_busnet_2, TR_RAM_DO_B_net_busnet_5 => 
        TR_RAM_DO_B_net_busnet_5, Temp_over70C_net => 
        Temp_over70C_net, TR_RAM_DI_B_net_busnet_0 => 
        TR_RAM_DI_B_net_busnet_0, TR_RAM_DI_B_net_busnet_1 => 
        TR_RAM_DI_B_net_busnet_1, EV_CHHOLD_net_busnet_4 => 
        EV_CHHOLD_net_busnet_4, EV_CHHOLD_net_busnet_3 => 
        EV_CHHOLD_net_busnet_3, TR_RAM_ADDR_B_net_busnet_3 => 
        TR_RAM_ADDR_B_net_busnet_3, EV_CHHOLD_net_busnet_2 => 
        EV_CHHOLD_net_busnet_2, TR_RAM_DI_B_net_busnet_5 => 
        TR_RAM_DI_B_net_busnet_5, TR_RAM_ADDR_B_net_busnet_4 => 
        TR_RAM_ADDR_B_net_busnet_4, TR_RAM_DI_B_net_busnet_8 => 
        TR_RAM_DI_B_net_busnet_8, xgnmbzmtzbb_0 => xgnmbzmtzbb_0, 
        EV_DONE_net => EV_DONE_net, EV_RAM_DO_A_net_busnet_0 => 
        EV_RAM_DO_A_net_busnet_0, TR_RAM_DI_B_net_busnet_6 => 
        TR_RAM_DI_B_net_busnet_6, TR_RAM_ADDR_B_net_busnet_8 => 
        TR_RAM_ADDR_B_net_busnet_8, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, TR_TRFLAG_net => TR_TRFLAG_net, 
        TR_EV_ADDR_net_busnet_0 => TR_EV_ADDR_net_busnet_0, 
        TR_EV_ADDR_net_busnet_1 => TR_EV_ADDR_net_busnet_1, 
        TR_EV_ADDR_net_busnet_2 => TR_EV_ADDR_net_busnet_2, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        TR_EV_ADDR_net_busnet_5 => TR_EV_ADDR_net_busnet_5, 
        TR_EV_ADDR_net_busnet_6 => TR_EV_ADDR_net_busnet_6, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        TR_EV_ADDR_net_busnet_8 => TR_EV_ADDR_net_busnet_8);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_assc_ram is

    port( INIT_DATA_net                : in    std_logic_vector(8 downto 0);
          SYS_RESET_c                  : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_8   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_7   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_6   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_5   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_4   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_3   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_2   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_1   : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_0   : in    std_logic;
          SYS_CLK_int                  : in    std_logic;
          ASSC_RAM_WR_BUSY_B_net       : in    std_logic;
          N_250_i_0                    : in    std_logic;
          Analog_assc_ram_VCC          : in    std_logic;
          ASSC_RAM_RW_A_net            : in    std_logic;
          ASSC_RAM_CSN_A_net           : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_1 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : in    std_logic;
          Analog_assc_ram_GND          : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_8 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_7 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_6 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_5 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_4 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_3 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_7   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_6   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_5   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_4   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_2   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_7   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_6   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_5   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_4   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_3   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_1   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : out   std_logic
        );

end Analog_assc_ram;

architecture DEF_ARCH of Analog_assc_ram is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component RAM4K9
    generic (MEMORYFILE:string := "");

    port( ADDRA11 : in    std_logic := 'U';
          ADDRA10 : in    std_logic := 'U';
          ADDRA9  : in    std_logic := 'U';
          ADDRA8  : in    std_logic := 'U';
          ADDRA7  : in    std_logic := 'U';
          ADDRA6  : in    std_logic := 'U';
          ADDRA5  : in    std_logic := 'U';
          ADDRA4  : in    std_logic := 'U';
          ADDRA3  : in    std_logic := 'U';
          ADDRA2  : in    std_logic := 'U';
          ADDRA1  : in    std_logic := 'U';
          ADDRA0  : in    std_logic := 'U';
          ADDRB11 : in    std_logic := 'U';
          ADDRB10 : in    std_logic := 'U';
          ADDRB9  : in    std_logic := 'U';
          ADDRB8  : in    std_logic := 'U';
          ADDRB7  : in    std_logic := 'U';
          ADDRB6  : in    std_logic := 'U';
          ADDRB5  : in    std_logic := 'U';
          ADDRB4  : in    std_logic := 'U';
          ADDRB3  : in    std_logic := 'U';
          ADDRB2  : in    std_logic := 'U';
          ADDRB1  : in    std_logic := 'U';
          ADDRB0  : in    std_logic := 'U';
          DINA8   : in    std_logic := 'U';
          DINA7   : in    std_logic := 'U';
          DINA6   : in    std_logic := 'U';
          DINA5   : in    std_logic := 'U';
          DINA4   : in    std_logic := 'U';
          DINA3   : in    std_logic := 'U';
          DINA2   : in    std_logic := 'U';
          DINA1   : in    std_logic := 'U';
          DINA0   : in    std_logic := 'U';
          DINB8   : in    std_logic := 'U';
          DINB7   : in    std_logic := 'U';
          DINB6   : in    std_logic := 'U';
          DINB5   : in    std_logic := 'U';
          DINB4   : in    std_logic := 'U';
          DINB3   : in    std_logic := 'U';
          DINB2   : in    std_logic := 'U';
          DINB1   : in    std_logic := 'U';
          DINB0   : in    std_logic := 'U';
          WIDTHA0 : in    std_logic := 'U';
          WIDTHA1 : in    std_logic := 'U';
          WIDTHB0 : in    std_logic := 'U';
          WIDTHB1 : in    std_logic := 'U';
          PIPEA   : in    std_logic := 'U';
          PIPEB   : in    std_logic := 'U';
          WMODEA  : in    std_logic := 'U';
          WMODEB  : in    std_logic := 'U';
          BLKA    : in    std_logic := 'U';
          BLKB    : in    std_logic := 'U';
          WENA    : in    std_logic := 'U';
          WENB    : in    std_logic := 'U';
          CLKA    : in    std_logic := 'U';
          CLKB    : in    std_logic := 'U';
          RESET   : in    std_logic := 'U';
          DOUTA8  : out   std_logic;
          DOUTA7  : out   std_logic;
          DOUTA6  : out   std_logic;
          DOUTA5  : out   std_logic;
          DOUTA4  : out   std_logic;
          DOUTA3  : out   std_logic;
          DOUTA2  : out   std_logic;
          DOUTA1  : out   std_logic;
          DOUTA0  : out   std_logic;
          DOUTB8  : out   std_logic;
          DOUTB7  : out   std_logic;
          DOUTB6  : out   std_logic;
          DOUTB5  : out   std_logic;
          DOUTB4  : out   std_logic;
          DOUTB3  : out   std_logic;
          DOUTB2  : out   std_logic;
          DOUTB1  : out   std_logic;
          DOUTB0  : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    Analog_assc_ram_R0C0 : RAM4K9
      port map(ADDRA11 => Analog_assc_ram_GND, ADDRA10 => 
        Analog_assc_ram_GND, ADDRA9 => Analog_assc_ram_GND, 
        ADDRA8 => ASSC_RAM_ADDR_A_net_busnet_8, ADDRA7 => 
        ASSC_RAM_ADDR_A_net_busnet_7, ADDRA6 => 
        ASSC_RAM_ADDR_A_net_busnet_6, ADDRA5 => 
        ASSC_RAM_ADDR_A_net_busnet_5, ADDRA4 => 
        ASSC_RAM_ADDR_A_net_busnet_4, ADDRA3 => 
        ASSC_RAM_ADDR_A_net_busnet_3, ADDRA2 => 
        ASSC_RAM_ADDR_A_net_busnet_2, ADDRA1 => 
        ASSC_RAM_ADDR_A_net_busnet_1, ADDRA0 => 
        ASSC_RAM_ADDR_A_net_busnet_0, ADDRB11 => 
        Analog_assc_ram_GND, ADDRB10 => Analog_assc_ram_GND, 
        ADDRB9 => Analog_assc_ram_GND, ADDRB8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, ADDRB7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, ADDRB6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, ADDRB5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, ADDRB4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, ADDRB3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, ADDRB2 => 
        ASSC_RAM_ADDR_B_net_busnet_2, ADDRB1 => 
        ASSC_RAM_ADDR_B_net_busnet_1, ADDRB0 => 
        ASSC_RAM_ADDR_B_net_busnet_0, DINA8 => INIT_DATA_net(8), 
        DINA7 => INIT_DATA_net(7), DINA6 => INIT_DATA_net(6), 
        DINA5 => INIT_DATA_net(5), DINA4 => INIT_DATA_net(4), 
        DINA3 => INIT_DATA_net(3), DINA2 => INIT_DATA_net(2), 
        DINA1 => INIT_DATA_net(1), DINA0 => INIT_DATA_net(0), 
        DINB8 => ASSC_RAM_DI_B_net_busnet_8, DINB7 => 
        ASSC_RAM_DI_B_net_busnet_7, DINB6 => 
        ASSC_RAM_DI_B_net_busnet_6, DINB5 => 
        ASSC_RAM_DI_B_net_busnet_5, DINB4 => 
        ASSC_RAM_DI_B_net_busnet_4, DINB3 => 
        ASSC_RAM_DI_B_net_busnet_3, DINB2 => 
        ASSC_RAM_DI_B_net_busnet_2, DINB1 => 
        ASSC_RAM_DI_B_net_busnet_1, DINB0 => 
        ASSC_RAM_DI_B_net_busnet_0, WIDTHA0 => 
        Analog_assc_ram_VCC, WIDTHA1 => Analog_assc_ram_VCC, 
        WIDTHB0 => Analog_assc_ram_VCC, WIDTHB1 => 
        Analog_assc_ram_VCC, PIPEA => Analog_assc_ram_GND, PIPEB
         => Analog_assc_ram_GND, WMODEA => Analog_assc_ram_VCC, 
        WMODEB => Analog_assc_ram_VCC, BLKA => ASSC_RAM_CSN_A_net, 
        BLKB => N_250_i_0, WENA => ASSC_RAM_RW_A_net, WENB => 
        ASSC_RAM_WR_BUSY_B_net, CLKA => SYS_CLK_int, CLKB => 
        SYS_CLK_int, RESET => SYS_RESET_c, DOUTA8 => 
        ASSC_RAM_DO_A_net_busnet_8, DOUTA7 => 
        ASSC_RAM_DO_A_net_busnet_7, DOUTA6 => 
        ASSC_RAM_DO_A_net_busnet_6, DOUTA5 => 
        ASSC_RAM_DO_A_net_busnet_5, DOUTA4 => 
        ASSC_RAM_DO_A_net_busnet_4, DOUTA3 => 
        ASSC_RAM_DO_A_net_busnet_3, DOUTA2 => 
        ASSC_RAM_DO_A_net_busnet_2, DOUTA1 => 
        ASSC_RAM_DO_A_net_busnet_1, DOUTA0 => 
        ASSC_RAM_DO_A_net_busnet_0, DOUTB8 => 
        ASSC_RAM_DO_B_net_busnet_8, DOUTB7 => 
        ASSC_RAM_DO_B_net_busnet_7, DOUTB6 => 
        ASSC_RAM_DO_B_net_busnet_6, DOUTB5 => 
        ASSC_RAM_DO_B_net_busnet_5, DOUTB4 => 
        ASSC_RAM_DO_B_net_busnet_4, DOUTB3 => 
        ASSC_RAM_DO_B_net_busnet_3, DOUTB2 => 
        ASSC_RAM_DO_B_net_busnet_2, DOUTB1 => 
        ASSC_RAM_DO_B_net_busnet_1, DOUTB0 => 
        ASSC_RAM_DO_B_net_busnet_0);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity fmvgpwbdcxs is

    port( INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          ADC_RESET_net                : out   std_logic;
          ADC_CALIBRATE_net            : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic;
          ADC_START_net                : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic;
          EV_ASSCADDR_net_busnet_8     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic;
          ASSC_RAM_RW_A_net            : out   std_logic;
          un1_Analog_inst_1            : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic;
          ASSC_RAM_CSN_A_net           : out   std_logic;
          ADC_RESULT_net_busnet_11     : in    std_logic;
          ADC_RESULT_net_busnet_2      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_10     : in    std_logic;
          ADC_RESULT_net_busnet_1      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_9      : in    std_logic;
          ADC_RESULT_net_busnet_0      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          qvkpfznsfjx                  : out   std_logic;
          ADC_BUSY_net                 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          N_250_i_0                    : out   std_logic;
          fskhwddcbbg_1_sqmuxa         : in    std_logic;
          EV_DONE_net                  : in    std_logic;
          EV_EVFLAG_net                : in    std_logic;
          TR_TRFLAG_net                : in    std_logic;
          TR_DONE_net_i_0              : in    std_logic;
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : in    std_logic;
          INIT_DONE_net                : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          SYS_CLK_int                  : in    std_logic
        );

end fmvgpwbdcxs;

architecture DEF_ARCH of fmvgpwbdcxs is 

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1E1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component XNOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component OA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1E0C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component OA1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1P0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          PRE : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component AOI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component NOR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NAND2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1D
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XNOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component INV
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal un1_Analog_inst_5_0, \jzzdfrmzwdj_ns_i[3]_net_1\, 
        \jzzdfrmzwdj_0[14]_net_1\, \jzzdfrmzwdj_ns_i[1]_net_1\, 
        N_244_0, \jzzdfrmzwdj[8]_net_1\, N_314, \jdhgstfqkjm_2_i\, 
        \jdhgstfqkjm_2\, bksnhfwfshc_2_sqmuxa, N_275, N_311, 
        N_303, N_261_i_0, bksnhfwfshc_6_sqmuxa, N_302, 
        \un1_cfxfrwgjccr_12_0\, N_279, ADD_8x8_medium_I29_Y_0, 
        \hpvbctcvfcp[7]_net_1\, ADD_8x8_medium_I26_Y_0, 
        \hpvbctcvfcp[4]_net_1\, ADD_8x8_medium_I17_Y_0, 
        \hpvbctcvfcp[5]_net_1\, N132, ADD_8x8_medium_I24_Y_0, 
        \hpvbctcvfcp[2]_net_1\, un6_kftxkzdmgnn_0, 
        \jdhgstfqkjm_2_1\, N_288, \wwhrbsjdjpn\, 
        \jzzdfrmzwdj_ns_i_0[14]_net_1\, ddvbdtxtbpx_i_1, N_282, 
        N_250_2, \bwngcbddzsh_0_sqmuxa_2\, 
        \bwngcbddzsh_0_sqmuxa_0\, \un1_cfxfrwgjccr_9_0_0\, N_301, 
        \bksnhfwfshc_2_iv_0\, \znbkwkbspdc\, N_259, 
        \bksnhfwfshc_1_m\, \jzzdfrmzwdj_ns_0[0]_net_1\, N_291, 
        \jzzdfrmzwdj_ns_i_0[15]_net_1\, \ddvbdtxtbpx_i_1_0\, 
        \jzzdfrmzwdj[10]_net_1\, \svpqbbcnvqz_0[2]_net_1\, 
        \jzzdfrmzwdj[11]_net_1\, \zgzrtwwghwq_1_sqmuxa_i_a2_4\, 
        \zgzrtwwghwq_1_sqmuxa_i_a2_2\, \hpvbctcvfcp[0]_net_1\, 
        \hpvbctcvfcp[1]_net_1\, \hpvbctcvfcp[3]_net_1\, 
        \zgzrtwwghwq_1_sqmuxa_i_a2_1\, 
        \zgzrtwwghwq_1_sqmuxa_i_a2_0\, \hpvbctcvfcp[6]_net_1\, 
        \un6_bdbpcvshhqt_1\, N_359, un1_Analog_assc_wrapper_inst, 
        N_268, N_306, N_283, \jzzdfrmzwdj[4]_net_1\, 
        \jzzdfrmzwdj[5]_net_1\, \jzzdfrmzwdj_ns[0]_net_1\, 
        \bwngcbddzsh_0_sqmuxa\, \bcmkdjqtngz_1\, 
        \znbkwkbspdc_31_i\, N_269, un1_cfxfrwgjccr_9, 
        \jzzdfrmzwdj_ns_i[15]_net_1\, \jzzdfrmzwdj[0]_net_1\, 
        N_234_i_0, N_316, \jzzdfrmzwdj[1]_net_1\, 
        \jzzdfrmzwdj_ns_i[13]_net_1\, N_356, \jzzdfrmzwdj_ns[10]\, 
        \jzzdfrmzwdj[6]_net_1\, \un1_cfxfrwgjccr_12\, 
        \jhkbkqjtkbs\, \znbmnfdbzvr\, \un2_crgqqkcrfvm\, 
        \crgqqkcrfvm\, \un1_zgzrtwwghwq_1_sqmuxa[2]\, N120, 
        \un1_zgzrtwwghwq_1_sqmuxa[6]\, N166, 
        \un1_zgzrtwwghwq_1_sqmuxa[5]\, N147, N145, 
        \un1_zgzrtwwghwq_1_sqmuxa[3]\, 
        \un1_zgzrtwwghwq_1_sqmuxa[4]\, N168, 
        \un1_zgzrtwwghwq_1_sqmuxa_i[7]\, N156, 
        \un1_zgzrtwwghwq_1_sqmuxa_i[8]\, N138, N_286, N_244, 
        \jzzdfrmzwdj_ns_i[7]_net_1\, \jzzdfrmzwdj[9]_net_1\, 
        \hpvbctcvfcp_4[1]\, N_328, \hpvbctcvfcp_4[3]\, N_330, 
        \hpvbctcvfcp_4[6]\, N_333, \hpvbctcvfcp_4[7]\, N_334, 
        \jzzdfrmzwdj_i_0[3]\, \jzzdfrmzwdj_i_0[2]\, 
        \jzzdfrmzwdj_ns_i[12]_net_1\, \un2_wkpfnwqwgcb\, 
        \wkpfnwqwgcb\, qvkpfznsfjx_net_1, \un4_wkpfnwqwgcb\, 
        \bksczsjcvgb\, N_290, N_258, N_304, N_305, N_260, 
        \jzzdfrmzwdj[15]_net_1\, hdxtpkktfvz, 
        \jzzdfrmzwdj_ns_i[2]_net_1\, \jzzdfrmzwdj[13]_net_1\, 
        \jzzdfrmzwdj_ns_i[4]_net_1\, \jzzdfrmzwdj_ns_i[5]_net_1\, 
        \jzzdfrmzwdj_ns_i[6]_net_1\, \jzzdfrmzwdj_ns_i[9]_net_1\, 
        N_281, \jzzdfrmzwdj[7]_net_1\, 
        \jzzdfrmzwdj_ns_i[11]_net_1\, \ASSC_RAM_WR_BUSY_B_net\, 
        \bnrsdrtmtsg_5[5]_net_1\, \hgqdwrxvgzm_2[5]_net_1\, 
        \bnrsdrtmtsg_5[4]_net_1\, \hgqdwrxvgzm_2[4]_net_1\, 
        \bnrsdrtmtsg_5[3]_net_1\, \hgqdwrxvgzm_2[3]_net_1\, 
        \bnrsdrtmtsg_5[2]_net_1\, \hgqdwrxvgzm_2[2]_net_1\, 
        \bnrsdrtmtsg_5[1]_net_1\, \hgqdwrxvgzm_2[1]_net_1\, 
        \bnrsdrtmtsg_5[0]_net_1\, \hgqdwrxvgzm_2[0]_net_1\, 
        \znbmnfdbzvr_33\, \hgqdwrxvgzm[1]_net_1\, 
        \hgqdwrxvgzm[2]_net_1\, \hgqdwrxvgzm[3]_net_1\, 
        \un1_cfxfrwgjccr_1\, \jzzdfrmzwdj_ns[8]\, N123, 
        \hpvbctcvfcp_4[0]\, N_327, \hpvbctcvfcp_4[2]\, N_329, 
        \hpvbctcvfcp_4[4]\, N_331, N126, 
        \un1_zgzrtwwghwq_1_sqmuxa[1]\, \ADC_START_net\, N_332, 
        \hpvbctcvfcp_4[5]\, \hgqdwrxvgzm[5]_net_1\, 
        \jzzdfrmzwdj[14]_net_1\, \hgqdwrxvgzm[4]_net_1\, 
        \hgqdwrxvgzm[0]_net_1\, \gtxqsppgcmn\, \zbhmfptrcmn\, 
        \jzzdfrmzwdj[12]_net_1\, \dspfgfmqhwh[0]_net_1\, 
        \dspfgfmqhwh[1]_net_1\, \dspfgfmqhwh[2]_net_1\, 
        \dspfgfmqhwh[3]_net_1\, \dspfgfmqhwh[4]_net_1\, \GND\, 
        \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 

    dspfgfmqhwh(4) <= \dspfgfmqhwh[4]_net_1\;
    dspfgfmqhwh(3) <= \dspfgfmqhwh[3]_net_1\;
    dspfgfmqhwh(2) <= \dspfgfmqhwh[2]_net_1\;
    dspfgfmqhwh(1) <= \dspfgfmqhwh[1]_net_1\;
    dspfgfmqhwh(0) <= \dspfgfmqhwh[0]_net_1\;
    ADC_START_net <= \ADC_START_net\;
    qvkpfznsfjx <= qvkpfznsfjx_net_1;
    ASSC_RAM_WR_BUSY_B_net <= \ASSC_RAM_WR_BUSY_B_net\;

    cmbpphsszmt : AO1
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => N_279, 
        Y => un1_Analog_inst_1);
    
    \dbcvwwhvvwh[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_2, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_2);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I0_S : XNOR2
      port map(A => \hpvbctcvfcp[0]_net_1\, B => N_244, Y => 
        \un1_zgzrtwwghwq_1_sqmuxa[1]\);
    
    \bnrsdrtmtsg_5[1]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[1]_net_1\, Y => \bnrsdrtmtsg_5[1]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[2]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[3]\, B => 
        ASSC_RAM_DO_B_net_busnet_2, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_329);
    
    un1_cfxfrwgjccr_9_0 : AO1B
      port map(A => N_269, B => \znbkwkbspdc\, C => 
        \un1_cfxfrwgjccr_9_0_0\, Y => un1_cfxfrwgjccr_9);
    
    \ksbhwjctscp[0]\ : MX2B
      port map(A => INIT_ADDR_net(0), B => 
        EV_ASSCADDR_net_busnet_2, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_0);
    
    un1_cfxfrwgjccr_4_0_a4_0 : OR3B
      port map(A => ASSC_RAM_DO_B_net_busnet_6, B => N_261_i_0, C
         => ASSC_RAM_DO_B_net_busnet_7, Y => N_301);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[3]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_330, Y => 
        \hpvbctcvfcp_4[3]\);
    
    \jzzdfrmzwdj_ns_i[1]\ : NOR2A
      port map(A => INIT_DONE_net, B => N_282, Y => 
        \jzzdfrmzwdj_ns_i[1]_net_1\);
    
    fsrxhtjthgw_i_o4 : NOR3B
      port map(A => \znbkwkbspdc\, B => INIT_DONE_net, C => N_306, 
        Y => N_279);
    
    \hgqdwrxvgzm_2[5]\ : MX2
      port map(A => \hgqdwrxvgzm[5]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_5, S => \jzzdfrmzwdj[14]_net_1\, 
        Y => \hgqdwrxvgzm_2[5]_net_1\);
    
    \bnrsdrtmtsg_5[2]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[2]_net_1\, Y => \bnrsdrtmtsg_5[2]_net_1\);
    
    un1_bksnhfwfshc_1_sqmuxa_i_a4 : OR2A
      port map(A => \bksczsjcvgb\, B => \jzzdfrmzwdj_0[14]_net_1\, 
        Y => N_288);
    
    \dbcvwwhvvwh[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_0, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_0);
    
    \mksbfqnmmgw[6]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_6, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_6);
    
    \ptxbvztnpnf[4]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_4, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_4);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I25_Y : XOR3
      port map(A => N_244_0, B => \hpvbctcvfcp[3]_net_1\, C => 
        N168, Y => \un1_zgzrtwwghwq_1_sqmuxa[4]\);
    
    bwngcbddzsh_0_sqmuxa_2 : NOR3B
      port map(A => \dspfgfmqhwh[1]_net_1\, B => 
        \dspfgfmqhwh[0]_net_1\, C => \dspfgfmqhwh[2]_net_1\, Y
         => \bwngcbddzsh_0_sqmuxa_2\);
    
    \hpvbctcvfcp[3]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[3]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[3]_net_1\);
    
    \hgqdwrxvgzm[5]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_5, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[5]_net_1\);
    
    \dspfgfmqhwh[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_1, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => un1_Analog_inst_5_0, 
        Q => \dspfgfmqhwh[1]_net_1\);
    
    \hgqdwrxvgzm_2[3]\ : MX2
      port map(A => \hgqdwrxvgzm[3]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_3, S => 
        \jzzdfrmzwdj_0[14]_net_1\, Y => \hgqdwrxvgzm_2[3]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I17_Y_0 : OA1A
      port map(A => \hpvbctcvfcp[5]_net_1\, B => N_244_0, C => 
        N132, Y => ADD_8x8_medium_I17_Y_0);
    
    bcmkdjqtngz_1 : NOR2A
      port map(A => INIT_DONE_net, B => qvkpfznsfjx_net_1, Y => 
        \bcmkdjqtngz_1\);
    
    \pfkhhxxsrzp[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_6, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => ADC_MODE_net_busnet_1);
    
    jdhgstfqkjm_2 : NOR2A
      port map(A => \jdhgstfqkjm_2_1\, B => N_316, Y => 
        \jdhgstfqkjm_2\);
    
    bksnhfwfshc_2_iv_0 : AO1A
      port map(A => \znbkwkbspdc\, B => N_259, C => 
        \bksnhfwfshc_1_m\, Y => \bksnhfwfshc_2_iv_0\);
    
    bksczsjcvgb : DFN1E1C0
      port map(D => \jdhgstfqkjm_2_i\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \un4_wkpfnwqwgcb\, Q => 
        \bksczsjcvgb\);
    
    \jzzdfrmzwdj_ns_i_o2_0[2]\ : OR2
      port map(A => ASSC_RAM_DO_B_net_busnet_7, B => 
        ASSC_RAM_DO_B_net_busnet_6, Y => N_258);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I24_Y_0 : XOR2
      port map(A => \hpvbctcvfcp[2]_net_1\, B => N_244_0, Y => 
        ADD_8x8_medium_I24_Y_0);
    
    \dspfgfmqhwh[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_3, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => \dspfgfmqhwh[3]_net_1\);
    
    ddvbdtxtbpx_i_1_1 : NOR3C
      port map(A => \ASSC_RAM_WR_BUSY_B_net\, B => N_282, C => 
        N_250_2, Y => ddvbdtxtbpx_i_1);
    
    \bnrsdrtmtsg[3]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[3]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_6);
    
    \mksbfqnmmgw[2]\ : MX2
      port map(A => ADC_RESULT_net_busnet_2, B => 
        ADC_RESULT_net_busnet_11, S => \jzzdfrmzwdj[4]_net_1\, Y
         => ASSC_RAM_DI_B_net_busnet_2);
    
    jhkbkqjtkbs : OA1
      port map(A => bksnhfwfshc_6_sqmuxa, B => 
        \bksnhfwfshc_2_iv_0\, C => INIT_DONE_net, Y => 
        \jhkbkqjtkbs\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[1]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_328, Y => 
        \hpvbctcvfcp_4[1]\);
    
    \jzzdfrmzwdj[10]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[5]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[10]_net_1\);
    
    \hpvbctcvfcp[6]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[6]_net_1\);
    
    wwhrbsjdjpn : DFN1C0
      port map(D => ADC_CALIBRATE_net, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \wwhrbsjdjpn\);
    
    \jzzdfrmzwdj[8]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[7]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[8]_net_1\);
    
    \ptxbvztnpnf[7]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_7, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_7);
    
    \ksbhwjctscp[5]\ : MX2
      port map(A => INIT_ADDR_net(5), B => 
        EV_ASSCADDR_net_busnet_5, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_5);
    
    \jzzdfrmzwdj[1]\ : DFN1C0
      port map(D => N_234_i_0, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \jzzdfrmzwdj[1]_net_1\);
    
    \bnrsdrtmtsg[4]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[4]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_7);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[5]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[6]\, B => 
        ASSC_RAM_DO_B_net_busnet_5, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_332);
    
    \bnrsdrtmtsg_5[0]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[0]_net_1\, Y => \bnrsdrtmtsg_5[0]_net_1\);
    
    \dbcvwwhvvwh[5]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_5, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_5);
    
    \bnrsdrtmtsg[5]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[5]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_8);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[4]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[5]\, B => 
        ASSC_RAM_DO_B_net_busnet_4, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_331);
    
    wkpfnwqwgcb : DFN1C0
      port map(D => \wwhrbsjdjpn\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \wkpfnwqwgcb\);
    
    \jzzdfrmzwdj[2]\ : DFN1P0
      port map(D => \jzzdfrmzwdj_ns_i[13]_net_1\, CLK => 
        SYS_CLK_int, PRE => SYS_RESET_c, Q => 
        \jzzdfrmzwdj_i_0[2]\);
    
    un2_wkpfnwqwgcb : NOR2A
      port map(A => \wkpfnwqwgcb\, B => \wwhrbsjdjpn\, Y => 
        \un2_wkpfnwqwgcb\);
    
    \jzzdfrmzwdj_ns_i[9]\ : OA1
      port map(A => N_281, B => \jzzdfrmzwdj[7]_net_1\, C => 
        INIT_DONE_net, Y => \jzzdfrmzwdj_ns_i[9]_net_1\);
    
    nptwvwnctcg_i_o4 : NOR2
      port map(A => \jzzdfrmzwdj[5]_net_1\, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => \ASSC_RAM_WR_BUSY_B_net\);
    
    \dspfgfmqhwh[4]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_4, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => \dspfgfmqhwh[4]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[5]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_332, Y => 
        \hpvbctcvfcp_4[5]\);
    
    fsrxhtjthgw_i_a2_1 : OR2A
      port map(A => N_260, B => N_356, Y => N_305);
    
    un1_cfxfrwgjccr_9_0_0 : NOR2B
      port map(A => INIT_DONE_net, B => N_301, Y => 
        \un1_cfxfrwgjccr_9_0_0\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    crgqqkcrfvm : DFN1C0
      port map(D => \gtxqsppgcmn\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \crgqqkcrfvm\);
    
    \bwngcbddzsh[0]\ : DFN1E1C0
      port map(D => \bwngcbddzsh_0_sqmuxa\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un2_crgqqkcrfvm\, Q => 
        TM_STB_net_0);
    
    zgzrtwwghwq_1_sqmuxa_i_a2_2 : NOR2
      port map(A => \hpvbctcvfcp[3]_net_1\, B => 
        \hpvbctcvfcp[2]_net_1\, Y => 
        \zgzrtwwghwq_1_sqmuxa_i_a2_2\);
    
    un1_cfxfrwgjccr_12_0 : OR2A
      port map(A => INIT_DONE_net, B => N_279, Y => 
        \un1_cfxfrwgjccr_12_0\);
    
    fsrxhtjthgw_i_a2 : AOI1
      port map(A => N_304, B => N_305, C => 
        \jzzdfrmzwdj[0]_net_1\, Y => N_306);
    
    zwtzpwdfptq_un6_kftxkzdmgnn_0 : NOR2A
      port map(A => INIT_DONE_net, B => EV_ASSCADDR_net_busnet_2, 
        Y => un6_kftxkzdmgnn_0);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[6]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_333, Y => 
        \hpvbctcvfcp_4[6]\);
    
    un6_bdbpcvshhqt_1 : NOR3A
      port map(A => TR_DONE_net_i_0, B => TR_TRFLAG_net, C => 
        EV_EVFLAG_net, Y => \un6_bdbpcvshhqt_1\);
    
    dtcvhtqxgdc : DFN1E1C0
      port map(D => N_286, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => un1_cfxfrwgjccr_9, Q => ADC_PDOWN_net);
    
    \hpvbctcvfcp[0]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[0]_net_1\);
    
    bksnhfwfshc_2_sqmuxa_0_a4 : NOR2
      port map(A => N_275, B => N_311, Y => bksnhfwfshc_2_sqmuxa);
    
    \ptxbvztnpnf[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_0, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_0);
    
    \bnrsdrtmtsg_5[5]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[5]_net_1\, Y => \bnrsdrtmtsg_5[5]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I0_CO1 : NOR2A
      port map(A => \hpvbctcvfcp[0]_net_1\, B => N_244, Y => N120);
    
    \ksbhwjctscp[1]\ : MX2B
      port map(A => INIT_ADDR_net(1), B => 
        EV_ASSCADDR_net_busnet_2, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_1);
    
    \jzzdfrmzwdj_ns_i[3]\ : NOR2B
      port map(A => INIT_DONE_net, B => \jzzdfrmzwdj[13]_net_1\, 
        Y => \jzzdfrmzwdj_ns_i[3]_net_1\);
    
    \mksbfqnmmgw[3]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_3, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_3);
    
    \bnrsdrtmtsg_5[3]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[3]_net_1\, Y => \bnrsdrtmtsg_5[3]_net_1\);
    
    \ksbhwjctscp[6]\ : MX2
      port map(A => INIT_ADDR_net(6), B => 
        EV_ASSCADDR_net_busnet_6, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_6);
    
    znbkwkbspdc_31_i : NOR3B
      port map(A => INIT_DONE_net, B => \znbkwkbspdc\, C => N_269, 
        Y => \znbkwkbspdc_31_i\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[7]\ : MX2A
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa_i[8]\, B => 
        ASSC_RAM_DO_B_net_busnet_7, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_334);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[0]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_327, Y => 
        \hpvbctcvfcp_4[0]\);
    
    hdxtpkktfvz_0 : OR2B
      port map(A => N_290, B => N_268, Y => hdxtpkktfvz);
    
    \jzzdfrmzwdj_ns_i_o2[9]\ : NOR2B
      port map(A => \jzzdfrmzwdj[6]_net_1\, B => ADC_BUSY_net, Y
         => N_281);
    
    bksnhfwfshc_2_sqmuxa_0_a2 : NAND2
      port map(A => ASSC_RAM_DO_B_net_busnet_6, B => 
        ASSC_RAM_DO_B_net_busnet_7, Y => N_311);
    
    \pfkhhxxsrzp[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_7, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => ADC_MODE_net_busnet_2);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I2_G0N : NOR2A
      port map(A => \hpvbctcvfcp[2]_net_1\, B => N_244, Y => N126);
    
    \svpqbbcnvqz[0]\ : OR3
      port map(A => N_283, B => \ddvbdtxtbpx_i_1_0\, C => 
        \jzzdfrmzwdj[5]_net_1\, Y => ASSC_RAM_ADDR_B_net_busnet_0);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I4_G0N : OR2A
      port map(A => \hpvbctcvfcp[4]_net_1\, B => N_244, Y => N132);
    
    \mksbfqnmmgw[5]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_5, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_5);
    
    \bnrsdrtmtsg[1]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[1]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_4);
    
    \jzzdfrmzwdj_0[12]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[3]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => un1_Analog_inst_5_0);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[7]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_334, Y => 
        \hpvbctcvfcp_4[7]\);
    
    \ptxbvztnpnf[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_1, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_1);
    
    ddvbdtxtbpx_i : NOR3A
      port map(A => ddvbdtxtbpx_i_1, B => N_283, C => 
        \ddvbdtxtbpx_i_1_0\, Y => N_250_i_0);
    
    \ksbhwjctscp[4]\ : MX2
      port map(A => INIT_ADDR_net(4), B => 
        EV_ASSCADDR_net_busnet_4, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_4);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    un1_cfxfrwgjccr_4_0_o2 : NOR2B
      port map(A => \jzzdfrmzwdj_0[14]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_8, Y => N_261_i_0);
    
    zgzrtwwghwq_1_sqmuxa_i_a2_0 : NOR2
      port map(A => \hpvbctcvfcp[7]_net_1\, B => 
        \hpvbctcvfcp[6]_net_1\, Y => 
        \zgzrtwwghwq_1_sqmuxa_i_a2_0\);
    
    znbkwkbspdc_31_i_o4 : OR2
      port map(A => \jzzdfrmzwdj[0]_net_1\, B => N_259, Y => 
        N_269);
    
    \svpqbbcnvqz_0[2]\ : NOR2
      port map(A => \jzzdfrmzwdj[10]_net_1\, B => 
        \jzzdfrmzwdj[11]_net_1\, Y => \svpqbbcnvqz_0[2]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[0]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[1]\, B => 
        ASSC_RAM_DO_B_net_busnet_0, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_327);
    
    \ptxbvztnpnf[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_3, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_3);
    
    \bcmkdjqtngz\ : DFN1E0C0
      port map(D => \bcmkdjqtngz_1\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \un1_cfxfrwgjccr_1\, Q => bcmkdjqtngz);
    
    \hgqdwrxvgzm_2[4]\ : MX2
      port map(A => \hgqdwrxvgzm[4]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_4, S => \jzzdfrmzwdj[14]_net_1\, 
        Y => \hgqdwrxvgzm_2[4]_net_1\);
    
    \mksbfqnmmgw[7]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_7, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_7);
    
    \bnrsdrtmtsg[0]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[0]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_3);
    
    \ptxbvztnpnf[6]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_6, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_6);
    
    \dbcvwwhvvwh[7]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_7, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_7);
    
    \jzzdfrmzwdj_ns_i[6]\ : NOR2B
      port map(A => INIT_DONE_net, B => \jzzdfrmzwdj[10]_net_1\, 
        Y => \jzzdfrmzwdj_ns_i[6]_net_1\);
    
    \dspfgfmqhwh[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_0, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => un1_Analog_inst_5_0, 
        Q => \dspfgfmqhwh[0]_net_1\);
    
    \jzzdfrmzwdj_ns_i[15]\ : OA1C
      port map(A => N_268, B => \jzzdfrmzwdj[0]_net_1\, C => 
        \jzzdfrmzwdj_ns_i_0[15]_net_1\, Y => 
        \jzzdfrmzwdj_ns_i[15]_net_1\);
    
    \dbcvwwhvvwh[4]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_4, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_4);
    
    \jzzdfrmzwdj_ns_i[11]\ : NOR2B
      port map(A => INIT_DONE_net, B => \jzzdfrmzwdj[5]_net_1\, Y
         => \jzzdfrmzwdj_ns_i[11]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I29_Y : AX1D
      port map(A => N138, B => N156, C => ADD_8x8_medium_I29_Y_0, 
        Y => \un1_zgzrtwwghwq_1_sqmuxa_i[8]\);
    
    \hgqdwrxvgzm[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_0, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[0]_net_1\);
    
    \ksbhwjctscp[3]\ : MX2
      port map(A => INIT_ADDR_net(3), B => 
        EV_ASSCADDR_net_busnet_3, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_3);
    
    bwngcbddzsh_0_sqmuxa : NOR3C
      port map(A => \bwngcbddzsh_0_sqmuxa_2\, B => 
        \bwngcbddzsh_0_sqmuxa_0\, C => \bcmkdjqtngz_1\, Y => 
        \bwngcbddzsh_0_sqmuxa\);
    
    \ptxbvztnpnf[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_2, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_2);
    
    \jzzdfrmzwdj_ns_o4[0]\ : NAND2
      port map(A => N_302, B => N_303, Y => bksnhfwfshc_6_sqmuxa);
    
    un1_cfxfrwgjccr_1 : NOR2A
      port map(A => \bcmkdjqtngz_1\, B => un1_Analog_inst_5_0, Y
         => \un1_cfxfrwgjccr_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I23_Y : XNOR3
      port map(A => N_244_0, B => \hpvbctcvfcp[1]_net_1\, C => 
        N120, Y => \un1_zgzrtwwghwq_1_sqmuxa[2]\);
    
    \jzzdfrmzwdj_ns_i_0[14]\ : NOR2B
      port map(A => N_288, B => INIT_DONE_net, Y => 
        \jzzdfrmzwdj_ns_i_0[14]_net_1\);
    
    un1_cfxfrwgjccr_12 : AOI1
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \un1_cfxfrwgjccr_12_0\, Y => \un1_cfxfrwgjccr_12\);
    
    un6_bdbpcvshhqt : OR2A
      port map(A => \un6_bdbpcvshhqt_1\, B => EV_DONE_net, Y => 
        N_359);
    
    un1_cfxfrwgjccr_4_0_a4 : NOR2A
      port map(A => INIT_DONE_net, B => N_301, Y => N_286);
    
    \jzzdfrmzwdj_ns_i[5]\ : NOR2B
      port map(A => INIT_DONE_net, B => \jzzdfrmzwdj[11]_net_1\, 
        Y => \jzzdfrmzwdj_ns_i[5]_net_1\);
    
    \hgqdwrxvgzm[4]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_4, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[4]_net_1\);
    
    \jzzdfrmzwdj_ns_i[7]\ : OA1A
      port map(A => N_244, B => \jzzdfrmzwdj[9]_net_1\, C => 
        INIT_DONE_net, Y => \jzzdfrmzwdj_ns_i[7]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I22_Y : NOR2
      port map(A => N147, B => N126, Y => N168);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[1]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[2]\, B => 
        ASSC_RAM_DO_B_net_busnet_1, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_328);
    
    \bnrsdrtmtsg[2]\ : DFN1E0C0
      port map(D => \bnrsdrtmtsg_5[2]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \un1_cfxfrwgjccr_12\, Q => 
        ASSC_RAM_ADDR_B_net_busnet_5);
    
    \mksbfqnmmgw[4]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_4, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_4);
    
    \jzzdfrmzwdj_ns_i_o4[1]\ : OR2B
      port map(A => \jzzdfrmzwdj[15]_net_1\, B => \bksczsjcvgb\, 
        Y => N_282);
    
    \svpqbbcnvqz[2]\ : OR3A
      port map(A => \svpqbbcnvqz_0[2]_net_1\, B => 
        un1_Analog_inst_5_0, C => \jzzdfrmzwdj[4]_net_1\, Y => 
        ASSC_RAM_ADDR_B_net_busnet_2);
    
    \jzzdfrmzwdj_ns_i_o2[2]\ : OR2A
      port map(A => \jzzdfrmzwdj_0[14]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_8, Y => N_275);
    
    \jzzdfrmzwdj_ns_i[4]\ : NOR2B
      port map(A => un1_Analog_inst_5_0, B => INIT_DONE_net, Y
         => \jzzdfrmzwdj_ns_i[4]_net_1\);
    
    \mksbfqnmmgw[1]\ : MX2
      port map(A => ADC_RESULT_net_busnet_1, B => 
        ADC_RESULT_net_busnet_10, S => \jzzdfrmzwdj[4]_net_1\, Y
         => ASSC_RAM_DI_B_net_busnet_1);
    
    \jzzdfrmzwdj_ns[0]\ : OR3A
      port map(A => INIT_DONE_net, B => 
        \jzzdfrmzwdj_ns_0[0]_net_1\, C => bksnhfwfshc_6_sqmuxa, Y
         => \jzzdfrmzwdj_ns[0]_net_1\);
    
    \dbcvwwhvvwh[6]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_6, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_6);
    
    \hpvbctcvfcp[7]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[7]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[7]_net_1\);
    
    \dspfgfmqhwh[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_2, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => un1_Analog_inst_5_0, 
        Q => \dspfgfmqhwh[2]_net_1\);
    
    ddvbdtxtbpx_i_2 : NOR2
      port map(A => \jzzdfrmzwdj[13]_net_1\, B => 
        \jzzdfrmzwdj[11]_net_1\, Y => N_250_2);
    
    \jzzdfrmzwdj_ns_0[0]\ : OR2
      port map(A => N_291, B => N_259, Y => 
        \jzzdfrmzwdj_ns_0[0]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I1_G0N : OR2A
      port map(A => \hpvbctcvfcp[1]_net_1\, B => N_244, Y => N123);
    
    \hpvbctcvfcp[5]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[5]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[5]_net_1\);
    
    \hgqdwrxvgzm[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_2, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[2]_net_1\);
    
    jdhgstfqkjm_2_i : INV
      port map(A => \jdhgstfqkjm_2\, Y => \jdhgstfqkjm_2_i\);
    
    \svpqbbcnvqz[1]\ : OR3A
      port map(A => N_250_2, B => \jzzdfrmzwdj[5]_net_1\, C => 
        \jzzdfrmzwdj[10]_net_1\, Y => 
        ASSC_RAM_ADDR_B_net_busnet_1);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I27_Y : XNOR3
      port map(A => N_244_0, B => \hpvbctcvfcp[5]_net_1\, C => 
        N166, Y => \un1_zgzrtwwghwq_1_sqmuxa[6]\);
    
    un2_crgqqkcrfvm : OR3A
      port map(A => INIT_DONE_net, B => qvkpfznsfjx_net_1, C => 
        \crgqqkcrfvm\, Y => \un2_crgqqkcrfvm\);
    
    \jzzdfrmzwdj_ns_i[13]\ : OR3C
      port map(A => N_359, B => N_356, C => INIT_DONE_net, Y => 
        \jzzdfrmzwdj_ns_i[13]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[6]\ : MX2A
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa_i[7]\, B => 
        ASSC_RAM_DO_B_net_busnet_6, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_333);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I6_G0N : NOR2A
      port map(A => \hpvbctcvfcp[6]_net_1\, B => N_244, Y => N138);
    
    un1_bksnhfwfshc_1_sqmuxa_1_0_o2 : OR2B
      port map(A => \jzzdfrmzwdj[1]_net_1\, B => \bksczsjcvgb\, Y
         => N_260);
    
    \jzzdfrmzwdj[4]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[11]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[4]_net_1\);
    
    \ksbhwjctscp[7]\ : MX2
      port map(A => INIT_ADDR_net(7), B => 
        EV_ASSCADDR_net_busnet_7, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_7);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    \zpsvrxkccbh_hpvbctcvfcp_4[3]\ : MX2
      port map(A => \un1_zgzrtwwghwq_1_sqmuxa[4]\, B => 
        ASSC_RAM_DO_B_net_busnet_3, S => \jzzdfrmzwdj[9]_net_1\, 
        Y => N_330);
    
    ddvbdtxtbpx_i_1_0 : OR2
      port map(A => \jzzdfrmzwdj[10]_net_1\, B => 
        un1_Analog_inst_5_0, Y => \ddvbdtxtbpx_i_1_0\);
    
    hdxtpkktfvz_0_o2 : XAI1
      port map(A => ASSC_RAM_DO_B_net_busnet_6, B => 
        ASSC_RAM_DO_B_net_busnet_7, C => N_261_i_0, Y => N_268);
    
    zwtzpwdfptq_un6_kftxkzdmgnn : OR2B
      port map(A => un6_kftxkzdmgnn_0, B => fskhwddcbbg_1_sqmuxa, 
        Y => un1_Analog_assc_wrapper_inst);
    
    zgzrtwwghwq_1_sqmuxa_i_a2 : OR3C
      port map(A => \zgzrtwwghwq_1_sqmuxa_i_a2_0\, B => 
        \zgzrtwwghwq_1_sqmuxa_i_a2_1\, C => 
        \zgzrtwwghwq_1_sqmuxa_i_a2_4\, Y => N_314);
    
    \jzzdfrmzwdj[3]\ : DFN1P0
      port map(D => \jzzdfrmzwdj_ns_i[12]_net_1\, CLK => 
        SYS_CLK_int, PRE => SYS_RESET_c, Q => 
        \jzzdfrmzwdj_i_0[3]\);
    
    \hpvbctcvfcp[1]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[1]_net_1\);
    
    \jzzdfrmzwdj_ns_i_0[15]\ : AO1C
      port map(A => \jzzdfrmzwdj_0[14]_net_1\, B => \znbkwkbspdc\, 
        C => INIT_DONE_net, Y => \jzzdfrmzwdj_ns_i_0[15]_net_1\);
    
    \jzzdfrmzwdj_0[14]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj_0[14]_net_1\);
    
    \jzzdfrmzwdj_ns_i[14]\ : OA1A
      port map(A => N_316, B => \jzzdfrmzwdj[1]_net_1\, C => 
        \jzzdfrmzwdj_ns_i_0[14]_net_1\, Y => N_234_i_0);
    
    \ksbhwjctscp[8]\ : MX2
      port map(A => INIT_ADDR_net(8), B => 
        EV_ASSCADDR_net_busnet_8, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_8);
    
    \hpvbctcvfcp[2]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[2]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I26_Y : AX1
      port map(A => N147, B => N145, C => ADD_8x8_medium_I26_Y_0, 
        Y => \un1_zgzrtwwghwq_1_sqmuxa[5]\);
    
    \hgqdwrxvgzm[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_3, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[3]_net_1\);
    
    \jzzdfrmzwdj_ns_i_o4[2]\ : NOR3B
      port map(A => \jzzdfrmzwdj_0[14]_net_1\, B => N_258, C => 
        ASSC_RAM_DO_B_net_busnet_8, Y => N_283);
    
    \jzzdfrmzwdj[7]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns[8]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \jzzdfrmzwdj[7]_net_1\);
    
    \jzzdfrmzwdj[0]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[15]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[0]_net_1\);
    
    \dbcvwwhvvwh[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_3, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_3);
    
    \jzzdfrmzwdj[12]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[3]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[12]_net_1\);
    
    fsrxhtjthgw_i_a2_0 : OR2A
      port map(A => N_359, B => \jzzdfrmzwdj[1]_net_1\, Y => 
        N_304);
    
    zgzrtwwghwq_1_sqmuxa_i_a2_4 : NOR3A
      port map(A => \zgzrtwwghwq_1_sqmuxa_i_a2_2\, B => 
        \hpvbctcvfcp[0]_net_1\, C => \hpvbctcvfcp[1]_net_1\, Y
         => \zgzrtwwghwq_1_sqmuxa_i_a2_4\);
    
    \mksbfqnmmgw[8]\ : NOR2A
      port map(A => ADC_RESULT_net_busnet_8, B => 
        \jzzdfrmzwdj[4]_net_1\, Y => ASSC_RAM_DI_B_net_busnet_8);
    
    \jzzdfrmzwdj_ns_i[12]\ : OR2B
      port map(A => INIT_DONE_net, B => \jzzdfrmzwdj[4]_net_1\, Y
         => \jzzdfrmzwdj_ns_i[12]_net_1\);
    
    bwngcbddzsh_0_sqmuxa_0 : NOR2
      port map(A => \dspfgfmqhwh[4]_net_1\, B => 
        \dspfgfmqhwh[3]_net_1\, Y => \bwngcbddzsh_0_sqmuxa_0\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I12_Y : OR2A
      port map(A => N123, B => N120, Y => N147);
    
    hdxtpkktfvz_0_a4 : OR2A
      port map(A => N_356, B => N_359, Y => N_290);
    
    \jzzdfrmzwdj_ns_a4[8]\ : NOR2B
      port map(A => INIT_DONE_net, B => \ADC_START_net\, Y => 
        \jzzdfrmzwdj_ns[8]\);
    
    \bnrsdrtmtsg_5[4]\ : NOR3C
      port map(A => \jhkbkqjtkbs\, B => \znbmnfdbzvr\, C => 
        \hgqdwrxvgzm_2[4]_net_1\, Y => \bnrsdrtmtsg_5[4]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[4]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_331, Y => 
        \hpvbctcvfcp_4[4]\);
    
    jdhgstfqkjm_2_1 : NOR3B
      port map(A => N_288, B => INIT_DONE_net, C => \wwhrbsjdjpn\, 
        Y => \jdhgstfqkjm_2_1\);
    
    bksnhfwfshc_1_m : NOR2
      port map(A => \znbmnfdbzvr\, B => N_282, Y => 
        \bksnhfwfshc_1_m\);
    
    un4_wkpfnwqwgcb : OR2
      port map(A => \un2_wkpfnwqwgcb\, B => \jdhgstfqkjm_2\, Y
         => \un4_wkpfnwqwgcb\);
    
    gtxqsppgcmn : DFN1C0
      port map(D => \zbhmfptrcmn\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \gtxqsppgcmn\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I26_Y_0 : XOR2
      port map(A => \hpvbctcvfcp[4]_net_1\, B => N_244_0, Y => 
        ADD_8x8_medium_I26_Y_0);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I17_Y : OR3B
      port map(A => N145, B => ADD_8x8_medium_I17_Y_0, C => N147, 
        Y => N156);
    
    \pfkhhxxsrzp[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_8, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => ADC_MODE_net_busnet_3);
    
    \jzzdfrmzwdj_ns_a2[0]\ : OR3A
      port map(A => \jzzdfrmzwdj_0[14]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_8, C => N_258, Y => N_302);
    
    \hgqdwrxvgzm_2[1]\ : MX2
      port map(A => \hgqdwrxvgzm[1]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_1, S => 
        \jzzdfrmzwdj_0[14]_net_1\, Y => \hgqdwrxvgzm_2[1]_net_1\);
    
    zgzrtwwghwq_0_sqmuxa_0_a2 : NOR2A
      port map(A => \jzzdfrmzwdj[8]_net_1\, B => N_314, Y => 
        \ADC_START_net\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I10_Y : OA1C
      port map(A => \hpvbctcvfcp[3]_net_1\, B => N_244, C => N126, 
        Y => N145);
    
    \jzzdfrmzwdj[11]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[4]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[11]_net_1\);
    
    \jzzdfrmzwdj_ns_a4[0]\ : NOR2B
      port map(A => \znbkwkbspdc\, B => \jzzdfrmzwdj[0]_net_1\, Y
         => N_291);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I21_Y : OR3B
      port map(A => N145, B => N132, C => N147, Y => N166);
    
    hbxwhvjzqbt_iv : OAI1
      port map(A => INIT_ASSC_WEN_net, B => INIT_DONE_net, C => 
        un1_Analog_assc_wrapper_inst, Y => ASSC_RAM_CSN_A_net);
    
    \jzzdfrmzwdj[14]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[14]_net_1\);
    
    zgzrtwwghwq_1_sqmuxa_i_a2_1 : NOR2
      port map(A => \hpvbctcvfcp[5]_net_1\, B => 
        \hpvbctcvfcp[4]_net_1\, Y => 
        \zgzrtwwghwq_1_sqmuxa_i_a2_1\);
    
    \jzzdfrmzwdj_ns_i_0_tz[7]\ : OR2B
      port map(A => \jzzdfrmzwdj[8]_net_1\, B => N_314, Y => 
        N_244);
    
    \dbcvwwhvvwh[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_1, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[13]_net_1\, Q => ADC_TVC_net_busnet_1);
    
    znbmnfdbzvr : DFN1C0
      port map(D => \znbmnfdbzvr_33\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \znbmnfdbzvr\);
    
    \pfkhhxxsrzp[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_5, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[12]_net_1\, Q => ADC_MODE_net_busnet_0);
    
    jdhgstfqkjm : DFN1P0
      port map(D => \jdhgstfqkjm_2\, CLK => SYS_CLK_int, PRE => 
        SYS_RESET_c, Q => ADC_RESET_net);
    
    \hgqdwrxvgzm[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_1, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[14]_net_1\, Q => \hgqdwrxvgzm[1]_net_1\);
    
    \jzzdfrmzwdj_ns_a2_0[0]\ : OR2A
      port map(A => N_261_i_0, B => N_311, Y => N_303);
    
    un1_bksnhfwfshc_1_sqmuxa_i_a2 : OA1C
      port map(A => N_261_i_0, B => N_258, C => 
        \jzzdfrmzwdj[15]_net_1\, Y => N_316);
    
    \jzzdfrmzwdj[6]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[9]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[6]_net_1\);
    
    \jzzdfrmzwdj[5]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns[10]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \jzzdfrmzwdj[5]_net_1\);
    
    \jzzdfrmzwdj[15]\ : DFN1P0
      port map(D => \jzzdfrmzwdj_ns[0]_net_1\, CLK => SYS_CLK_int, 
        PRE => SYS_RESET_c, Q => \jzzdfrmzwdj[15]_net_1\);
    
    \jzzdfrmzwdj_ns_i_0_tz_0[7]\ : OR2B
      port map(A => \jzzdfrmzwdj[8]_net_1\, B => N_314, Y => 
        N_244_0);
    
    zbhmfptrcmn : DFN1C0
      port map(D => bksnhfwfshc_2_sqmuxa, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \zbhmfptrcmn\);
    
    \mksbfqnmmgw[0]\ : MX2
      port map(A => ADC_RESULT_net_busnet_0, B => 
        ADC_RESULT_net_busnet_9, S => \jzzdfrmzwdj[4]_net_1\, Y
         => ASSC_RAM_DI_B_net_busnet_0);
    
    \jzzdfrmzwdj[13]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[2]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[13]_net_1\);
    
    \jzzdfrmzwdj_ns_i[2]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_283, Y => 
        \jzzdfrmzwdj_ns_i[2]_net_1\);
    
    \ksbhwjctscp[2]\ : MX2
      port map(A => INIT_ADDR_net(2), B => 
        EV_ASSCADDR_net_busnet_2, S => INIT_DONE_net, Y => 
        ASSC_RAM_ADDR_A_net_busnet_2);
    
    znbmnfdbzvr_33 : OR2
      port map(A => \znbmnfdbzvr\, B => \jhkbkqjtkbs\, Y => 
        \znbmnfdbzvr_33\);
    
    \hpvbctcvfcp[4]\ : DFN1C0
      port map(D => \hpvbctcvfcp_4[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \hpvbctcvfcp[4]_net_1\);
    
    \zpsvrxkccbh_hpvbctcvfcp_4_r[2]\ : NOR2B
      port map(A => INIT_DONE_net, B => N_329, Y => 
        \hpvbctcvfcp_4[2]\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I24_Y : XNOR2
      port map(A => ADD_8x8_medium_I24_Y_0, B => N147, Y => 
        \un1_zgzrtwwghwq_1_sqmuxa[3]\);
    
    \jzzdfrmzwdj[9]\ : DFN1C0
      port map(D => \jzzdfrmzwdj_ns_i[6]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \jzzdfrmzwdj[9]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I28_Y : XOR3
      port map(A => N_244_0, B => \hpvbctcvfcp[6]_net_1\, C => 
        N156, Y => \un1_zgzrtwwghwq_1_sqmuxa_i[7]\);
    
    bksnhfwfshc_0_sqmuxa_3_i_0_o2 : OR2B
      port map(A => \jzzdfrmzwdj_i_0[3]\, B => 
        \jzzdfrmzwdj_i_0[2]\, Y => N_356);
    
    znbkwkbspdc : DFN1C0
      port map(D => \znbkwkbspdc_31_i\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \znbkwkbspdc\);
    
    \jzzdfrmzwdj_ns_a4[10]\ : NOR3B
      port map(A => \jzzdfrmzwdj[6]_net_1\, B => INIT_DONE_net, C
         => ADC_BUSY_net, Y => \jzzdfrmzwdj_ns[10]\);
    
    jngpzgpmcms : OR2A
      port map(A => INIT_ASSC_WEN_net, B => INIT_DONE_net, Y => 
        ASSC_RAM_RW_A_net);
    
    \hgqdwrxvgzm_2[0]\ : MX2
      port map(A => \hgqdwrxvgzm[0]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_0, S => \jzzdfrmzwdj[14]_net_1\, 
        Y => \hgqdwrxvgzm_2[0]_net_1\);
    
    \qvkpfznsfjx\ : DFN1C0
      port map(D => hdxtpkktfvz, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => qvkpfznsfjx_net_1);
    
    \hgqdwrxvgzm_2[2]\ : MX2
      port map(A => \hgqdwrxvgzm[2]_net_1\, B => 
        ASSC_RAM_DO_B_net_busnet_2, S => 
        \jzzdfrmzwdj_0[14]_net_1\, Y => \hgqdwrxvgzm_2[2]_net_1\);
    
    un1_zgzrtwwghwq_1_sqmuxa_ADD_8x8_medium_I29_Y_0 : XOR2
      port map(A => \hpvbctcvfcp[7]_net_1\, B => N_244_0, Y => 
        ADD_8x8_medium_I29_Y_0);
    
    \ptxbvztnpnf[5]\ : DFN1E1C0
      port map(D => ASSC_RAM_DO_B_net_busnet_5, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \jzzdfrmzwdj[11]_net_1\, Q => ADC_STC_net_busnet_5);
    
    un1_bksnhfwfshc_1_sqmuxa_1_0_o4 : OR2B
      port map(A => N_290, B => N_260, Y => N_259);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity ASSC is

    port( dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          SYS_CLK_int                  : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic;
          INIT_DONE_net                : in    std_logic;
          EV_ASSCADDR_net_busnet_2     : in    std_logic;
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          TR_DONE_net_i_0              : in    std_logic;
          TR_TRFLAG_net                : in    std_logic;
          EV_EVFLAG_net                : in    std_logic;
          EV_DONE_net                  : in    std_logic;
          fskhwddcbbg_1_sqmuxa         : in    std_logic;
          N_250_i_0                    : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ADC_BUSY_net                 : in    std_logic;
          qvkpfznsfjx                  : out   std_logic;
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          ADC_RESULT_net_busnet_0      : in    std_logic;
          ADC_RESULT_net_busnet_9      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_1      : in    std_logic;
          ADC_RESULT_net_busnet_10     : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_2      : in    std_logic;
          ADC_RESULT_net_busnet_11     : in    std_logic;
          ASSC_RAM_CSN_A_net           : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic;
          un1_Analog_inst_1            : out   std_logic;
          ASSC_RAM_RW_A_net            : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_8     : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ADC_START_net                : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic;
          ADC_CALIBRATE_net            : in    std_logic;
          ADC_RESET_net                : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic
        );

end ASSC;

architecture DEF_ARCH of ASSC is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component fmvgpwbdcxs
    port( INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          ADC_RESET_net                : out   std_logic;
          ADC_CALIBRATE_net            : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          ADC_START_net                : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_8     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_RW_A_net            : out   std_logic;
          un1_Analog_inst_1            : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic := 'U';
          ASSC_RAM_CSN_A_net           : out   std_logic;
          ADC_RESULT_net_busnet_11     : in    std_logic := 'U';
          ADC_RESULT_net_busnet_2      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_10     : in    std_logic := 'U';
          ADC_RESULT_net_busnet_1      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_9      : in    std_logic := 'U';
          ADC_RESULT_net_busnet_0      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          qvkpfznsfjx                  : out   std_logic;
          ADC_BUSY_net                 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          N_250_i_0                    : out   std_logic;
          fskhwddcbbg_1_sqmuxa         : in    std_logic := 'U';
          EV_DONE_net                  : in    std_logic := 'U';
          EV_EVFLAG_net                : in    std_logic := 'U';
          TR_TRFLAG_net                : in    std_logic := 'U';
          TR_DONE_net_i_0              : in    std_logic := 'U';
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : in    std_logic := 'U';
          INIT_DONE_net                : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U'
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : fmvgpwbdcxs
	Use entity work.fmvgpwbdcxs(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    u_fmvgpwbdcxs : fmvgpwbdcxs
      port map(INIT_ADDR_net(8) => INIT_ADDR_net(8), 
        INIT_ADDR_net(7) => INIT_ADDR_net(7), INIT_ADDR_net(6)
         => INIT_ADDR_net(6), INIT_ADDR_net(5) => 
        INIT_ADDR_net(5), INIT_ADDR_net(4) => INIT_ADDR_net(4), 
        INIT_ADDR_net(3) => INIT_ADDR_net(3), INIT_ADDR_net(2)
         => INIT_ADDR_net(2), INIT_ADDR_net(1) => 
        INIT_ADDR_net(1), INIT_ADDR_net(0) => INIT_ADDR_net(0), 
        dspfgfmqhwh(4) => dspfgfmqhwh(4), dspfgfmqhwh(3) => 
        dspfgfmqhwh(3), dspfgfmqhwh(2) => dspfgfmqhwh(2), 
        dspfgfmqhwh(1) => dspfgfmqhwh(1), dspfgfmqhwh(0) => 
        dspfgfmqhwh(0), ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, ADC_MODE_net_busnet_3 => 
        ADC_MODE_net_busnet_3, ADC_MODE_net_busnet_2 => 
        ADC_MODE_net_busnet_2, ADC_MODE_net_busnet_1 => 
        ADC_MODE_net_busnet_1, ADC_MODE_net_busnet_0 => 
        ADC_MODE_net_busnet_0, ADC_TVC_net_busnet_7 => 
        ADC_TVC_net_busnet_7, ADC_TVC_net_busnet_6 => 
        ADC_TVC_net_busnet_6, ADC_TVC_net_busnet_5 => 
        ADC_TVC_net_busnet_5, ADC_TVC_net_busnet_4 => 
        ADC_TVC_net_busnet_4, ADC_TVC_net_busnet_3 => 
        ADC_TVC_net_busnet_3, ADC_TVC_net_busnet_2 => 
        ADC_TVC_net_busnet_2, ADC_TVC_net_busnet_1 => 
        ADC_TVC_net_busnet_1, ADC_TVC_net_busnet_0 => 
        ADC_TVC_net_busnet_0, ADC_STC_net_busnet_7 => 
        ADC_STC_net_busnet_7, ADC_STC_net_busnet_6 => 
        ADC_STC_net_busnet_6, ADC_STC_net_busnet_5 => 
        ADC_STC_net_busnet_5, ADC_STC_net_busnet_4 => 
        ADC_STC_net_busnet_4, ADC_STC_net_busnet_3 => 
        ADC_STC_net_busnet_3, ADC_STC_net_busnet_2 => 
        ADC_STC_net_busnet_2, ADC_STC_net_busnet_1 => 
        ADC_STC_net_busnet_1, ADC_STC_net_busnet_0 => 
        ADC_STC_net_busnet_0, bcmkdjqtngz => bcmkdjqtngz, 
        TM_STB_net_0 => TM_STB_net_0, ADC_PDOWN_net => 
        ADC_PDOWN_net, ADC_RESET_net => ADC_RESET_net, 
        ADC_CALIBRATE_net => ADC_CALIBRATE_net, 
        ASSC_RAM_DO_B_net_busnet_5 => ASSC_RAM_DO_B_net_busnet_5, 
        ASSC_RAM_DO_B_net_busnet_4 => ASSC_RAM_DO_B_net_busnet_4, 
        ASSC_RAM_DO_B_net_busnet_0 => ASSC_RAM_DO_B_net_busnet_0, 
        ADC_START_net => ADC_START_net, 
        ASSC_RAM_ADDR_B_net_busnet_0 => 
        ASSC_RAM_ADDR_B_net_busnet_0, ASSC_RAM_DO_B_net_busnet_3
         => ASSC_RAM_DO_B_net_busnet_3, 
        ASSC_RAM_DO_B_net_busnet_2 => ASSC_RAM_DO_B_net_busnet_2, 
        EV_ASSCADDR_net_busnet_8 => EV_ASSCADDR_net_busnet_8, 
        ASSC_RAM_ADDR_A_net_busnet_8 => 
        ASSC_RAM_ADDR_A_net_busnet_8, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_A_net_busnet_7 => 
        ASSC_RAM_ADDR_A_net_busnet_7, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_A_net_busnet_6 => 
        ASSC_RAM_ADDR_A_net_busnet_6, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_A_net_busnet_5 => 
        ASSC_RAM_ADDR_A_net_busnet_5, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_A_net_busnet_4 => 
        ASSC_RAM_ADDR_A_net_busnet_4, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_3 => 
        ASSC_RAM_ADDR_A_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_2 => 
        ASSC_RAM_ADDR_A_net_busnet_2, 
        ASSC_RAM_ADDR_A_net_busnet_1 => 
        ASSC_RAM_ADDR_A_net_busnet_1, 
        ASSC_RAM_ADDR_A_net_busnet_0 => 
        ASSC_RAM_ADDR_A_net_busnet_0, ASSC_RAM_DO_B_net_busnet_1
         => ASSC_RAM_DO_B_net_busnet_1, ASSC_RAM_RW_A_net => 
        ASSC_RAM_RW_A_net, un1_Analog_inst_1 => un1_Analog_inst_1, 
        ADC_RESULT_net_busnet_8 => ADC_RESULT_net_busnet_8, 
        ASSC_RAM_DI_B_net_busnet_8 => ASSC_RAM_DI_B_net_busnet_8, 
        ADC_RESULT_net_busnet_7 => ADC_RESULT_net_busnet_7, 
        ASSC_RAM_DI_B_net_busnet_7 => ASSC_RAM_DI_B_net_busnet_7, 
        ADC_RESULT_net_busnet_6 => ADC_RESULT_net_busnet_6, 
        ASSC_RAM_DI_B_net_busnet_6 => ASSC_RAM_DI_B_net_busnet_6, 
        ADC_RESULT_net_busnet_5 => ADC_RESULT_net_busnet_5, 
        ASSC_RAM_DI_B_net_busnet_5 => ASSC_RAM_DI_B_net_busnet_5, 
        ADC_RESULT_net_busnet_4 => ADC_RESULT_net_busnet_4, 
        ASSC_RAM_DI_B_net_busnet_4 => ASSC_RAM_DI_B_net_busnet_4, 
        ADC_RESULT_net_busnet_3 => ADC_RESULT_net_busnet_3, 
        ASSC_RAM_DI_B_net_busnet_3 => ASSC_RAM_DI_B_net_busnet_3, 
        INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, 
        ASSC_RAM_CSN_A_net => ASSC_RAM_CSN_A_net, 
        ADC_RESULT_net_busnet_11 => ADC_RESULT_net_busnet_11, 
        ADC_RESULT_net_busnet_2 => ADC_RESULT_net_busnet_2, 
        ASSC_RAM_DI_B_net_busnet_2 => ASSC_RAM_DI_B_net_busnet_2, 
        ADC_RESULT_net_busnet_10 => ADC_RESULT_net_busnet_10, 
        ADC_RESULT_net_busnet_1 => ADC_RESULT_net_busnet_1, 
        ASSC_RAM_DI_B_net_busnet_1 => ASSC_RAM_DI_B_net_busnet_1, 
        ADC_RESULT_net_busnet_9 => ADC_RESULT_net_busnet_9, 
        ADC_RESULT_net_busnet_0 => ADC_RESULT_net_busnet_0, 
        ASSC_RAM_DI_B_net_busnet_0 => ASSC_RAM_DI_B_net_busnet_0, 
        qvkpfznsfjx => qvkpfznsfjx, ADC_BUSY_net => ADC_BUSY_net, 
        ASSC_RAM_ADDR_B_net_busnet_1 => 
        ASSC_RAM_ADDR_B_net_busnet_1, 
        ASSC_RAM_ADDR_B_net_busnet_2 => 
        ASSC_RAM_ADDR_B_net_busnet_2, N_250_i_0 => N_250_i_0, 
        fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, EV_DONE_net
         => EV_DONE_net, EV_EVFLAG_net => EV_EVFLAG_net, 
        TR_TRFLAG_net => TR_TRFLAG_net, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, ASSC_RAM_WR_BUSY_B_net => 
        ASSC_RAM_WR_BUSY_B_net, EV_ASSCADDR_net_busnet_2 => 
        EV_ASSCADDR_net_busnet_2, INIT_DONE_net => INIT_DONE_net, 
        ASSC_RAM_DO_B_net_busnet_8 => ASSC_RAM_DO_B_net_busnet_8, 
        ASSC_RAM_DO_B_net_busnet_7 => ASSC_RAM_DO_B_net_busnet_7, 
        ASSC_RAM_DO_B_net_busnet_6 => ASSC_RAM_DO_B_net_busnet_6, 
        SYS_RESET_c => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_assc_wrapper is

    port( INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          ADC_RESET_net                : out   std_logic;
          ADC_CALIBRATE_net            : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic;
          ADC_START_net                : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic;
          EV_ASSCADDR_net_busnet_8     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic;
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic;
          ASSC_RAM_RW_A_net            : out   std_logic;
          un1_Analog_inst_1            : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic;
          ASSC_RAM_CSN_A_net           : out   std_logic;
          ADC_RESULT_net_busnet_11     : in    std_logic;
          ADC_RESULT_net_busnet_2      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_10     : in    std_logic;
          ADC_RESULT_net_busnet_1      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_9      : in    std_logic;
          ADC_RESULT_net_busnet_0      : in    std_logic;
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          qvkpfznsfjx                  : out   std_logic;
          ADC_BUSY_net                 : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          N_250_i_0                    : out   std_logic;
          fskhwddcbbg_1_sqmuxa         : in    std_logic;
          EV_DONE_net                  : in    std_logic;
          EV_EVFLAG_net                : in    std_logic;
          TR_TRFLAG_net                : in    std_logic;
          TR_DONE_net_i_0              : in    std_logic;
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : in    std_logic;
          INIT_DONE_net                : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          SYS_CLK_int                  : in    std_logic
        );

end Analog_assc_wrapper;

architecture DEF_ARCH of Analog_assc_wrapper is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component ASSC
    port( dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          SYS_CLK_int                  : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          INIT_DONE_net                : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_2     : in    std_logic := 'U';
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          TR_DONE_net_i_0              : in    std_logic := 'U';
          TR_TRFLAG_net                : in    std_logic := 'U';
          EV_EVFLAG_net                : in    std_logic := 'U';
          EV_DONE_net                  : in    std_logic := 'U';
          fskhwddcbbg_1_sqmuxa         : in    std_logic := 'U';
          N_250_i_0                    : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ADC_BUSY_net                 : in    std_logic := 'U';
          qvkpfznsfjx                  : out   std_logic;
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          ADC_RESULT_net_busnet_0      : in    std_logic := 'U';
          ADC_RESULT_net_busnet_9      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_1      : in    std_logic := 'U';
          ADC_RESULT_net_busnet_10     : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_2      : in    std_logic := 'U';
          ADC_RESULT_net_busnet_11     : in    std_logic := 'U';
          ASSC_RAM_CSN_A_net           : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic := 'U';
          un1_Analog_inst_1            : out   std_logic;
          ASSC_RAM_RW_A_net            : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_8     : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ADC_START_net                : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          ADC_CALIBRATE_net            : in    std_logic := 'U';
          ADC_RESET_net                : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : ASSC
	Use entity work.ASSC(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    U0 : ASSC
      port map(dspfgfmqhwh(4) => dspfgfmqhwh(4), dspfgfmqhwh(3)
         => dspfgfmqhwh(3), dspfgfmqhwh(2) => dspfgfmqhwh(2), 
        dspfgfmqhwh(1) => dspfgfmqhwh(1), dspfgfmqhwh(0) => 
        dspfgfmqhwh(0), INIT_ADDR_net(8) => INIT_ADDR_net(8), 
        INIT_ADDR_net(7) => INIT_ADDR_net(7), INIT_ADDR_net(6)
         => INIT_ADDR_net(6), INIT_ADDR_net(5) => 
        INIT_ADDR_net(5), INIT_ADDR_net(4) => INIT_ADDR_net(4), 
        INIT_ADDR_net(3) => INIT_ADDR_net(3), INIT_ADDR_net(2)
         => INIT_ADDR_net(2), INIT_ADDR_net(1) => 
        INIT_ADDR_net(1), INIT_ADDR_net(0) => INIT_ADDR_net(0), 
        SYS_CLK_int => SYS_CLK_int, SYS_RESET_c => SYS_RESET_c, 
        ASSC_RAM_DO_B_net_busnet_6 => ASSC_RAM_DO_B_net_busnet_6, 
        ASSC_RAM_DO_B_net_busnet_7 => ASSC_RAM_DO_B_net_busnet_7, 
        ASSC_RAM_DO_B_net_busnet_8 => ASSC_RAM_DO_B_net_busnet_8, 
        INIT_DONE_net => INIT_DONE_net, EV_ASSCADDR_net_busnet_2
         => EV_ASSCADDR_net_busnet_2, ASSC_RAM_WR_BUSY_B_net => 
        ASSC_RAM_WR_BUSY_B_net, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, TR_TRFLAG_net => TR_TRFLAG_net, 
        EV_EVFLAG_net => EV_EVFLAG_net, EV_DONE_net => 
        EV_DONE_net, fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, 
        N_250_i_0 => N_250_i_0, ASSC_RAM_ADDR_B_net_busnet_2 => 
        ASSC_RAM_ADDR_B_net_busnet_2, 
        ASSC_RAM_ADDR_B_net_busnet_1 => 
        ASSC_RAM_ADDR_B_net_busnet_1, ADC_BUSY_net => 
        ADC_BUSY_net, qvkpfznsfjx => qvkpfznsfjx, 
        ASSC_RAM_DI_B_net_busnet_0 => ASSC_RAM_DI_B_net_busnet_0, 
        ADC_RESULT_net_busnet_0 => ADC_RESULT_net_busnet_0, 
        ADC_RESULT_net_busnet_9 => ADC_RESULT_net_busnet_9, 
        ASSC_RAM_DI_B_net_busnet_1 => ASSC_RAM_DI_B_net_busnet_1, 
        ADC_RESULT_net_busnet_1 => ADC_RESULT_net_busnet_1, 
        ADC_RESULT_net_busnet_10 => ADC_RESULT_net_busnet_10, 
        ASSC_RAM_DI_B_net_busnet_2 => ASSC_RAM_DI_B_net_busnet_2, 
        ADC_RESULT_net_busnet_2 => ADC_RESULT_net_busnet_2, 
        ADC_RESULT_net_busnet_11 => ADC_RESULT_net_busnet_11, 
        ASSC_RAM_CSN_A_net => ASSC_RAM_CSN_A_net, 
        INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, 
        ASSC_RAM_DI_B_net_busnet_3 => ASSC_RAM_DI_B_net_busnet_3, 
        ADC_RESULT_net_busnet_3 => ADC_RESULT_net_busnet_3, 
        ASSC_RAM_DI_B_net_busnet_4 => ASSC_RAM_DI_B_net_busnet_4, 
        ADC_RESULT_net_busnet_4 => ADC_RESULT_net_busnet_4, 
        ASSC_RAM_DI_B_net_busnet_5 => ASSC_RAM_DI_B_net_busnet_5, 
        ADC_RESULT_net_busnet_5 => ADC_RESULT_net_busnet_5, 
        ASSC_RAM_DI_B_net_busnet_6 => ASSC_RAM_DI_B_net_busnet_6, 
        ADC_RESULT_net_busnet_6 => ADC_RESULT_net_busnet_6, 
        ASSC_RAM_DI_B_net_busnet_7 => ASSC_RAM_DI_B_net_busnet_7, 
        ADC_RESULT_net_busnet_7 => ADC_RESULT_net_busnet_7, 
        ASSC_RAM_DI_B_net_busnet_8 => ASSC_RAM_DI_B_net_busnet_8, 
        ADC_RESULT_net_busnet_8 => ADC_RESULT_net_busnet_8, 
        un1_Analog_inst_1 => un1_Analog_inst_1, ASSC_RAM_RW_A_net
         => ASSC_RAM_RW_A_net, ASSC_RAM_DO_B_net_busnet_1 => 
        ASSC_RAM_DO_B_net_busnet_1, ASSC_RAM_ADDR_A_net_busnet_0
         => ASSC_RAM_ADDR_A_net_busnet_0, 
        ASSC_RAM_ADDR_A_net_busnet_1 => 
        ASSC_RAM_ADDR_A_net_busnet_1, 
        ASSC_RAM_ADDR_A_net_busnet_2 => 
        ASSC_RAM_ADDR_A_net_busnet_2, 
        ASSC_RAM_ADDR_A_net_busnet_3 => 
        ASSC_RAM_ADDR_A_net_busnet_3, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_4 => 
        ASSC_RAM_ADDR_A_net_busnet_4, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_A_net_busnet_5 => 
        ASSC_RAM_ADDR_A_net_busnet_5, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_A_net_busnet_6 => 
        ASSC_RAM_ADDR_A_net_busnet_6, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_A_net_busnet_7 => 
        ASSC_RAM_ADDR_A_net_busnet_7, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_A_net_busnet_8 => 
        ASSC_RAM_ADDR_A_net_busnet_8, EV_ASSCADDR_net_busnet_8
         => EV_ASSCADDR_net_busnet_8, ASSC_RAM_DO_B_net_busnet_2
         => ASSC_RAM_DO_B_net_busnet_2, 
        ASSC_RAM_DO_B_net_busnet_3 => ASSC_RAM_DO_B_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_0 => 
        ASSC_RAM_ADDR_B_net_busnet_0, ADC_START_net => 
        ADC_START_net, ASSC_RAM_DO_B_net_busnet_0 => 
        ASSC_RAM_DO_B_net_busnet_0, ASSC_RAM_DO_B_net_busnet_4
         => ASSC_RAM_DO_B_net_busnet_4, 
        ASSC_RAM_DO_B_net_busnet_5 => ASSC_RAM_DO_B_net_busnet_5, 
        ADC_CALIBRATE_net => ADC_CALIBRATE_net, ADC_RESET_net => 
        ADC_RESET_net, ADC_PDOWN_net => ADC_PDOWN_net, 
        TM_STB_net_0 => TM_STB_net_0, bcmkdjqtngz => bcmkdjqtngz, 
        ADC_STC_net_busnet_0 => ADC_STC_net_busnet_0, 
        ADC_STC_net_busnet_1 => ADC_STC_net_busnet_1, 
        ADC_STC_net_busnet_2 => ADC_STC_net_busnet_2, 
        ADC_STC_net_busnet_3 => ADC_STC_net_busnet_3, 
        ADC_STC_net_busnet_4 => ADC_STC_net_busnet_4, 
        ADC_STC_net_busnet_5 => ADC_STC_net_busnet_5, 
        ADC_STC_net_busnet_6 => ADC_STC_net_busnet_6, 
        ADC_STC_net_busnet_7 => ADC_STC_net_busnet_7, 
        ADC_TVC_net_busnet_0 => ADC_TVC_net_busnet_0, 
        ADC_TVC_net_busnet_1 => ADC_TVC_net_busnet_1, 
        ADC_TVC_net_busnet_2 => ADC_TVC_net_busnet_2, 
        ADC_TVC_net_busnet_3 => ADC_TVC_net_busnet_3, 
        ADC_TVC_net_busnet_4 => ADC_TVC_net_busnet_4, 
        ADC_TVC_net_busnet_5 => ADC_TVC_net_busnet_5, 
        ADC_TVC_net_busnet_6 => ADC_TVC_net_busnet_6, 
        ADC_TVC_net_busnet_7 => ADC_TVC_net_busnet_7, 
        ADC_MODE_net_busnet_0 => ADC_MODE_net_busnet_0, 
        ADC_MODE_net_busnet_1 => ADC_MODE_net_busnet_1, 
        ADC_MODE_net_busnet_2 => ADC_MODE_net_busnet_2, 
        ADC_MODE_net_busnet_3 => ADC_MODE_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity nbnjbfrkqwq is

    port( dspfgfmqhwh                  : in    std_logic_vector(4 downto 0);
          rdgwgtpkbgc_0_3              : out   std_logic;
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          rdgwgtpkbgc_3                : in    std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic;
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_DONE_net                  : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_RD_net                 : in    std_logic;
          EV_RAM_CSN_A_net             : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic;
          EV_RAM_RW_A_net              : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic;
          TR_EV_ADDR_net_busnet_7      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          un1_Analog_inst_1            : in    std_logic;
          bcmkdjqtngz                  : in    std_logic;
          qvkpfznsfjx                  : in    std_logic;
          EV_RAM_DO_B_net_busnet_7     : in    std_logic;
          EV_RAM_DO_B_net_busnet_5     : in    std_logic;
          EV_RAM_DO_B_net_busnet_4     : in    std_logic;
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          INIT_DONE_net                : in    std_logic;
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_RAM_DO_B_net_busnet_3     : in    std_logic;
          EV_RAM_DO_B_net_busnet_6     : in    std_logic;
          EV_RAM_DO_B_net_busnet_8     : in    std_logic;
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_2     : in    std_logic;
          EV_RAM_DO_B_net_busnet_1     : in    std_logic;
          EV_RAM_DO_B_net_busnet_0     : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          SYS_CLK_int                  : in    std_logic;
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic;
          EV_RAM_DI_B_net_busnet_1     : out   std_logic
        );

end nbnjbfrkqwq;

architecture DEF_ARCH of nbnjbfrkqwq is 

  component DFN1E1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1D
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1E0C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component AOI1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XNOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XO1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AOI1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO13
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component MX2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OAI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AND3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO18
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XNOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AOI1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AND2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XAI1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component OR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AND2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1P0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          PRE : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component MAJ3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MIN3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AXOI7
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AXOI5
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

    signal \gjkdbmpgrtc[8]\, N_463, \gjkdbmpgrtc_11[8]_net_1\, 
        \rdgwgtpkbgc_1[2]_net_1\, \gjkdbmpgrtc[7]\, N_462, 
        \gjkdbmpgrtc_11[7]_net_1\, ADD_18x18_fast_I87_Y, N330, 
        N322, N297, N293, N257, N254, \fqkdsnjfpdb_35_0\, 
        \bnvtvdkcnpp[1]_net_1\, \bnwcvzjbgtc[7]\, 
        \fqkdsnjfpdb_40_0\, \bnvtvdkcnpp[2]_net_1\, 
        \bnwcvzjbgtc[8]\, N_496, \gjkdbmpgrtc_11_d[7]_net_1\, 
        \gjkdbmpgrtc_11_s[7]_net_1\, N_497, 
        \gjkdbmpgrtc_11_d[8]_net_1\, ADD_18x18_fast_I133_un1_Y, 
        N338, ADD_18x18_fast_I133_un1_Y_1_0, N_263, 
        \fqkdsnjfpdb_21\, \fqkdsnjfpdb_36_0\, 
        ADD_18x18_fast_I8_P0N_0, ADD_18x18_fast_I133_Y_3, 
        I86_un1_Y, ADD_18x18_fast_I133_Y_1, \bnwcvzjbgtc[5]\, 
        N_664, \bnwcvzjbgtc_11[5]_net_1\, 
        \rdgwgtpkbgc_2[2]_net_1\, \rdgwgtpkbgc_0[1]_net_1\, N_698, 
        \bnwcvzjbgtc_11_d[5]_net_1\, N_255, \gjkdbmpgrtc[5]\, 
        \ftbkrvpxdbp[5]_net_1\, ADD_18x18_fast_I5_P0N_0, 
        fqkdsnjfpdb_9, \fqkdsnjfpdb_20_0\, ADD_18x18_fast_I133_Y, 
        ADD_18x18_fast_I114_un1_Y, \fqkdsnjfpdb_i[16]\, 
        ADD_18x18_fast_I166_Y_0, N245, \gjkdbmpgrtc[4]\, N_399, 
        \gjkdbmpgrtc_12_d[4]_net_1\, \gjkdbmpgrtc_12_s[3]_net_1\, 
        N_391, \gjkdbmpgrtc_11[4]_net_1\, 
        \rdgwgtpkbgc_0[2]_net_1\, \ftbkrvpxdbp[4]_net_1\, 
        \bnwcvzjbgtc[4]\, \fqkdsnjfpdb_m[16]_net_1\, 
        \zbqggxmnpbs_0_iv_0[1]_net_1\, N_197, N305, N242, N301, 
        I102_un1_Y, N345, ADD_18x18_fast_I102_Y, N337, N_395, 
        N_491, N_493, \rqrqhcwpqdn[2]_net_1\, 
        \rqrqhcwpqdn[3]_net_1\, \rdgwgtpkbgc_0[0]_net_1\, 
        \rqrqhcwpqdn[4]_net_1\, \rqrqhcwpqdn[5]_net_1\, 
        \tkcbxxqbtfx_1[4]_net_1\, fskhwddcbbg_1_sqmuxa_0, N_240, 
        \rgmpzqrbghh_0\, \hmzcpnxsdwg\, \rdgwgtpkbgc_1[0]_net_1\, 
        \rdgwgtpkbgc_2[1]_net_1\, \rdgwgtpkbgc_1[1]_net_1\, 
        \tkcbxxqbtfx_ns_i[13]_net_1\, \tkcbxxqbtfx_0[4]_net_1\, 
        N_12, \rqrqhcwpqdn[1]_net_1\, N_4, \DWACT_FINC_E[0]\, 
        \zbqggxmnpbs_0_iv_0[2]_net_1\, \fqkdsnjfpdb[8]\, 
        \tkcbxxqbtfx[5]_net_1\, \ckghxwbsztp_m[1]_net_1\, 
        \fqkdsnjfpdb[7]\, \ckghxwbsztp_m[0]_net_1\, 
        \zbqggxmnpbs_0_iv_1[0]_net_1\, un2_pbzxzjhqhwz_m, 
        \tddhwjzbsrj_m\, \fqkdsnjfpdb_m[6]_net_1\, 
        ADD_18x18_fast_I167_Y_2, ADD_18x18_fast_I167_Y_1, N_278, 
        \bnvtvdkcnpp[11]_net_1\, \rqrqhcwpqdn[11]_net_1\, 
        \gjkdbmpgrtc68\, \zbqggxmnpbs_0_iv_0[3]_net_1\, 
        \fqkdsnjfpdb[0]\, \ckghxwbsztp_m[2]_net_1\, 
        \zbqggxmnpbs_0_iv_0[4]_net_1\, \ckghxwbsztp[3]_net_1\, 
        \tkcbxxqbtfx[0]_net_1\, \fqkdsnjfpdb_m[1]_net_1\, N_277, 
        N_276, ADD_18x18_fast_I132_Y_3, I84_un1_Y, 
        ADD_18x18_fast_I132_Y_1, I132_un1_Y_i, N286, N283, 
        ADD_18x18_fast_I132_Y_0, N274, 
        \zbqggxmnpbs_0_iv_0[5]_net_1\, \fqkdsnjfpdb[2]\, 
        \ckghxwbsztp_m[4]_net_1\, ADD_18x18_fast_I164_Y_0, N_273, 
        N_272, ADD_18x18_fast_I159_Y_0, N_262, 
        ADD_18x18_fast_I163_Y_0, fqkdsnjfpdb_33, 
        \fqkdsnjfpdb_60_0\, N_271, ADD_18x18_fast_I165_Y_0, N_275, 
        N_274, N285, N288, ADD_18x18_fast_I133_Y_0, N271, 
        ADD_18x18_fast_I162_Y_0, N_269, N_268, 
        ADD_18x18_fast_I160_Y_0, fqkdsnjfpdb_24, 
        \fqkdsnjfpdb_45_0\, N_265, ADD_18x18_fast_I117_Y_1, N326, 
        N333, ADD_18x18_fast_I117_Y_0, N289, N292, 
        ADD_18x18_fast_I118_Y_0, N335, N328, N327, 
        ADD_18x18_fast_I116_Y_1, I56_un1_Y, I88_un1_Y, 
        ADD_18x18_fast_I112_un1_Y_0, N287_i, 
        ADD_18x18_fast_I156_Y_0, N_257, N_256, 
        ADD_18x18_fast_I158_Y_0, N_260, ADD_18x18_fast_I119_Y_0, 
        N329, ADD_18x18_fast_I117_un1_Y_0, N334, 
        ADD_18x18_fast_I155_Y_0, ADD_18x18_fast_I116_un1_Y_0, 
        N332, N291, ADD_18x18_fast_I132_un1_Y_2, 
        ADD_18x18_fast_I132_un1_Y_0, N314, 
        ADD_18x18_fast_I121_Y_0, I121_un1_Y, 
        ADD_18x18_fast_I123_Y_0, ADD_18x18_fast_I154_Y_0, N_253, 
        N_252, ADD_18x18_fast_I119_un1_Y_0, 
        ADD_18x18_fast_I120_Y_0, N340, 
        ADD_18x18_fast_I120_un1_Y_0, N331, N239, 
        ADD_18x18_fast_I79_Y_0, \bnwcvzjbgtc[0]\, 
        ADD_18x18_fast_I121_un1_Y_0, N309, N349, I80_un1_Y_i, 
        N310, ADD_18x18_fast_I153_Y_0, \gjkdbmpgrtc[3]\, 
        \fqkdsnjfpdb_11_0\, N_250, ADD_18x18_fast_I152_Y_0, N_249, 
        N_248, N313, N236, ADD_18x18_fast_I151_Y_0, 
        \bnwcvzjbgtc[1]\, \fqkdsnjfpdb_1_0\, \gjkdbmpgrtc[1]\, 
        \dhzrwbnrbpw_7_iv_0[8]\, N_199_i_0, 
        \qrbxknbdvjj_m[8]_net_1\, ADD_18x18_fast_I13_P0N_0, 
        ADD_18x18_fast_I6_P0N_0, \dhzrwbnrbpw_7_iv_1[4]\, 
        \qrbxknbdvjj_m[4]_net_1\, \mtbjcfqsbqf_m[3]_net_1\, 
        \jrgzmrqhbkv_m[4]_net_1\, ADD_18x18_fast_I11_P0N_0, 
        \bnvtvdkcnpp[4]_net_1\, \gjkdbmpgrtc[10]\, 
        \bnwcvzjbgtc[10]\, \dhzrwbnrbpw_7_iv_0[6]\, 
        \qrbxknbdvjj_m[6]_net_1\, \dhzrwbnrbpw_7_iv_1[3]\, 
        \dhzrwbnrbpw_7_iv_0[3]\, \qrbxknbdvjj_m[3]_net_1\, 
        ADD_18x18_fast_I2_P0N_0, \ftbkrvpxdbp[1]_net_1\, 
        \ftbkrvpxdbp[0]_net_1\, \dhzrwbnrbpw_7_iv_0[5]\, 
        \qrbxknbdvjj_m[5]_net_1\, \dhzrwbnrbpw_7_iv_1[2]\, 
        \dhzrwbnrbpw_7_iv_0[2]\, \qrbxknbdvjj_m[2]_net_1\, 
        ADD_9x9_medium_I8_Y_1, N105, \dhzrwbnrbpw_7_iv_0[1]\, 
        \qrbxknbdvjj_m[1]_net_1\, \fqkdsnjfpdb_56_0\, 
        \bnvtvdkcnpp[6]_net_1\, \bnwcvzjbgtc[12]\, 
        \fqkdsnjfpdb_16_0\, \fqkdsnjfpdb_31_0\, 
        \fqkdsnjfpdb_41_0\, \bnvtvdkcnpp[3]_net_1\, 
        \bnwcvzjbgtc[9]\, \ftbkrvpxdbp[3]_net_1\, 
        \bnwcvzjbgtc[3]\, \kkjrqmngvjc_0_0\, N_215, 
        \bskrjhjvqpf_i_2_1\, \tkcbxxqbtfx[1]_net_1\, 
        \bskrjhjvqpf_i_1\, \bskrjhjvqpf_i_0\, 
        \tkcbxxqbtfx[15]_net_1\, \tkcbxxqbtfx[9]_net_1\, 
        \tkcbxxqbtfx_ns_a3_0[6]_net_1\, N_205, 
        \un1_rdgwgtpkbgc_2_0\, \fskhwddcbbg_6_sqmuxa_0_a3_0\, 
        \gpjgkmhxbkn_NE_2\, gpjgkmhxbkn_3_i, gpjgkmhxbkn_4_i, 
        gpjgkmhxbkn_0_i, \gpjgkmhxbkn_NE_1\, gpjgkmhxbkn_1_i, 
        \wqpbnjzjqsx_NE_2\, wqpbnjzjqsx_3_i, wqpbnjzjqsx_4_i, 
        wqpbnjzjqsx_0_i, \wqpbnjzjqsx_NE_1\, wqpbnjzjqsx_1_i, 
        \tkcbxxqbtfx[6]_net_1\, \tkcbxxqbtfx[17]_net_1\, 
        I112_un1_Y, I100_un1_Y, N454_i, N478, I116_un1_Y, N469, 
        I118_un1_Y, N336, N475, N457_i, N339, N344, N121, N107, 
        N108, N124, N_209, \tkcbxxqbtfx[3]_net_1\, 
        \tkcbxxqbtfx_ns[14]\, N_241, \dhzrwbnrbpw_7[5]\, 
        \jrgzmrqhbkv_m[5]_net_1\, \un1_bskrjhjvqpf_m[6]_net_1\, 
        \dhzrwbnrbpw_7[4]\, N_201_i_0, \un1_bskrjhjvqpf[5]\, 
        \dhzrwbnrbpw_7[1]\, \jrgzmrqhbkv_m[1]_net_1\, 
        \un1_bskrjhjvqpf_m[2]_net_1\, \tkcbxxqbtfx_ns[6]\, 
        \tkcbxxqbtfx[12]_net_1\, \dhzrwbnrbpw_7[8]\, 
        \un1_bskrjhjvqpf[9]\, \dhzrwbnrbpw_7[6]\, 
        \un1_bskrjhjvqpf[7]\, \dhzrwbnrbpw_7[0]\, 
        \jrgzmrqhbkv_m[0]_net_1\, \qrbxknbdvjj_m[0]_net_1\, 
        \un1_bskrjhjvqpf_m[1]_net_1\, fskhwddcbbg_6_sqmuxa, 
        \dhzrwbnrbpw_7[7]\, \jrgzmrqhbkv_m[7]_net_1\, 
        \qrbxknbdvjj_m[7]_net_1\, \un1_bskrjhjvqpf_m[8]_net_1\, 
        \bnwcvzjbgtc[16]\, \bnvtvdkcnpp[10]_net_1\, 
        \gjkdbmpgrtc[16]\, \bnwcvzjbgtc[15]\, 
        \bnvtvdkcnpp[9]_net_1\, \gjkdbmpgrtc[15]\, 
        \gjkdbmpgrtc[14]\, \bnvtvdkcnpp[8]_net_1\, 
        \bnwcvzjbgtc[14]\, \gjkdbmpgrtc[13]\, 
        \bnvtvdkcnpp[7]_net_1\, \bnwcvzjbgtc[13]\, 
        \gjkdbmpgrtc[12]\, N_267, \bnwcvzjbgtc[11]\, 
        \bnvtvdkcnpp[5]_net_1\, \gjkdbmpgrtc[11]\, 
        \gjkdbmpgrtc[9]\, N_259, \bnwcvzjbgtc[6]\, 
        \bnvtvdkcnpp[0]_net_1\, \gjkdbmpgrtc[6]\, 
        \gjkdbmpgrtc[2]\, \ftbkrvpxdbp[2]_net_1\, 
        \bnwcvzjbgtc[2]\, \fqkdsnjfpdb_i[17]\, \fqkdsnjfpdb[15]\, 
        \fqkdsnjfpdb_i[13]\, \fqkdsnjfpdb_i[12]\, 
        \fqkdsnjfpdb[11]\, N_266, \fqkdsnjfpdb[10]\, I98_un1_Y, 
        \fqkdsnjfpdb[9]\, N463, N_258, \fqkdsnjfpdb_i[5]\, 
        \fqkdsnjfpdb_i[4]\, \fqkdsnjfpdb_i[3]\, \fqkdsnjfpdb[1]\, 
        \gjkdbmpgrtc[0]\, N_228, \tkcbxxqbtfx_ns_i[1]_net_1\, 
        N_227, N_227_1, N_239, \tkcbxxqbtfx_ns[4]_net_1\, N_226, 
        \fqkdsnjfpdb[6]\, N341, I105_un1_Y_i, \fqkdsnjfpdb_i[14]\, 
        I117_un1_Y, \dhzrwbnrbpw_7[2]\, \un1_bskrjhjvqpf[3]\, 
        \dhzrwbnrbpw_7[3]\, \un1_bskrjhjvqpf[4]\, N248, N260, 
        N269, N263, N_737, N_701, \bnwcvzjbgtc_11_d[10]_net_1\, 
        \gjkdbmpgrtc_11_s[11]_net_1\, N_703, N_735, N_699, 
        \bnwcvzjbgtc_11_d[8]_net_1\, N_734, 
        \bnwcvzjbgtc_11_d[7]_net_1\, N_702, 
        \bnwcvzjbgtc_11_s[7]_net_1\, N_704, N_736, 
        \bnwcvzjbgtc_11_d[9]_net_1\, N_700, 
        \bnwcvzjbgtc_11_d_d[5]_net_1\, 
        \bnwcvzjbgtc_11_d_s[5]_net_1\, N_738, 
        \bnwcvzjbgtc_11_d[11]_net_1\, N_533, 
        \gjkdbmpgrtc_11_d[10]_net_1\, N_499, N_398, 
        \gjkdbmpgrtc_12_d[3]_net_1\, N_390, N_526, 
        \tkcbxxqbtfx_ns[16]\, N_237, \tkcbxxqbtfx_ns_1[16]\, 
        \tkcbxxqbtfx_ns[15]\, N_532, N_498, 
        \gjkdbmpgrtc_11_d[9]_net_1\, N_534, 
        \gjkdbmpgrtc_11_d[11]_net_1\, N_500, N_529, 
        \gjkdbmpgrtc_11_d_0[6]_net_1\, 
        \gjkdbmpgrtc_11_s_0[6]_net_1\, \rqrqhcwpqdn[0]_net_1\, 
        \gjkdbmpgrtc_11_s[6]_net_1\, N_495, N_733, 
        \bnwcvzjbgtc_11_d[6]_net_1\, N_697, N_494, 
        \fqkdsnjfpdb_70_0\, N_673, \fqkdsnjfpdb_38\, 
        \fqkdsnjfpdb_m[15]_net_1\, \fqkdsnjfpdb_m[17]_net_1\, 
        \fqkdsnjfpdb_m[9]_net_1\, \fqkdsnjfpdb_m[10]_net_1\, 
        \fqkdsnjfpdb_m[11]_net_1\, \fqkdsnjfpdb_m[3]_net_1\, 
        \fqkdsnjfpdb_m[12]_net_1\, \fqkdsnjfpdb_m[4]_net_1\, 
        \fqkdsnjfpdb_m[13]_net_1\, \fqkdsnjfpdb_m[5]_net_1\, 
        \fqkdsnjfpdb_m[14]_net_1\, N229, N230, N235, N241, N247, 
        N259, N265, N272, N275, N268, N262, N296, N253, N256, 
        N300, I40_un1_Y, N304, N244, N308, N238, N312, N233, N232, 
        ADD_18x18_fast_I62_un1_Y, I81_un1_Y, I107_un1_Y_i, N250, 
        N278, N294, N295, N298, N299, N302, N306, N307, N311, 
        N290, N303, I76_un1_Y, I104_un1_Y_i, I106_un1_Y_i, 
        I122_un1_Y_i, N_392, N_473, N_490, N_393, N_489, N_394, 
        N_492, N_396, N_397, N_400, N_401, N_402, N_460, N_403, 
        N_464, N_447, \rqrqhcwpqdn[6]_net_1\, 
        \rqrqhcwpqdn[7]_net_1\, \rqrqhcwpqdn[8]_net_1\, 
        \rqrqhcwpqdn[9]_net_1\, \rqrqhcwpqdn[10]_net_1\, N_535, 
        N_536, N_455, N_523, N_456, N_524, N_457, N_525, N_528, 
        N_465, N_466, N_467, N_468, N_470, N_538, N_471, N_539, 
        N_557, N_558, N_574, N_575, N_591, N_592, N_593, N_676, 
        N_594, N_677, N_595, N_693, N_596, N_694, N_597, N_695, 
        N_598, N_696, N_599, N_600, N_601, N_602, N_603, N_604, 
        \rdgwgtpkbgc[1]_net_1\, N_605, N_606, N_659, N_660, N_661, 
        N_662, N_663, N_665, N_666, N_667, N_607, N_668, N_651, 
        \rdgwgtpkbgc[0]_net_1\, N_727, N_728, N_729, N_730, N_731, 
        N_739, N_740, N_669, \rdgwgtpkbgc[2]_net_1\, N_670, N_671, 
        N_672, N_674, N_742, N_675, N_743, N_234, I18_un1_Y, 
        \EV_RAM_ADDR_B_net_busnet_3\, \un1_bskrjhjvqpf[1]\, 
        \EV_RAM_ADDR_B_net_busnet_0\, 
        \EV_RAM_ADDR_B_net_busnet_4\, 
        \EV_RAM_ADDR_B_net_busnet_5\, 
        \EV_RAM_ADDR_B_net_busnet_6\, \un1_mvnkctvqsgp\, 
        \tkcbxxqbtfx[8]_net_1\, \rfrdbqfdrhx[0]_net_1\, 
        \rfrdbqfdrhx[1]_net_1\, \tkcbxxqbtfx_ns_i[12]_net_1\, 
        N_784, N_785, N_786, \rqrqhcwpqdn_9[9]_net_1\, N_787, 
        \qrbxknbdvjj[7]_net_1\, \EV_RAM_ADDR_B_net_busnet_7\, 
        \un1_kkgccghmrzf\, \ftbkrvpxdbp_1_sqmuxa\, N_212, N_206, 
        N_203, \bnvtvdkcnpp_8[0]_net_1\, \bnvtvdkcnpp_4[0]_net_1\, 
        \bnvtvdkcnpp_8[1]_net_1\, \bnvtvdkcnpp_4[1]_net_1\, 
        \bnvtvdkcnpp_8[2]_net_1\, \bnvtvdkcnpp_4[2]_net_1\, 
        \bnvtvdkcnpp_8[3]_net_1\, \bnvtvdkcnpp_4[3]_net_1\, 
        \bnvtvdkcnpp_8[4]_net_1\, \bnvtvdkcnpp_4[4]_net_1\, 
        \bnvtvdkcnpp_8[5]_net_1\, \bnvtvdkcnpp_4[5]_net_1\, 
        \bnvtvdkcnpp_8[6]_net_1\, \bnvtvdkcnpp_4[6]_net_1\, 
        \bnvtvdkcnpp_8[7]_net_1\, \bnvtvdkcnpp_4[7]_net_1\, 
        \bnvtvdkcnpp_8[8]_net_1\, \bnvtvdkcnpp_4[8]_net_1\, 
        \bnvtvdkcnpp_8[9]_net_1\, \bnvtvdkcnpp_7[9]_net_1\, 
        \bnvtvdkcnpp_8[10]_net_1\, \bnvtvdkcnpp_7[10]_net_1\, 
        \bnvtvdkcnpp_8[11]_net_1\, \bnvtvdkcnpp_7[11]_net_1\, 
        un2_pbzxzjhqhwz, dbdctxjdvkp_2_sqmuxa, \tddhwjzbsrj\, 
        \ckghxwbsztp[0]_net_1\, \tkcbxxqbtfx[4]_net_1\, 
        \ckghxwbsztp[1]_net_1\, \ckghxwbsztp[2]_net_1\, 
        \ckghxwbsztp[4]_net_1\, \un3_qvqqfftqsfc\, 
        \ftbkrvpxdbp_4[0]_net_1\, \ftbkrvpxdbp_4[1]_net_1\, 
        \ftbkrvpxdbp_4[2]_net_1\, \ftbkrvpxdbp_4[4]_net_1\, 
        \ftbkrvpxdbp_4[5]_net_1\, \tkcbxxqbtfx[2]_net_1\, 
        \qmmwhjxxxmv\, \tkcbxxqbtfx_ns[10]\, 
        \fskhwddcbbg_1_sqmuxa\, \tkcbxxqbtfx_ns_i[3]_net_1\, 
        \tkcbxxqbtfx_ns_i[7]_net_1\, \tkcbxxqbtfx[11]_net_1\, 
        \tkcbxxqbtfx_ns_i[11]_net_1\, \EV_ASSCADDR_net_busnet_2\, 
        \tkcbxxqbtfx_ns_i[17]_net_1\, \qrbxknbdvjj[0]_net_1\, 
        \qrbxknbdvjj[1]_net_1\, \EV_RAM_ADDR_B_net_busnet_1\, 
        \qrbxknbdvjj[4]_net_1\, \rgmpzqrbghh\, 
        \qrbxknbdvjj[5]_net_1\, \qrbxknbdvjj[6]_net_1\, 
        \qrbxknbdvjj[8]_net_1\, \ftbkrvpxdbp_4[3]_net_1\, 
        \tkcbxxqbtfx[14]_net_1\, N_207, \un1_xkwrgrspmcf\, 
        \un1_qvqqfftqsfc\, \tkcbxxqbtfx_ns_i[9]_net_1\, N_763, 
        N_764, N_765, N_766, N_767, N_768, N_769, N_770, N_771, 
        \rqrqhcwpqdn_5[0]_net_1\, N_772_i, \ckghxwbsztp_2[0]\, 
        N_9, \ckghxwbsztp_2[1]\, I_5, \ckghxwbsztp_2[2]\, I_9, 
        \ckghxwbsztp_2[3]\, I_13, \ckghxwbsztp_2[4]\, I_20, N_20, 
        gcqsptsqnzg, N_10, \spbznmtdmpd\, fskhwddcbbg_0_sqmuxa, 
        \un1_fskhwddcbbg_6_sqmuxa_1\, N_211, 
        \tkcbxxqbtfx_ns_i[8]_net_1\, \tkcbxxqbtfx[10]_net_1\, 
        \tkcbxxqbtfx_ns_i[5]_net_1\, \tkcbxxqbtfx[13]_net_1\, 
        \tkcbxxqbtfx_ns_i[2]_net_1\, \tkcbxxqbtfx[16]_net_1\, 
        \tkcbxxqbtfx_ns[0]_net_1\, N_469, N_537, N_741, N_461, 
        \qrbxknbdvjj[3]_net_1\, \qrbxknbdvjj[2]_net_1\, 
        \EV_RAM_ADDR_B_net_busnet_2\, \EV_CHHOLD_net_busnet_0\, 
        \EV_CHHOLD_net_busnet_1\, \EV_CHHOLD_net_busnet_2\, 
        \EV_CHHOLD_net_busnet_3\, \EV_CHHOLD_net_busnet_4\, 
        \EV_RAM_ADDR_B_net_busnet_8\, N_9_0, \DWACT_COMP0_E[1]\, 
        \DWACT_COMP0_E[2]\, \DWACT_COMP0_E[0]\, 
        \DWACT_CMPLE_PO2_DWACT_COMP0_E[1]\, 
        \DWACT_CMPLE_PO2_DWACT_COMP0_E[2]\, 
        \DWACT_CMPLE_PO2_DWACT_COMP0_E[0]\, \ACT_LT4_E[3]\, 
        \ACT_LT4_E[6]\, \ACT_LT4_E[10]\, \ACT_LT4_E[7]\, 
        \ACT_LT4_E[8]\, \ACT_LT4_E[5]\, \ACT_LT4_E[4]\, 
        \ACT_LT4_E[0]\, \ACT_LT4_E[1]\, \ACT_LT4_E[2]\, 
        \ACT_LT3_E[3]\, \ACT_LT3_E[4]\, \ACT_LT3_E[5]\, 
        \ACT_LT3_E[0]\, \ACT_LT3_E[1]\, \ACT_LT3_E[2]\, 
        \DWACT_BL_EQUAL_0_E[2]\, \DWACT_BL_EQUAL_0_E[1]\, 
        \DWACT_BL_EQUAL_0_E[0]\, N_37, N_36, N_35, N_32, N_34, 
        N_33, N_31, N_28, N_29, N_30, 
        \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[1]\, 
        \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[0]\, 
        \DWACT_BL_EQUAL_0_E[4]\, \DWACT_BL_EQUAL_0_E[3]\, 
        \DWACT_BL_EQUAL_0_E_0[0]\, \DWACT_BL_EQUAL_0_E_0[1]\, 
        \DWACT_BL_EQUAL_0_E_0[2]\, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

begin 

    EV_CHHOLD_net_busnet_3 <= \EV_CHHOLD_net_busnet_3\;
    EV_RAM_ADDR_B_net_busnet_8 <= \EV_RAM_ADDR_B_net_busnet_8\;
    EV_RAM_ADDR_B_net_busnet_7 <= \EV_RAM_ADDR_B_net_busnet_7\;
    EV_RAM_ADDR_B_net_busnet_0 <= \EV_RAM_ADDR_B_net_busnet_0\;
    EV_RAM_ADDR_B_net_busnet_1 <= \EV_RAM_ADDR_B_net_busnet_1\;
    EV_RAM_ADDR_B_net_busnet_2 <= \EV_RAM_ADDR_B_net_busnet_2\;
    EV_RAM_ADDR_B_net_busnet_3 <= \EV_RAM_ADDR_B_net_busnet_3\;
    EV_RAM_ADDR_B_net_busnet_4 <= \EV_RAM_ADDR_B_net_busnet_4\;
    EV_ASSCADDR_net_busnet_2 <= \EV_ASSCADDR_net_busnet_2\;
    EV_CHHOLD_net_busnet_0 <= \EV_CHHOLD_net_busnet_0\;
    EV_RAM_ADDR_B_net_busnet_6 <= \EV_RAM_ADDR_B_net_busnet_6\;
    EV_RAM_ADDR_B_net_busnet_5 <= \EV_RAM_ADDR_B_net_busnet_5\;
    EV_CHHOLD_net_busnet_1 <= \EV_CHHOLD_net_busnet_1\;
    EV_CHHOLD_net_busnet_4 <= \EV_CHHOLD_net_busnet_4\;
    EV_CHHOLD_net_busnet_2 <= \EV_CHHOLD_net_busnet_2\;
    fskhwddcbbg_1_sqmuxa <= \fskhwddcbbg_1_sqmuxa\;

    \qrbxknbdvjj[4]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_4\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[4]_net_1\);
    
    \bnwcvzjbgtc_7[10]\ : NOR2A
      port map(A => N_601, B => rdgwgtpkbgc_3, Y => N_669);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I163_Y : AX1D
      port map(A => I118_un1_Y, B => ADD_18x18_fast_I118_Y_0, C
         => ADD_18x18_fast_I163_Y_0, Y => \fqkdsnjfpdb_i[13]\);
    
    \rdgwgtpkbgc[2]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_2, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \fskhwddcbbg_1_sqmuxa\, Q => 
        \rdgwgtpkbgc[2]_net_1\);
    
    \zbqggxmnpbs_r[5]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[11]_net_1\, B => 
        \zbqggxmnpbs_0_iv_0[5]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_5);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[2]\ : AOI1B
      port map(A => \rgmpzqrbghh_0\, B => 
        \EV_CHHOLD_net_busnet_1\, C => \qrbxknbdvjj_m[2]_net_1\, 
        Y => \dhzrwbnrbpw_7_iv_0[2]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I104_un1_Y : AO1C
      port map(A => N310, B => I80_un1_Y_i, C => N340, Y => 
        I104_un1_Y_i);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I79_Y_0 : NOR2B
      port map(A => N313, B => N236, Y => ADD_18x18_fast_I79_Y_0);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_1 : XNOR2
      port map(A => \bnvtvdkcnpp[8]_net_1\, B => 
        \rqrqhcwpqdn[8]_net_1\, Y => \DWACT_BL_EQUAL_0_E_0[1]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I3_P0N : XO1A
      port map(A => \gjkdbmpgrtc[3]\, B => \fqkdsnjfpdb_11_0\, C
         => N_250, Y => N239);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I123_Y_0 : AO1
      port map(A => N338, B => ADD_18x18_fast_I133_un1_Y_1_0, C
         => N337, Y => ADD_18x18_fast_I123_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I4_G0N : NOR2B
      port map(A => N_253, B => N_252, Y => N241);
    
    \bnvtvdkcnpp_4[8]\ : MX2C
      port map(A => \bnvtvdkcnpp[8]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_8, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[8]_net_1\);
    
    \gjkdbmpgrtc_11[12]\ : MX2
      port map(A => N_403, B => \rqrqhcwpqdn[6]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_535);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I23_Y : OR2B
      port map(A => N272, B => N269, Y => N287_i);
    
    \bnwcvzjbgtc_7[15]\ : NOR2A
      port map(A => N_606, B => rdgwgtpkbgc_3, Y => N_674);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I8_G0N : XA1A
      port map(A => \gjkdbmpgrtc[8]\, B => \fqkdsnjfpdb_36_0\, C
         => N_260, Y => N253);
    
    \gjkdbmpgrtc_11[13]\ : MX2
      port map(A => N_447, B => \rqrqhcwpqdn[7]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_536);
    
    \bnwcvzjbgtc_9[11]\ : NOR2A
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        \rdgwgtpkbgc[0]_net_1\, Y => N_704);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_58 : AOI1A
      port map(A => \ACT_LT4_E[0]\, B => \ACT_LT4_E[1]\, C => 
        \ACT_LT4_E[2]\, Y => \ACT_LT4_E[3]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I11_G0N : NOR2B
      port map(A => N_267, B => N_266, Y => N262);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_35 : XNOR2
      port map(A => \bnvtvdkcnpp[5]_net_1\, B => 
        \rqrqhcwpqdn[5]_net_1\, Y => \DWACT_BL_EQUAL_0_E[1]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_60 : NOR2A
      port map(A => \rqrqhcwpqdn[3]_net_1\, B => 
        \bnvtvdkcnpp[3]_net_1\, Y => \ACT_LT4_E[5]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I122_Y : OR3B
      port map(A => N335, B => I122_un1_Y_i, C => I100_un1_Y, Y
         => N463);
    
    tddhwjzbsrj : DFN1E1C0
      port map(D => gcqsptsqnzg, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \tddhwjzbsrj\);
    
    \un1_bskrjhjvqpf_m[8]\ : XAI1
      port map(A => N121, B => \EV_RAM_ADDR_B_net_busnet_7\, C
         => N_201_i_0, Y => \un1_bskrjhjvqpf_m[8]_net_1\);
    
    fqkdsnjfpdb_50 : AO13
      port map(A => \bnvtvdkcnpp[4]_net_1\, B => 
        \gjkdbmpgrtc[10]\, C => \bnwcvzjbgtc[10]\, Y => N_266);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I155_Y_0 : AX1D
      port map(A => fqkdsnjfpdb_9, B => \fqkdsnjfpdb_20_0\, C => 
        N_255, Y => ADD_18x18_fast_I155_Y_0);
    
    \gjkdbmpgrtc_11_s_0[6]\ : NOR2
      port map(A => \rdgwgtpkbgc_0[1]_net_1\, B => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => 
        \gjkdbmpgrtc_11_s_0[6]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_20 : OR2A
      port map(A => \rqrqhcwpqdn[11]_net_1\, B => 
        \bnvtvdkcnpp[11]_net_1\, Y => N_31);
    
    \rfrdbqfdrhx[0]\ : DFN1E1C0
      port map(D => EV_RAM_DO_B_net_busnet_4, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_0_sqmuxa, Q => 
        \rfrdbqfdrhx[0]_net_1\);
    
    \bnwcvzjbgtc_7[2]\ : MX2
      port map(A => N_593, B => N_601, S => rdgwgtpkbgc_3, Y => 
        N_661);
    
    \bnwcvzjbgtc_9[3]\ : MX2
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => 
        \bnvtvdkcnpp[4]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_696);
    
    \tkcbxxqbtfx_0[4]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[13]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx_0[4]_net_1\);
    
    rgmpzqrbghh : DFN1C0
      port map(D => \hmzcpnxsdwg\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \rgmpzqrbghh\);
    
    \gjkdbmpgrtc_12[9]\ : MX2
      port map(A => N_464, B => N_532, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[9]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I64_Y : AO1C
      port map(A => N295, B => N298, C => N294, Y => N331);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_46 : OR2A
      port map(A => \rqrqhcwpqdn[6]_net_1\, B => 
        \bnvtvdkcnpp[6]_net_1\, Y => \ACT_LT3_E[4]\);
    
    \bnwcvzjbgtc_11[11]\ : MX2
      port map(A => N_702, B => \bnwcvzjbgtc_11_d[11]_net_1\, S
         => \gjkdbmpgrtc_11_s[11]_net_1\, Y => N_738);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I66_Y : AO1
      port map(A => N297, B => N300, C => N296, Y => N333);
    
    \qrbxknbdvjj[2]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_2\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[2]_net_1\);
    
    \rqrqhcwpqdn_9[9]\ : MX2A
      port map(A => N_784, B => \rqrqhcwpqdn[9]_net_1\, S => 
        N_787, Y => \rqrqhcwpqdn_9[9]_net_1\);
    
    \gjkdbmpgrtc_7[6]\ : MX2
      port map(A => N_393, B => N_397, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => N_461);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I62_Y : OR2
      port map(A => N292, B => ADD_18x18_fast_I62_un1_Y, Y => 
        N329);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I5_P0N : OR2
      port map(A => ADD_18x18_fast_I5_P0N_0, B => N_255, Y => 
        N245);
    
    \bnwcvzjbgtc_9[5]\ : MX2
      port map(A => \bnvtvdkcnpp[5]_net_1\, B => 
        \bnvtvdkcnpp[6]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_698);
    
    \bnwcvzjbgtc_3[8]\ : MX2
      port map(A => N_695, B => N_697, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_599);
    
    \bnwcvzjbgtc_11[9]\ : MX2
      port map(A => N_702, B => \bnwcvzjbgtc_11_d[9]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => N_736);
    
    \bnwcvzjbgtc_3[14]\ : MX2
      port map(A => N_701, B => N_703, S => 
        \rdgwgtpkbgc[1]_net_1\, Y => N_605);
    
    \bnwcvzjbgtc_9[1]\ : MX2
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => 
        \bnvtvdkcnpp[2]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_694);
    
    fqkdsnjfpdb_56_0 : XOR2
      port map(A => \bnvtvdkcnpp[6]_net_1\, B => 
        \bnwcvzjbgtc[12]\, Y => \fqkdsnjfpdb_56_0\);
    
    \gjkdbmpgrtc_11_s[6]\ : OR2A
      port map(A => \rdgwgtpkbgc_0[1]_net_1\, B => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => 
        \gjkdbmpgrtc_11_s[6]_net_1\);
    
    \gjkdbmpgrtc_3[16]\ : NOR2A
      port map(A => N_499, B => \rdgwgtpkbgc[1]_net_1\, Y => 
        N_403);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_5 : XNOR2
      port map(A => \bnvtvdkcnpp[7]_net_1\, B => 
        \rqrqhcwpqdn[7]_net_1\, Y => \DWACT_BL_EQUAL_0_E_0[0]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I35_Y : OAI1
      port map(A => N_258, B => N_259, C => N254, Y => N299);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I160_Y_0 : AX1B
      port map(A => fqkdsnjfpdb_24, B => \fqkdsnjfpdb_45_0\, C
         => N_265, Y => ADD_18x18_fast_I160_Y_0);
    
    fskhwddcbbg_6_sqmuxa_0_a2 : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_7, B => 
        \tkcbxxqbtfx[12]_net_1\, Y => N_241);
    
    \bnwcvzjbgtc_11[2]\ : MX2
      port map(A => N_597, B => \ftbkrvpxdbp[2]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_729);
    
    \zbqggxmnpbs_r[4]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[10]_net_1\, B => 
        \zbqggxmnpbs_0_iv_0[4]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_4);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I166_Y : XNOR2
      port map(A => ADD_18x18_fast_I166_Y_0, B => 
        ADD_18x18_fast_I133_Y, Y => \fqkdsnjfpdb_i[16]\);
    
    \bnwcvzjbgtc_11[16]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => \bnvtvdkcnpp[10]_net_1\, 
        Y => N_743);
    
    \tkcbxxqbtfx_ns_o3[0]\ : NOR2A
      port map(A => INIT_DONE_net, B => fskhwddcbbg_6_sqmuxa, Y
         => N_211);
    
    \gjkdbmpgrtc_9[9]\ : MX2
      port map(A => \rqrqhcwpqdn[9]_net_1\, B => 
        \rqrqhcwpqdn[10]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_498);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I47_Y : NOR2B
      port map(A => N236, B => N233, Y => N311);
    
    un2_ckghxwbsztp_I_16 : AND3
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \rqrqhcwpqdn[2]_net_1\, C => \rqrqhcwpqdn[3]_net_1\, Y
         => \DWACT_FINC_E[0]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_17 : OR2A
      port map(A => \rqrqhcwpqdn[8]_net_1\, B => 
        \bnvtvdkcnpp[8]_net_1\, Y => N_28);
    
    \bnwcvzjbgtc_3[4]\ : MX2
      port map(A => N_676, B => N_693, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_595);
    
    gcqsptsqnzg_iv_0 : OA1C
      port map(A => N_10, B => \spbznmtdmpd\, C => N_20, Y => 
        gcqsptsqnzg);
    
    \dhzrwbnrbpw[0]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_0\);
    
    un1_kkgccghmrzf : NOR3B
      port map(A => \rfrdbqfdrhx[0]_net_1\, B => 
        \tkcbxxqbtfx[8]_net_1\, C => \rfrdbqfdrhx[1]_net_1\, Y
         => \un1_kkgccghmrzf\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_Y_0 : AO18
      port map(A => N_275, B => N_274, C => N271, Y => 
        ADD_18x18_fast_I133_Y_0);
    
    \fqkdsnjfpdb_m[3]\ : OR2A
      port map(A => \tkcbxxqbtfx[4]_net_1\, B => 
        \fqkdsnjfpdb_i[3]\, Y => \fqkdsnjfpdb_m[3]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I165_Y_0 : XNOR2
      port map(A => N_275, B => N_274, Y => 
        ADD_18x18_fast_I165_Y_0);
    
    fqkdsnjfpdb_76 : XNOR3
      port map(A => \bnwcvzjbgtc[16]\, B => 
        \bnvtvdkcnpp[10]_net_1\, C => \gjkdbmpgrtc[16]\, Y => 
        N_277);
    
    fqkdsnjfpdb_43 : NOR2B
      port map(A => \gjkdbmpgrtc[9]\, B => \bnvtvdkcnpp[3]_net_1\, 
        Y => fqkdsnjfpdb_24);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_36 : XNOR2
      port map(A => \bnvtvdkcnpp[6]_net_1\, B => 
        \rqrqhcwpqdn[6]_net_1\, Y => \DWACT_BL_EQUAL_0_E[2]\);
    
    \bnwcvzjbgtc_12[2]\ : MX2
      port map(A => N_661, B => N_729, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[2]\);
    
    un2_ckghxwbsztp_I_13 : XOR2
      port map(A => N_9_0, B => \rqrqhcwpqdn[4]_net_1\, Y => I_13);
    
    \gjkdbmpgrtc_12[3]\ : MX2
      port map(A => N_398, B => \gjkdbmpgrtc_12_d[3]_net_1\, S
         => \gjkdbmpgrtc_12_s[3]_net_1\, Y => \gjkdbmpgrtc[3]\);
    
    \jrgzmrqhbkv_m[4]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_4, B => N_199_i_0, Y
         => \jrgzmrqhbkv_m[4]_net_1\);
    
    \bnvtvdkcnpp[5]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[5]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[5]_net_1\);
    
    \tkcbxxqbtfx_ns_a3_0_1[4]\ : NOR2B
      port map(A => EV_RAM_DO_B_net_busnet_6, B => 
        \tkcbxxqbtfx[12]_net_1\, Y => N_227_1);
    
    \qrbxknbdvjj_m[2]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[2]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[2]_net_1\);
    
    \gjkdbmpgrtc_7[2]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => N_397, Y => N_457);
    
    fqkdsnjfpdb_31 : XNOR2
      port map(A => \fqkdsnjfpdb_31_0\, B => \gjkdbmpgrtc[7]\, Y
         => N_259);
    
    \rdgwgtpkbgc_1[2]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_2, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_1[2]_net_1\);
    
    \ckghxwbsztp_2_0_a3[1]\ : NOR2B
      port map(A => I_5, B => N_9, Y => \ckghxwbsztp_2[1]\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I2_Y : OR2B
      port map(A => \EV_RAM_ADDR_B_net_busnet_2\, B => 
        \EV_RAM_ADDR_B_net_busnet_1\, Y => N107);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I119_un1_Y_0 : NOR2A
      port map(A => N338, B => N330, Y => 
        ADD_18x18_fast_I119_un1_Y_0);
    
    \ckghxwbsztp[1]\ : DFN1E1C0
      port map(D => \ckghxwbsztp_2[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \ckghxwbsztp[1]_net_1\);
    
    fqkdsnjfpdb_61 : XNOR3
      port map(A => \gjkdbmpgrtc[13]\, B => 
        \bnvtvdkcnpp[7]_net_1\, C => \bnwcvzjbgtc[13]\, Y => 
        N_271);
    
    fqkdsnjfpdb_26 : XNOR3
      port map(A => \bnwcvzjbgtc[6]\, B => \bnvtvdkcnpp[0]_net_1\, 
        C => \gjkdbmpgrtc[6]\, Y => N_257);
    
    \bnwcvzjbgtc_8[1]\ : MX2
      port map(A => \ftbkrvpxdbp[5]_net_1\, B => 
        \bnvtvdkcnpp[0]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_677);
    
    \bnvtvdkcnpp_8[5]\ : MX2
      port map(A => \bnvtvdkcnpp_4[5]_net_1\, B => 
        \fqkdsnjfpdb[11]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[5]_net_1\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_1[2]\ : AOI1B
      port map(A => N_199_i_0, B => EV_RAM_DO_B_net_busnet_2, C
         => \dhzrwbnrbpw_7_iv_0[2]\, Y => \dhzrwbnrbpw_7_iv_1[2]\);
    
    \rdgwgtpkbgc_1[1]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_1[1]_net_1\);
    
    \ftbkrvpxdbp[4]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[4]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[4]_net_1\);
    
    \gjkdbmpgrtc_3[9]\ : MX2
      port map(A => N_492, B => N_494, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_396);
    
    \fqkdsnjfpdb_m[13]\ : OR2A
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => 
        \fqkdsnjfpdb_i[13]\, Y => \fqkdsnjfpdb_m[13]_net_1\);
    
    \bnwcvzjbgtc_12[7]\ : MX2
      port map(A => N_666, B => N_734, S => rdgwgtpkbgc_3, Y => 
        \bnwcvzjbgtc[7]\);
    
    gcqsptsqnzg_iv_0_a2 : AOI1
      port map(A => \wqpbnjzjqsx_NE_1\, B => \wqpbnjzjqsx_NE_2\, 
        C => \rqrqhcwpqdn[0]_net_1\, Y => N_20);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I6_P0N_0 : AO13
      port map(A => \ftbkrvpxdbp[5]_net_1\, B => \gjkdbmpgrtc[5]\, 
        C => \bnwcvzjbgtc[5]\, Y => ADD_18x18_fast_I6_P0N_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I69_Y : NOR2A
      port map(A => N303, B => N299, Y => N336);
    
    \bnwcvzjbgtc_3[1]\ : MX2
      port map(A => N_558, B => N_575, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_592);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_57 : AND2A
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \bnvtvdkcnpp[1]_net_1\, Y => \ACT_LT4_E[2]\);
    
    \bnwcvzjbgtc_12[12]\ : MX2
      port map(A => N_671, B => N_739, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[12]\);
    
    \kkkmkxwwscv[0]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_3, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_3);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I154_Y : XNOR2
      port map(A => ADD_18x18_fast_I154_Y_0, B => N478, Y => 
        \fqkdsnjfpdb_i[4]\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I9_Y : NOR3
      port map(A => N105, B => N107, C => N108, Y => N124);
    
    \bnwcvzjbgtc_11[7]\ : MX2
      port map(A => \bnwcvzjbgtc_11_d[7]_net_1\, B => N_702, S
         => \bnwcvzjbgtc_11_s[7]_net_1\, Y => N_734);
    
    \gjkdbmpgrtc_11_d[9]\ : MX2
      port map(A => N_496, B => \rqrqhcwpqdn[3]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \gjkdbmpgrtc_11_d[9]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I41_Y : NOR2B
      port map(A => N245, B => N242, Y => N305);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I162_Y : XOR2
      port map(A => ADD_18x18_fast_I162_Y_0, B => N454_i, Y => 
        \fqkdsnjfpdb_i[12]\);
    
    \rqrqhcwpqdn[2]\ : DFN1E1C0
      port map(D => N_765, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[2]_net_1\);
    
    \gjkdbmpgrtc_3[12]\ : MX2
      port map(A => N_495, B => N_497, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_399);
    
    \jrgzmrqhbkv_m[5]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_5, B => N_199_i_0, Y
         => \jrgzmrqhbkv_m[5]_net_1\);
    
    \bnwcvzjbgtc_7[5]\ : MX2
      port map(A => N_596, B => N_604, S => rdgwgtpkbgc_3, Y => 
        N_664);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I106_Y : OR3A
      port map(A => I106_un1_Y_i, B => I76_un1_Y, C => N306, Y
         => N475);
    
    \tkcbxxqbtfx[2]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[15]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \tkcbxxqbtfx[2]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I4_P0N : OR2
      port map(A => N_253, B => N_252, Y => N242);
    
    \un1_bskrjhjvqpf_m[1]\ : OR2B
      port map(A => \un1_bskrjhjvqpf[1]\, B => N_201_i_0, Y => 
        \un1_bskrjhjvqpf_m[1]_net_1\);
    
    xwhwqsjfmgh : DFN1C0
      port map(D => fskhwddcbbg_6_sqmuxa, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => EV_DONE_net);
    
    \bnvtvdkcnpp_4[4]\ : MX2
      port map(A => \bnvtvdkcnpp[4]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_4, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[4]_net_1\);
    
    \fqkdsnjfpdb_m[1]\ : OR2B
      port map(A => \tkcbxxqbtfx[4]_net_1\, B => \fqkdsnjfpdb[1]\, 
        Y => \fqkdsnjfpdb_m[1]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I117_Y_1 : AO1
      port map(A => N326, B => N333, C => ADD_18x18_fast_I117_Y_0, 
        Y => ADD_18x18_fast_I117_Y_1);
    
    gcqsptsqnzg_iv_0_o2 : AO1B
      port map(A => \gpjgkmhxbkn_NE_1\, B => \gpjgkmhxbkn_NE_2\, 
        C => \rqrqhcwpqdn[0]_net_1\, Y => N_10);
    
    \gjkdbmpgrtc_7[8]\ : MX2
      port map(A => N_395, B => N_403, S => rdgwgtpkbgc_3, Y => 
        N_463);
    
    fqkdsnjfpdb_10 : AO13
      port map(A => \gjkdbmpgrtc[2]\, B => \ftbkrvpxdbp[2]_net_1\, 
        C => \bnwcvzjbgtc[2]\, Y => N_250);
    
    un2_ckghxwbsztp_I_20 : XOR2
      port map(A => N_4, B => \rqrqhcwpqdn[5]_net_1\, Y => I_20);
    
    \gjkdbmpgrtc_11[2]\ : NOR2A
      port map(A => N_393, B => rdgwgtpkbgc_3, Y => N_525);
    
    \mkmkbnghgkd[5]\ : MX2
      port map(A => INIT_ADDR_net(5), B => 
        TR_EV_ADDR_net_busnet_5, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_5);
    
    \tkcbxxqbtfx[13]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[4]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \tkcbxxqbtfx[13]_net_1\);
    
    \tkcbxxqbtfx_ns_i[8]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[10]_net_1\, 
        Y => \tkcbxxqbtfx_ns_i[8]_net_1\);
    
    \zbqggxmnpbs_0_iv_0[2]\ : AOI1B
      port map(A => \fqkdsnjfpdb[8]\, B => \tkcbxxqbtfx[5]_net_1\, 
        C => \ckghxwbsztp_m[1]_net_1\, Y => 
        \zbqggxmnpbs_0_iv_0[2]_net_1\);
    
    \mtbjcfqsbqf_m[3]\ : OR2B
      port map(A => \EV_CHHOLD_net_busnet_3\, B => 
        \rgmpzqrbghh_0\, Y => \mtbjcfqsbqf_m[3]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I167_Y_2 : XOR2
      port map(A => ADD_18x18_fast_I167_Y_1, B => N_278, Y => 
        ADD_18x18_fast_I167_Y_2);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[1]\ : AOI1B
      port map(A => \rgmpzqrbghh_0\, B => 
        \EV_CHHOLD_net_busnet_0\, C => \qrbxknbdvjj_m[1]_net_1\, 
        Y => \dhzrwbnrbpw_7_iv_0[1]\);
    
    \bnwcvzjbgtc_3[3]\ : MX2
      port map(A => N_575, B => N_677, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_594);
    
    \gjkdbmpgrtc_3[5]\ : MX2
      port map(A => N_473, B => N_490, S => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => N_392);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_Y_1 : OA1A
      port map(A => N286, B => N283, C => ADD_18x18_fast_I132_Y_0, 
        Y => ADD_18x18_fast_I132_Y_1);
    
    \tkcbxxqbtfx_ns_a3[10]\ : NOR2A
      port map(A => INIT_DONE_net, B => \fskhwddcbbg_1_sqmuxa\, Y
         => \tkcbxxqbtfx_ns[10]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I81_un1_Y : NOR2A
      port map(A => N313, B => \bnwcvzjbgtc[0]\, Y => I81_un1_Y);
    
    \bnwcvzjbgtc_11[4]\ : MX2
      port map(A => N_599, B => \ftbkrvpxdbp[4]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_731);
    
    \bnwcvzjbgtc_11[13]\ : MX2
      port map(A => N_651, B => \bnvtvdkcnpp[7]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_740);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I7_G0N : NOR2B
      port map(A => N_259, B => N_258, Y => N250);
    
    un1_xkwrgrspmcf : NOR3A
      port map(A => \tkcbxxqbtfx[9]_net_1\, B => 
        \rfrdbqfdrhx[0]_net_1\, C => \rfrdbqfdrhx[1]_net_1\, Y
         => \un1_xkwrgrspmcf\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I78_Y : AO1
      port map(A => N309, B => N312, C => N308, Y => N345);
    
    \ftbkrvpxdbp[5]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[5]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[5]_net_1\);
    
    \bnwcvzjbgtc_12[8]\ : MX2
      port map(A => N_667, B => N_735, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[8]\);
    
    \zbqggxmnpbs_0_iv_0[4]\ : AOI1B
      port map(A => \ckghxwbsztp[3]_net_1\, B => 
        \tkcbxxqbtfx[0]_net_1\, C => \fqkdsnjfpdb_m[1]_net_1\, Y
         => \zbqggxmnpbs_0_iv_0[4]_net_1\);
    
    wqpbnjzjqsx_1 : XNOR2
      port map(A => \rqrqhcwpqdn[2]_net_1\, B => 
        \bnvtvdkcnpp[2]_net_1\, Y => wqpbnjzjqsx_1_i);
    
    un1_rdgwgtpkbgc_2_0 : NOR2
      port map(A => \rdgwgtpkbgc_0[0]_net_1\, B => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => \un1_rdgwgtpkbgc_2_0\);
    
    \rqrqhcwpqdn_5_0[6]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_6, B => 
        EV_RAM_DO_B_net_busnet_6, S => \un1_xkwrgrspmcf\, Y => 
        N_769);
    
    kkjrqmngvjc_0_a2 : NOR2
      port map(A => EV_RAM_DO_B_net_busnet_8, B => N_237, Y => 
        N_240);
    
    \un1_bskrjhjvqpf_m[2]\ : XAI1A
      port map(A => N108, B => \EV_RAM_ADDR_B_net_busnet_1\, C
         => N_201_i_0, Y => \un1_bskrjhjvqpf_m[2]_net_1\);
    
    \qrbxknbdvjj_m[4]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[4]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[4]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_72 : AO1
      port map(A => \DWACT_CMPLE_PO2_DWACT_COMP0_E[1]\, B => 
        \DWACT_CMPLE_PO2_DWACT_COMP0_E[2]\, C => 
        \DWACT_CMPLE_PO2_DWACT_COMP0_E[0]\, Y => 
        \DWACT_COMP0_E[2]\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[3]\ : AOI1B
      port map(A => \rgmpzqrbghh_0\, B => 
        \EV_CHHOLD_net_busnet_2\, C => \qrbxknbdvjj_m[3]_net_1\, 
        Y => \dhzrwbnrbpw_7_iv_0[3]\);
    
    \ckghxwbsztp[0]\ : DFN1E1C0
      port map(D => \ckghxwbsztp_2[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \ckghxwbsztp[0]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_61 : NOR2A
      port map(A => \ACT_LT4_E[4]\, B => \ACT_LT4_E[5]\, Y => 
        \ACT_LT4_E[6]\);
    
    fqkdsnjfpdb_41 : XNOR2
      port map(A => \fqkdsnjfpdb_41_0\, B => \gjkdbmpgrtc[9]\, Y
         => N_263);
    
    \bnwcvzjbgtc_11[10]\ : MX2
      port map(A => N_701, B => \bnwcvzjbgtc_11_d[10]_net_1\, S
         => \gjkdbmpgrtc_11_s[11]_net_1\, Y => N_737);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I116_Y_1 : OR3
      port map(A => I56_un1_Y, B => N286, C => I88_un1_Y, Y => 
        ADD_18x18_fast_I116_Y_1);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I154_Y_0 : XOR2
      port map(A => N_253, B => N_252, Y => 
        ADD_18x18_fast_I154_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I102_Y : OR2
      port map(A => N337, B => I102_un1_Y, Y => 
        ADD_18x18_fast_I102_Y);
    
    fqkdsnjfpdb_11_0 : XOR2
      port map(A => \ftbkrvpxdbp[3]_net_1\, B => \bnwcvzjbgtc[3]\, 
        Y => \fqkdsnjfpdb_11_0\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_21 : AO1C
      port map(A => \rqrqhcwpqdn[8]_net_1\, B => 
        \bnvtvdkcnpp[8]_net_1\, C => N_30, Y => N_32);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_Y_3 : NOR3C
      port map(A => I84_un1_Y, B => ADD_18x18_fast_I132_Y_1, C
         => I132_un1_Y_i, Y => ADD_18x18_fast_I132_Y_3);
    
    fqkdsnjfpdb_80 : AO18
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        \bnwcvzjbgtc[16]\, C => \gjkdbmpgrtc[16]\, Y => N_278);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I67_Y : NOR2B
      port map(A => N301, B => N297, Y => N334);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I120_un1_Y_0 : OA1A
      port map(A => I80_un1_Y_i, B => N310, C => N332, Y => 
        ADD_18x18_fast_I120_un1_Y_0);
    
    \gjkdbmpgrtc_7[0]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => N_395, Y => N_455);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I25_Y : OA1
      port map(A => N_268, B => N_269, C => N269, Y => N289);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I70_Y : AO1
      port map(A => N301, B => N304, C => N300, Y => N337);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I6_P0N : OR2
      port map(A => ADD_18x18_fast_I6_P0N_0, B => N_257, Y => 
        N248);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I12_G0N : NOR2B
      port map(A => N_269, B => N_268, Y => N265);
    
    \gjkdbmpgrtc_11_s[7]\ : OR2A
      port map(A => \rdgwgtpkbgc_0[1]_net_1\, B => rdgwgtpkbgc_3, 
        Y => \gjkdbmpgrtc_11_s[7]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I5_G0N : OA1
      port map(A => fqkdsnjfpdb_9, B => \fqkdsnjfpdb_20_0\, C => 
        N_255, Y => N244);
    
    \bnwcvzjbgtc_11[1]\ : MX2
      port map(A => N_596, B => \ftbkrvpxdbp[1]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_728);
    
    wqpbnjzjqsx_4 : XNOR2
      port map(A => \rqrqhcwpqdn[5]_net_1\, B => 
        \bnvtvdkcnpp[5]_net_1\, Y => wqpbnjzjqsx_4_i);
    
    \tkcbxxqbtfx[10]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[7]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[10]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_m : OR2B
      port map(A => un2_pbzxzjhqhwz, B => dbdctxjdvkp_2_sqmuxa, Y
         => un2_pbzxzjhqhwz_m);
    
    \mtbjcfqsbqf[1]\ : DFN1E1C0
      port map(D => dspfgfmqhwh(1), CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \qmmwhjxxxmv\, Q => 
        \EV_CHHOLD_net_busnet_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I43_Y : NOR2B
      port map(A => N242, B => N239, Y => N307);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I119_Y_0 : AO1A
      port map(A => N330, B => N337, C => N329, Y => 
        ADD_18x18_fast_I119_Y_0);
    
    \tkcbxxqbtfx[7]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[10]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_ASSCADDR_net_busnet_2\);
    
    gpjgkmhxbkn_NE_2 : NOR3C
      port map(A => gpjgkmhxbkn_3_i, B => gpjgkmhxbkn_4_i, C => 
        gpjgkmhxbkn_0_i, Y => \gpjgkmhxbkn_NE_2\);
    
    \zbqggxmnpbs_r[8]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[5]_net_1\, B => 
        \fqkdsnjfpdb_m[14]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_8);
    
    \bnvtvdkcnpp_4[0]\ : MX2
      port map(A => \bnvtvdkcnpp[0]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_0, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[0]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I11_P0N : OR2
      port map(A => ADD_18x18_fast_I11_P0N_0, B => N_267, Y => 
        N263);
    
    zcjzqnkdqwb_iv : MX2C
      port map(A => INIT_EV_WEN_net, B => TR_EV_RD_net, S => 
        INIT_DONE_net, Y => EV_RAM_CSN_A_net);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[8]\ : AO1B
      port map(A => N_201_i_0, B => \un1_bskrjhjvqpf[9]\, C => 
        \dhzrwbnrbpw_7_iv_0[8]\, Y => \dhzrwbnrbpw_7[8]\);
    
    \bnwcvzjbgtc_11_d[6]\ : MX2
      port map(A => N_697, B => \bnvtvdkcnpp[0]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \bnwcvzjbgtc_11_d[6]_net_1\);
    
    fqkdsnjfpdb_55 : AO13
      port map(A => \bnvtvdkcnpp[5]_net_1\, B => 
        \gjkdbmpgrtc[11]\, C => \bnwcvzjbgtc[11]\, Y => N_268);
    
    fqkdsnjfpdb_16_0 : XOR2
      port map(A => \ftbkrvpxdbp[4]_net_1\, B => \bnwcvzjbgtc[4]\, 
        Y => \fqkdsnjfpdb_16_0\);
    
    \dhzrwbnrbpw[2]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_2\);
    
    \ckghxwbsztp_m[1]\ : OR2B
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => 
        \ckghxwbsztp[1]_net_1\, Y => \ckghxwbsztp_m[1]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I102_un1_Y : NOR2B
      port map(A => N345, B => N338, Y => I102_un1_Y);
    
    \bnvtvdkcnpp_7[11]\ : MX2C
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_2, S => \un1_kkgccghmrzf\, Y => 
        \bnvtvdkcnpp_7[11]_net_1\);
    
    \rqrqhcwpqdn[3]\ : DFN1E1C0
      port map(D => N_766, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[3]_net_1\);
    
    \dhzrwbnrbpw[1]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_1\);
    
    \bnwcvzjbgtc_11_d[5]\ : MX2A
      port map(A => \bnwcvzjbgtc_11_d_d[5]_net_1\, B => 
        \bnvtvdkcnpp[4]_net_1\, S => 
        \bnwcvzjbgtc_11_d_s[5]_net_1\, Y => 
        \bnwcvzjbgtc_11_d[5]_net_1\);
    
    \bnvtvdkcnpp[8]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[8]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[8]_net_1\);
    
    \tkcbxxqbtfx[15]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[2]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[15]_net_1\);
    
    fqkdsnjfpdb_66 : XNOR3
      port map(A => \gjkdbmpgrtc[14]\, B => 
        \bnvtvdkcnpp[8]_net_1\, C => \bnwcvzjbgtc[14]\, Y => 
        N_273);
    
    fqkdsnjfpdb_45_0 : OA1B
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => \gjkdbmpgrtc[9]\, 
        C => \bnwcvzjbgtc[9]\, Y => \fqkdsnjfpdb_45_0\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    fskhwddcbbg_1_sqmuxa_0_a2 : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_7, B => N_240, Y => 
        \fskhwddcbbg_1_sqmuxa\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I100_un1_Y : OA1
      port map(A => I76_un1_Y, B => N306, C => N336, Y => 
        I100_un1_Y);
    
    \tkcbxxqbtfx_ns_i[5]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[13]_net_1\, 
        Y => \tkcbxxqbtfx_ns_i[5]_net_1\);
    
    \bnvtvdkcnpp[2]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[2]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[2]_net_1\);
    
    fqkdsnjfpdb_20_0 : OA1B
      port map(A => \ftbkrvpxdbp[4]_net_1\, B => \gjkdbmpgrtc[4]\, 
        C => \bnwcvzjbgtc[4]\, Y => \fqkdsnjfpdb_20_0\);
    
    gpjgkmhxbkn_3 : XNOR2
      port map(A => EV_RAM_DO_B_net_busnet_4, B => 
        \rqrqhcwpqdn[4]_net_1\, Y => gpjgkmhxbkn_3_i);
    
    \gjkdbmpgrtc_12_d[3]\ : MX2C
      port map(A => N_390, B => N_526, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => 
        \gjkdbmpgrtc_12_d[3]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I74_Y : AO1
      port map(A => N305, B => N308, C => N304, Y => N341);
    
    \bnwcvzjbgtc_7[14]\ : OR2A
      port map(A => N_605, B => rdgwgtpkbgc_3, Y => N_673);
    
    \rqrqhcwpqdn_9_0[9]\ : MX2C
      port map(A => ASSC_RAM_DO_A_net_busnet_0, B => 
        EV_RAM_DO_B_net_busnet_0, S => \un1_mvnkctvqsgp\, Y => 
        N_784);
    
    \gjkdbmpgrtc_11[1]\ : NOR2A
      port map(A => N_392, B => rdgwgtpkbgc_3, Y => N_524);
    
    \rdgwgtpkbgc_1[0]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_0, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_1[0]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I2_P0N_0 : AO18
      port map(A => \ftbkrvpxdbp[1]_net_1\, B => \bnwcvzjbgtc[1]\, 
        C => \ftbkrvpxdbp[0]_net_1\, Y => ADD_18x18_fast_I2_P0N_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I164_Y_0 : XNOR2
      port map(A => N_273, B => N_272, Y => 
        ADD_18x18_fast_I164_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I13_P0N : OR2
      port map(A => ADD_18x18_fast_I13_P0N_0, B => 
        \fqkdsnjfpdb_60_0\, Y => N269);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I118_Y_0 : AO1A
      port map(A => N335, B => N328, C => N327, Y => 
        ADD_18x18_fast_I118_Y_0);
    
    gpjgkmhxbkn_NE_1 : XA1A
      port map(A => \rqrqhcwpqdn[3]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_3, C => gpjgkmhxbkn_1_i, Y => 
        \gpjgkmhxbkn_NE_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I72_Y : AO1
      port map(A => N303, B => N306, C => N302, Y => N339);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I61_Y : NOR2
      port map(A => N295, B => N291, Y => N328);
    
    \rqrqhcwpqdn[5]\ : DFN1E1C0
      port map(D => N_768, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[5]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I159_Y : XOR2
      port map(A => ADD_18x18_fast_I159_Y_0, B => N463, Y => 
        \fqkdsnjfpdb[9]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I107_un1_Y : OR3B
      port map(A => N239, B => ADD_18x18_fast_I79_Y_0, C => 
        \bnwcvzjbgtc[0]\, Y => I107_un1_Y_i);
    
    \bnwcvzjbgtc_12[11]\ : MX2
      port map(A => N_670, B => N_738, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[11]\);
    
    un2_ckghxwbsztp_I_12 : AND3
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \rqrqhcwpqdn[2]_net_1\, C => \rqrqhcwpqdn[3]_net_1\, Y
         => N_9_0);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_64 : AOI1A
      port map(A => \ACT_LT4_E[7]\, B => \ACT_LT4_E[8]\, C => 
        \ACT_LT4_E[5]\, Y => \ACT_LT4_E[10]\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[6]\ : AOI1B
      port map(A => N_199_i_0, B => EV_RAM_DO_B_net_busnet_6, C
         => \qrbxknbdvjj_m[6]_net_1\, Y => 
        \dhzrwbnrbpw_7_iv_0[6]\);
    
    bskrjhjvqpf_i_1 : OR3
      port map(A => N_215, B => \bskrjhjvqpf_i_2_1\, C => 
        \bskrjhjvqpf_i_0\, Y => \bskrjhjvqpf_i_1\);
    
    \zbqggxmnpbs_r[6]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[3]_net_1\, B => 
        \fqkdsnjfpdb_m[12]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_6);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[1]\ : OR3C
      port map(A => \jrgzmrqhbkv_m[1]_net_1\, B => 
        \dhzrwbnrbpw_7_iv_0[1]\, C => 
        \un1_bskrjhjvqpf_m[2]_net_1\, Y => \dhzrwbnrbpw_7[1]\);
    
    fqkdsnjfpdb_5 : AO13
      port map(A => \ftbkrvpxdbp[0]_net_1\, B => 
        \ftbkrvpxdbp[1]_net_1\, C => \bnwcvzjbgtc[1]\, Y => N_248);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I156_Y_0 : XOR2
      port map(A => N_257, B => N_256, Y => 
        ADD_18x18_fast_I156_Y_0);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_24 : OR2A
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        \rqrqhcwpqdn[11]_net_1\, Y => N_35);
    
    \tkcbxxqbtfx[0]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[17]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[0]_net_1\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[4]\ : AO1B
      port map(A => N_201_i_0, B => \un1_bskrjhjvqpf[5]\, C => 
        \dhzrwbnrbpw_7_iv_1[4]\, Y => \dhzrwbnrbpw_7[4]\);
    
    zbcrjjxqjgg_i_o3 : AO1
      port map(A => N_203, B => \tkcbxxqbtfx[12]_net_1\, C => 
        \tkcbxxqbtfx[5]_net_1\, Y => N_206);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I112_un1_Y_0 : NOR3A
      port map(A => N328, B => N283, C => N287_i, Y => 
        ADD_18x18_fast_I112_un1_Y_0);
    
    bskrjhjvqpf_i_o2_0 : NOR2
      port map(A => \tkcbxxqbtfx[14]_net_1\, B => 
        \tkcbxxqbtfx[8]_net_1\, Y => N_207);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I121_un1_Y : NOR2B
      port map(A => ADD_18x18_fast_I121_un1_Y_0, B => N334, Y => 
        I121_un1_Y);
    
    \rdgwgtpkbgc_2[2]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_2, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_2[2]_net_1\);
    
    \tkcbxxqbtfx_ns_a3_1[4]\ : OR3B
      port map(A => INIT_DONE_net, B => N_240, C => 
        EV_RAM_DO_B_net_busnet_7_0, Y => N_228);
    
    \bnwcvzjbgtc_3[13]\ : MX2
      port map(A => N_700, B => N_702, S => 
        \rdgwgtpkbgc[1]_net_1\, Y => N_604);
    
    \bnwcvzjbgtc_12[16]\ : MX2
      port map(A => N_675, B => N_743, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[16]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I158_Y : AX1D
      port map(A => I102_un1_Y, B => ADD_18x18_fast_I123_Y_0, C
         => ADD_18x18_fast_I158_Y_0, Y => \fqkdsnjfpdb[8]\);
    
    \mkmkbnghgkd[0]\ : MX2
      port map(A => INIT_ADDR_net(0), B => 
        TR_EV_ADDR_net_busnet_0, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_0);
    
    \bnwcvzjbgtc_6[9]\ : NOR3A
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        \rdgwgtpkbgc[0]_net_1\, C => \rdgwgtpkbgc[1]_net_1\, Y
         => N_651);
    
    \tkcbxxqbtfx_ns_a3[14]\ : NOR3A
      port map(A => INIT_DONE_net, B => N_241, C => N_205, Y => 
        \tkcbxxqbtfx_ns[14]\);
    
    \zbqggxmnpbs_0_iv_0[5]\ : AOI1B
      port map(A => \fqkdsnjfpdb[2]\, B => 
        \tkcbxxqbtfx_0[4]_net_1\, C => \ckghxwbsztp_m[4]_net_1\, 
        Y => \zbqggxmnpbs_0_iv_0[5]_net_1\);
    
    fqkdsnjfpdb_40_0 : OA1B
      port map(A => \bnvtvdkcnpp[2]_net_1\, B => \gjkdbmpgrtc[8]\, 
        C => \bnwcvzjbgtc[8]\, Y => \fqkdsnjfpdb_40_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I157_Y : XOR3
      port map(A => N_258, B => N_259, C => N469, Y => 
        \fqkdsnjfpdb[7]\);
    
    bskrjhjvqpf_i_0 : OR2
      port map(A => \tkcbxxqbtfx[15]_net_1\, B => 
        \tkcbxxqbtfx[9]_net_1\, Y => \bskrjhjvqpf_i_0\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[2]\ : AO1B
      port map(A => N_201_i_0, B => \un1_bskrjhjvqpf[3]\, C => 
        \dhzrwbnrbpw_7_iv_1[2]\, Y => \dhzrwbnrbpw_7[2]\);
    
    \bnwcvzjbgtc_3[2]\ : MX2
      port map(A => N_574, B => N_676, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_593);
    
    \gjkdbmpgrtc_11[7]\ : MX2
      port map(A => N_496, B => \gjkdbmpgrtc_11_d[7]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => 
        \gjkdbmpgrtc_11[7]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I151_Y : XOR2
      port map(A => ADD_18x18_fast_I151_Y_0, B => N314, Y => 
        \fqkdsnjfpdb[1]\);
    
    \gjkdbmpgrtc_7[5]\ : MX2
      port map(A => N_392, B => N_400, S => rdgwgtpkbgc_3, Y => 
        N_460);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I2_G0N : NOR2B
      port map(A => N_249, B => N_248, Y => N235);
    
    \rqrqhcwpqdn[8]\ : DFN1E1C0
      port map(D => N_771, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[8]_net_1\);
    
    \qrbxknbdvjj[8]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_8\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[8]_net_1\);
    
    \dhzrwbnrbpw[7]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[7]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_7\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I150_Y : XOR3
      port map(A => \gjkdbmpgrtc[0]\, B => \ftbkrvpxdbp[0]_net_1\, 
        C => \bnwcvzjbgtc[0]\, Y => \fqkdsnjfpdb[0]\);
    
    \bnwcvzjbgtc_11_d[9]\ : MX2
      port map(A => N_700, B => \bnvtvdkcnpp[3]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \bnwcvzjbgtc_11_d[9]_net_1\);
    
    \gjkdbmpgrtc_12[16]\ : MX2
      port map(A => N_471, B => N_539, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[16]\);
    
    \gjkdbmpgrtc_12[15]\ : MX2
      port map(A => N_470, B => N_538, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[15]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I155_Y : XNOR2
      port map(A => ADD_18x18_fast_I155_Y_0, B => N475, Y => 
        \fqkdsnjfpdb_i[5]\);
    
    \rdgwgtpkbgc_0[2]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_2, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \fskhwddcbbg_1_sqmuxa\, Q => 
        \rdgwgtpkbgc_0[2]_net_1\);
    
    \bnwcvzjbgtc_9[10]\ : MX2
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        \bnvtvdkcnpp[11]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_703);
    
    \bnvtvdkcnpp[3]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[3]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[3]_net_1\);
    
    \zbqggxmnpbs_r[2]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[17]_net_1\, B => 
        \zbqggxmnpbs_0_iv_0[2]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_2);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_1[3]\ : AOI1B
      port map(A => N_199_i_0, B => EV_RAM_DO_B_net_busnet_3, C
         => \dhzrwbnrbpw_7_iv_0[3]\, Y => \dhzrwbnrbpw_7_iv_1[3]\);
    
    fqkdsnjfpdb_46 : XNOR3
      port map(A => \bnwcvzjbgtc[10]\, B => 
        \bnvtvdkcnpp[4]_net_1\, C => \gjkdbmpgrtc[10]\, Y => 
        N_265);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I117_Y_0 : AO1
      port map(A => N289, B => N292, C => N288, Y => 
        ADD_18x18_fast_I117_Y_0);
    
    \gjkdbmpgrtc_11[8]\ : MX2
      port map(A => N_497, B => \gjkdbmpgrtc_11_d[8]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => 
        \gjkdbmpgrtc_11[8]_net_1\);
    
    zbcrjjxqjgg_i_o3_0 : NOR2
      port map(A => \tkcbxxqbtfx[2]_net_1\, B => N_209, Y => 
        N_212);
    
    \gjkdbmpgrtc_11_d[8]\ : MX2
      port map(A => N_495, B => \rqrqhcwpqdn[2]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \gjkdbmpgrtc_11_d[8]_net_1\);
    
    \ckghxwbsztp_2_0_a3[3]\ : NOR2B
      port map(A => I_13, B => N_9, Y => \ckghxwbsztp_2[3]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I151_Y_0 : XNOR3
      port map(A => \bnwcvzjbgtc[1]\, B => \fqkdsnjfpdb_1_0\, C
         => \gjkdbmpgrtc[1]\, Y => ADD_18x18_fast_I151_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I3_G0N : XA1A
      port map(A => \gjkdbmpgrtc[3]\, B => \fqkdsnjfpdb_11_0\, C
         => N_250, Y => N238);
    
    dbdctxjdvkp_2_sqmuxa_0_a3 : NOR2A
      port map(A => N_227_1, B => N_239, Y => 
        dbdctxjdvkp_2_sqmuxa);
    
    \mkmkbnghgkd[8]\ : MX2
      port map(A => INIT_ADDR_net(8), B => 
        TR_EV_ADDR_net_busnet_8, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_8);
    
    wqpbnjzjqsx_3 : XNOR2
      port map(A => \rqrqhcwpqdn[4]_net_1\, B => 
        \bnvtvdkcnpp[4]_net_1\, Y => wqpbnjzjqsx_3_i);
    
    \gjkdbmpgrtc_3[7]\ : MX2
      port map(A => N_490, B => N_492, S => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => N_394);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I166_Y_0 : XNOR2
      port map(A => N_277, B => N_276, Y => 
        ADD_18x18_fast_I166_Y_0);
    
    \bnwcvzjbgtc_7[3]\ : MX2
      port map(A => N_594, B => N_602, S => rdgwgtpkbgc_3, Y => 
        N_662);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_55 : NOR2A
      port map(A => \rqrqhcwpqdn[0]_net_1\, B => 
        \bnvtvdkcnpp[0]_net_1\, Y => \ACT_LT4_E[0]\);
    
    \gjkdbmpgrtc_11[5]\ : NOR2A
      port map(A => N_396, B => rdgwgtpkbgc_3, Y => N_528);
    
    \qrbxknbdvjj[7]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_7\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[7]_net_1\);
    
    \gjkdbmpgrtc_9[11]\ : NOR2A
      port map(A => \rqrqhcwpqdn[11]_net_1\, B => 
        \rdgwgtpkbgc[0]_net_1\, Y => N_500);
    
    \zbqggxmnpbs_0_iv_0[1]\ : AOI1B
      port map(A => \fqkdsnjfpdb[7]\, B => \tkcbxxqbtfx[5]_net_1\, 
        C => \ckghxwbsztp_m[0]_net_1\, Y => 
        \zbqggxmnpbs_0_iv_0[1]_net_1\);
    
    \zbqggxmnpbs_r[7]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[4]_net_1\, B => 
        \fqkdsnjfpdb_m[13]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_7);
    
    \bnvtvdkcnpp_8[10]\ : MX2C
      port map(A => \bnvtvdkcnpp_7[10]_net_1\, B => 
        \fqkdsnjfpdb_i[16]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[10]_net_1\);
    
    \gjkdbmpgrtc_11[9]\ : MX2
      port map(A => N_498, B => \gjkdbmpgrtc_11_d[9]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => N_532);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_7 : AND2
      port map(A => \DWACT_BL_EQUAL_0_E[4]\, B => 
        \DWACT_BL_EQUAL_0_E[3]\, Y => 
        \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[1]\);
    
    \tkcbxxqbtfx[4]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[13]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[4]_net_1\);
    
    \fqkdsnjfpdb_m[12]\ : OR2A
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => 
        \fqkdsnjfpdb_i[12]\, Y => \fqkdsnjfpdb_m[12]_net_1\);
    
    \gjkdbmpgrtc_12[11]\ : MX2
      port map(A => N_466, B => N_534, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[11]\);
    
    \tkcbxxqbtfx_ns_a3[16]\ : NOR3A
      port map(A => INIT_DONE_net, B => N_237, C => 
        \tkcbxxqbtfx_ns_1[16]\, Y => \tkcbxxqbtfx_ns[16]\);
    
    \gjkdbmpgrtc_11[6]\ : MX2
      port map(A => \gjkdbmpgrtc_11_d_0[6]_net_1\, B => N_497, S
         => \gjkdbmpgrtc_11_s_0[6]_net_1\, Y => N_529);
    
    un2_ckghxwbsztp_I_5 : XOR2
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \rqrqhcwpqdn[2]_net_1\, Y => I_5);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_62 : NOR2A
      port map(A => \bnvtvdkcnpp[2]_net_1\, B => 
        \rqrqhcwpqdn[2]_net_1\, Y => \ACT_LT4_E[7]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_8 : AND2
      port map(A => \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[1]\, B => 
        \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[0]\, Y => 
        \DWACT_COMP0_E[1]\);
    
    fqkdsnjfpdb_15 : AO13
      port map(A => \ftbkrvpxdbp[3]_net_1\, B => \gjkdbmpgrtc[3]\, 
        C => \bnwcvzjbgtc[3]\, Y => N_252);
    
    \gjkdbmpgrtc_12[10]\ : MX2
      port map(A => N_465, B => N_533, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[10]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I63_Y : OR2B
      port map(A => N297, B => N293, Y => N330);
    
    \rqrqhcwpqdn[9]\ : DFN1C0
      port map(D => \rqrqhcwpqdn_9[9]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \rqrqhcwpqdn[9]_net_1\);
    
    \rqrqhcwpqdn_5_0[7]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_7, B => 
        EV_RAM_DO_B_net_busnet_7, S => \un1_xkwrgrspmcf\, Y => 
        N_770);
    
    \tkcbxxqbtfx[3]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[14]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \tkcbxxqbtfx[3]_net_1\);
    
    fskhwddcbbg_5_sqmuxa_0_a2 : OR2A
      port map(A => \tkcbxxqbtfx[12]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_6, Y => N_237);
    
    fqkdsnjfpdb_60_0 : OA1B
      port map(A => \bnvtvdkcnpp[6]_net_1\, B => 
        \gjkdbmpgrtc[12]\, C => \bnwcvzjbgtc[12]\, Y => 
        \fqkdsnjfpdb_60_0\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_22 : OA1A
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        \rqrqhcwpqdn[10]_net_1\, C => N_29, Y => N_33);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I84_un1_Y : OR3A
      port map(A => N327, B => N283, C => N287_i, Y => I84_un1_Y);
    
    \bnwcvzjbgtc_12[0]\ : MX2
      port map(A => N_659, B => N_727, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[0]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I55_Y : OR2B
      port map(A => N289, B => N285, Y => N322);
    
    \gjkdbmpgrtc_11[14]\ : NOR2B
      port map(A => \rqrqhcwpqdn[8]_net_1\, B => rdgwgtpkbgc_3, Y
         => N_537);
    
    \bnwcvzjbgtc_12[4]\ : MX2
      port map(A => N_663, B => N_731, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[4]\);
    
    \kkkmkxwwscv[1]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_4, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_4);
    
    \tkcbxxqbtfx[6]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[11]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[6]_net_1\);
    
    \tkcbxxqbtfx[12]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[5]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[12]_net_1\);
    
    \gjkdbmpgrtc_9[4]\ : MX2
      port map(A => \rqrqhcwpqdn[4]_net_1\, B => 
        \rqrqhcwpqdn[5]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_493);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I18_un1_Y : OR3A
      port map(A => \EV_RAM_ADDR_B_net_busnet_3\, B => N107, C
         => N108, Y => I18_un1_Y);
    
    \rqrqhcwpqdn_5_0[8]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_8, B => 
        EV_RAM_DO_B_net_busnet_8, S => \un1_xkwrgrspmcf\, Y => 
        N_771);
    
    wqpbnjzjqsx_NE_1 : XA1A
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => 
        \rqrqhcwpqdn[3]_net_1\, C => wqpbnjzjqsx_1_i, Y => 
        \wqpbnjzjqsx_NE_1\);
    
    \gjkdbmpgrtc_7[7]\ : MX2
      port map(A => N_394, B => N_402, S => rdgwgtpkbgc_3, Y => 
        N_462);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I8_Y_1 : NOR3B
      port map(A => \EV_RAM_ADDR_B_net_busnet_5\, B => 
        \EV_RAM_ADDR_B_net_busnet_6\, C => N105, Y => 
        ADD_9x9_medium_I8_Y_1);
    
    \bnvtvdkcnpp_4[2]\ : MX2
      port map(A => \bnvtvdkcnpp[2]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_2, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[2]_net_1\);
    
    \rqrqhcwpqdn[4]\ : DFN1E1C0
      port map(D => N_767, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[4]_net_1\);
    
    \bnvtvdkcnpp_8[4]\ : MX2
      port map(A => \bnvtvdkcnpp_4[4]_net_1\, B => 
        \fqkdsnjfpdb[10]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[4]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_44 : AND2A
      port map(A => \rqrqhcwpqdn[5]_net_1\, B => 
        \bnvtvdkcnpp[5]_net_1\, Y => \ACT_LT3_E[2]\);
    
    \qrbxknbdvjj_m[1]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[1]_net_1\, C => \rgmpzqrbghh_0\, Y => 
        \qrbxknbdvjj_m[1]_net_1\);
    
    \bnwcvzjbgtc_9[0]\ : MX2
      port map(A => \bnvtvdkcnpp[0]_net_1\, B => 
        \bnvtvdkcnpp[1]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_693);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I106_un1_Y : OR2B
      port map(A => N344, B => N314, Y => I106_un1_Y_i);
    
    \qrbxknbdvjj[6]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_6\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[6]_net_1\);
    
    \bnvtvdkcnpp[9]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[9]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[9]_net_1\);
    
    \rdgwgtpkbgc_2[1]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_2[1]_net_1\);
    
    bskrjhjvqpf_i_o2 : OR2A
      port map(A => EV_RAM_DO_B_net_busnet_6, B => 
        EV_RAM_DO_B_net_busnet_8, Y => N_205);
    
    dhzrwbnrbpw_0_sqmuxa_i : OA1B
      port map(A => \tkcbxxqbtfx[11]_net_1\, B => 
        \tkcbxxqbtfx[14]_net_1\, C => \rgmpzqrbghh\, Y => 
        N_199_i_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I6_G0N : NOR2B
      port map(A => N_257, B => N_256, Y => N247);
    
    \bnwcvzjbgtc_12[13]\ : MX2
      port map(A => N_672, B => N_740, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[13]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I80_un1_Y : OR2B
      port map(A => N314, B => N311, Y => I80_un1_Y_i);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I98_un1_Y : NOR2B
      port map(A => N341, B => N334, Y => I98_un1_Y);
    
    \bnwcvzjbgtc_2[1]\ : MX2
      port map(A => \ftbkrvpxdbp[3]_net_1\, B => 
        \ftbkrvpxdbp[4]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_575);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I38_Y : AO1
      port map(A => N244, B => N248, C => N247, Y => N302);
    
    \tkcbxxqbtfx[11]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \tkcbxxqbtfx[11]_net_1\);
    
    \bnvtvdkcnpp_4[3]\ : MX2
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_3, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[3]_net_1\);
    
    \kkkmkxwwscv[2]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_5, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_5);
    
    fskhwddcbbg_6_sqmuxa_0_a3 : NOR2
      port map(A => \fskhwddcbbg_6_sqmuxa_0_a3_0\, B => N_241, Y
         => fskhwddcbbg_6_sqmuxa);
    
    un2_ckghxwbsztp_I_9 : XOR2
      port map(A => N_12, B => \rqrqhcwpqdn[3]_net_1\, Y => I_9);
    
    un1_fskhwddcbbg_i : OR2
      port map(A => N_209, B => N_206, Y => N_197);
    
    \gjkdbmpgrtc_8[1]\ : NOR2B
      port map(A => \rqrqhcwpqdn[0]_net_1\, B => 
        \rdgwgtpkbgc[0]_net_1\, Y => N_473);
    
    \gjkdbmpgrtc_12[7]\ : MX2
      port map(A => N_462, B => \gjkdbmpgrtc_11[7]_net_1\, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[7]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I120_Y_0 : AO1
      port map(A => N340, B => ADD_18x18_fast_I120_un1_Y_0, C => 
        N331, Y => ADD_18x18_fast_I120_Y_0);
    
    \tkcbxxqbtfx_ns_i[9]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[9]_net_1\, Y
         => \tkcbxxqbtfx_ns_i[9]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_77 : AO1
      port map(A => \DWACT_COMP0_E[1]\, B => \DWACT_COMP0_E[2]\, 
        C => \DWACT_COMP0_E[0]\, Y => un2_pbzxzjhqhwz);
    
    \tkcbxxqbtfx[14]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[3]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[14]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_56 : OR2A
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \bnvtvdkcnpp[1]_net_1\, Y => \ACT_LT4_E[1]\);
    
    gpjgkmhxbkn_1 : XNOR2
      port map(A => EV_RAM_DO_B_net_busnet_2, B => 
        \rqrqhcwpqdn[2]_net_1\, Y => gpjgkmhxbkn_1_i);
    
    \bnwcvzjbgtc_3[5]\ : MX2
      port map(A => N_677, B => N_694, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_596);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_Y_0 : AO18
      port map(A => N_277, B => N_276, C => N274, Y => 
        ADD_18x18_fast_I132_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I45_Y : NOR2B
      port map(A => N239, B => N236, Y => N309);
    
    \ftbkrvpxdbp[2]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[2]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[2]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I56_un1_Y : NOR2
      port map(A => N290, B => N287_i, Y => I56_un1_Y);
    
    \mkmkbnghgkd[6]\ : MX2
      port map(A => INIT_ADDR_net(6), B => 
        TR_EV_ADDR_net_busnet_6, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_6);
    
    \tkcbxxqbtfx_1[4]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[13]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx_1[4]_net_1\);
    
    \bnwcvzjbgtc_3[11]\ : MX2
      port map(A => N_698, B => N_700, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_602);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I14_P0N : OR2A
      port map(A => N_272, B => N_273, Y => N272);
    
    \ckghxwbsztp_2_0_a3[2]\ : NOR2B
      port map(A => I_9, B => N_9, Y => \ckghxwbsztp_2[2]\);
    
    \bnwcvzjbgtc_12[10]\ : MX2
      port map(A => N_669, B => N_737, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[10]\);
    
    kkjrqmngvjc_0_0 : OR3
      port map(A => N_215, B => \bskrjhjvqpf_i_2_1\, C => 
        \tkcbxxqbtfx[1]_net_1\, Y => \kkjrqmngvjc_0_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I77_Y : NOR2B
      port map(A => N311, B => N307, Y => N344);
    
    \gjkdbmpgrtc_11_d_0[6]\ : MX2
      port map(A => N_499, B => \rqrqhcwpqdn[0]_net_1\, S => 
        \gjkdbmpgrtc_11_s[6]_net_1\, Y => 
        \gjkdbmpgrtc_11_d_0[6]_net_1\);
    
    fqkdsnjfpdb_51 : XNOR3
      port map(A => \bnwcvzjbgtc[11]\, B => 
        \bnvtvdkcnpp[5]_net_1\, C => \gjkdbmpgrtc[11]\, Y => 
        N_267);
    
    \gjkdbmpgrtc_12[12]\ : MX2
      port map(A => N_467, B => N_535, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[12]\);
    
    fqkdsnjfpdb_31_0 : XOR2
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => \bnwcvzjbgtc[7]\, 
        Y => \fqkdsnjfpdb_31_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I167_Y_1 : MX2
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        \rqrqhcwpqdn[11]_net_1\, S => \gjkdbmpgrtc68\, Y => 
        ADD_18x18_fast_I167_Y_1);
    
    \qrbxknbdvjj[1]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[1]_net_1\);
    
    fqkdsnjfpdb_38 : NOR2B
      port map(A => \gjkdbmpgrtc[8]\, B => \bnvtvdkcnpp[2]_net_1\, 
        Y => \fqkdsnjfpdb_21\);
    
    \gjkdbmpgrtc_12[13]\ : MX2
      port map(A => N_468, B => N_536, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[13]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I30_Y : AOI1
      port map(A => N256, B => N260, C => N259, Y => N294);
    
    \bnwcvzjbgtc_11[14]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => \bnvtvdkcnpp[8]_net_1\, Y
         => N_741);
    
    \tkcbxxqbtfx_ns_i[17]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[1]_net_1\, Y
         => \tkcbxxqbtfx_ns_i[17]_net_1\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[3]\ : AO1B
      port map(A => N_201_i_0, B => \un1_bskrjhjvqpf[4]\, C => 
        \dhzrwbnrbpw_7_iv_1[3]\, Y => \dhzrwbnrbpw_7[3]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_34 : XNOR2
      port map(A => \bnvtvdkcnpp[4]_net_1\, B => 
        \rqrqhcwpqdn[4]_net_1\, Y => \DWACT_BL_EQUAL_0_E[0]\);
    
    \kkkmkxwwscv[3]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_6, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_6);
    
    \gjkdbmpgrtc_9[3]\ : MX2
      port map(A => \rqrqhcwpqdn[3]_net_1\, B => 
        \rqrqhcwpqdn[4]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_492);
    
    \bnwcvzjbgtc_3[0]\ : MX2
      port map(A => N_557, B => N_574, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_591);
    
    \gjkdbmpgrtc_11_d[10]\ : MX2
      port map(A => N_499, B => \rqrqhcwpqdn[4]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \gjkdbmpgrtc_11_d[10]_net_1\);
    
    \rqrqhcwpqdn[11]\ : DFN1E0C0
      port map(D => N_786, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_787, Q => \rqrqhcwpqdn[11]_net_1\);
    
    gpjgkmhxbkn_4 : XNOR2
      port map(A => EV_RAM_DO_B_net_busnet_5, B => 
        \rqrqhcwpqdn[5]_net_1\, Y => gpjgkmhxbkn_4_i);
    
    \gjkdbmpgrtc_9[10]\ : MX2
      port map(A => \rqrqhcwpqdn[10]_net_1\, B => 
        \rqrqhcwpqdn[11]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_499);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I159_Y_0 : XOR2
      port map(A => N_263, B => N_262, Y => 
        ADD_18x18_fast_I159_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I122_un1_Y : OR3C
      port map(A => N336, B => N344, C => N314, Y => I122_un1_Y_i);
    
    \bnwcvzjbgtc_1_0[1]\ : MX2
      port map(A => \ftbkrvpxdbp[1]_net_1\, B => 
        \ftbkrvpxdbp[2]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_558);
    
    \bnvtvdkcnpp[6]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[6]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[6]_net_1\);
    
    \tkcbxxqbtfx_ns_a3_0[4]\ : OR3B
      port map(A => INIT_DONE_net, B => N_227_1, C => N_239, Y
         => N_227);
    
    \bnwcvzjbgtc_11_s[7]\ : NOR2
      port map(A => \rdgwgtpkbgc_0[2]_net_1\, B => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => 
        \bnwcvzjbgtc_11_s[7]_net_1\);
    
    \ckghxwbsztp[4]\ : DFN1E1C0
      port map(D => \ckghxwbsztp_2[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \ckghxwbsztp[4]_net_1\);
    
    fqkdsnjfpdb_70_0 : OA1
      port map(A => N_673, B => \bnvtvdkcnpp[8]_net_1\, C => 
        \gjkdbmpgrtc[14]\, Y => \fqkdsnjfpdb_70_0\);
    
    \tkcbxxqbtfx_ns_a3_0[6]\ : OR2A
      port map(A => INIT_DONE_net, B => N_205, Y => 
        \tkcbxxqbtfx_ns_a3_0[6]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I13_G0N : OA1
      port map(A => fqkdsnjfpdb_33, B => \fqkdsnjfpdb_60_0\, C
         => N_271, Y => N268);
    
    \gjkdbmpgrtc_3[3]\ : OR3C
      port map(A => \rdgwgtpkbgc[0]_net_1\, B => 
        \rqrqhcwpqdn[0]_net_1\, C => \rdgwgtpkbgc[1]_net_1\, Y
         => N_390);
    
    \bnwcvzjbgtc_1_0[0]\ : MX2
      port map(A => \ftbkrvpxdbp[0]_net_1\, B => 
        \ftbkrvpxdbp[1]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_557);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I9_G0N : NOR2B
      port map(A => N_263, B => N_262, Y => N256);
    
    \rqrqhcwpqdn_5_0[3]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_3, B => 
        EV_RAM_DO_B_net_busnet_3, S => \un1_xkwrgrspmcf\, Y => 
        N_766);
    
    un1_qvqqfftqsfc : OR3B
      port map(A => \rfrdbqfdrhx[0]_net_1\, B => 
        \tkcbxxqbtfx[9]_net_1\, C => \rfrdbqfdrhx[1]_net_1\, Y
         => \un1_qvqqfftqsfc\);
    
    \gjkdbmpgrtc_9[6]\ : MX2
      port map(A => \rqrqhcwpqdn[6]_net_1\, B => 
        \rqrqhcwpqdn[7]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_495);
    
    fqkdsnjfpdb_36_0 : XOR2
      port map(A => \bnvtvdkcnpp[2]_net_1\, B => \bnwcvzjbgtc[8]\, 
        Y => \fqkdsnjfpdb_36_0\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I8_Y : NOR3A
      port map(A => ADD_9x9_medium_I8_Y_1, B => N107, C => N108, 
        Y => N121);
    
    \bnvtvdkcnpp[4]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[4]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[4]_net_1\);
    
    ftbkrvpxdbp_1_sqmuxa : NOR2
      port map(A => \un1_kkgccghmrzf\, B => 
        \tkcbxxqbtfx_0[4]_net_1\, Y => \ftbkrvpxdbp_1_sqmuxa\);
    
    \qrbxknbdvjj_m[7]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[7]_net_1\, C => \rgmpzqrbghh_0\, Y => 
        \qrbxknbdvjj_m[7]_net_1\);
    
    \tkcbxxqbtfx[17]\ : DFN1P0
      port map(D => \tkcbxxqbtfx_ns[0]_net_1\, CLK => SYS_CLK_int, 
        PRE => SYS_RESET_c, Q => \tkcbxxqbtfx[17]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_42 : NOR2A
      port map(A => \rqrqhcwpqdn[4]_net_1\, B => 
        \bnvtvdkcnpp[4]_net_1\, Y => \ACT_LT3_E[0]\);
    
    \bnwcvzjbgtc_12[6]\ : MX2
      port map(A => N_665, B => N_733, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[6]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I14_G0N : NOR2A
      port map(A => N_273, B => N_272, Y => N271);
    
    \qrbxknbdvjj_m[6]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[6]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[6]_net_1\);
    
    \rdgwgtpkbgc_0[0]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_0, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_0[0]_net_1\);
    
    \bnwcvzjbgtc_11[6]\ : MX2
      port map(A => N_699, B => \bnwcvzjbgtc_11_d[6]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => N_733);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_63 : OR2A
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => 
        \rqrqhcwpqdn[3]_net_1\, Y => \ACT_LT4_E[8]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I8_P0N_0 : AO1
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => \gjkdbmpgrtc[7]\, 
        C => \fqkdsnjfpdb_35_0\, Y => ADD_18x18_fast_I8_P0N_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I34_Y : AO1
      port map(A => N250, B => N254, C => N253, Y => N298);
    
    \ckghxwbsztp_m[4]\ : OR2B
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => 
        \ckghxwbsztp[4]_net_1\, Y => \ckghxwbsztp_m[4]_net_1\);
    
    njhxtffzjds : DFN1E0C0
      port map(D => N_211, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => \un1_fskhwddcbbg_6_sqmuxa_1\, Q => EV_EVFLAG_net);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_23 : AO1C
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        \rqrqhcwpqdn[9]_net_1\, C => N_28, Y => N_34);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I71_Y : NOR2B
      port map(A => N305, B => N301, Y => N338);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I36_Y : MAJ3
      port map(A => N_258, B => N_259, C => N247, Y => N300);
    
    \gjkdbmpgrtc_9[5]\ : MX2
      port map(A => \rqrqhcwpqdn[5]_net_1\, B => 
        \rqrqhcwpqdn[6]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_494);
    
    \mkmkbnghgkd[7]\ : MX2
      port map(A => INIT_ADDR_net(7), B => 
        TR_EV_ADDR_net_busnet_7, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_7);
    
    \kkkmkxwwscv[4]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_7, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_7);
    
    un2_ckghxwbsztp_I_8 : NOR2B
      port map(A => \rqrqhcwpqdn[2]_net_1\, B => 
        \rqrqhcwpqdn[1]_net_1\, Y => N_12);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I32_Y : AO1
      port map(A => N253, B => N257, C => N256, Y => N296);
    
    \bnvtvdkcnpp[11]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[11]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[11]_net_1\);
    
    rqrqhcwpqdn_9_sn_m1 : NOR2
      port map(A => \un1_mvnkctvqsgp\, B => 
        \tkcbxxqbtfx[6]_net_1\, Y => N_787);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I158_Y_0 : XNOR3
      port map(A => \gjkdbmpgrtc[8]\, B => \fqkdsnjfpdb_36_0\, C
         => N_260, Y => ADD_18x18_fast_I158_Y_0);
    
    \bnwcvzjbgtc_11_d[11]\ : MX2
      port map(A => N_704, B => \bnvtvdkcnpp[5]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \bnwcvzjbgtc_11_d[11]_net_1\);
    
    \rqrqhcwpqdn[1]\ : DFN1E1C0
      port map(D => N_764, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[1]_net_1\);
    
    \ftbkrvpxdbp[3]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[3]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[3]_net_1\);
    
    \bnwcvzjbgtc_7[13]\ : NOR2A
      port map(A => N_604, B => rdgwgtpkbgc_3, Y => N_672);
    
    fqkdsnjfpdb_70 : NOR2
      port map(A => \fqkdsnjfpdb_70_0\, B => \fqkdsnjfpdb_38\, Y
         => N_274);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I22_Y : AX1
      port map(A => N108, B => \EV_RAM_ADDR_B_net_busnet_1\, C
         => \EV_RAM_ADDR_B_net_busnet_2\, Y => 
        \un1_bskrjhjvqpf[3]\);
    
    \bnvtvdkcnpp_4[5]\ : MX2
      port map(A => \bnvtvdkcnpp[5]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_5, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[5]_net_1\);
    
    \bnwcvzjbgtc_3[16]\ : NOR2A
      port map(A => N_703, B => \rdgwgtpkbgc[1]_net_1\, Y => 
        N_607);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I114_un1_Y : OR2B
      port map(A => ADD_18x18_fast_I102_Y, B => 
        ADD_18x18_fast_I87_Y, Y => ADD_18x18_fast_I114_un1_Y);
    
    kkjrqmngvjc_0 : OR3
      port map(A => N_240, B => \kkjrqmngvjc_0_0\, C => 
        fskhwddcbbg_6_sqmuxa, Y => EV_RAM_CSN_B_net);
    
    \bnwcvzjbgtc_7[1]\ : MX2
      port map(A => N_592, B => N_600, S => rdgwgtpkbgc_3, Y => 
        N_660);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_6 : AND3
      port map(A => \DWACT_BL_EQUAL_0_E_0[0]\, B => 
        \DWACT_BL_EQUAL_0_E_0[1]\, C => \DWACT_BL_EQUAL_0_E_0[2]\, 
        Y => \DWACT_BL_EQUAL_0_DWACT_ANDTREE_E[0]\);
    
    \bnvtvdkcnpp_8[1]\ : MX2
      port map(A => \bnvtvdkcnpp_4[1]_net_1\, B => 
        \fqkdsnjfpdb[7]\, S => \tkcbxxqbtfx_0[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[1]_net_1\);
    
    \qrbxknbdvjj[3]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_3\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[3]_net_1\);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_1[4]\ : NOR3C
      port map(A => \qrbxknbdvjj_m[4]_net_1\, B => 
        \mtbjcfqsbqf_m[3]_net_1\, C => \jrgzmrqhbkv_m[4]_net_1\, 
        Y => \dhzrwbnrbpw_7_iv_1[4]\);
    
    \bnwcvzjbgtc_11_d_s[5]\ : NOR2A
      port map(A => \rdgwgtpkbgc_0[0]_net_1\, B => rdgwgtpkbgc_3, 
        Y => \bnwcvzjbgtc_11_d_s[5]_net_1\);
    
    \bnwcvzjbgtc_9[4]\ : MX2
      port map(A => \bnvtvdkcnpp[4]_net_1\, B => 
        \bnvtvdkcnpp[5]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_697);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_2 : XNOR2
      port map(A => \bnvtvdkcnpp[11]_net_1\, B => 
        \rqrqhcwpqdn[11]_net_1\, Y => \DWACT_BL_EQUAL_0_E[4]\);
    
    \rqrqhcwpqdn_5[0]\ : MX2B
      port map(A => \rqrqhcwpqdn[0]_net_1\, B => N_763, S => 
        N_772_i, Y => \rqrqhcwpqdn_5[0]_net_1\);
    
    \mkmkbnghgkd[1]\ : MX2
      port map(A => INIT_ADDR_net(1), B => 
        TR_EV_ADDR_net_busnet_1, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_1);
    
    \qrbxknbdvjj_m[3]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[3]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[3]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I164_Y : AX1B
      port map(A => I117_un1_Y, B => ADD_18x18_fast_I117_Y_1, C
         => ADD_18x18_fast_I164_Y_0, Y => \fqkdsnjfpdb_i[14]\);
    
    \ckghxwbsztp_m[0]\ : OR2B
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => 
        \ckghxwbsztp[0]_net_1\, Y => \ckghxwbsztp_m[0]_net_1\);
    
    \fqkdsnjfpdb_m[6]\ : OR2B
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => \fqkdsnjfpdb[6]\, 
        Y => \fqkdsnjfpdb_m[6]_net_1\);
    
    \rqrqhcwpqdn[6]\ : DFN1E1C0
      port map(D => N_769, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[6]_net_1\);
    
    fqkdsnjfpdb_1_0 : XOR2
      port map(A => \ftbkrvpxdbp[1]_net_1\, B => 
        \ftbkrvpxdbp[0]_net_1\, Y => \fqkdsnjfpdb_1_0\);
    
    \bnvtvdkcnpp[10]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[10]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[10]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I153_Y_0 : XNOR3
      port map(A => \gjkdbmpgrtc[3]\, B => \fqkdsnjfpdb_11_0\, C
         => N_250, Y => ADD_18x18_fast_I153_Y_0);
    
    \bnvtvdkcnpp_8[2]\ : MX2
      port map(A => \bnvtvdkcnpp_4[2]_net_1\, B => 
        \fqkdsnjfpdb[8]\, S => \tkcbxxqbtfx_0[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[2]_net_1\);
    
    \ftbkrvpxdbp[1]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[1]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[1]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I153_Y : AX1
      port map(A => N310, B => I80_un1_Y_i, C => 
        ADD_18x18_fast_I153_Y_0, Y => \fqkdsnjfpdb_i[3]\);
    
    \rqrqhcwpqdn_5_0[5]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_5, B => 
        EV_RAM_DO_B_net_busnet_5, S => \un1_xkwrgrspmcf\, Y => 
        N_768);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I0_P0N : OR2A
      port map(A => \ftbkrvpxdbp[0]_net_1\, B => \gjkdbmpgrtc[0]\, 
        Y => N230);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_Y : OR2B
      port map(A => ADD_18x18_fast_I133_Y_3, B => 
        ADD_18x18_fast_I114_un1_Y, Y => ADD_18x18_fast_I133_Y);
    
    \tkcbxxqbtfx_ns_i[13]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[5]_net_1\, Y
         => \tkcbxxqbtfx_ns_i[13]_net_1\);
    
    \mtbjcfqsbqf[0]\ : DFN1E1C0
      port map(D => dspfgfmqhwh(0), CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \qmmwhjxxxmv\, Q => 
        \EV_CHHOLD_net_busnet_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I65_Y : NOR2
      port map(A => N299, B => N295, Y => N332);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I28_Y : AO1
      port map(A => N259, B => N263, C => N262, Y => N292);
    
    \fqkdsnjfpdb_m[5]\ : OR2A
      port map(A => \tkcbxxqbtfx_0[4]_net_1\, B => 
        \fqkdsnjfpdb_i[5]\, Y => \fqkdsnjfpdb_m[5]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I8_P0N : XO1A
      port map(A => \gjkdbmpgrtc[8]\, B => \fqkdsnjfpdb_36_0\, C
         => ADD_18x18_fast_I8_P0N_0, Y => N254);
    
    fqkdsnjfpdb_56 : XNOR2
      port map(A => \fqkdsnjfpdb_56_0\, B => \gjkdbmpgrtc[12]\, Y
         => N_269);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I10_G0N : OA1
      port map(A => fqkdsnjfpdb_24, B => \fqkdsnjfpdb_45_0\, C
         => N_265, Y => N259);
    
    \bnwcvzjbgtc_9[2]\ : MX2
      port map(A => \bnvtvdkcnpp[2]_net_1\, B => 
        \bnvtvdkcnpp[3]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_695);
    
    un3_qvqqfftqsfc : OAI1
      port map(A => N_237, B => \tkcbxxqbtfx_ns_1[16]\, C => 
        \un1_qvqqfftqsfc\, Y => \un3_qvqqfftqsfc\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I39_Y : NOR2B
      port map(A => N248, B => N245, Y => N303);
    
    \fqkdsnjfpdb_m[17]\ : OR2A
      port map(A => \tkcbxxqbtfx[4]_net_1\, B => 
        \fqkdsnjfpdb_i[17]\, Y => \fqkdsnjfpdb_m[17]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I0_G0N : NOR2A
      port map(A => \gjkdbmpgrtc[0]\, B => \ftbkrvpxdbp[0]_net_1\, 
        Y => N229);
    
    \bnvtvdkcnpp_7[9]\ : MX2
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_0, S => \un1_kkgccghmrzf\, Y => 
        \bnvtvdkcnpp_7[9]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I13_P0N_0 : OR2
      port map(A => fqkdsnjfpdb_33, B => N_271, Y => 
        ADD_18x18_fast_I13_P0N_0);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[5]\ : AOI1B
      port map(A => \rgmpzqrbghh_0\, B => 
        \EV_CHHOLD_net_busnet_4\, C => \qrbxknbdvjj_m[5]_net_1\, 
        Y => \dhzrwbnrbpw_7_iv_0[5]\);
    
    \fqkdsnjfpdb_m[16]\ : OR2A
      port map(A => \tkcbxxqbtfx_1[4]_net_1\, B => 
        \fqkdsnjfpdb_i[16]\, Y => \fqkdsnjfpdb_m[16]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I73_Y : NOR2B
      port map(A => N307, B => N303, Y => N340);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I16_P0N : OR2A
      port map(A => N_276, B => N_277, Y => N278);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I9_P0N : OR3
      port map(A => N_263, B => \fqkdsnjfpdb_21\, C => 
        \fqkdsnjfpdb_40_0\, Y => N257);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_un1_Y_0 : NOR2A
      port map(A => N314, B => N283, Y => 
        ADD_18x18_fast_I132_un1_Y_0);
    
    \tkcbxxqbtfx[5]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[12]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[5]_net_1\);
    
    \ftbkrvpxdbp_4[2]\ : MX2
      port map(A => EV_RAM_DO_B_net_busnet_5, B => 
        \fqkdsnjfpdb[2]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[2]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_27 : OA1
      port map(A => N_37, B => N_36, C => N_35, Y => 
        \DWACT_COMP0_E[0]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_48 : AOI1A
      port map(A => \ACT_LT3_E[3]\, B => \ACT_LT3_E[4]\, C => 
        \ACT_LT3_E[5]\, Y => \DWACT_CMPLE_PO2_DWACT_COMP0_E[0]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I40_un1_Y : NOR2B
      port map(A => N245, B => N241, Y => I40_un1_Y);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I119_Y : AOI1
      port map(A => N478, B => ADD_18x18_fast_I119_un1_Y_0, C => 
        ADD_18x18_fast_I119_Y_0, Y => N454_i);
    
    \fqkdsnjfpdb_m[10]\ : OR2B
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => 
        \fqkdsnjfpdb[10]\, Y => \fqkdsnjfpdb_m[10]_net_1\);
    
    \tkcbxxqbtfx_ns[0]\ : AO1C
      port map(A => \rgmpzqrbghh\, B => \tkcbxxqbtfx[17]_net_1\, 
        C => N_211, Y => \tkcbxxqbtfx_ns[0]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_43 : OR2A
      port map(A => \rqrqhcwpqdn[5]_net_1\, B => 
        \bnvtvdkcnpp[5]_net_1\, Y => \ACT_LT3_E[1]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I11_P0N_0 : AO13
      port map(A => \bnvtvdkcnpp[4]_net_1\, B => 
        \gjkdbmpgrtc[10]\, C => \bnwcvzjbgtc[10]\, Y => 
        ADD_18x18_fast_I11_P0N_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I104_Y : OR2A
      port map(A => I104_un1_Y_i, B => N339, Y => N469);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I105_un1_Y : OR3C
      port map(A => N305, B => N309, C => N349, Y => I105_un1_Y_i);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I163_Y_0 : AX1B
      port map(A => fqkdsnjfpdb_33, B => \fqkdsnjfpdb_60_0\, C
         => N_271, Y => ADD_18x18_fast_I163_Y_0);
    
    \bnvtvdkcnpp[1]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[1]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[1]_net_1\);
    
    qmmwhjxxxmv : NOR2B
      port map(A => bcmkdjqtngz, B => un1_Analog_inst_1, Y => 
        \qmmwhjxxxmv\);
    
    \ckghxwbsztp_m[2]\ : OR2B
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => 
        \ckghxwbsztp[2]_net_1\, Y => \ckghxwbsztp_m[2]_net_1\);
    
    frhjqwkkhgk_0 : NOR2A
      port map(A => N_212, B => N_206, Y => EV_RAM_WR_BUSY_B_net);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I156_Y : AX1A
      port map(A => N341, B => I105_un1_Y_i, C => 
        ADD_18x18_fast_I156_Y_0, Y => \fqkdsnjfpdb[6]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I120_Y : AOI1
      port map(A => N332, B => N339, C => ADD_18x18_fast_I120_Y_0, 
        Y => N457_i);
    
    fskhwddcbbg_1_sqmuxa_0_a2_0 : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_7_0, B => N_240, Y => 
        fskhwddcbbg_1_sqmuxa_0);
    
    \ftbkrvpxdbp_4[4]\ : MX2B
      port map(A => EV_RAM_DO_B_net_busnet_7, B => 
        \fqkdsnjfpdb_i[4]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[4]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I87_Y : NOR2
      port map(A => N330, B => N322, Y => ADD_18x18_fast_I87_Y);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv_0[8]\ : AOI1B
      port map(A => N_199_i_0, B => EV_RAM_DO_B_net_busnet_8, C
         => \qrbxknbdvjj_m[8]_net_1\, Y => 
        \dhzrwbnrbpw_7_iv_0[8]\);
    
    un1_fskhwddcbbg_i_o3 : OR3
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => 
        \tkcbxxqbtfx[3]_net_1\, C => \tkcbxxqbtfx_0[4]_net_1\, Y
         => N_209);
    
    \gjkdbmpgrtc_9[7]\ : MX2
      port map(A => \rqrqhcwpqdn[7]_net_1\, B => 
        \rqrqhcwpqdn[8]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_496);
    
    \bnvtvdkcnpp[0]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[0]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[0]_net_1\);
    
    \tkcbxxqbtfx_ns_a3_1[16]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_8, B => 
        EV_RAM_DO_B_net_busnet_7_0, Y => \tkcbxxqbtfx_ns_1[16]\);
    
    \ftbkrvpxdbp_4[1]\ : MX2
      port map(A => EV_RAM_DO_B_net_busnet_4, B => 
        \fqkdsnjfpdb[1]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[1]_net_1\);
    
    \dhzrwbnrbpw[3]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[3]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_3\);
    
    bskrjhjvqpf_i_o3 : OR2A
      port map(A => N_207, B => \tkcbxxqbtfx[11]_net_1\, Y => 
        N_215);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I10_P0N : OR3
      port map(A => N_265, B => fqkdsnjfpdb_24, C => 
        \fqkdsnjfpdb_45_0\, Y => N260);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_Y_1 : AOI1B
      port map(A => N285, B => N288, C => ADD_18x18_fast_I133_Y_0, 
        Y => ADD_18x18_fast_I133_Y_1);
    
    \ftbkrvpxdbp_4[0]\ : MX2
      port map(A => EV_RAM_DO_B_net_busnet_3, B => 
        \fqkdsnjfpdb[0]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[0]_net_1\);
    
    \bnvtvdkcnpp_8[6]\ : MX2C
      port map(A => \bnvtvdkcnpp_4[6]_net_1\, B => 
        \fqkdsnjfpdb_i[12]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[6]_net_1\);
    
    \qrbxknbdvjj_m[8]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[8]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[8]_net_1\);
    
    \gjkdbmpgrtc_7[13]\ : NOR2A
      port map(A => N_400, B => rdgwgtpkbgc_3, Y => N_468);
    
    \tkcbxxqbtfx_ns_a3[6]\ : NOR3A
      port map(A => \tkcbxxqbtfx[12]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_7_0, C => 
        \tkcbxxqbtfx_ns_a3_0[6]_net_1\, Y => \tkcbxxqbtfx_ns[6]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_4 : XNOR2
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        \rqrqhcwpqdn[10]_net_1\, Y => \DWACT_BL_EQUAL_0_E[3]\);
    
    \bnwcvzjbgtc_11[15]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => \bnvtvdkcnpp[9]_net_1\, Y
         => N_742);
    
    \fqkdsnjfpdb_m[15]\ : OR2B
      port map(A => \tkcbxxqbtfx_1[4]_net_1\, B => 
        \fqkdsnjfpdb[15]\, Y => \fqkdsnjfpdb_m[15]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I1_G0N : XA1A
      port map(A => \bnwcvzjbgtc[1]\, B => \fqkdsnjfpdb_1_0\, C
         => \gjkdbmpgrtc[1]\, Y => N232);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I19_Y : OR2B
      port map(A => N278, B => N275, Y => N283);
    
    \bnwcvzjbgtc_7[11]\ : NOR2A
      port map(A => N_602, B => rdgwgtpkbgc_3, Y => N_670);
    
    \bnwcvzjbgtc_7[7]\ : MX2
      port map(A => N_598, B => N_602, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => N_666);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[5]\ : OR3C
      port map(A => \jrgzmrqhbkv_m[5]_net_1\, B => 
        \dhzrwbnrbpw_7_iv_0[5]\, C => 
        \un1_bskrjhjvqpf_m[6]_net_1\, Y => \dhzrwbnrbpw_7[5]\);
    
    \mkmkbnghgkd[4]\ : MX2
      port map(A => INIT_ADDR_net(4), B => 
        TR_EV_ADDR_net_busnet_4, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_4);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I24_Y : AO1
      port map(A => N265, B => N269, C => N268, Y => N288);
    
    \ckghxwbsztp_2_0_o2[0]\ : MX2A
      port map(A => N_10, B => N_20, S => \spbznmtdmpd\, Y => N_9);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I26_Y : MIN3
      port map(A => N_268, B => N_269, C => N262, Y => N290);
    
    \gjkdbmpgrtc_7[15]\ : NOR2A
      port map(A => N_402, B => rdgwgtpkbgc_3, Y => N_470);
    
    \tkcbxxqbtfx_ns_a3[15]\ : NOR3A
      port map(A => INIT_DONE_net, B => N_237, C => N_239, Y => 
        \tkcbxxqbtfx_ns[15]\);
    
    \gjkdbmpgrtc_7[9]\ : MX2
      port map(A => N_396, B => N_447, S => rdgwgtpkbgc_3, Y => 
        N_464);
    
    \rdgwgtpkbgc[0]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_0, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \fskhwddcbbg_1_sqmuxa\, Q => 
        \rdgwgtpkbgc[0]_net_1\);
    
    fqkdsnjfpdb_30 : AO13
      port map(A => \bnvtvdkcnpp[0]_net_1\, B => \gjkdbmpgrtc[6]\, 
        C => \bnwcvzjbgtc[6]\, Y => N_258);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I22_Y : AO13
      port map(A => N_273, B => N268, C => N_272, Y => N286);
    
    \bnwcvzjbgtc_7[8]\ : MX2
      port map(A => N_599, B => N_607, S => rdgwgtpkbgc_3, Y => 
        N_667);
    
    \bnwcvzjbgtc_3[12]\ : MX2
      port map(A => N_699, B => N_701, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_603);
    
    \bnwcvzjbgtc_9[7]\ : MX2
      port map(A => \bnvtvdkcnpp[7]_net_1\, B => 
        \bnvtvdkcnpp[8]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_700);
    
    \bnwcvzjbgtc_3[6]\ : MX2
      port map(A => N_693, B => N_695, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_597);
    
    pfbntnkqtmt : OR2A
      port map(A => INIT_EV_WEN_net, B => INIT_DONE_net, Y => 
        EV_RAM_RW_A_net);
    
    \gjkdbmpgrtc_12[6]\ : MX2
      port map(A => N_461, B => N_529, S => rdgwgtpkbgc_3, Y => 
        \gjkdbmpgrtc[6]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I37_Y : OA1
      port map(A => N_258, B => N_259, C => N248, Y => N301);
    
    \bnwcvzjbgtc_11_d[10]\ : MX2
      port map(A => N_703, B => \bnvtvdkcnpp[4]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \bnwcvzjbgtc_11_d[10]_net_1\);
    
    \gjkdbmpgrtc_9[1]\ : MX2
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \rqrqhcwpqdn[2]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_490);
    
    \ftbkrvpxdbp_4[3]\ : MX2B
      port map(A => EV_RAM_DO_B_net_busnet_6, B => 
        \fqkdsnjfpdb_i[3]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[3]_net_1\);
    
    \bnvtvdkcnpp_4[6]\ : MX2C
      port map(A => \bnvtvdkcnpp[6]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_6, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[6]_net_1\);
    
    \bnvtvdkcnpp_7[10]\ : MX2C
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_1, S => \un1_kkgccghmrzf\, Y => 
        \bnvtvdkcnpp_7[10]_net_1\);
    
    \gjkdbmpgrtc_7[1]\ : NOR2B
      port map(A => rdgwgtpkbgc_3, B => N_396, Y => N_456);
    
    gjkdbmpgrtc68 : AXOI7
      port map(A => \un1_rdgwgtpkbgc_2_0\, B => 
        \rdgwgtpkbgc[2]_net_1\, C => rdgwgtpkbgc_3, Y => 
        \gjkdbmpgrtc68\);
    
    \dhzrwbnrbpw[8]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[8]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_8\);
    
    \gjkdbmpgrtc_7[11]\ : NOR2A
      port map(A => N_398, B => rdgwgtpkbgc_3, Y => N_466);
    
    \tkcbxxqbtfx_ns_a3[4]\ : AO1B
      port map(A => N_207, B => N_212, C => INIT_DONE_net, Y => 
        N_226);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I81_Y : OR2
      port map(A => N312, B => I81_un1_Y, Y => N349);
    
    \bnwcvzjbgtc_12[14]\ : MX2A
      port map(A => N_673, B => N_741, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[14]\);
    
    \bnwcvzjbgtc_9[6]\ : MX2
      port map(A => \bnvtvdkcnpp[6]_net_1\, B => 
        \bnvtvdkcnpp[7]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_699);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I1_P0N : XO1A
      port map(A => \bnwcvzjbgtc[1]\, B => \fqkdsnjfpdb_1_0\, C
         => \gjkdbmpgrtc[1]\, Y => N233);
    
    \mtbjcfqsbqf[4]\ : DFN1E1C0
      port map(D => dspfgfmqhwh(4), CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \qmmwhjxxxmv\, Q => 
        \EV_CHHOLD_net_busnet_4\);
    
    \qrbxknbdvjj_m[5]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[5]_net_1\, C => \rgmpzqrbghh\, Y => 
        \qrbxknbdvjj_m[5]_net_1\);
    
    \gjkdbmpgrtc_11[4]\ : OR2A
      port map(A => N_395, B => rdgwgtpkbgc_3, Y => 
        \gjkdbmpgrtc_11[4]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I152_Y : XOR2
      port map(A => ADD_18x18_fast_I152_Y_0, B => N349, Y => 
        \fqkdsnjfpdb[2]\);
    
    \tkcbxxqbtfx_ns_i[12]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[6]_net_1\, Y
         => \tkcbxxqbtfx_ns_i[12]_net_1\);
    
    \fqkdsnjfpdb_m[4]\ : OR2A
      port map(A => \tkcbxxqbtfx_0[4]_net_1\, B => 
        \fqkdsnjfpdb_i[4]\, Y => \fqkdsnjfpdb_m[4]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_Y_3 : NOR3C
      port map(A => I86_un1_Y, B => ADD_18x18_fast_I133_Y_1, C
         => ADD_18x18_fast_I133_un1_Y, Y => 
        ADD_18x18_fast_I133_Y_3);
    
    \bnwcvzjbgtc_9[9]\ : MX2
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        \bnvtvdkcnpp[10]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_702);
    
    \zbqggxmnpbs_r[3]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[9]_net_1\, B => 
        \zbqggxmnpbs_0_iv_0[3]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_3);
    
    \fqkdsnjfpdb_m[14]\ : OR2A
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => 
        \fqkdsnjfpdb_i[14]\, Y => \fqkdsnjfpdb_m[14]_net_1\);
    
    fqkdsnjfpdb_16 : XNOR2
      port map(A => \fqkdsnjfpdb_16_0\, B => \gjkdbmpgrtc[4]\, Y
         => N_253);
    
    \mtbjcfqsbqf[2]\ : DFN1E1C0
      port map(D => dspfgfmqhwh(2), CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \qmmwhjxxxmv\, Q => 
        \EV_CHHOLD_net_busnet_2\);
    
    \ckghxwbsztp[2]\ : DFN1E1C0
      port map(D => \ckghxwbsztp_2[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \ckghxwbsztp[2]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_3 : XNOR2
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        \rqrqhcwpqdn[9]_net_1\, Y => \DWACT_BL_EQUAL_0_E_0[2]\);
    
    \dhzrwbnrbpw[5]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[5]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_5\);
    
    \rfrdbqfdrhx[1]\ : DFN1E1C0
      port map(D => EV_RAM_DO_B_net_busnet_5, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_0_sqmuxa, Q => 
        \rfrdbqfdrhx[1]_net_1\);
    
    un2_ckghxwbsztp_I_19 : NOR2B
      port map(A => \rqrqhcwpqdn[4]_net_1\, B => 
        \DWACT_FINC_E[0]\, Y => N_4);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_47 : AND2A
      port map(A => \rqrqhcwpqdn[6]_net_1\, B => 
        \bnvtvdkcnpp[6]_net_1\, Y => \ACT_LT3_E[5]\);
    
    un1_mvnkctvqsgp : NOR3A
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \rfrdbqfdrhx[0]_net_1\, C => \rfrdbqfdrhx[1]_net_1\, Y
         => \un1_mvnkctvqsgp\);
    
    rgmpzqrbghh_0 : DFN1C0
      port map(D => \hmzcpnxsdwg\, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \rgmpzqrbghh_0\);
    
    \jrgzmrqhbkv_m[7]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_7_0, B => N_199_i_0, Y
         => \jrgzmrqhbkv_m[7]_net_1\);
    
    \bnwcvzjbgtc_7[4]\ : MX2
      port map(A => N_595, B => N_603, S => rdgwgtpkbgc_3, Y => 
        N_663);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I167_Y : AX1C
      port map(A => I112_un1_Y, B => ADD_18x18_fast_I132_Y_3, C
         => ADD_18x18_fast_I167_Y_2, Y => \fqkdsnjfpdb_i[17]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_un1_Y_1_0 : NOR3B
      port map(A => N239, B => ADD_18x18_fast_I79_Y_0, C => 
        \bnwcvzjbgtc[0]\, Y => ADD_18x18_fast_I133_un1_Y_1_0);
    
    \tkcbxxqbtfx_ns_i[3]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[15]_net_1\, 
        Y => \tkcbxxqbtfx_ns_i[3]_net_1\);
    
    \rdgwgtpkbgc[1]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \fskhwddcbbg_1_sqmuxa\, Q => 
        \rdgwgtpkbgc[1]_net_1\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I24_Y : XNOR2
      port map(A => \EV_RAM_ADDR_B_net_busnet_4\, B => I18_un1_Y, 
        Y => \un1_bskrjhjvqpf[5]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I161_Y : XNOR3
      port map(A => N_266, B => N_267, C => N457_i, Y => 
        \fqkdsnjfpdb[11]\);
    
    \bnwcvzjbgtc_9[8]\ : MX2
      port map(A => \bnvtvdkcnpp[8]_net_1\, B => 
        \bnvtvdkcnpp[9]_net_1\, S => \rdgwgtpkbgc[0]_net_1\, Y
         => N_701);
    
    fqkdsnjfpdb_75 : AO18
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        \bnwcvzjbgtc[15]\, C => \gjkdbmpgrtc[15]\, Y => N_276);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I31_Y : OR2B
      port map(A => N260, B => N257, Y => N295);
    
    \gjkdbmpgrtc_3[6]\ : MX2
      port map(A => N_489, B => N_491, S => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => N_393);
    
    \bnwcvzjbgtc_7[16]\ : NOR2A
      port map(A => N_607, B => rdgwgtpkbgc_3, Y => N_675);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I160_Y : AX1B
      port map(A => I98_un1_Y, B => ADD_18x18_fast_I121_Y_0, C
         => ADD_18x18_fast_I160_Y_0, Y => \fqkdsnjfpdb[10]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I15_G0N : NOR2A
      port map(A => N_275, B => N_274, Y => N274);
    
    \kkkmkxwwscv[5]\ : DFN1E1C0
      port map(D => ASSC_RAM_ADDR_B_net_busnet_8, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => \qmmwhjxxxmv\, Q
         => EV_ASSCADDR_net_busnet_8);
    
    \gjkdbmpgrtc_12[2]\ : MX2
      port map(A => N_457, B => N_525, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => \gjkdbmpgrtc[2]\);
    
    \dhzrwbnrbpw[6]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_6\);
    
    \rqrqhcwpqdn_9_0[10]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_1, B => 
        EV_RAM_DO_B_net_busnet_1, S => \un1_mvnkctvqsgp\, Y => 
        N_785);
    
    \rqrqhcwpqdn_5_0[0]\ : MX2C
      port map(A => ASSC_RAM_DO_A_net_busnet_0, B => 
        EV_RAM_DO_B_net_busnet_0, S => \un1_xkwrgrspmcf\, Y => 
        N_763);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I165_Y : AX1D
      port map(A => I116_un1_Y, B => ADD_18x18_fast_I116_Y_1, C
         => ADD_18x18_fast_I165_Y_0, Y => \fqkdsnjfpdb[15]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I118_un1_Y : NOR3C
      port map(A => N328, B => N336, C => N475, Y => I118_un1_Y);
    
    \gjkdbmpgrtc_3[4]\ : OR2B
      port map(A => \rdgwgtpkbgc[1]_net_1\, B => N_489, Y => 
        N_391);
    
    \gjkdbmpgrtc_12[8]\ : MX2
      port map(A => N_463, B => \gjkdbmpgrtc_11[8]_net_1\, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[8]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I29_Y : NOR2B
      port map(A => N263, B => N260, Y => N293);
    
    un1_gpwvqcjqzjx_1_i : NOR2
      port map(A => \rgmpzqrbghh\, B => N_215, Y => N_201_i_0);
    
    \gjkdbmpgrtc_11_d[11]\ : MX2
      port map(A => N_500, B => \rqrqhcwpqdn[5]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \gjkdbmpgrtc_11_d[11]_net_1\);
    
    \gjkdbmpgrtc_12[0]\ : MX2
      port map(A => N_455, B => N_523, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => \gjkdbmpgrtc[0]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I121_un1_Y_0 : NOR3C
      port map(A => N305, B => N309, C => N349, Y => 
        ADD_18x18_fast_I121_un1_Y_0);
    
    \bnvtvdkcnpp_8[7]\ : MX2C
      port map(A => \bnvtvdkcnpp_4[7]_net_1\, B => 
        \fqkdsnjfpdb_i[13]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[7]_net_1\);
    
    \jrgzmrqhbkv_m[0]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_0, B => N_199_i_0, Y
         => \jrgzmrqhbkv_m[0]_net_1\);
    
    fqkdsnjfpdb_25 : AO13
      port map(A => \ftbkrvpxdbp[5]_net_1\, B => \gjkdbmpgrtc[5]\, 
        C => \bnwcvzjbgtc[5]\, Y => N_256);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I88_un1_Y : NOR3A
      port map(A => N331, B => N287_i, C => N291, Y => I88_un1_Y);
    
    \mkmkbnghgkd[3]\ : MX2
      port map(A => INIT_ADDR_net(3), B => 
        TR_EV_ADDR_net_busnet_3, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_3);
    
    \bnwcvzjbgtc_3[10]\ : MX2
      port map(A => N_697, B => N_699, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_601);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[7]\ : OR3C
      port map(A => \jrgzmrqhbkv_m[7]_net_1\, B => 
        \qrbxknbdvjj_m[7]_net_1\, C => 
        \un1_bskrjhjvqpf_m[8]_net_1\, Y => \dhzrwbnrbpw_7[7]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I15_P0N : OR2A
      port map(A => N_274, B => N_275, Y => N275);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I112_un1_Y : AO1C
      port map(A => I100_un1_Y, B => N335, C => 
        ADD_18x18_fast_I112_un1_Y_0, Y => I112_un1_Y);
    
    fqkdsnjfpdb_40 : OR2
      port map(A => \fqkdsnjfpdb_40_0\, B => \fqkdsnjfpdb_21\, Y
         => N_262);
    
    \zbqggxmnpbs_r[0]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[15]_net_1\, B => 
        \zbqggxmnpbs_0_iv_1[0]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_0);
    
    \gjkdbmpgrtc_12[1]\ : MX2
      port map(A => N_456, B => N_524, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => \gjkdbmpgrtc[1]\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I2_P0N : OR2A
      port map(A => ADD_18x18_fast_I2_P0N_0, B => N_249, Y => 
        N236);
    
    \bnwcvzjbgtc_2[0]\ : MX2
      port map(A => \ftbkrvpxdbp[2]_net_1\, B => 
        \ftbkrvpxdbp[3]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_574);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I121_Y_0 : OR2
      port map(A => N333, B => I121_un1_Y, Y => 
        ADD_18x18_fast_I121_Y_0);
    
    fskhwddcbbg_6_sqmuxa_0_a3_0 : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_6, B => 
        EV_RAM_DO_B_net_busnet_8, Y => 
        \fskhwddcbbg_6_sqmuxa_0_a3_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I50_Y : AO18
      port map(A => \ftbkrvpxdbp[0]_net_1\, B => \gjkdbmpgrtc[0]\, 
        C => \bnwcvzjbgtc[0]\, Y => N314);
    
    gpjgkmhxbkn_0 : XNOR2
      port map(A => EV_RAM_DO_B_net_busnet_1, B => 
        \rqrqhcwpqdn[1]_net_1\, Y => gpjgkmhxbkn_0_i);
    
    \bnwcvzjbgtc_3[15]\ : MX2
      port map(A => N_702, B => N_704, S => 
        \rdgwgtpkbgc[1]_net_1\, Y => N_606);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I28_Y : AX1C
      port map(A => N121, B => \EV_RAM_ADDR_B_net_busnet_7\, C
         => \EV_RAM_ADDR_B_net_busnet_8\, Y => 
        \un1_bskrjhjvqpf[9]\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_37 : AND3
      port map(A => \DWACT_BL_EQUAL_0_E[2]\, B => 
        \DWACT_BL_EQUAL_0_E[1]\, C => \DWACT_BL_EQUAL_0_E[0]\, Y
         => \DWACT_CMPLE_PO2_DWACT_COMP0_E[1]\);
    
    \ftbkrvpxdbp[0]\ : DFN1E0C0
      port map(D => \ftbkrvpxdbp_4[0]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \ftbkrvpxdbp_1_sqmuxa\, Q => 
        \ftbkrvpxdbp[0]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I5_P0N_0 : OR2
      port map(A => fqkdsnjfpdb_9, B => \fqkdsnjfpdb_20_0\, Y => 
        ADD_18x18_fast_I5_P0N_0);
    
    spbznmtdmpd : DFN1E1C0
      port map(D => un2_pbzxzjhqhwz, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => dbdctxjdvkp_2_sqmuxa, Q => 
        \spbznmtdmpd\);
    
    fqkdsnjfpdb_41_0 : XOR2
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => \bnwcvzjbgtc[9]\, 
        Y => \fqkdsnjfpdb_41_0\);
    
    \gjkdbmpgrtc_9[0]\ : MX2
      port map(A => \rqrqhcwpqdn[0]_net_1\, B => 
        \rqrqhcwpqdn[1]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_489);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I48_Y : AO1
      port map(A => N229, B => N233, C => N232, Y => N312);
    
    rqrqhcwpqdn_5_sn_m1 : OR2
      port map(A => \EV_ASSCADDR_net_busnet_2\, B => 
        \un1_xkwrgrspmcf\, Y => N_772_i);
    
    fqkdsnjfpdb_58 : NOR2B
      port map(A => \gjkdbmpgrtc[12]\, B => 
        \bnvtvdkcnpp[6]_net_1\, Y => fqkdsnjfpdb_33);
    
    \bnwcvzjbgtc_11[8]\ : MX2
      port map(A => N_699, B => \bnwcvzjbgtc_11_d[8]_net_1\, S
         => \gjkdbmpgrtc_11_s[11]_net_1\, Y => N_735);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I117_un1_Y : OA1A
      port map(A => I105_un1_Y_i, B => N341, C => 
        ADD_18x18_fast_I117_un1_Y_0, Y => I117_un1_Y);
    
    \ckghxwbsztp_2_0_a3[4]\ : NOR2B
      port map(A => I_20, B => N_9, Y => \ckghxwbsztp_2[4]\);
    
    \rdgwgtpkbgc_0[1]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_1, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => fskhwddcbbg_1_sqmuxa_0, Q => 
        \rdgwgtpkbgc_0[1]_net_1\);
    
    \gjkdbmpgrtc_7[14]\ : NOR2A
      port map(A => N_401, B => rdgwgtpkbgc_3, Y => N_469);
    
    \bnwcvzjbgtc_12[1]\ : MX2
      port map(A => N_660, B => N_728, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[1]\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I20_Y : AX1B
      port map(A => N_234, B => \bskrjhjvqpf_i_1\, C => 
        \EV_RAM_ADDR_B_net_busnet_0\, Y => \un1_bskrjhjvqpf[1]\);
    
    \bnwcvzjbgtc_3[7]\ : MX2
      port map(A => N_694, B => N_696, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_598);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I86_un1_Y : OR2A
      port map(A => N329, B => N322, Y => I86_un1_Y);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I107_Y : OR2A
      port map(A => I107_un1_Y_i, B => N345, Y => N478);
    
    \gjkdbmpgrtc_7[10]\ : NOR2A
      port map(A => N_397, B => rdgwgtpkbgc_3, Y => N_465);
    
    \gjkdbmpgrtc_12_s[3]\ : OR2A
      port map(A => rdgwgtpkbgc_3, B => \rdgwgtpkbgc_0[2]_net_1\, 
        Y => \gjkdbmpgrtc_12_s[3]_net_1\);
    
    \bnwcvzjbgtc_11_d_d[5]\ : MX2C
      port map(A => \bnvtvdkcnpp[3]_net_1\, B => 
        \ftbkrvpxdbp[5]_net_1\, S => rdgwgtpkbgc_3, Y => 
        \bnwcvzjbgtc_11_d_d[5]_net_1\);
    
    \gjkdbmpgrtc_11[0]\ : NOR2
      port map(A => rdgwgtpkbgc_3, B => N_391, Y => N_523);
    
    \fqkdsnjfpdb_m[11]\ : OR2B
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => 
        \fqkdsnjfpdb[11]\, Y => \fqkdsnjfpdb_m[11]_net_1\);
    
    dbdctxjdvkp_2_sqmuxa_0_a2 : OR2A
      port map(A => EV_RAM_DO_B_net_busnet_8, B => 
        EV_RAM_DO_B_net_busnet_7, Y => N_239);
    
    \bnwcvzjbgtc_11_d[8]\ : MX2
      port map(A => N_701, B => \bnvtvdkcnpp[2]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \bnwcvzjbgtc_11_d[8]_net_1\);
    
    \tkcbxxqbtfx[16]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[16]_net_1\);
    
    \bnvtvdkcnpp_4[7]\ : MX2C
      port map(A => \bnvtvdkcnpp[7]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_7_0, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[7]_net_1\);
    
    \gjkdbmpgrtc_3[13]\ : MX2
      port map(A => N_496, B => N_498, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_400);
    
    \bnwcvzjbgtc_3[9]\ : MX2
      port map(A => N_696, B => N_698, S => 
        \rdgwgtpkbgc_2[1]_net_1\, Y => N_600);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_65 : AOI1A
      port map(A => \ACT_LT4_E[3]\, B => \ACT_LT4_E[6]\, C => 
        \ACT_LT4_E[10]\, Y => \DWACT_CMPLE_PO2_DWACT_COMP0_E[2]\);
    
    bskrjhjvqpf_i_a3 : NOR2A
      port map(A => N_205, B => N_241, Y => N_234);
    
    \gjkdbmpgrtc_12[14]\ : MX2
      port map(A => N_469, B => N_537, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \gjkdbmpgrtc[14]\);
    
    \gjkdbmpgrtc_12_d[4]\ : MX2C
      port map(A => N_391, B => \gjkdbmpgrtc_11[4]_net_1\, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => 
        \gjkdbmpgrtc_12_d[4]_net_1\);
    
    \bnvtvdkcnpp_4[1]\ : MX2
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_1, S => \un3_qvqqfftqsfc\, Y => 
        \bnvtvdkcnpp_4[1]_net_1\);
    
    \rqrqhcwpqdn_5_0[4]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_4, B => 
        EV_RAM_DO_B_net_busnet_4, S => \un1_xkwrgrspmcf\, Y => 
        N_767);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_25 : AO1C
      port map(A => \bnvtvdkcnpp[10]_net_1\, B => 
        \rqrqhcwpqdn[10]_net_1\, C => N_31, Y => N_36);
    
    \mkmkbnghgkd[2]\ : MX2
      port map(A => INIT_ADDR_net(2), B => 
        TR_EV_ADDR_net_busnet_2, S => INIT_DONE_net, Y => 
        EV_RAM_ADDR_A_net_busnet_2);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I40_Y : OR2
      port map(A => N244, B => I40_un1_Y, Y => N304);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I76_un1_Y : NOR2B
      port map(A => N310, B => N307, Y => I76_un1_Y);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I33_Y : NOR2B
      port map(A => N257, B => N254, Y => N297);
    
    fskhwddcbbg_0_sqmuxa_0_a3 : NOR3A
      port map(A => \tkcbxxqbtfx[12]_net_1\, B => 
        EV_RAM_DO_B_net_busnet_7, C => N_205, Y => 
        fskhwddcbbg_0_sqmuxa);
    
    \gjkdbmpgrtc_3[15]\ : MX2
      port map(A => N_498, B => N_500, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_402);
    
    \gjkdbmpgrtc_12[5]\ : MX2
      port map(A => N_460, B => N_528, S => 
        \rdgwgtpkbgc_1[2]_net_1\, Y => \gjkdbmpgrtc[5]\);
    
    \bnvtvdkcnpp_8[3]\ : MX2
      port map(A => \bnvtvdkcnpp_4[3]_net_1\, B => 
        \fqkdsnjfpdb[9]\, S => \tkcbxxqbtfx_0[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[3]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I27_Y : OAI1
      port map(A => N_268, B => N_269, C => N263, Y => N291);
    
    \bnwcvzjbgtc_11[3]\ : MX2
      port map(A => N_598, B => \ftbkrvpxdbp[3]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_730);
    
    \mtbjcfqsbqf[3]\ : DFN1E1C0
      port map(D => dspfgfmqhwh(3), CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, E => \qmmwhjxxxmv\, Q => 
        \EV_CHHOLD_net_busnet_3\);
    
    \tkcbxxqbtfx[1]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns[16]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \tkcbxxqbtfx[1]_net_1\);
    
    \rqrqhcwpqdn_9_0[11]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_2, B => 
        EV_RAM_DO_B_net_busnet_2, S => \un1_mvnkctvqsgp\, Y => 
        N_786);
    
    \rqrqhcwpqdn[0]\ : DFN1C0
      port map(D => \rqrqhcwpqdn_5[0]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \rqrqhcwpqdn[0]_net_1\);
    
    fqkdsnjfpdb_67 : NOR2A
      port map(A => \bnvtvdkcnpp[8]_net_1\, B => 
        \bnwcvzjbgtc[14]\, Y => \fqkdsnjfpdb_38\);
    
    \zbqggxmnpbs_r[1]\ : AOI1B
      port map(A => \fqkdsnjfpdb_m[16]_net_1\, B => 
        \zbqggxmnpbs_0_iv_0[1]_net_1\, C => N_197, Y => 
        EV_RAM_DI_B_net_busnet_1);
    
    tddhwjzbsrj_m : OR2B
      port map(A => \tkcbxxqbtfx[0]_net_1\, B => \tddhwjzbsrj\, Y
         => \tddhwjzbsrj_m\);
    
    \ckghxwbsztp[3]\ : DFN1E1C0
      port map(D => \ckghxwbsztp_2[3]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => \tkcbxxqbtfx[1]_net_1\, Q => 
        \ckghxwbsztp[3]_net_1\);
    
    zbcrjjxqjgg_i_o2 : AXOI5
      port map(A => EV_RAM_DO_B_net_busnet_6, B => 
        EV_RAM_DO_B_net_busnet_7_0, C => EV_RAM_DO_B_net_busnet_8, 
        Y => N_203);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[6]\ : AO1B
      port map(A => N_201_i_0, B => \un1_bskrjhjvqpf[7]\, C => 
        \dhzrwbnrbpw_7_iv_0[6]\, Y => \dhzrwbnrbpw_7[6]\);
    
    bskrjhjvqpf_i_2_1 : OR3
      port map(A => \tkcbxxqbtfx[6]_net_1\, B => 
        \tkcbxxqbtfx[17]_net_1\, C => \EV_ASSCADDR_net_busnet_2\, 
        Y => \bskrjhjvqpf_i_2_1\);
    
    \bnwcvzjbgtc_7[9]\ : MX2
      port map(A => N_600, B => N_651, S => rdgwgtpkbgc_3, Y => 
        N_668);
    
    \bnwcvzjbgtc_7[6]\ : MX2
      port map(A => N_597, B => N_605, S => rdgwgtpkbgc_3, Y => 
        N_665);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I23_Y : AX1B
      port map(A => N107, B => N108, C => 
        \EV_RAM_ADDR_B_net_busnet_3\, Y => \un1_bskrjhjvqpf[4]\);
    
    \rdgwgtpkbgc[3]\ : DFN1E0C0
      port map(D => EV_RAM_DO_B_net_busnet_3, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, E => \fskhwddcbbg_1_sqmuxa\, Q => 
        rdgwgtpkbgc_0_3);
    
    wqpbnjzjqsx_NE_2 : NOR3C
      port map(A => wqpbnjzjqsx_3_i, B => wqpbnjzjqsx_4_i, C => 
        wqpbnjzjqsx_0_i, Y => \wqpbnjzjqsx_NE_2\);
    
    \rqrqhcwpqdn_5_0[2]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_2, B => 
        EV_RAM_DO_B_net_busnet_2, S => \un1_xkwrgrspmcf\, Y => 
        N_765);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_19 : NOR2A
      port map(A => \rqrqhcwpqdn[7]_net_1\, B => 
        \bnvtvdkcnpp[7]_net_1\, Y => N_30);
    
    \pptwzsjcmcz_dhzrwbnrbpw_7_iv[0]\ : OR3C
      port map(A => \jrgzmrqhbkv_m[0]_net_1\, B => 
        \qrbxknbdvjj_m[0]_net_1\, C => 
        \un1_bskrjhjvqpf_m[1]_net_1\, Y => \dhzrwbnrbpw_7[0]\);
    
    \qrbxknbdvjj[5]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_5\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[5]_net_1\);
    
    \gjkdbmpgrtc_11_s[11]\ : OR2
      port map(A => rdgwgtpkbgc_3, B => \rdgwgtpkbgc_0[1]_net_1\, 
        Y => \gjkdbmpgrtc_11_s[11]_net_1\);
    
    \ftbkrvpxdbp_4[5]\ : MX2B
      port map(A => EV_RAM_DO_B_net_busnet_8, B => 
        \fqkdsnjfpdb_i[5]\, S => \tkcbxxqbtfx[4]_net_1\, Y => 
        \ftbkrvpxdbp_4[5]_net_1\);
    
    \bnwcvzjbgtc_12[5]\ : MX2
      port map(A => N_664, B => \bnwcvzjbgtc_11[5]_net_1\, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[5]\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I26_Y : AX1C
      port map(A => N124, B => \EV_RAM_ADDR_B_net_busnet_5\, C
         => \EV_RAM_ADDR_B_net_busnet_6\, Y => 
        \un1_bskrjhjvqpf[7]\);
    
    \gjkdbmpgrtc_3[11]\ : MX2
      port map(A => N_494, B => N_496, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_398);
    
    \gjkdbmpgrtc_7[16]\ : NOR2A
      port map(A => N_403, B => rdgwgtpkbgc_3, Y => N_471);
    
    \bnvtvdkcnpp_8[8]\ : MX2C
      port map(A => \bnvtvdkcnpp_4[8]_net_1\, B => 
        \fqkdsnjfpdb_i[14]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[8]_net_1\);
    
    \bnwcvzjbgtc_11[12]\ : MX2
      port map(A => N_607, B => \bnvtvdkcnpp[6]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_739);
    
    \gjkdbmpgrtc_11[16]\ : NOR2B
      port map(A => \rqrqhcwpqdn[10]_net_1\, B => rdgwgtpkbgc_3, 
        Y => N_539);
    
    \gjkdbmpgrtc_11[15]\ : NOR2B
      port map(A => \rqrqhcwpqdn[9]_net_1\, B => rdgwgtpkbgc_3, Y
         => N_538);
    
    \bnwcvzjbgtc_8[0]\ : MX2
      port map(A => \ftbkrvpxdbp[4]_net_1\, B => 
        \ftbkrvpxdbp[5]_net_1\, S => \rdgwgtpkbgc_1[0]_net_1\, Y
         => N_676);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I44_Y : AO1
      port map(A => N235, B => N239, C => N238, Y => N308);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    \jrgzmrqhbkv_m[1]\ : OR2B
      port map(A => EV_RAM_DO_B_net_busnet_1, B => N_199_i_0, Y
         => \jrgzmrqhbkv_m[1]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I46_Y : AO1
      port map(A => N232, B => N236, C => N235, Y => N310);
    
    \tkcbxxqbtfx_ns_i[11]\ : NOR2B
      port map(A => INIT_DONE_net, B => 
        \EV_ASSCADDR_net_busnet_2\, Y => 
        \tkcbxxqbtfx_ns_i[11]_net_1\);
    
    un1_fskhwddcbbg_6_sqmuxa_1 : NOR2A
      port map(A => N_211, B => \qmmwhjxxxmv\, Y => 
        \un1_fskhwddcbbg_6_sqmuxa_1\);
    
    fqkdsnjfpdb_35 : AO13
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => \gjkdbmpgrtc[7]\, 
        C => \bnwcvzjbgtc[7]\, Y => N_260);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I42_Y : MAJ3
      port map(A => N_252, B => N_253, C => N238, Y => N306);
    
    \bnwcvzjbgtc_11[5]\ : MX2
      port map(A => N_698, B => \bnwcvzjbgtc_11_d[5]_net_1\, S
         => \gjkdbmpgrtc_11_s[7]_net_1\, Y => 
        \bnwcvzjbgtc_11[5]_net_1\);
    
    \gjkdbmpgrtc_12[4]\ : MX2
      port map(A => N_399, B => \gjkdbmpgrtc_12_d[4]_net_1\, S
         => \gjkdbmpgrtc_12_s[3]_net_1\, Y => \gjkdbmpgrtc[4]\);
    
    \bnwcvzjbgtc_7[12]\ : NOR2A
      port map(A => N_603, B => rdgwgtpkbgc_3, Y => N_671);
    
    \bnwcvzjbgtc_12[15]\ : MX2
      port map(A => N_674, B => N_742, S => 
        \rdgwgtpkbgc[2]_net_1\, Y => \bnwcvzjbgtc[15]\);
    
    hmzcpnxsdwg : NOR2B
      port map(A => qvkpfznsfjx, B => bcmkdjqtngz, Y => 
        \hmzcpnxsdwg\);
    
    fqkdsnjfpdb_65 : AO18
      port map(A => \bnvtvdkcnpp[7]_net_1\, B => 
        \bnwcvzjbgtc[13]\, C => \gjkdbmpgrtc[13]\, Y => N_272);
    
    wqpbnjzjqsx_0 : XNOR2
      port map(A => \rqrqhcwpqdn[1]_net_1\, B => 
        \bnvtvdkcnpp[1]_net_1\, Y => wqpbnjzjqsx_0_i);
    
    \tkcbxxqbtfx[9]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[8]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[9]_net_1\);
    
    \bnvtvdkcnpp_8[11]\ : MX2C
      port map(A => \bnvtvdkcnpp_7[11]_net_1\, B => 
        \fqkdsnjfpdb_i[17]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[11]_net_1\);
    
    fqkdsnjfpdb_35_0 : OA1B
      port map(A => \bnvtvdkcnpp[1]_net_1\, B => \gjkdbmpgrtc[7]\, 
        C => \bnwcvzjbgtc[7]\, Y => \fqkdsnjfpdb_35_0\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I21_Y : NOR2B
      port map(A => N275, B => N272, Y => N285);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I117_un1_Y_0 : NOR2B
      port map(A => N326, B => N334, Y => 
        ADD_18x18_fast_I117_un1_Y_0);
    
    \fqkdsnjfpdb_m[9]\ : OR2B
      port map(A => \tkcbxxqbtfx[5]_net_1\, B => \fqkdsnjfpdb[9]\, 
        Y => \fqkdsnjfpdb_m[9]_net_1\);
    
    \tkcbxxqbtfx_ns[4]\ : OR3C
      port map(A => N_228, B => N_227, C => N_226, Y => 
        \tkcbxxqbtfx_ns[4]_net_1\);
    
    \tkcbxxqbtfx[8]\ : DFN1C0
      port map(D => \tkcbxxqbtfx_ns_i[9]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \tkcbxxqbtfx[8]_net_1\);
    
    \gjkdbmpgrtc_11[11]\ : MX2
      port map(A => N_498, B => \gjkdbmpgrtc_11_d[11]_net_1\, S
         => \gjkdbmpgrtc_11_s[11]_net_1\, Y => N_534);
    
    \bnwcvzjbgtc_11[0]\ : MX2
      port map(A => N_595, B => \ftbkrvpxdbp[0]_net_1\, S => 
        rdgwgtpkbgc_3, Y => N_727);
    
    \tkcbxxqbtfx_ns_i[2]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[16]_net_1\, 
        Y => \tkcbxxqbtfx_ns_i[2]_net_1\);
    
    \un1_bskrjhjvqpf_m[6]\ : XAI1
      port map(A => N124, B => \EV_RAM_ADDR_B_net_busnet_5\, C
         => N_201_i_0, Y => \un1_bskrjhjvqpf_m[6]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_59 : OR2A
      port map(A => \rqrqhcwpqdn[2]_net_1\, B => 
        \bnvtvdkcnpp[2]_net_1\, Y => \ACT_LT4_E[4]\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I1_Y : OR2B
      port map(A => \EV_RAM_ADDR_B_net_busnet_4\, B => 
        \EV_RAM_ADDR_B_net_busnet_3\, Y => N105);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_26 : OA1A
      port map(A => N_32, B => N_34, C => N_33, Y => N_37);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I152_Y_0 : XOR2
      port map(A => N_249, B => N_248, Y => 
        ADD_18x18_fast_I152_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I59_Y : NOR2B
      port map(A => N293, B => N289, Y => N326);
    
    \gjkdbmpgrtc_11[10]\ : MX2
      port map(A => N_497, B => \gjkdbmpgrtc_11_d[10]_net_1\, S
         => \gjkdbmpgrtc_11_s[11]_net_1\, Y => N_533);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    \qrbxknbdvjj_m[0]\ : OR3B
      port map(A => \tkcbxxqbtfx[8]_net_1\, B => 
        \qrbxknbdvjj[0]_net_1\, C => \rgmpzqrbghh_0\, Y => 
        \qrbxknbdvjj_m[0]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I62_un1_Y : NOR2B
      port map(A => N296, B => N293, Y => 
        ADD_18x18_fast_I62_un1_Y);
    
    fqkdsnjfpdb_18 : NOR2B
      port map(A => \gjkdbmpgrtc[4]\, B => \ftbkrvpxdbp[4]_net_1\, 
        Y => fqkdsnjfpdb_9);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I116_un1_Y : NOR2B
      port map(A => ADD_18x18_fast_I116_un1_Y_0, B => N469, Y => 
        I116_un1_Y);
    
    \ckghxwbsztp_2_0_a3[0]\ : NOR2A
      port map(A => N_9, B => \rqrqhcwpqdn[1]_net_1\, Y => 
        \ckghxwbsztp_2[0]\);
    
    \bnvtvdkcnpp_8[0]\ : MX2
      port map(A => \bnvtvdkcnpp_4[0]_net_1\, B => 
        \fqkdsnjfpdb[6]\, S => \tkcbxxqbtfx_0[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[0]_net_1\);
    
    \tkcbxxqbtfx_ns_i[7]\ : NOR2B
      port map(A => INIT_DONE_net, B => \tkcbxxqbtfx[11]_net_1\, 
        Y => \tkcbxxqbtfx_ns_i[7]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I133_un1_Y : OR3C
      port map(A => N338, B => ADD_18x18_fast_I133_un1_Y_1_0, C
         => ADD_18x18_fast_I87_Y, Y => ADD_18x18_fast_I133_un1_Y);
    
    \qrbxknbdvjj[0]\ : DFN1E1C0
      port map(D => \EV_RAM_ADDR_B_net_busnet_0\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, E => 
        \tkcbxxqbtfx[11]_net_1\, Q => \qrbxknbdvjj[0]_net_1\);
    
    \bnwcvzjbgtc_7[0]\ : MX2
      port map(A => N_591, B => N_599, S => rdgwgtpkbgc_3, Y => 
        N_659);
    
    fqkdsnjfpdb_6 : XNOR3
      port map(A => \gjkdbmpgrtc[2]\, B => \ftbkrvpxdbp[2]_net_1\, 
        C => \bnwcvzjbgtc[2]\, Y => N_249);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I68_Y : OA1C
      port map(A => N302, B => N299, C => N298, Y => N335);
    
    \zbqggxmnpbs_0_iv_0[3]\ : AOI1B
      port map(A => \fqkdsnjfpdb[0]\, B => 
        \tkcbxxqbtfx_0[4]_net_1\, C => \ckghxwbsztp_m[2]_net_1\, 
        Y => \zbqggxmnpbs_0_iv_0[3]_net_1\);
    
    \gjkdbmpgrtc_9[8]\ : MX2
      port map(A => \rqrqhcwpqdn[8]_net_1\, B => 
        \rqrqhcwpqdn[9]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_497);
    
    \gjkdbmpgrtc_3[8]\ : MX2
      port map(A => N_491, B => N_493, S => 
        \rdgwgtpkbgc_0[1]_net_1\, Y => N_395);
    
    \rqrqhcwpqdn[7]\ : DFN1E1C0
      port map(D => N_770, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_772_i, Q => \rqrqhcwpqdn[7]_net_1\);
    
    un1_bskrjhjvqpf_ADD_9x9_medium_I3_Y : OR3A
      port map(A => \EV_RAM_ADDR_B_net_busnet_0\, B => N_234, C
         => \bskrjhjvqpf_i_1\, Y => N108);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_45 : AOI1A
      port map(A => \ACT_LT3_E[0]\, B => \ACT_LT3_E[1]\, C => 
        \ACT_LT3_E[2]\, Y => \ACT_LT3_E[3]\);
    
    fqkdsnjfpdb_71 : XNOR3
      port map(A => \bnwcvzjbgtc[15]\, B => 
        \bnvtvdkcnpp[9]_net_1\, C => \gjkdbmpgrtc[15]\, Y => 
        N_275);
    
    \bnvtvdkcnpp_8[9]\ : MX2
      port map(A => \bnvtvdkcnpp_7[9]_net_1\, B => 
        \fqkdsnjfpdb[15]\, S => \tkcbxxqbtfx_1[4]_net_1\, Y => 
        \bnvtvdkcnpp_8[9]_net_1\);
    
    \tkcbxxqbtfx_ns_i[1]\ : NOR3C
      port map(A => \rgmpzqrbghh_0\, B => \tkcbxxqbtfx[17]_net_1\, 
        C => INIT_DONE_net, Y => \tkcbxxqbtfx_ns_i[1]_net_1\);
    
    pvtdpmmqdpp_un2_pbzxzjhqhwz_0_I_18 : OR2A
      port map(A => \bnvtvdkcnpp[9]_net_1\, B => 
        \rqrqhcwpqdn[9]_net_1\, Y => N_29);
    
    \gjkdbmpgrtc_7[12]\ : NOR2A
      port map(A => N_399, B => rdgwgtpkbgc_3, Y => N_467);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_un1_Y : OR3C
      port map(A => N336, B => N344, C => 
        ADD_18x18_fast_I132_un1_Y_2, Y => I132_un1_Y_i);
    
    \bnwcvzjbgtc_12[3]\ : MX2
      port map(A => N_662, B => N_730, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[3]\);
    
    \rqrqhcwpqdn_5_0[1]\ : MX2
      port map(A => ASSC_RAM_DO_A_net_busnet_1, B => 
        EV_RAM_DO_B_net_busnet_1, S => \un1_xkwrgrspmcf\, Y => 
        N_764);
    
    \dhzrwbnrbpw[4]\ : DFN1C0
      port map(D => \dhzrwbnrbpw_7[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \EV_RAM_ADDR_B_net_busnet_4\);
    
    \rqrqhcwpqdn[10]\ : DFN1E0C0
      port map(D => N_785, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        E => N_787, Q => \rqrqhcwpqdn[10]_net_1\);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I132_un1_Y_2 : NOR3B
      port map(A => ADD_18x18_fast_I132_un1_Y_0, B => N328, C => 
        N287_i, Y => ADD_18x18_fast_I132_un1_Y_2);
    
    \gjkdbmpgrtc_9[2]\ : MX2
      port map(A => \rqrqhcwpqdn[2]_net_1\, B => 
        \rqrqhcwpqdn[3]_net_1\, S => \rdgwgtpkbgc_0[0]_net_1\, Y
         => N_491);
    
    \bnwcvzjbgtc_11_d[7]\ : MX2
      port map(A => N_704, B => \bnvtvdkcnpp[1]_net_1\, S => 
        \rdgwgtpkbgc_0[2]_net_1\, Y => 
        \bnwcvzjbgtc_11_d[7]_net_1\);
    
    \bnvtvdkcnpp[7]\ : DFN1C0
      port map(D => \bnvtvdkcnpp_8[7]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \bnvtvdkcnpp[7]_net_1\);
    
    \gjkdbmpgrtc_11_d[7]\ : MX2
      port map(A => N_494, B => \rqrqhcwpqdn[1]_net_1\, S => 
        rdgwgtpkbgc_3, Y => \gjkdbmpgrtc_11_d[7]_net_1\);
    
    fqkdsnjfpdb_21 : XNOR3
      port map(A => \gjkdbmpgrtc[5]\, B => \ftbkrvpxdbp[5]_net_1\, 
        C => \bnwcvzjbgtc[5]\, Y => N_255);
    
    \gjkdbmpgrtc_11[3]\ : OR2A
      port map(A => N_394, B => rdgwgtpkbgc_3, Y => N_526);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I49_Y : NOR2B
      port map(A => N233, B => N230, Y => N313);
    
    \gjkdbmpgrtc_3[14]\ : MX2
      port map(A => N_497, B => N_499, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_401);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I116_un1_Y_0 : NOR3A
      port map(A => N332, B => N287_i, C => N291, Y => 
        ADD_18x18_fast_I116_un1_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I162_Y_0 : XOR2
      port map(A => N_269, B => N_268, Y => 
        ADD_18x18_fast_I162_Y_0);
    
    fqkdsnjfpdb_0_0_ADD_18x18_fast_I60_Y : OAI1
      port map(A => N291, B => N294, C => N290, Y => N327);
    
    \bnwcvzjbgtc_12[9]\ : MX2
      port map(A => N_668, B => N_736, S => 
        \rdgwgtpkbgc_2[2]_net_1\, Y => \bnwcvzjbgtc[9]\);
    
    \gjkdbmpgrtc_3[10]\ : MX2
      port map(A => N_493, B => N_495, S => 
        \rdgwgtpkbgc_1[1]_net_1\, Y => N_397);
    
    \gjkdbmpgrtc_6[9]\ : NOR3A
      port map(A => \rqrqhcwpqdn[11]_net_1\, B => 
        \rdgwgtpkbgc[0]_net_1\, C => \rdgwgtpkbgc[1]_net_1\, Y
         => N_447);
    
    \zbqggxmnpbs_0_iv_1[0]\ : NOR3C
      port map(A => un2_pbzxzjhqhwz_m, B => \tddhwjzbsrj_m\, C
         => \fqkdsnjfpdb_m[6]_net_1\, Y => 
        \zbqggxmnpbs_0_iv_1[0]_net_1\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity SMEV is

    port( rdgwgtpkbgc_0                : in    std_logic_vector(3 to 3);
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          rdgwgtpkbgc                  : out   std_logic_vector(3 to 3);
          dspfgfmqhwh                  : in    std_logic_vector(4 downto 0);
          EV_RAM_DI_B_net_busnet_1     : out   std_logic;
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic;
          SYS_CLK_int                  : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          EV_RAM_DO_B_net_busnet_0     : in    std_logic;
          EV_RAM_DO_B_net_busnet_1     : in    std_logic;
          EV_RAM_DO_B_net_busnet_2     : in    std_logic;
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_8     : in    std_logic;
          EV_RAM_DO_B_net_busnet_6     : in    std_logic;
          EV_RAM_DO_B_net_busnet_3     : in    std_logic;
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          INIT_DONE_net                : in    std_logic;
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic;
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          EV_RAM_DO_B_net_busnet_4     : in    std_logic;
          EV_RAM_DO_B_net_busnet_5     : in    std_logic;
          EV_RAM_DO_B_net_busnet_7     : in    std_logic;
          qvkpfznsfjx                  : in    std_logic;
          bcmkdjqtngz                  : in    std_logic;
          un1_Analog_inst_1            : in    std_logic;
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_7      : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic;
          EV_RAM_RW_A_net              : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic;
          EV_RAM_CSN_A_net             : out   std_logic;
          TR_EV_RD_net                 : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic;
          EV_DONE_net                  : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic
        );

end SMEV;

architecture DEF_ARCH of SMEV is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component nbnjbfrkqwq
    port( dspfgfmqhwh                  : in    std_logic_vector(4 downto 0) := (others => 'U');
          rdgwgtpkbgc_0_3              : out   std_logic;
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          rdgwgtpkbgc_3                : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_DONE_net                  : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_RD_net                 : in    std_logic := 'U';
          EV_RAM_CSN_A_net             : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic := 'U';
          EV_RAM_RW_A_net              : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic := 'U';
          TR_EV_ADDR_net_busnet_7      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          un1_Analog_inst_1            : in    std_logic := 'U';
          bcmkdjqtngz                  : in    std_logic := 'U';
          qvkpfznsfjx                  : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_7     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_5     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_4     : in    std_logic := 'U';
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          INIT_DONE_net                : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_RAM_DO_B_net_busnet_3     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_6     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_8     : in    std_logic := 'U';
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_2     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_1     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_0     : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_1     : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : nbnjbfrkqwq
	Use entity work.nbnjbfrkqwq(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_nbnjbfrkqwq : nbnjbfrkqwq
      port map(dspfgfmqhwh(4) => dspfgfmqhwh(4), dspfgfmqhwh(3)
         => dspfgfmqhwh(3), dspfgfmqhwh(2) => dspfgfmqhwh(2), 
        dspfgfmqhwh(1) => dspfgfmqhwh(1), dspfgfmqhwh(0) => 
        dspfgfmqhwh(0), rdgwgtpkbgc_0_3 => rdgwgtpkbgc(3), 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), rdgwgtpkbgc_3 => 
        rdgwgtpkbgc_0(3), ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, EV_ASSCADDR_net_busnet_8
         => EV_ASSCADDR_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, EV_EVFLAG_net => 
        EV_EVFLAG_net, EV_DONE_net => EV_DONE_net, 
        TR_EV_ADDR_net_busnet_0 => TR_EV_ADDR_net_busnet_0, 
        EV_RAM_ADDR_A_net_busnet_0 => EV_RAM_ADDR_A_net_busnet_0, 
        TR_EV_ADDR_net_busnet_6 => TR_EV_ADDR_net_busnet_6, 
        EV_RAM_ADDR_A_net_busnet_6 => EV_RAM_ADDR_A_net_busnet_6, 
        TR_EV_ADDR_net_busnet_1 => TR_EV_ADDR_net_busnet_1, 
        EV_RAM_ADDR_A_net_busnet_1 => EV_RAM_ADDR_A_net_busnet_1, 
        TR_EV_ADDR_net_busnet_2 => TR_EV_ADDR_net_busnet_2, 
        EV_RAM_ADDR_A_net_busnet_2 => EV_RAM_ADDR_A_net_busnet_2, 
        TR_EV_ADDR_net_busnet_5 => TR_EV_ADDR_net_busnet_5, 
        EV_RAM_ADDR_A_net_busnet_5 => EV_RAM_ADDR_A_net_busnet_5, 
        TR_EV_ADDR_net_busnet_8 => TR_EV_ADDR_net_busnet_8, 
        EV_RAM_ADDR_A_net_busnet_8 => EV_RAM_ADDR_A_net_busnet_8, 
        TR_EV_RD_net => TR_EV_RD_net, EV_RAM_CSN_A_net => 
        EV_RAM_CSN_A_net, INIT_EV_WEN_net => INIT_EV_WEN_net, 
        EV_RAM_RW_A_net => EV_RAM_RW_A_net, 
        ASSC_RAM_DO_A_net_busnet_8 => ASSC_RAM_DO_A_net_busnet_8, 
        ASSC_RAM_DO_A_net_busnet_7 => ASSC_RAM_DO_A_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_6 => ASSC_RAM_DO_A_net_busnet_6, 
        ASSC_RAM_DO_A_net_busnet_5 => ASSC_RAM_DO_A_net_busnet_5, 
        ASSC_RAM_DO_A_net_busnet_4 => ASSC_RAM_DO_A_net_busnet_4, 
        ASSC_RAM_DO_A_net_busnet_3 => ASSC_RAM_DO_A_net_busnet_3, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        EV_RAM_ADDR_A_net_busnet_7 => EV_RAM_ADDR_A_net_busnet_7, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        EV_RAM_ADDR_A_net_busnet_4 => EV_RAM_ADDR_A_net_busnet_4, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        EV_RAM_ADDR_A_net_busnet_3 => EV_RAM_ADDR_A_net_busnet_3, 
        EV_CHHOLD_net_busnet_3 => EV_CHHOLD_net_busnet_3, 
        un1_Analog_inst_1 => un1_Analog_inst_1, bcmkdjqtngz => 
        bcmkdjqtngz, qvkpfznsfjx => qvkpfznsfjx, 
        EV_RAM_DO_B_net_busnet_7 => EV_RAM_DO_B_net_busnet_7, 
        EV_RAM_DO_B_net_busnet_5 => EV_RAM_DO_B_net_busnet_5, 
        EV_RAM_DO_B_net_busnet_4 => EV_RAM_DO_B_net_busnet_4, 
        EV_RAM_WR_BUSY_B_net => EV_RAM_WR_BUSY_B_net, 
        ASSC_RAM_DO_A_net_busnet_2 => ASSC_RAM_DO_A_net_busnet_2, 
        ASSC_RAM_DO_A_net_busnet_1 => ASSC_RAM_DO_A_net_busnet_1, 
        ASSC_RAM_DO_A_net_busnet_0 => ASSC_RAM_DO_A_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_8 => EV_RAM_ADDR_B_net_busnet_8, 
        EV_RAM_ADDR_B_net_busnet_7 => EV_RAM_ADDR_B_net_busnet_7, 
        EV_RAM_ADDR_B_net_busnet_0 => EV_RAM_ADDR_B_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_1 => EV_RAM_ADDR_B_net_busnet_1, 
        EV_RAM_ADDR_B_net_busnet_2 => EV_RAM_ADDR_B_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_3 => EV_RAM_ADDR_B_net_busnet_3, 
        EV_RAM_ADDR_B_net_busnet_4 => EV_RAM_ADDR_B_net_busnet_4, 
        EV_RAM_DI_B_net_busnet_8 => EV_RAM_DI_B_net_busnet_8, 
        EV_RAM_DI_B_net_busnet_7 => EV_RAM_DI_B_net_busnet_7, 
        EV_RAM_DI_B_net_busnet_6 => EV_RAM_DI_B_net_busnet_6, 
        EV_RAM_DI_B_net_busnet_5 => EV_RAM_DI_B_net_busnet_5, 
        EV_RAM_DI_B_net_busnet_4 => EV_RAM_DI_B_net_busnet_4, 
        EV_RAM_DI_B_net_busnet_3 => EV_RAM_DI_B_net_busnet_3, 
        EV_RAM_DI_B_net_busnet_2 => EV_RAM_DI_B_net_busnet_2, 
        EV_RAM_DI_B_net_busnet_0 => EV_RAM_DI_B_net_busnet_0, 
        EV_RAM_CSN_B_net => EV_RAM_CSN_B_net, 
        EV_ASSCADDR_net_busnet_2 => EV_ASSCADDR_net_busnet_2, 
        INIT_DONE_net => INIT_DONE_net, EV_CHHOLD_net_busnet_0
         => EV_CHHOLD_net_busnet_0, EV_RAM_ADDR_B_net_busnet_6
         => EV_RAM_ADDR_B_net_busnet_6, 
        EV_RAM_ADDR_B_net_busnet_5 => EV_RAM_ADDR_B_net_busnet_5, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        EV_CHHOLD_net_busnet_4 => EV_CHHOLD_net_busnet_4, 
        EV_CHHOLD_net_busnet_2 => EV_CHHOLD_net_busnet_2, 
        EV_RAM_DO_B_net_busnet_3 => EV_RAM_DO_B_net_busnet_3, 
        EV_RAM_DO_B_net_busnet_6 => EV_RAM_DO_B_net_busnet_6, 
        EV_RAM_DO_B_net_busnet_8 => EV_RAM_DO_B_net_busnet_8, 
        fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, 
        EV_RAM_DO_B_net_busnet_2 => EV_RAM_DO_B_net_busnet_2, 
        EV_RAM_DO_B_net_busnet_1 => EV_RAM_DO_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_0 => EV_RAM_DO_B_net_busnet_0, 
        SYS_RESET_c => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, 
        EV_RAM_DO_B_net_busnet_7_0 => EV_RAM_DO_B_net_busnet_7_0, 
        EV_RAM_DI_B_net_busnet_1 => EV_RAM_DI_B_net_busnet_1);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog_smev_wrapper is

    port( dspfgfmqhwh                  : in    std_logic_vector(4 downto 0);
          rdgwgtpkbgc_0                : out   std_logic_vector(3 to 3);
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0);
          rdgwgtpkbgc                  : in    std_logic_vector(3 to 3);
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic;
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic;
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic;
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic;
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic;
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic;
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_DONE_net                  : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_RD_net                 : in    std_logic;
          EV_RAM_CSN_A_net             : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic;
          EV_RAM_RW_A_net              : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic;
          TR_EV_ADDR_net_busnet_7      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic;
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          un1_Analog_inst_1            : in    std_logic;
          bcmkdjqtngz                  : in    std_logic;
          qvkpfznsfjx                  : in    std_logic;
          EV_RAM_DO_B_net_busnet_7     : in    std_logic;
          EV_RAM_DO_B_net_busnet_5     : in    std_logic;
          EV_RAM_DO_B_net_busnet_4     : in    std_logic;
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic;
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          INIT_DONE_net                : in    std_logic;
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_RAM_DO_B_net_busnet_3     : in    std_logic;
          EV_RAM_DO_B_net_busnet_6     : in    std_logic;
          EV_RAM_DO_B_net_busnet_8     : in    std_logic;
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_2     : in    std_logic;
          EV_RAM_DO_B_net_busnet_1     : in    std_logic;
          EV_RAM_DO_B_net_busnet_0     : in    std_logic;
          SYS_RESET_c                  : in    std_logic;
          SYS_CLK_int                  : in    std_logic;
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic;
          EV_RAM_DI_B_net_busnet_1     : out   std_logic
        );

end Analog_smev_wrapper;

architecture DEF_ARCH of Analog_smev_wrapper is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component SMEV
    port( rdgwgtpkbgc_0                : in    std_logic_vector(3 to 3) := (others => 'U');
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          rdgwgtpkbgc                  : out   std_logic_vector(3 to 3);
          dspfgfmqhwh                  : in    std_logic_vector(4 downto 0) := (others => 'U');
          EV_RAM_DI_B_net_busnet_1     : out   std_logic;
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_0     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_1     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_2     : in    std_logic := 'U';
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_8     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_6     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_3     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          INIT_DONE_net                : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic := 'U';
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          EV_RAM_DO_B_net_busnet_4     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_5     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_7     : in    std_logic := 'U';
          qvkpfznsfjx                  : in    std_logic := 'U';
          bcmkdjqtngz                  : in    std_logic := 'U';
          un1_Analog_inst_1            : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_7      : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic := 'U';
          EV_RAM_RW_A_net              : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic := 'U';
          EV_RAM_CSN_A_net             : out   std_logic;
          TR_EV_RD_net                 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic := 'U';
          EV_DONE_net                  : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U'
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : SMEV
	Use entity work.SMEV(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    U0 : SMEV
      port map(rdgwgtpkbgc_0(3) => rdgwgtpkbgc(3), 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), rdgwgtpkbgc(3) => 
        rdgwgtpkbgc_0(3), dspfgfmqhwh(4) => dspfgfmqhwh(4), 
        dspfgfmqhwh(3) => dspfgfmqhwh(3), dspfgfmqhwh(2) => 
        dspfgfmqhwh(2), dspfgfmqhwh(1) => dspfgfmqhwh(1), 
        dspfgfmqhwh(0) => dspfgfmqhwh(0), 
        EV_RAM_DI_B_net_busnet_1 => EV_RAM_DI_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_7_0 => EV_RAM_DO_B_net_busnet_7_0, 
        SYS_CLK_int => SYS_CLK_int, SYS_RESET_c => SYS_RESET_c, 
        EV_RAM_DO_B_net_busnet_0 => EV_RAM_DO_B_net_busnet_0, 
        EV_RAM_DO_B_net_busnet_1 => EV_RAM_DO_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_2 => EV_RAM_DO_B_net_busnet_2, 
        fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, 
        EV_RAM_DO_B_net_busnet_8 => EV_RAM_DO_B_net_busnet_8, 
        EV_RAM_DO_B_net_busnet_6 => EV_RAM_DO_B_net_busnet_6, 
        EV_RAM_DO_B_net_busnet_3 => EV_RAM_DO_B_net_busnet_3, 
        EV_CHHOLD_net_busnet_2 => EV_CHHOLD_net_busnet_2, 
        EV_CHHOLD_net_busnet_4 => EV_CHHOLD_net_busnet_4, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        EV_RAM_ADDR_B_net_busnet_5 => EV_RAM_ADDR_B_net_busnet_5, 
        EV_RAM_ADDR_B_net_busnet_6 => EV_RAM_ADDR_B_net_busnet_6, 
        EV_CHHOLD_net_busnet_0 => EV_CHHOLD_net_busnet_0, 
        INIT_DONE_net => INIT_DONE_net, EV_ASSCADDR_net_busnet_2
         => EV_ASSCADDR_net_busnet_2, EV_RAM_CSN_B_net => 
        EV_RAM_CSN_B_net, EV_RAM_DI_B_net_busnet_0 => 
        EV_RAM_DI_B_net_busnet_0, EV_RAM_DI_B_net_busnet_2 => 
        EV_RAM_DI_B_net_busnet_2, EV_RAM_DI_B_net_busnet_3 => 
        EV_RAM_DI_B_net_busnet_3, EV_RAM_DI_B_net_busnet_4 => 
        EV_RAM_DI_B_net_busnet_4, EV_RAM_DI_B_net_busnet_5 => 
        EV_RAM_DI_B_net_busnet_5, EV_RAM_DI_B_net_busnet_6 => 
        EV_RAM_DI_B_net_busnet_6, EV_RAM_DI_B_net_busnet_7 => 
        EV_RAM_DI_B_net_busnet_7, EV_RAM_DI_B_net_busnet_8 => 
        EV_RAM_DI_B_net_busnet_8, EV_RAM_ADDR_B_net_busnet_4 => 
        EV_RAM_ADDR_B_net_busnet_4, EV_RAM_ADDR_B_net_busnet_3
         => EV_RAM_ADDR_B_net_busnet_3, 
        EV_RAM_ADDR_B_net_busnet_2 => EV_RAM_ADDR_B_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_1 => EV_RAM_ADDR_B_net_busnet_1, 
        EV_RAM_ADDR_B_net_busnet_0 => EV_RAM_ADDR_B_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_7 => EV_RAM_ADDR_B_net_busnet_7, 
        EV_RAM_ADDR_B_net_busnet_8 => EV_RAM_ADDR_B_net_busnet_8, 
        ASSC_RAM_DO_A_net_busnet_0 => ASSC_RAM_DO_A_net_busnet_0, 
        ASSC_RAM_DO_A_net_busnet_1 => ASSC_RAM_DO_A_net_busnet_1, 
        ASSC_RAM_DO_A_net_busnet_2 => ASSC_RAM_DO_A_net_busnet_2, 
        EV_RAM_WR_BUSY_B_net => EV_RAM_WR_BUSY_B_net, 
        EV_RAM_DO_B_net_busnet_4 => EV_RAM_DO_B_net_busnet_4, 
        EV_RAM_DO_B_net_busnet_5 => EV_RAM_DO_B_net_busnet_5, 
        EV_RAM_DO_B_net_busnet_7 => EV_RAM_DO_B_net_busnet_7, 
        qvkpfznsfjx => qvkpfznsfjx, bcmkdjqtngz => bcmkdjqtngz, 
        un1_Analog_inst_1 => un1_Analog_inst_1, 
        EV_CHHOLD_net_busnet_3 => EV_CHHOLD_net_busnet_3, 
        EV_RAM_ADDR_A_net_busnet_3 => EV_RAM_ADDR_A_net_busnet_3, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        EV_RAM_ADDR_A_net_busnet_4 => EV_RAM_ADDR_A_net_busnet_4, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        EV_RAM_ADDR_A_net_busnet_7 => EV_RAM_ADDR_A_net_busnet_7, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_3 => ASSC_RAM_DO_A_net_busnet_3, 
        ASSC_RAM_DO_A_net_busnet_4 => ASSC_RAM_DO_A_net_busnet_4, 
        ASSC_RAM_DO_A_net_busnet_5 => ASSC_RAM_DO_A_net_busnet_5, 
        ASSC_RAM_DO_A_net_busnet_6 => ASSC_RAM_DO_A_net_busnet_6, 
        ASSC_RAM_DO_A_net_busnet_7 => ASSC_RAM_DO_A_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_8 => ASSC_RAM_DO_A_net_busnet_8, 
        EV_RAM_RW_A_net => EV_RAM_RW_A_net, INIT_EV_WEN_net => 
        INIT_EV_WEN_net, EV_RAM_CSN_A_net => EV_RAM_CSN_A_net, 
        TR_EV_RD_net => TR_EV_RD_net, EV_RAM_ADDR_A_net_busnet_8
         => EV_RAM_ADDR_A_net_busnet_8, TR_EV_ADDR_net_busnet_8
         => TR_EV_ADDR_net_busnet_8, EV_RAM_ADDR_A_net_busnet_5
         => EV_RAM_ADDR_A_net_busnet_5, TR_EV_ADDR_net_busnet_5
         => TR_EV_ADDR_net_busnet_5, EV_RAM_ADDR_A_net_busnet_2
         => EV_RAM_ADDR_A_net_busnet_2, TR_EV_ADDR_net_busnet_2
         => TR_EV_ADDR_net_busnet_2, EV_RAM_ADDR_A_net_busnet_1
         => EV_RAM_ADDR_A_net_busnet_1, TR_EV_ADDR_net_busnet_1
         => TR_EV_ADDR_net_busnet_1, EV_RAM_ADDR_A_net_busnet_6
         => EV_RAM_ADDR_A_net_busnet_6, TR_EV_ADDR_net_busnet_6
         => TR_EV_ADDR_net_busnet_6, EV_RAM_ADDR_A_net_busnet_0
         => EV_RAM_ADDR_A_net_busnet_0, TR_EV_ADDR_net_busnet_0
         => TR_EV_ADDR_net_busnet_0, EV_DONE_net => EV_DONE_net, 
        EV_EVFLAG_net => EV_EVFLAG_net, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, EV_ASSCADDR_net_busnet_8
         => EV_ASSCADDR_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity Analog is

    port( rdgwgtpkbgc_0      : in    std_logic_vector(3 to 3);
          rdgwgtpkbgc        : out   std_logic_vector(3 to 3);
          INIT_DATA_net      : in    std_logic_vector(8 downto 0);
          INIT_ADDR_net      : in    std_logic_vector(8 downto 0);
          INIT_ASSC_WEN_net  : in    std_logic;
          INIT_EV_WEN_net    : in    std_logic;
          INIT_DONE_net      : in    std_logic;
          AV5V_over5p25_net  : out   std_logic;
          AV5V_under4p75_net : out   std_logic;
          N_4                : in    std_logic;
          N_10               : in    std_logic;
          Analog_VCC         : in    std_logic;
          SYS_CLK_int        : in    std_logic;
          Supply_good_en_net : in    std_logic;
          SYS_RESET_c        : in    std_logic;
          CLK10M             : in    std_logic;
          VAREF              : inout std_logic := 'Z';
          AV5V               : in    std_logic;
          Analog_GND         : in    std_logic;
          INIT_ACM_WEN_net   : in    std_logic;
          Over_temp          : out   std_logic;
          Supply_good        : out   std_logic;
          ATRETURN01         : in    std_logic;
          Temp               : in    std_logic
        );

end Analog;

architecture DEF_ARCH of Analog is 

  component Analog_smev_ram
    port( INIT_DATA_net              : in    std_logic_vector(8 downto 0) := (others => 'U');
          SYS_RESET_c                : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_8   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_7   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_6   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_5   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_4   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_3   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_2   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_1   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_0   : in    std_logic := 'U';
          SYS_CLK_int                : in    std_logic := 'U';
          EV_RAM_WR_BUSY_B_net       : in    std_logic := 'U';
          EV_RAM_CSN_B_net           : in    std_logic := 'U';
          Analog_smev_ram_VCC        : in    std_logic := 'U';
          EV_RAM_RW_A_net            : in    std_logic := 'U';
          EV_RAM_CSN_A_net           : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_2 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_1 : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_0 : in    std_logic := 'U';
          Analog_smev_ram_GND        : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_8 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_7 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_6 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_5 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_4 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_3 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_2 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_1 : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_0 : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_8   : out   std_logic;
          EV_RAM_DO_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_B_net_busnet_5   : out   std_logic;
          EV_RAM_DO_B_net_busnet_4   : out   std_logic;
          EV_RAM_DO_B_net_busnet_3   : out   std_logic;
          EV_RAM_DO_B_net_busnet_2   : out   std_logic;
          EV_RAM_DO_B_net_busnet_1   : out   std_logic;
          EV_RAM_DO_B_net_busnet_0   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : out   std_logic;
          EV_RAM_DO_B_net_busnet_7   : out   std_logic;
          EV_RAM_DO_B_net_busnet_7_0 : out   std_logic
        );
  end component;

  component Analog_smtr_ram
    port( INIT_DATA_net              : in    std_logic_vector(8 downto 0) := (others => 'U');
          INIT_ADDR_net              : in    std_logic_vector(8 downto 0) := (others => 'U');
          SYS_RESET_c                : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_8   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_7   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_6   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_5   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_4   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_3   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_2   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_1   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_0   : in    std_logic := 'U';
          SYS_CLK_int                : in    std_logic := 'U';
          xgnmbzmtzbb_0              : in    std_logic := 'U';
          TR_RAM_CSN_B_net           : in    std_logic := 'U';
          Analog_smtr_ram_VCC        : in    std_logic := 'U';
          TR_RAM_RW_A_net            : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_2 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_1 : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_0 : in    std_logic := 'U';
          Analog_smtr_ram_GND        : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_8   : out   std_logic;
          TR_RAM_DO_B_net_busnet_7   : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : out   std_logic;
          TR_RAM_DO_B_net_busnet_2   : out   std_logic;
          TR_RAM_DO_B_net_busnet_1   : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : out   std_logic
        );
  end component;

  component OUTBUF_A
    port( D   : in    std_logic := 'U';
          PAD : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component INBUF_A
    port( PAD : in    std_logic := 'U';
          Y   : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component Analog_smtr_wrapper
    port( TR_EV_ADDR_net_busnet_8    : out   std_logic;
          TR_EV_ADDR_net_busnet_7    : out   std_logic;
          TR_EV_ADDR_net_busnet_6    : out   std_logic;
          TR_EV_ADDR_net_busnet_5    : out   std_logic;
          TR_EV_ADDR_net_busnet_4    : out   std_logic;
          TR_EV_ADDR_net_busnet_3    : out   std_logic;
          TR_EV_ADDR_net_busnet_2    : out   std_logic;
          TR_EV_ADDR_net_busnet_1    : out   std_logic;
          TR_EV_ADDR_net_busnet_0    : out   std_logic;
          TR_TRFLAG_net              : out   std_logic;
          TR_DONE_net_i_0            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          TR_RAM_DI_B_net_busnet_6   : out   std_logic;
          EV_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          EV_DONE_net                : in    std_logic := 'U';
          xgnmbzmtzbb_0              : out   std_logic;
          TR_RAM_DI_B_net_busnet_8   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          TR_RAM_DI_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_2     : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          EV_CHHOLD_net_busnet_3     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_4     : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_1   : out   std_logic;
          TR_RAM_DI_B_net_busnet_0   : out   std_logic;
          Temp_over70C_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_2   : out   std_logic;
          TR_RAM_DI_B_net_busnet_3   : out   std_logic;
          TR_RAM_DI_B_net_busnet_4   : out   std_logic;
          N_10                       : in    std_logic := 'U';
          N_4                        : in    std_logic := 'U';
          TR_RAM_RW_A_net            : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          EV_CHHOLD_net_busnet_1     : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_0     : in    std_logic := 'U';
          TR_RAM_DI_B_net_busnet_7   : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          TR_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          TR_RAM_CSN_B_net           : out   std_logic;
          TR_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          TR_EV_RD_net               : out   std_logic;
          AV5V_under4p75_net         : out   std_logic;
          AV5V_over5p25_net          : out   std_logic;
          TR_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          TR_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          TR_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          TR_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          TR_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          INIT_DONE_net              : in    std_logic := 'U';
          SYS_RESET_c                : in    std_logic := 'U';
          SYS_CLK_int                : in    std_logic := 'U'
        );
  end component;

  component Analog_assc_ram
    port( INIT_DATA_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          SYS_RESET_c                  : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_8   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_6   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_3   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_2   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_0   : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U';
          ASSC_RAM_WR_BUSY_B_net       : in    std_logic := 'U';
          N_250_i_0                    : in    std_logic := 'U';
          Analog_assc_ram_VCC          : in    std_logic := 'U';
          ASSC_RAM_RW_A_net            : in    std_logic := 'U';
          ASSC_RAM_CSN_A_net           : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_2 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_1 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_0 : in    std_logic := 'U';
          Analog_assc_ram_GND          : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_8 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_7 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_6 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_5 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_4 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_3 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_2 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_1 : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_0 : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_7   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_6   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_5   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_4   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_2   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_0   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_7   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_6   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_5   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_4   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_3   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_1   : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_0   : out   std_logic
        );
  end component;

  component AB
    port( DAVOUT0     : out   std_logic;
          DACOUT0     : out   std_logic;
          DATOUT0     : out   std_logic;
          DAVOUT1     : out   std_logic;
          DACOUT1     : out   std_logic;
          DATOUT1     : out   std_logic;
          DAVOUT2     : out   std_logic;
          DACOUT2     : out   std_logic;
          DATOUT2     : out   std_logic;
          DAVOUT3     : out   std_logic;
          DACOUT3     : out   std_logic;
          DATOUT3     : out   std_logic;
          DAVOUT4     : out   std_logic;
          DACOUT4     : out   std_logic;
          DATOUT4     : out   std_logic;
          DAVOUT5     : out   std_logic;
          DACOUT5     : out   std_logic;
          DATOUT5     : out   std_logic;
          DAVOUT6     : out   std_logic;
          DACOUT6     : out   std_logic;
          DATOUT6     : out   std_logic;
          DAVOUT7     : out   std_logic;
          DACOUT7     : out   std_logic;
          DATOUT7     : out   std_logic;
          DAVOUT8     : out   std_logic;
          DACOUT8     : out   std_logic;
          DATOUT8     : out   std_logic;
          DAVOUT9     : out   std_logic;
          DACOUT9     : out   std_logic;
          DATOUT9     : out   std_logic;
          DENAV0      : in    std_logic := 'U';
          DENAC0      : in    std_logic := 'U';
          DENAT0      : in    std_logic := 'U';
          DENAV1      : in    std_logic := 'U';
          DENAC1      : in    std_logic := 'U';
          DENAT1      : in    std_logic := 'U';
          DENAV2      : in    std_logic := 'U';
          DENAC2      : in    std_logic := 'U';
          DENAT2      : in    std_logic := 'U';
          DENAV3      : in    std_logic := 'U';
          DENAC3      : in    std_logic := 'U';
          DENAT3      : in    std_logic := 'U';
          DENAV4      : in    std_logic := 'U';
          DENAC4      : in    std_logic := 'U';
          DENAT4      : in    std_logic := 'U';
          DENAV5      : in    std_logic := 'U';
          DENAC5      : in    std_logic := 'U';
          DENAT5      : in    std_logic := 'U';
          DENAV6      : in    std_logic := 'U';
          DENAC6      : in    std_logic := 'U';
          DENAT6      : in    std_logic := 'U';
          DENAV7      : in    std_logic := 'U';
          DENAC7      : in    std_logic := 'U';
          DENAT7      : in    std_logic := 'U';
          DENAV8      : in    std_logic := 'U';
          DENAC8      : in    std_logic := 'U';
          DENAT8      : in    std_logic := 'U';
          DENAV9      : in    std_logic := 'U';
          DENAC9      : in    std_logic := 'U';
          DENAT9      : in    std_logic := 'U';
          AV0         : in    std_logic := 'U';
          AC0         : in    std_logic := 'U';
          AT0         : in    std_logic := 'U';
          AG0         : out   std_logic;
          AV1         : in    std_logic := 'U';
          AC1         : in    std_logic := 'U';
          AT1         : in    std_logic := 'U';
          AG1         : out   std_logic;
          AV2         : in    std_logic := 'U';
          AC2         : in    std_logic := 'U';
          AT2         : in    std_logic := 'U';
          AG2         : out   std_logic;
          AV3         : in    std_logic := 'U';
          AC3         : in    std_logic := 'U';
          AT3         : in    std_logic := 'U';
          AG3         : out   std_logic;
          AV4         : in    std_logic := 'U';
          AC4         : in    std_logic := 'U';
          AT4         : in    std_logic := 'U';
          AG4         : out   std_logic;
          AV5         : in    std_logic := 'U';
          AC5         : in    std_logic := 'U';
          AT5         : in    std_logic := 'U';
          AG5         : out   std_logic;
          AV6         : in    std_logic := 'U';
          AC6         : in    std_logic := 'U';
          AT6         : in    std_logic := 'U';
          AG6         : out   std_logic;
          AV7         : in    std_logic := 'U';
          AC7         : in    std_logic := 'U';
          AT7         : in    std_logic := 'U';
          AG7         : out   std_logic;
          AV8         : in    std_logic := 'U';
          AC8         : in    std_logic := 'U';
          AT8         : in    std_logic := 'U';
          AG8         : out   std_logic;
          AV9         : in    std_logic := 'U';
          AC9         : in    std_logic := 'U';
          AT9         : in    std_logic := 'U';
          AG9         : out   std_logic;
          ATRETURN01  : in    std_logic := 'U';
          ATRETURN23  : in    std_logic := 'U';
          ATRETURN45  : in    std_logic := 'U';
          ATRETURN67  : in    std_logic := 'U';
          ATRETURN89  : in    std_logic := 'U';
          VAREF       : inout   std_logic;
          GNDREF      : in    std_logic := 'U';
          GDON0       : in    std_logic := 'U';
          GDON1       : in    std_logic := 'U';
          GDON2       : in    std_logic := 'U';
          GDON3       : in    std_logic := 'U';
          GDON4       : in    std_logic := 'U';
          GDON5       : in    std_logic := 'U';
          GDON6       : in    std_logic := 'U';
          GDON7       : in    std_logic := 'U';
          GDON8       : in    std_logic := 'U';
          GDON9       : in    std_logic := 'U';
          CMSTB0      : in    std_logic := 'U';
          CMSTB1      : in    std_logic := 'U';
          CMSTB2      : in    std_logic := 'U';
          CMSTB3      : in    std_logic := 'U';
          CMSTB4      : in    std_logic := 'U';
          CMSTB5      : in    std_logic := 'U';
          CMSTB6      : in    std_logic := 'U';
          CMSTB7      : in    std_logic := 'U';
          CMSTB8      : in    std_logic := 'U';
          CMSTB9      : in    std_logic := 'U';
          TMSTB0      : in    std_logic := 'U';
          TMSTB1      : in    std_logic := 'U';
          TMSTB2      : in    std_logic := 'U';
          TMSTB3      : in    std_logic := 'U';
          TMSTB4      : in    std_logic := 'U';
          TMSTB5      : in    std_logic := 'U';
          TMSTB6      : in    std_logic := 'U';
          TMSTB7      : in    std_logic := 'U';
          TMSTB8      : in    std_logic := 'U';
          TMSTB9      : in    std_logic := 'U';
          TMSTBINT    : in    std_logic := 'U';
          RESULT      : out   std_logic_vector(11 downto 0);
          ACMRDATA    : out   std_logic_vector(7 downto 0);
          ACMWDATA    : in    std_logic_vector(7 downto 0) := (others => 'U');
          ACMADDR     : in    std_logic_vector(7 downto 0) := (others => 'U');
          STC         : in    std_logic_vector(7 downto 0) := (others => 'U');
          TVC         : in    std_logic_vector(7 downto 0) := (others => 'U');
          CHNUMBER    : in    std_logic_vector(4 downto 0) := (others => 'U');
          MODE        : in    std_logic_vector(3 downto 0) := (others => 'U');
          RTCXTLMODE  : out   std_logic_vector(1 downto 0);
          ACMRESET    : in    std_logic := 'U';
          ACMCLK      : in    std_logic := 'U';
          ACMWEN      : in    std_logic := 'U';
          VAREFSEL    : in    std_logic := 'U';
          DATAVALID   : out   std_logic;
          CALIBRATE   : out   std_logic;
          SAMPLE      : out   std_logic;
          BUSY        : out   std_logic;
          PWRDWN      : in    std_logic := 'U';
          SYSCLK      : in    std_logic := 'U';
          ADCRESET    : in    std_logic := 'U';
          ADCSTART    : in    std_logic := 'U';
          RTCMATCH    : out   std_logic;
          RTCPSMMATCH : out   std_logic;
          RTCXTLSEL   : out   std_logic;
          RTCCLK      : in    std_logic := 'U'
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component Analog_assc_wrapper
    port( INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          dspfgfmqhwh                  : out   std_logic_vector(4 downto 0);
          ASSC_RAM_ADDR_B_net_busnet_8 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : out   std_logic;
          ADC_MODE_net_busnet_3        : out   std_logic;
          ADC_MODE_net_busnet_2        : out   std_logic;
          ADC_MODE_net_busnet_1        : out   std_logic;
          ADC_MODE_net_busnet_0        : out   std_logic;
          ADC_TVC_net_busnet_7         : out   std_logic;
          ADC_TVC_net_busnet_6         : out   std_logic;
          ADC_TVC_net_busnet_5         : out   std_logic;
          ADC_TVC_net_busnet_4         : out   std_logic;
          ADC_TVC_net_busnet_3         : out   std_logic;
          ADC_TVC_net_busnet_2         : out   std_logic;
          ADC_TVC_net_busnet_1         : out   std_logic;
          ADC_TVC_net_busnet_0         : out   std_logic;
          ADC_STC_net_busnet_7         : out   std_logic;
          ADC_STC_net_busnet_6         : out   std_logic;
          ADC_STC_net_busnet_5         : out   std_logic;
          ADC_STC_net_busnet_4         : out   std_logic;
          ADC_STC_net_busnet_3         : out   std_logic;
          ADC_STC_net_busnet_2         : out   std_logic;
          ADC_STC_net_busnet_1         : out   std_logic;
          ADC_STC_net_busnet_0         : out   std_logic;
          bcmkdjqtngz                  : out   std_logic;
          TM_STB_net_0                 : out   std_logic;
          ADC_PDOWN_net                : out   std_logic;
          ADC_RESET_net                : out   std_logic;
          ADC_CALIBRATE_net            : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_0   : in    std_logic := 'U';
          ADC_START_net                : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_3   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_2   : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_8     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_8 : out   std_logic;
          EV_ASSCADDR_net_busnet_7     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_7 : out   std_logic;
          EV_ASSCADDR_net_busnet_6     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_6 : out   std_logic;
          EV_ASSCADDR_net_busnet_5     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_5 : out   std_logic;
          EV_ASSCADDR_net_busnet_4     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_4 : out   std_logic;
          EV_ASSCADDR_net_busnet_3     : in    std_logic := 'U';
          ASSC_RAM_ADDR_A_net_busnet_3 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_2 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_A_net_busnet_0 : out   std_logic;
          ASSC_RAM_DO_B_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_RW_A_net            : out   std_logic;
          un1_Analog_inst_1            : out   std_logic;
          ADC_RESULT_net_busnet_8      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_8   : out   std_logic;
          ADC_RESULT_net_busnet_7      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_7   : out   std_logic;
          ADC_RESULT_net_busnet_6      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_6   : out   std_logic;
          ADC_RESULT_net_busnet_5      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_5   : out   std_logic;
          ADC_RESULT_net_busnet_4      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_4   : out   std_logic;
          ADC_RESULT_net_busnet_3      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_3   : out   std_logic;
          INIT_ASSC_WEN_net            : in    std_logic := 'U';
          ASSC_RAM_CSN_A_net           : out   std_logic;
          ADC_RESULT_net_busnet_11     : in    std_logic := 'U';
          ADC_RESULT_net_busnet_2      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_2   : out   std_logic;
          ADC_RESULT_net_busnet_10     : in    std_logic := 'U';
          ADC_RESULT_net_busnet_1      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_1   : out   std_logic;
          ADC_RESULT_net_busnet_9      : in    std_logic := 'U';
          ADC_RESULT_net_busnet_0      : in    std_logic := 'U';
          ASSC_RAM_DI_B_net_busnet_0   : out   std_logic;
          qvkpfznsfjx                  : out   std_logic;
          ADC_BUSY_net                 : in    std_logic := 'U';
          ASSC_RAM_ADDR_B_net_busnet_1 : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_2 : out   std_logic;
          N_250_i_0                    : out   std_logic;
          fskhwddcbbg_1_sqmuxa         : in    std_logic := 'U';
          EV_DONE_net                  : in    std_logic := 'U';
          EV_EVFLAG_net                : in    std_logic := 'U';
          TR_TRFLAG_net                : in    std_logic := 'U';
          TR_DONE_net_i_0              : in    std_logic := 'U';
          ASSC_RAM_WR_BUSY_B_net       : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : in    std_logic := 'U';
          INIT_DONE_net                : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_8   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_B_net_busnet_6   : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U'
        );
  end component;

  component Analog_smev_wrapper
    port( dspfgfmqhwh                  : in    std_logic_vector(4 downto 0) := (others => 'U');
          rdgwgtpkbgc_0                : out   std_logic_vector(3 to 3);
          INIT_ADDR_net                : in    std_logic_vector(8 downto 0) := (others => 'U');
          rdgwgtpkbgc                  : in    std_logic_vector(3 to 3) := (others => 'U');
          ASSC_RAM_ADDR_B_net_busnet_8 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_8     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_7 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_7     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_6 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_6     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_5 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_5     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_4 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_4     : out   std_logic;
          ASSC_RAM_ADDR_B_net_busnet_3 : in    std_logic := 'U';
          EV_ASSCADDR_net_busnet_3     : out   std_logic;
          EV_EVFLAG_net                : out   std_logic;
          EV_DONE_net                  : out   std_logic;
          TR_EV_ADDR_net_busnet_0      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_0   : out   std_logic;
          TR_EV_ADDR_net_busnet_6      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_6   : out   std_logic;
          TR_EV_ADDR_net_busnet_1      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_1   : out   std_logic;
          TR_EV_ADDR_net_busnet_2      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_2   : out   std_logic;
          TR_EV_ADDR_net_busnet_5      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_5   : out   std_logic;
          TR_EV_ADDR_net_busnet_8      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_8   : out   std_logic;
          TR_EV_RD_net                 : in    std_logic := 'U';
          EV_RAM_CSN_A_net             : out   std_logic;
          INIT_EV_WEN_net              : in    std_logic := 'U';
          EV_RAM_RW_A_net              : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_8   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_7   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_6   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_5   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_4   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_3   : in    std_logic := 'U';
          TR_EV_ADDR_net_busnet_7      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_7   : out   std_logic;
          TR_EV_ADDR_net_busnet_4      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_4   : out   std_logic;
          TR_EV_ADDR_net_busnet_3      : in    std_logic := 'U';
          EV_RAM_ADDR_A_net_busnet_3   : out   std_logic;
          EV_CHHOLD_net_busnet_3       : out   std_logic;
          un1_Analog_inst_1            : in    std_logic := 'U';
          bcmkdjqtngz                  : in    std_logic := 'U';
          qvkpfznsfjx                  : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_7     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_5     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_4     : in    std_logic := 'U';
          EV_RAM_WR_BUSY_B_net         : out   std_logic;
          ASSC_RAM_DO_A_net_busnet_2   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_1   : in    std_logic := 'U';
          ASSC_RAM_DO_A_net_busnet_0   : in    std_logic := 'U';
          EV_RAM_ADDR_B_net_busnet_8   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_7   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_0   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_1   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_2   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_3   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_4   : out   std_logic;
          EV_RAM_DI_B_net_busnet_8     : out   std_logic;
          EV_RAM_DI_B_net_busnet_7     : out   std_logic;
          EV_RAM_DI_B_net_busnet_6     : out   std_logic;
          EV_RAM_DI_B_net_busnet_5     : out   std_logic;
          EV_RAM_DI_B_net_busnet_4     : out   std_logic;
          EV_RAM_DI_B_net_busnet_3     : out   std_logic;
          EV_RAM_DI_B_net_busnet_2     : out   std_logic;
          EV_RAM_DI_B_net_busnet_0     : out   std_logic;
          EV_RAM_CSN_B_net             : out   std_logic;
          EV_ASSCADDR_net_busnet_2     : out   std_logic;
          INIT_DONE_net                : in    std_logic := 'U';
          EV_CHHOLD_net_busnet_0       : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_6   : out   std_logic;
          EV_RAM_ADDR_B_net_busnet_5   : out   std_logic;
          EV_CHHOLD_net_busnet_1       : out   std_logic;
          EV_CHHOLD_net_busnet_4       : out   std_logic;
          EV_CHHOLD_net_busnet_2       : out   std_logic;
          EV_RAM_DO_B_net_busnet_3     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_6     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_8     : in    std_logic := 'U';
          fskhwddcbbg_1_sqmuxa         : out   std_logic;
          EV_RAM_DO_B_net_busnet_2     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_1     : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_0     : in    std_logic := 'U';
          SYS_RESET_c                  : in    std_logic := 'U';
          SYS_CLK_int                  : in    std_logic := 'U';
          EV_RAM_DO_B_net_busnet_7_0   : in    std_logic := 'U';
          EV_RAM_DI_B_net_busnet_1     : out   std_logic
        );
  end component;

    signal AT0_net, ATRETURN01_net, AG0_net, AG1_net, 
        INIT_ACM_WEN_OR_net, AV0_net, \AB_INST_ACMRDATA[0]\, 
        \AB_INST_ACMRDATA[1]\, \AB_INST_ACMRDATA[2]\, 
        \AB_INST_ACMRDATA[3]\, \AB_INST_ACMRDATA[4]\, 
        \AB_INST_ACMRDATA[5]\, \AB_INST_ACMRDATA[6]\, 
        \AB_INST_ACMRDATA[7]\, AB_INST_AG2, AB_INST_AG3, 
        AB_INST_AG4, AB_INST_AG5, AB_INST_AG6, AB_INST_AG7, 
        AB_INST_AG8, AB_INST_AG9, ADC_BUSY_net, ADC_CALIBRATE_net, 
        AB_INST_DACOUT0, AB_INST_DACOUT1, AB_INST_DACOUT2, 
        AB_INST_DACOUT3, AB_INST_DACOUT4, AB_INST_DACOUT5, 
        AB_INST_DACOUT6, AB_INST_DACOUT7, AB_INST_DACOUT8, 
        AB_INST_DACOUT9, AB_INST_DATAVALID, AB_INST_DATOUT0, 
        AB_INST_DATOUT1, AB_INST_DATOUT2, AB_INST_DATOUT3, 
        AB_INST_DATOUT4, AB_INST_DATOUT5, AB_INST_DATOUT6, 
        AB_INST_DATOUT7, AB_INST_DATOUT8, AB_INST_DATOUT9, 
        AB_INST_DAVOUT0, AB_INST_DAVOUT1, AB_INST_DAVOUT2, 
        AB_INST_DAVOUT3, AB_INST_DAVOUT4, AB_INST_DAVOUT5, 
        AB_INST_DAVOUT6, AB_INST_DAVOUT7, AB_INST_DAVOUT8, 
        AB_INST_DAVOUT9, ADC_RESULT_net_busnet_0, 
        ADC_RESULT_net_busnet_1, ADC_RESULT_net_busnet_2, 
        ADC_RESULT_net_busnet_3, ADC_RESULT_net_busnet_4, 
        ADC_RESULT_net_busnet_5, ADC_RESULT_net_busnet_6, 
        ADC_RESULT_net_busnet_7, ADC_RESULT_net_busnet_8, 
        ADC_RESULT_net_busnet_9, ADC_RESULT_net_busnet_10, 
        ADC_RESULT_net_busnet_11, AB_INST_RTCMATCH, 
        AB_INST_RTCPSMMATCH, \AB_INST_RTCXTLMODE[0]\, 
        \AB_INST_RTCXTLMODE[1]\, AB_INST_RTCXTLSEL, 
        AB_INST_SAMPLE, ADC_RESET_net, ADC_START_net, 
        \dspfgfmqhwh[0]\, \dspfgfmqhwh[1]\, \dspfgfmqhwh[2]\, 
        \dspfgfmqhwh[3]\, \dspfgfmqhwh[4]\, Temp_over70C_net, 
        ADC_MODE_net_busnet_0, ADC_MODE_net_busnet_1, 
        ADC_MODE_net_busnet_2, ADC_MODE_net_busnet_3, 
        ADC_PDOWN_net, ADC_STC_net_busnet_0, ADC_STC_net_busnet_1, 
        ADC_STC_net_busnet_2, ADC_STC_net_busnet_3, 
        ADC_STC_net_busnet_4, ADC_STC_net_busnet_5, 
        ADC_STC_net_busnet_6, ADC_STC_net_busnet_7, TM_STB_net_0, 
        ADC_TVC_net_busnet_0, ADC_TVC_net_busnet_1, 
        ADC_TVC_net_busnet_2, ADC_TVC_net_busnet_3, 
        ADC_TVC_net_busnet_4, ADC_TVC_net_busnet_5, 
        ADC_TVC_net_busnet_6, ADC_TVC_net_busnet_7, 
        TR_RAM_DI_B_net_busnet_8, TR_RAM_DI_B_net_busnet_7, 
        TR_RAM_DI_B_net_busnet_6, TR_RAM_DI_B_net_busnet_5, 
        TR_RAM_DI_B_net_busnet_4, TR_RAM_DI_B_net_busnet_3, 
        TR_RAM_DI_B_net_busnet_2, TR_RAM_DI_B_net_busnet_1, 
        TR_RAM_DI_B_net_busnet_0, xgnmbzmtzbb_0, TR_RAM_CSN_B_net, 
        TR_RAM_RW_A_net, TR_RAM_ADDR_B_net_busnet_8, 
        TR_RAM_ADDR_B_net_busnet_7, TR_RAM_ADDR_B_net_busnet_6, 
        TR_RAM_ADDR_B_net_busnet_5, TR_RAM_ADDR_B_net_busnet_4, 
        TR_RAM_ADDR_B_net_busnet_3, TR_RAM_ADDR_B_net_busnet_2, 
        TR_RAM_ADDR_B_net_busnet_1, TR_RAM_ADDR_B_net_busnet_0, 
        TR_RAM_DO_B_net_busnet_8, TR_RAM_DO_B_net_busnet_7, 
        TR_RAM_DO_B_net_busnet_6, TR_RAM_DO_B_net_busnet_5, 
        TR_RAM_DO_B_net_busnet_4, TR_RAM_DO_B_net_busnet_3, 
        TR_RAM_DO_B_net_busnet_2, TR_RAM_DO_B_net_busnet_1, 
        TR_RAM_DO_B_net_busnet_0, TR_EV_ADDR_net_busnet_8, 
        TR_EV_ADDR_net_busnet_7, TR_EV_ADDR_net_busnet_6, 
        TR_EV_ADDR_net_busnet_5, TR_EV_ADDR_net_busnet_4, 
        TR_EV_ADDR_net_busnet_3, TR_EV_ADDR_net_busnet_2, 
        TR_EV_ADDR_net_busnet_1, TR_EV_ADDR_net_busnet_0, 
        TR_TRFLAG_net, TR_DONE_net_i_0, EV_RAM_DO_A_net_busnet_0, 
        EV_DONE_net, EV_CHHOLD_net_busnet_2, 
        EV_CHHOLD_net_busnet_3, EV_CHHOLD_net_busnet_4, 
        EV_CHHOLD_net_busnet_1, EV_CHHOLD_net_busnet_0, 
        TR_EV_RD_net, ASSC_RAM_DI_B_net_busnet_8, 
        ASSC_RAM_DI_B_net_busnet_7, ASSC_RAM_DI_B_net_busnet_6, 
        ASSC_RAM_DI_B_net_busnet_5, ASSC_RAM_DI_B_net_busnet_4, 
        ASSC_RAM_DI_B_net_busnet_3, ASSC_RAM_DI_B_net_busnet_2, 
        ASSC_RAM_DI_B_net_busnet_1, ASSC_RAM_DI_B_net_busnet_0, 
        ASSC_RAM_WR_BUSY_B_net, N_250_i_0, ASSC_RAM_RW_A_net, 
        ASSC_RAM_CSN_A_net, ASSC_RAM_ADDR_B_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_2, 
        ASSC_RAM_ADDR_B_net_busnet_1, 
        ASSC_RAM_ADDR_B_net_busnet_0, 
        ASSC_RAM_ADDR_A_net_busnet_8, 
        ASSC_RAM_ADDR_A_net_busnet_7, 
        ASSC_RAM_ADDR_A_net_busnet_6, 
        ASSC_RAM_ADDR_A_net_busnet_5, 
        ASSC_RAM_ADDR_A_net_busnet_4, 
        ASSC_RAM_ADDR_A_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_2, 
        ASSC_RAM_ADDR_A_net_busnet_1, 
        ASSC_RAM_ADDR_A_net_busnet_0, ASSC_RAM_DO_B_net_busnet_8, 
        ASSC_RAM_DO_B_net_busnet_7, ASSC_RAM_DO_B_net_busnet_6, 
        ASSC_RAM_DO_B_net_busnet_5, ASSC_RAM_DO_B_net_busnet_4, 
        ASSC_RAM_DO_B_net_busnet_3, ASSC_RAM_DO_B_net_busnet_2, 
        ASSC_RAM_DO_B_net_busnet_1, ASSC_RAM_DO_B_net_busnet_0, 
        ASSC_RAM_DO_A_net_busnet_8, ASSC_RAM_DO_A_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_6, ASSC_RAM_DO_A_net_busnet_5, 
        ASSC_RAM_DO_A_net_busnet_4, ASSC_RAM_DO_A_net_busnet_3, 
        ASSC_RAM_DO_A_net_busnet_2, ASSC_RAM_DO_A_net_busnet_1, 
        ASSC_RAM_DO_A_net_busnet_0, EV_ASSCADDR_net_busnet_8, 
        EV_ASSCADDR_net_busnet_7, EV_ASSCADDR_net_busnet_6, 
        EV_ASSCADDR_net_busnet_5, EV_ASSCADDR_net_busnet_4, 
        EV_ASSCADDR_net_busnet_3, EV_EVFLAG_net, 
        EV_RAM_ADDR_A_net_busnet_0, EV_RAM_ADDR_A_net_busnet_6, 
        EV_RAM_ADDR_A_net_busnet_1, EV_RAM_ADDR_A_net_busnet_2, 
        EV_RAM_ADDR_A_net_busnet_5, EV_RAM_ADDR_A_net_busnet_8, 
        EV_RAM_CSN_A_net, EV_RAM_RW_A_net, 
        EV_RAM_ADDR_A_net_busnet_7, EV_RAM_ADDR_A_net_busnet_4, 
        EV_RAM_ADDR_A_net_busnet_3, un1_Analog_inst_1, 
        bcmkdjqtngz, qvkpfznsfjx, EV_RAM_DO_B_net_busnet_7, 
        EV_RAM_DO_B_net_busnet_5, EV_RAM_DO_B_net_busnet_4, 
        EV_RAM_WR_BUSY_B_net, EV_RAM_ADDR_B_net_busnet_8, 
        EV_RAM_ADDR_B_net_busnet_7, EV_RAM_ADDR_B_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_1, EV_RAM_ADDR_B_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_3, EV_RAM_ADDR_B_net_busnet_4, 
        EV_RAM_DI_B_net_busnet_8, EV_RAM_DI_B_net_busnet_7, 
        EV_RAM_DI_B_net_busnet_6, EV_RAM_DI_B_net_busnet_5, 
        EV_RAM_DI_B_net_busnet_4, EV_RAM_DI_B_net_busnet_3, 
        EV_RAM_DI_B_net_busnet_2, EV_RAM_DI_B_net_busnet_0, 
        EV_RAM_CSN_B_net, EV_ASSCADDR_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_6, EV_RAM_ADDR_B_net_busnet_5, 
        EV_RAM_DO_B_net_busnet_3, EV_RAM_DO_B_net_busnet_6, 
        EV_RAM_DO_B_net_busnet_8, fskhwddcbbg_1_sqmuxa, 
        EV_RAM_DO_B_net_busnet_2, EV_RAM_DO_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_0, EV_RAM_DO_B_net_busnet_7_0, 
        EV_RAM_DI_B_net_busnet_1, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

    for all : Analog_smev_ram
	Use entity work.Analog_smev_ram(DEF_ARCH);
    for all : Analog_smtr_ram
	Use entity work.Analog_smtr_ram(DEF_ARCH);
    for all : Analog_smtr_wrapper
	Use entity work.Analog_smtr_wrapper(DEF_ARCH);
    for all : Analog_assc_ram
	Use entity work.Analog_assc_ram(DEF_ARCH);
    for all : Analog_assc_wrapper
	Use entity work.Analog_assc_wrapper(DEF_ARCH);
    for all : Analog_smev_wrapper
	Use entity work.Analog_smev_wrapper(DEF_ARCH);
begin 


    Analog_smev_ram_inst : Analog_smev_ram
      port map(INIT_DATA_net(8) => INIT_DATA_net(8), 
        INIT_DATA_net(7) => INIT_DATA_net(7), INIT_DATA_net(6)
         => INIT_DATA_net(6), INIT_DATA_net(5) => 
        INIT_DATA_net(5), INIT_DATA_net(4) => INIT_DATA_net(4), 
        INIT_DATA_net(3) => INIT_DATA_net(3), INIT_DATA_net(2)
         => INIT_DATA_net(2), INIT_DATA_net(1) => 
        INIT_DATA_net(1), INIT_DATA_net(0) => INIT_DATA_net(0), 
        SYS_RESET_c => SYS_RESET_c, EV_RAM_DI_B_net_busnet_8 => 
        EV_RAM_DI_B_net_busnet_8, EV_RAM_DI_B_net_busnet_7 => 
        EV_RAM_DI_B_net_busnet_7, EV_RAM_DI_B_net_busnet_6 => 
        EV_RAM_DI_B_net_busnet_6, EV_RAM_DI_B_net_busnet_5 => 
        EV_RAM_DI_B_net_busnet_5, EV_RAM_DI_B_net_busnet_4 => 
        EV_RAM_DI_B_net_busnet_4, EV_RAM_DI_B_net_busnet_3 => 
        EV_RAM_DI_B_net_busnet_3, EV_RAM_DI_B_net_busnet_2 => 
        EV_RAM_DI_B_net_busnet_2, EV_RAM_DI_B_net_busnet_1 => 
        EV_RAM_DI_B_net_busnet_1, EV_RAM_DI_B_net_busnet_0 => 
        EV_RAM_DI_B_net_busnet_0, SYS_CLK_int => SYS_CLK_int, 
        EV_RAM_WR_BUSY_B_net => EV_RAM_WR_BUSY_B_net, 
        EV_RAM_CSN_B_net => EV_RAM_CSN_B_net, Analog_smev_ram_VCC
         => Analog_VCC, EV_RAM_RW_A_net => EV_RAM_RW_A_net, 
        EV_RAM_CSN_A_net => EV_RAM_CSN_A_net, 
        EV_RAM_ADDR_B_net_busnet_8 => EV_RAM_ADDR_B_net_busnet_8, 
        EV_RAM_ADDR_B_net_busnet_7 => EV_RAM_ADDR_B_net_busnet_7, 
        EV_RAM_ADDR_B_net_busnet_6 => EV_RAM_ADDR_B_net_busnet_6, 
        EV_RAM_ADDR_B_net_busnet_5 => EV_RAM_ADDR_B_net_busnet_5, 
        EV_RAM_ADDR_B_net_busnet_4 => EV_RAM_ADDR_B_net_busnet_4, 
        EV_RAM_ADDR_B_net_busnet_3 => EV_RAM_ADDR_B_net_busnet_3, 
        EV_RAM_ADDR_B_net_busnet_2 => EV_RAM_ADDR_B_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_1 => EV_RAM_ADDR_B_net_busnet_1, 
        EV_RAM_ADDR_B_net_busnet_0 => EV_RAM_ADDR_B_net_busnet_0, 
        Analog_smev_ram_GND => Analog_GND, 
        EV_RAM_ADDR_A_net_busnet_8 => EV_RAM_ADDR_A_net_busnet_8, 
        EV_RAM_ADDR_A_net_busnet_7 => EV_RAM_ADDR_A_net_busnet_7, 
        EV_RAM_ADDR_A_net_busnet_6 => EV_RAM_ADDR_A_net_busnet_6, 
        EV_RAM_ADDR_A_net_busnet_5 => EV_RAM_ADDR_A_net_busnet_5, 
        EV_RAM_ADDR_A_net_busnet_4 => EV_RAM_ADDR_A_net_busnet_4, 
        EV_RAM_ADDR_A_net_busnet_3 => EV_RAM_ADDR_A_net_busnet_3, 
        EV_RAM_ADDR_A_net_busnet_2 => EV_RAM_ADDR_A_net_busnet_2, 
        EV_RAM_ADDR_A_net_busnet_1 => EV_RAM_ADDR_A_net_busnet_1, 
        EV_RAM_ADDR_A_net_busnet_0 => EV_RAM_ADDR_A_net_busnet_0, 
        EV_RAM_DO_B_net_busnet_8 => EV_RAM_DO_B_net_busnet_8, 
        EV_RAM_DO_B_net_busnet_6 => EV_RAM_DO_B_net_busnet_6, 
        EV_RAM_DO_B_net_busnet_5 => EV_RAM_DO_B_net_busnet_5, 
        EV_RAM_DO_B_net_busnet_4 => EV_RAM_DO_B_net_busnet_4, 
        EV_RAM_DO_B_net_busnet_3 => EV_RAM_DO_B_net_busnet_3, 
        EV_RAM_DO_B_net_busnet_2 => EV_RAM_DO_B_net_busnet_2, 
        EV_RAM_DO_B_net_busnet_1 => EV_RAM_DO_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_0 => EV_RAM_DO_B_net_busnet_0, 
        EV_RAM_DO_A_net_busnet_0 => EV_RAM_DO_A_net_busnet_0, 
        EV_RAM_DO_B_net_busnet_7 => EV_RAM_DO_B_net_busnet_7, 
        EV_RAM_DO_B_net_busnet_7_0 => EV_RAM_DO_B_net_busnet_7_0);
    
    Analog_smtr_ram_inst : Analog_smtr_ram
      port map(INIT_DATA_net(8) => INIT_DATA_net(8), 
        INIT_DATA_net(7) => INIT_DATA_net(7), INIT_DATA_net(6)
         => INIT_DATA_net(6), INIT_DATA_net(5) => 
        INIT_DATA_net(5), INIT_DATA_net(4) => INIT_DATA_net(4), 
        INIT_DATA_net(3) => INIT_DATA_net(3), INIT_DATA_net(2)
         => INIT_DATA_net(2), INIT_DATA_net(1) => 
        INIT_DATA_net(1), INIT_DATA_net(0) => INIT_DATA_net(0), 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), SYS_RESET_c => 
        SYS_RESET_c, TR_RAM_DI_B_net_busnet_8 => 
        TR_RAM_DI_B_net_busnet_8, TR_RAM_DI_B_net_busnet_7 => 
        TR_RAM_DI_B_net_busnet_7, TR_RAM_DI_B_net_busnet_6 => 
        TR_RAM_DI_B_net_busnet_6, TR_RAM_DI_B_net_busnet_5 => 
        TR_RAM_DI_B_net_busnet_5, TR_RAM_DI_B_net_busnet_4 => 
        TR_RAM_DI_B_net_busnet_4, TR_RAM_DI_B_net_busnet_3 => 
        TR_RAM_DI_B_net_busnet_3, TR_RAM_DI_B_net_busnet_2 => 
        TR_RAM_DI_B_net_busnet_2, TR_RAM_DI_B_net_busnet_1 => 
        TR_RAM_DI_B_net_busnet_1, TR_RAM_DI_B_net_busnet_0 => 
        TR_RAM_DI_B_net_busnet_0, SYS_CLK_int => SYS_CLK_int, 
        xgnmbzmtzbb_0 => xgnmbzmtzbb_0, TR_RAM_CSN_B_net => 
        TR_RAM_CSN_B_net, Analog_smtr_ram_VCC => Analog_VCC, 
        TR_RAM_RW_A_net => TR_RAM_RW_A_net, 
        TR_RAM_ADDR_B_net_busnet_8 => TR_RAM_ADDR_B_net_busnet_8, 
        TR_RAM_ADDR_B_net_busnet_7 => TR_RAM_ADDR_B_net_busnet_7, 
        TR_RAM_ADDR_B_net_busnet_6 => TR_RAM_ADDR_B_net_busnet_6, 
        TR_RAM_ADDR_B_net_busnet_5 => TR_RAM_ADDR_B_net_busnet_5, 
        TR_RAM_ADDR_B_net_busnet_4 => TR_RAM_ADDR_B_net_busnet_4, 
        TR_RAM_ADDR_B_net_busnet_3 => TR_RAM_ADDR_B_net_busnet_3, 
        TR_RAM_ADDR_B_net_busnet_2 => TR_RAM_ADDR_B_net_busnet_2, 
        TR_RAM_ADDR_B_net_busnet_1 => TR_RAM_ADDR_B_net_busnet_1, 
        TR_RAM_ADDR_B_net_busnet_0 => TR_RAM_ADDR_B_net_busnet_0, 
        Analog_smtr_ram_GND => Analog_GND, 
        TR_RAM_DO_B_net_busnet_8 => TR_RAM_DO_B_net_busnet_8, 
        TR_RAM_DO_B_net_busnet_7 => TR_RAM_DO_B_net_busnet_7, 
        TR_RAM_DO_B_net_busnet_6 => TR_RAM_DO_B_net_busnet_6, 
        TR_RAM_DO_B_net_busnet_5 => TR_RAM_DO_B_net_busnet_5, 
        TR_RAM_DO_B_net_busnet_4 => TR_RAM_DO_B_net_busnet_4, 
        TR_RAM_DO_B_net_busnet_3 => TR_RAM_DO_B_net_busnet_3, 
        TR_RAM_DO_B_net_busnet_2 => TR_RAM_DO_B_net_busnet_2, 
        TR_RAM_DO_B_net_busnet_1 => TR_RAM_DO_B_net_busnet_1, 
        TR_RAM_DO_B_net_busnet_0 => TR_RAM_DO_B_net_busnet_0);
    
    AG1_PAD : OUTBUF_A
      port map(D => AG1_net, PAD => Over_temp);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    ATRETURN01_PAD : INBUF_A
      port map(PAD => ATRETURN01, Y => ATRETURN01_net);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    Analog_smtr_wrapper_inst : Analog_smtr_wrapper
      port map(TR_EV_ADDR_net_busnet_8 => TR_EV_ADDR_net_busnet_8, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        TR_EV_ADDR_net_busnet_6 => TR_EV_ADDR_net_busnet_6, 
        TR_EV_ADDR_net_busnet_5 => TR_EV_ADDR_net_busnet_5, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        TR_EV_ADDR_net_busnet_2 => TR_EV_ADDR_net_busnet_2, 
        TR_EV_ADDR_net_busnet_1 => TR_EV_ADDR_net_busnet_1, 
        TR_EV_ADDR_net_busnet_0 => TR_EV_ADDR_net_busnet_0, 
        TR_TRFLAG_net => TR_TRFLAG_net, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, TR_RAM_ADDR_B_net_busnet_8 => 
        TR_RAM_ADDR_B_net_busnet_8, TR_RAM_DI_B_net_busnet_6 => 
        TR_RAM_DI_B_net_busnet_6, EV_RAM_DO_A_net_busnet_0 => 
        EV_RAM_DO_A_net_busnet_0, EV_DONE_net => EV_DONE_net, 
        xgnmbzmtzbb_0 => xgnmbzmtzbb_0, TR_RAM_DI_B_net_busnet_8
         => TR_RAM_DI_B_net_busnet_8, TR_RAM_ADDR_B_net_busnet_4
         => TR_RAM_ADDR_B_net_busnet_4, TR_RAM_DI_B_net_busnet_5
         => TR_RAM_DI_B_net_busnet_5, EV_CHHOLD_net_busnet_2 => 
        EV_CHHOLD_net_busnet_2, TR_RAM_ADDR_B_net_busnet_3 => 
        TR_RAM_ADDR_B_net_busnet_3, EV_CHHOLD_net_busnet_3 => 
        EV_CHHOLD_net_busnet_3, EV_CHHOLD_net_busnet_4 => 
        EV_CHHOLD_net_busnet_4, TR_RAM_DI_B_net_busnet_1 => 
        TR_RAM_DI_B_net_busnet_1, TR_RAM_DI_B_net_busnet_0 => 
        TR_RAM_DI_B_net_busnet_0, Temp_over70C_net => 
        Temp_over70C_net, TR_RAM_DO_B_net_busnet_5 => 
        TR_RAM_DO_B_net_busnet_5, TR_RAM_DI_B_net_busnet_2 => 
        TR_RAM_DI_B_net_busnet_2, TR_RAM_DI_B_net_busnet_3 => 
        TR_RAM_DI_B_net_busnet_3, TR_RAM_DI_B_net_busnet_4 => 
        TR_RAM_DI_B_net_busnet_4, N_10 => N_10, N_4 => N_4, 
        TR_RAM_RW_A_net => TR_RAM_RW_A_net, 
        TR_RAM_ADDR_B_net_busnet_7 => TR_RAM_ADDR_B_net_busnet_7, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        EV_CHHOLD_net_busnet_0 => EV_CHHOLD_net_busnet_0, 
        TR_RAM_DI_B_net_busnet_7 => TR_RAM_DI_B_net_busnet_7, 
        TR_RAM_ADDR_B_net_busnet_0 => TR_RAM_ADDR_B_net_busnet_0, 
        TR_RAM_ADDR_B_net_busnet_1 => TR_RAM_ADDR_B_net_busnet_1, 
        TR_RAM_ADDR_B_net_busnet_2 => TR_RAM_ADDR_B_net_busnet_2, 
        TR_RAM_DO_B_net_busnet_6 => TR_RAM_DO_B_net_busnet_6, 
        TR_RAM_DO_B_net_busnet_8 => TR_RAM_DO_B_net_busnet_8, 
        TR_RAM_CSN_B_net => TR_RAM_CSN_B_net, 
        TR_RAM_DO_B_net_busnet_3 => TR_RAM_DO_B_net_busnet_3, 
        TR_RAM_DO_B_net_busnet_7 => TR_RAM_DO_B_net_busnet_7, 
        TR_EV_RD_net => TR_EV_RD_net, AV5V_under4p75_net => 
        AV5V_under4p75_net, AV5V_over5p25_net => 
        AV5V_over5p25_net, TR_RAM_DO_B_net_busnet_0 => 
        TR_RAM_DO_B_net_busnet_0, TR_RAM_DO_B_net_busnet_1 => 
        TR_RAM_DO_B_net_busnet_1, TR_RAM_DO_B_net_busnet_2 => 
        TR_RAM_DO_B_net_busnet_2, TR_RAM_ADDR_B_net_busnet_6 => 
        TR_RAM_ADDR_B_net_busnet_6, TR_RAM_ADDR_B_net_busnet_5
         => TR_RAM_ADDR_B_net_busnet_5, TR_RAM_DO_B_net_busnet_4
         => TR_RAM_DO_B_net_busnet_4, INIT_DONE_net => 
        INIT_DONE_net, SYS_RESET_c => SYS_RESET_c, SYS_CLK_int
         => SYS_CLK_int);
    
    Analog_assc_ram_inst : Analog_assc_ram
      port map(INIT_DATA_net(8) => INIT_DATA_net(8), 
        INIT_DATA_net(7) => INIT_DATA_net(7), INIT_DATA_net(6)
         => INIT_DATA_net(6), INIT_DATA_net(5) => 
        INIT_DATA_net(5), INIT_DATA_net(4) => INIT_DATA_net(4), 
        INIT_DATA_net(3) => INIT_DATA_net(3), INIT_DATA_net(2)
         => INIT_DATA_net(2), INIT_DATA_net(1) => 
        INIT_DATA_net(1), INIT_DATA_net(0) => INIT_DATA_net(0), 
        SYS_RESET_c => SYS_RESET_c, ASSC_RAM_DI_B_net_busnet_8
         => ASSC_RAM_DI_B_net_busnet_8, 
        ASSC_RAM_DI_B_net_busnet_7 => ASSC_RAM_DI_B_net_busnet_7, 
        ASSC_RAM_DI_B_net_busnet_6 => ASSC_RAM_DI_B_net_busnet_6, 
        ASSC_RAM_DI_B_net_busnet_5 => ASSC_RAM_DI_B_net_busnet_5, 
        ASSC_RAM_DI_B_net_busnet_4 => ASSC_RAM_DI_B_net_busnet_4, 
        ASSC_RAM_DI_B_net_busnet_3 => ASSC_RAM_DI_B_net_busnet_3, 
        ASSC_RAM_DI_B_net_busnet_2 => ASSC_RAM_DI_B_net_busnet_2, 
        ASSC_RAM_DI_B_net_busnet_1 => ASSC_RAM_DI_B_net_busnet_1, 
        ASSC_RAM_DI_B_net_busnet_0 => ASSC_RAM_DI_B_net_busnet_0, 
        SYS_CLK_int => SYS_CLK_int, ASSC_RAM_WR_BUSY_B_net => 
        ASSC_RAM_WR_BUSY_B_net, N_250_i_0 => N_250_i_0, 
        Analog_assc_ram_VCC => Analog_VCC, ASSC_RAM_RW_A_net => 
        ASSC_RAM_RW_A_net, ASSC_RAM_CSN_A_net => 
        ASSC_RAM_CSN_A_net, ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, 
        ASSC_RAM_ADDR_B_net_busnet_2 => 
        ASSC_RAM_ADDR_B_net_busnet_2, 
        ASSC_RAM_ADDR_B_net_busnet_1 => 
        ASSC_RAM_ADDR_B_net_busnet_1, 
        ASSC_RAM_ADDR_B_net_busnet_0 => 
        ASSC_RAM_ADDR_B_net_busnet_0, Analog_assc_ram_GND => 
        Analog_GND, ASSC_RAM_ADDR_A_net_busnet_8 => 
        ASSC_RAM_ADDR_A_net_busnet_8, 
        ASSC_RAM_ADDR_A_net_busnet_7 => 
        ASSC_RAM_ADDR_A_net_busnet_7, 
        ASSC_RAM_ADDR_A_net_busnet_6 => 
        ASSC_RAM_ADDR_A_net_busnet_6, 
        ASSC_RAM_ADDR_A_net_busnet_5 => 
        ASSC_RAM_ADDR_A_net_busnet_5, 
        ASSC_RAM_ADDR_A_net_busnet_4 => 
        ASSC_RAM_ADDR_A_net_busnet_4, 
        ASSC_RAM_ADDR_A_net_busnet_3 => 
        ASSC_RAM_ADDR_A_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_2 => 
        ASSC_RAM_ADDR_A_net_busnet_2, 
        ASSC_RAM_ADDR_A_net_busnet_1 => 
        ASSC_RAM_ADDR_A_net_busnet_1, 
        ASSC_RAM_ADDR_A_net_busnet_0 => 
        ASSC_RAM_ADDR_A_net_busnet_0, ASSC_RAM_DO_B_net_busnet_8
         => ASSC_RAM_DO_B_net_busnet_8, 
        ASSC_RAM_DO_B_net_busnet_7 => ASSC_RAM_DO_B_net_busnet_7, 
        ASSC_RAM_DO_B_net_busnet_6 => ASSC_RAM_DO_B_net_busnet_6, 
        ASSC_RAM_DO_B_net_busnet_5 => ASSC_RAM_DO_B_net_busnet_5, 
        ASSC_RAM_DO_B_net_busnet_4 => ASSC_RAM_DO_B_net_busnet_4, 
        ASSC_RAM_DO_B_net_busnet_3 => ASSC_RAM_DO_B_net_busnet_3, 
        ASSC_RAM_DO_B_net_busnet_2 => ASSC_RAM_DO_B_net_busnet_2, 
        ASSC_RAM_DO_B_net_busnet_1 => ASSC_RAM_DO_B_net_busnet_1, 
        ASSC_RAM_DO_B_net_busnet_0 => ASSC_RAM_DO_B_net_busnet_0, 
        ASSC_RAM_DO_A_net_busnet_8 => ASSC_RAM_DO_A_net_busnet_8, 
        ASSC_RAM_DO_A_net_busnet_7 => ASSC_RAM_DO_A_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_6 => ASSC_RAM_DO_A_net_busnet_6, 
        ASSC_RAM_DO_A_net_busnet_5 => ASSC_RAM_DO_A_net_busnet_5, 
        ASSC_RAM_DO_A_net_busnet_4 => ASSC_RAM_DO_A_net_busnet_4, 
        ASSC_RAM_DO_A_net_busnet_3 => ASSC_RAM_DO_A_net_busnet_3, 
        ASSC_RAM_DO_A_net_busnet_2 => ASSC_RAM_DO_A_net_busnet_2, 
        ASSC_RAM_DO_A_net_busnet_1 => ASSC_RAM_DO_A_net_busnet_1, 
        ASSC_RAM_DO_A_net_busnet_0 => ASSC_RAM_DO_A_net_busnet_0);
    
    AB_INST : AB
      port map(DAVOUT0 => AB_INST_DAVOUT0, DACOUT0 => 
        AB_INST_DACOUT0, DATOUT0 => AB_INST_DATOUT0, DAVOUT1 => 
        AB_INST_DAVOUT1, DACOUT1 => AB_INST_DACOUT1, DATOUT1 => 
        AB_INST_DATOUT1, DAVOUT2 => AB_INST_DAVOUT2, DACOUT2 => 
        AB_INST_DACOUT2, DATOUT2 => AB_INST_DATOUT2, DAVOUT3 => 
        AB_INST_DAVOUT3, DACOUT3 => AB_INST_DACOUT3, DATOUT3 => 
        AB_INST_DATOUT3, DAVOUT4 => AB_INST_DAVOUT4, DACOUT4 => 
        AB_INST_DACOUT4, DATOUT4 => AB_INST_DATOUT4, DAVOUT5 => 
        AB_INST_DAVOUT5, DACOUT5 => AB_INST_DACOUT5, DATOUT5 => 
        AB_INST_DATOUT5, DAVOUT6 => AB_INST_DAVOUT6, DACOUT6 => 
        AB_INST_DACOUT6, DATOUT6 => AB_INST_DATOUT6, DAVOUT7 => 
        AB_INST_DAVOUT7, DACOUT7 => AB_INST_DACOUT7, DATOUT7 => 
        AB_INST_DATOUT7, DAVOUT8 => AB_INST_DAVOUT8, DACOUT8 => 
        AB_INST_DACOUT8, DATOUT8 => AB_INST_DATOUT8, DAVOUT9 => 
        AB_INST_DAVOUT9, DACOUT9 => AB_INST_DACOUT9, DATOUT9 => 
        AB_INST_DATOUT9, DENAV0 => Analog_GND, DENAC0 => 
        Analog_GND, DENAT0 => Analog_GND, DENAV1 => Analog_GND, 
        DENAC1 => Analog_GND, DENAT1 => Analog_GND, DENAV2 => 
        Analog_GND, DENAC2 => Analog_GND, DENAT2 => Analog_GND, 
        DENAV3 => Analog_GND, DENAC3 => Analog_GND, DENAT3 => 
        Analog_GND, DENAV4 => Analog_GND, DENAC4 => Analog_GND, 
        DENAT4 => Analog_GND, DENAV5 => Analog_GND, DENAC5 => 
        Analog_GND, DENAT5 => Analog_GND, DENAV6 => Analog_GND, 
        DENAC6 => Analog_GND, DENAT6 => Analog_GND, DENAV7 => 
        Analog_GND, DENAC7 => Analog_GND, DENAT7 => Analog_GND, 
        DENAV8 => Analog_GND, DENAC8 => Analog_GND, DENAT8 => 
        Analog_GND, DENAV9 => Analog_GND, DENAC9 => Analog_GND, 
        DENAT9 => Analog_GND, AV0 => AV0_net, AC0 => Analog_GND, 
        AT0 => AT0_net, AG0 => AG0_net, AV1 => Analog_GND, AC1
         => Analog_GND, AT1 => Analog_GND, AG1 => AG1_net, AV2
         => Analog_GND, AC2 => Analog_GND, AT2 => Analog_GND, AG2
         => AB_INST_AG2, AV3 => Analog_GND, AC3 => Analog_GND, 
        AT3 => Analog_GND, AG3 => AB_INST_AG3, AV4 => Analog_GND, 
        AC4 => Analog_GND, AT4 => Analog_GND, AG4 => AB_INST_AG4, 
        AV5 => Analog_GND, AC5 => Analog_GND, AT5 => Analog_GND, 
        AG5 => AB_INST_AG5, AV6 => Analog_GND, AC6 => Analog_GND, 
        AT6 => Analog_GND, AG6 => AB_INST_AG6, AV7 => Analog_GND, 
        AC7 => Analog_GND, AT7 => Analog_GND, AG7 => AB_INST_AG7, 
        AV8 => Analog_GND, AC8 => Analog_GND, AT8 => Analog_GND, 
        AG8 => AB_INST_AG8, AV9 => Analog_GND, AC9 => Analog_GND, 
        AT9 => Analog_GND, AG9 => AB_INST_AG9, ATRETURN01 => 
        ATRETURN01_net, ATRETURN23 => Analog_GND, ATRETURN45 => 
        Analog_GND, ATRETURN67 => Analog_GND, ATRETURN89 => 
        Analog_GND, VAREF => VAREF, GNDREF => Analog_GND, GDON0
         => Supply_good_en_net, GDON1 => Temp_over70C_net, GDON2
         => Analog_GND, GDON3 => Analog_GND, GDON4 => Analog_GND, 
        GDON5 => Analog_GND, GDON6 => Analog_GND, GDON7 => 
        Analog_GND, GDON8 => Analog_GND, GDON9 => Analog_GND, 
        CMSTB0 => Analog_GND, CMSTB1 => Analog_GND, CMSTB2 => 
        Analog_GND, CMSTB3 => Analog_GND, CMSTB4 => Analog_GND, 
        CMSTB5 => Analog_GND, CMSTB6 => Analog_GND, CMSTB7 => 
        Analog_GND, CMSTB8 => Analog_GND, CMSTB9 => Analog_GND, 
        TMSTB0 => TM_STB_net_0, TMSTB1 => Analog_GND, TMSTB2 => 
        Analog_GND, TMSTB3 => Analog_GND, TMSTB4 => Analog_GND, 
        TMSTB5 => Analog_GND, TMSTB6 => Analog_GND, TMSTB7 => 
        Analog_GND, TMSTB8 => Analog_GND, TMSTB9 => Analog_GND, 
        TMSTBINT => Analog_GND, RESULT(11) => 
        ADC_RESULT_net_busnet_11, RESULT(10) => 
        ADC_RESULT_net_busnet_10, RESULT(9) => 
        ADC_RESULT_net_busnet_9, RESULT(8) => 
        ADC_RESULT_net_busnet_8, RESULT(7) => 
        ADC_RESULT_net_busnet_7, RESULT(6) => 
        ADC_RESULT_net_busnet_6, RESULT(5) => 
        ADC_RESULT_net_busnet_5, RESULT(4) => 
        ADC_RESULT_net_busnet_4, RESULT(3) => 
        ADC_RESULT_net_busnet_3, RESULT(2) => 
        ADC_RESULT_net_busnet_2, RESULT(1) => 
        ADC_RESULT_net_busnet_1, RESULT(0) => 
        ADC_RESULT_net_busnet_0, ACMRDATA(7) => 
        \AB_INST_ACMRDATA[7]\, ACMRDATA(6) => 
        \AB_INST_ACMRDATA[6]\, ACMRDATA(5) => 
        \AB_INST_ACMRDATA[5]\, ACMRDATA(4) => 
        \AB_INST_ACMRDATA[4]\, ACMRDATA(3) => 
        \AB_INST_ACMRDATA[3]\, ACMRDATA(2) => 
        \AB_INST_ACMRDATA[2]\, ACMRDATA(1) => 
        \AB_INST_ACMRDATA[1]\, ACMRDATA(0) => 
        \AB_INST_ACMRDATA[0]\, ACMWDATA(7) => INIT_DATA_net(7), 
        ACMWDATA(6) => INIT_DATA_net(6), ACMWDATA(5) => 
        INIT_DATA_net(5), ACMWDATA(4) => INIT_DATA_net(4), 
        ACMWDATA(3) => INIT_DATA_net(3), ACMWDATA(2) => 
        INIT_DATA_net(2), ACMWDATA(1) => INIT_DATA_net(1), 
        ACMWDATA(0) => INIT_DATA_net(0), ACMADDR(7) => 
        INIT_ADDR_net(7), ACMADDR(6) => INIT_ADDR_net(6), 
        ACMADDR(5) => INIT_ADDR_net(5), ACMADDR(4) => 
        INIT_ADDR_net(4), ACMADDR(3) => INIT_ADDR_net(3), 
        ACMADDR(2) => INIT_ADDR_net(2), ACMADDR(1) => 
        INIT_ADDR_net(1), ACMADDR(0) => INIT_ADDR_net(0), STC(7)
         => ADC_STC_net_busnet_7, STC(6) => ADC_STC_net_busnet_6, 
        STC(5) => ADC_STC_net_busnet_5, STC(4) => 
        ADC_STC_net_busnet_4, STC(3) => ADC_STC_net_busnet_3, 
        STC(2) => ADC_STC_net_busnet_2, STC(1) => 
        ADC_STC_net_busnet_1, STC(0) => ADC_STC_net_busnet_0, 
        TVC(7) => ADC_TVC_net_busnet_7, TVC(6) => 
        ADC_TVC_net_busnet_6, TVC(5) => ADC_TVC_net_busnet_5, 
        TVC(4) => ADC_TVC_net_busnet_4, TVC(3) => 
        ADC_TVC_net_busnet_3, TVC(2) => ADC_TVC_net_busnet_2, 
        TVC(1) => ADC_TVC_net_busnet_1, TVC(0) => 
        ADC_TVC_net_busnet_0, CHNUMBER(4) => \dspfgfmqhwh[4]\, 
        CHNUMBER(3) => \dspfgfmqhwh[3]\, CHNUMBER(2) => 
        \dspfgfmqhwh[2]\, CHNUMBER(1) => \dspfgfmqhwh[1]\, 
        CHNUMBER(0) => \dspfgfmqhwh[0]\, MODE(3) => 
        ADC_MODE_net_busnet_3, MODE(2) => ADC_MODE_net_busnet_2, 
        MODE(1) => ADC_MODE_net_busnet_1, MODE(0) => 
        ADC_MODE_net_busnet_0, RTCXTLMODE(1) => 
        \AB_INST_RTCXTLMODE[1]\, RTCXTLMODE(0) => 
        \AB_INST_RTCXTLMODE[0]\, ACMRESET => SYS_RESET_c, ACMCLK
         => CLK10M, ACMWEN => INIT_ACM_WEN_OR_net, VAREFSEL => 
        Analog_GND, DATAVALID => AB_INST_DATAVALID, CALIBRATE => 
        ADC_CALIBRATE_net, SAMPLE => AB_INST_SAMPLE, BUSY => 
        ADC_BUSY_net, PWRDWN => ADC_PDOWN_net, SYSCLK => 
        SYS_CLK_int, ADCRESET => ADC_RESET_net, ADCSTART => 
        ADC_START_net, RTCMATCH => AB_INST_RTCMATCH, RTCPSMMATCH
         => AB_INST_RTCPSMMATCH, RTCXTLSEL => AB_INST_RTCXTLSEL, 
        RTCCLK => Analog_GND);
    
    GND_i : GND
      port map(Y => \GND\);
    
    AG0_PAD : OUTBUF_A
      port map(D => AG0_net, PAD => Supply_good);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    INIT_ACMWEN_OR : OR2
      port map(A => INIT_ACM_WEN_net, B => Analog_GND, Y => 
        INIT_ACM_WEN_OR_net);
    
    AT0_PAD : INBUF_A
      port map(PAD => Temp, Y => AT0_net);
    
    Analog_assc_wrapper_inst : Analog_assc_wrapper
      port map(INIT_ADDR_net(8) => INIT_ADDR_net(8), 
        INIT_ADDR_net(7) => INIT_ADDR_net(7), INIT_ADDR_net(6)
         => INIT_ADDR_net(6), INIT_ADDR_net(5) => 
        INIT_ADDR_net(5), INIT_ADDR_net(4) => INIT_ADDR_net(4), 
        INIT_ADDR_net(3) => INIT_ADDR_net(3), INIT_ADDR_net(2)
         => INIT_ADDR_net(2), INIT_ADDR_net(1) => 
        INIT_ADDR_net(1), INIT_ADDR_net(0) => INIT_ADDR_net(0), 
        dspfgfmqhwh(4) => \dspfgfmqhwh[4]\, dspfgfmqhwh(3) => 
        \dspfgfmqhwh[3]\, dspfgfmqhwh(2) => \dspfgfmqhwh[2]\, 
        dspfgfmqhwh(1) => \dspfgfmqhwh[1]\, dspfgfmqhwh(0) => 
        \dspfgfmqhwh[0]\, ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, ADC_MODE_net_busnet_3 => 
        ADC_MODE_net_busnet_3, ADC_MODE_net_busnet_2 => 
        ADC_MODE_net_busnet_2, ADC_MODE_net_busnet_1 => 
        ADC_MODE_net_busnet_1, ADC_MODE_net_busnet_0 => 
        ADC_MODE_net_busnet_0, ADC_TVC_net_busnet_7 => 
        ADC_TVC_net_busnet_7, ADC_TVC_net_busnet_6 => 
        ADC_TVC_net_busnet_6, ADC_TVC_net_busnet_5 => 
        ADC_TVC_net_busnet_5, ADC_TVC_net_busnet_4 => 
        ADC_TVC_net_busnet_4, ADC_TVC_net_busnet_3 => 
        ADC_TVC_net_busnet_3, ADC_TVC_net_busnet_2 => 
        ADC_TVC_net_busnet_2, ADC_TVC_net_busnet_1 => 
        ADC_TVC_net_busnet_1, ADC_TVC_net_busnet_0 => 
        ADC_TVC_net_busnet_0, ADC_STC_net_busnet_7 => 
        ADC_STC_net_busnet_7, ADC_STC_net_busnet_6 => 
        ADC_STC_net_busnet_6, ADC_STC_net_busnet_5 => 
        ADC_STC_net_busnet_5, ADC_STC_net_busnet_4 => 
        ADC_STC_net_busnet_4, ADC_STC_net_busnet_3 => 
        ADC_STC_net_busnet_3, ADC_STC_net_busnet_2 => 
        ADC_STC_net_busnet_2, ADC_STC_net_busnet_1 => 
        ADC_STC_net_busnet_1, ADC_STC_net_busnet_0 => 
        ADC_STC_net_busnet_0, bcmkdjqtngz => bcmkdjqtngz, 
        TM_STB_net_0 => TM_STB_net_0, ADC_PDOWN_net => 
        ADC_PDOWN_net, ADC_RESET_net => ADC_RESET_net, 
        ADC_CALIBRATE_net => ADC_CALIBRATE_net, 
        ASSC_RAM_DO_B_net_busnet_5 => ASSC_RAM_DO_B_net_busnet_5, 
        ASSC_RAM_DO_B_net_busnet_4 => ASSC_RAM_DO_B_net_busnet_4, 
        ASSC_RAM_DO_B_net_busnet_0 => ASSC_RAM_DO_B_net_busnet_0, 
        ADC_START_net => ADC_START_net, 
        ASSC_RAM_ADDR_B_net_busnet_0 => 
        ASSC_RAM_ADDR_B_net_busnet_0, ASSC_RAM_DO_B_net_busnet_3
         => ASSC_RAM_DO_B_net_busnet_3, 
        ASSC_RAM_DO_B_net_busnet_2 => ASSC_RAM_DO_B_net_busnet_2, 
        EV_ASSCADDR_net_busnet_8 => EV_ASSCADDR_net_busnet_8, 
        ASSC_RAM_ADDR_A_net_busnet_8 => 
        ASSC_RAM_ADDR_A_net_busnet_8, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_A_net_busnet_7 => 
        ASSC_RAM_ADDR_A_net_busnet_7, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_A_net_busnet_6 => 
        ASSC_RAM_ADDR_A_net_busnet_6, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_A_net_busnet_5 => 
        ASSC_RAM_ADDR_A_net_busnet_5, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_A_net_busnet_4 => 
        ASSC_RAM_ADDR_A_net_busnet_4, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_3 => 
        ASSC_RAM_ADDR_A_net_busnet_3, 
        ASSC_RAM_ADDR_A_net_busnet_2 => 
        ASSC_RAM_ADDR_A_net_busnet_2, 
        ASSC_RAM_ADDR_A_net_busnet_1 => 
        ASSC_RAM_ADDR_A_net_busnet_1, 
        ASSC_RAM_ADDR_A_net_busnet_0 => 
        ASSC_RAM_ADDR_A_net_busnet_0, ASSC_RAM_DO_B_net_busnet_1
         => ASSC_RAM_DO_B_net_busnet_1, ASSC_RAM_RW_A_net => 
        ASSC_RAM_RW_A_net, un1_Analog_inst_1 => un1_Analog_inst_1, 
        ADC_RESULT_net_busnet_8 => ADC_RESULT_net_busnet_8, 
        ASSC_RAM_DI_B_net_busnet_8 => ASSC_RAM_DI_B_net_busnet_8, 
        ADC_RESULT_net_busnet_7 => ADC_RESULT_net_busnet_7, 
        ASSC_RAM_DI_B_net_busnet_7 => ASSC_RAM_DI_B_net_busnet_7, 
        ADC_RESULT_net_busnet_6 => ADC_RESULT_net_busnet_6, 
        ASSC_RAM_DI_B_net_busnet_6 => ASSC_RAM_DI_B_net_busnet_6, 
        ADC_RESULT_net_busnet_5 => ADC_RESULT_net_busnet_5, 
        ASSC_RAM_DI_B_net_busnet_5 => ASSC_RAM_DI_B_net_busnet_5, 
        ADC_RESULT_net_busnet_4 => ADC_RESULT_net_busnet_4, 
        ASSC_RAM_DI_B_net_busnet_4 => ASSC_RAM_DI_B_net_busnet_4, 
        ADC_RESULT_net_busnet_3 => ADC_RESULT_net_busnet_3, 
        ASSC_RAM_DI_B_net_busnet_3 => ASSC_RAM_DI_B_net_busnet_3, 
        INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, 
        ASSC_RAM_CSN_A_net => ASSC_RAM_CSN_A_net, 
        ADC_RESULT_net_busnet_11 => ADC_RESULT_net_busnet_11, 
        ADC_RESULT_net_busnet_2 => ADC_RESULT_net_busnet_2, 
        ASSC_RAM_DI_B_net_busnet_2 => ASSC_RAM_DI_B_net_busnet_2, 
        ADC_RESULT_net_busnet_10 => ADC_RESULT_net_busnet_10, 
        ADC_RESULT_net_busnet_1 => ADC_RESULT_net_busnet_1, 
        ASSC_RAM_DI_B_net_busnet_1 => ASSC_RAM_DI_B_net_busnet_1, 
        ADC_RESULT_net_busnet_9 => ADC_RESULT_net_busnet_9, 
        ADC_RESULT_net_busnet_0 => ADC_RESULT_net_busnet_0, 
        ASSC_RAM_DI_B_net_busnet_0 => ASSC_RAM_DI_B_net_busnet_0, 
        qvkpfznsfjx => qvkpfznsfjx, ADC_BUSY_net => ADC_BUSY_net, 
        ASSC_RAM_ADDR_B_net_busnet_1 => 
        ASSC_RAM_ADDR_B_net_busnet_1, 
        ASSC_RAM_ADDR_B_net_busnet_2 => 
        ASSC_RAM_ADDR_B_net_busnet_2, N_250_i_0 => N_250_i_0, 
        fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, EV_DONE_net
         => EV_DONE_net, EV_EVFLAG_net => EV_EVFLAG_net, 
        TR_TRFLAG_net => TR_TRFLAG_net, TR_DONE_net_i_0 => 
        TR_DONE_net_i_0, ASSC_RAM_WR_BUSY_B_net => 
        ASSC_RAM_WR_BUSY_B_net, EV_ASSCADDR_net_busnet_2 => 
        EV_ASSCADDR_net_busnet_2, INIT_DONE_net => INIT_DONE_net, 
        ASSC_RAM_DO_B_net_busnet_8 => ASSC_RAM_DO_B_net_busnet_8, 
        ASSC_RAM_DO_B_net_busnet_7 => ASSC_RAM_DO_B_net_busnet_7, 
        ASSC_RAM_DO_B_net_busnet_6 => ASSC_RAM_DO_B_net_busnet_6, 
        SYS_RESET_c => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int);
    
    AV0_PAD : INBUF_A
      port map(PAD => AV5V, Y => AV0_net);
    
    Analog_smev_wrapper_inst : Analog_smev_wrapper
      port map(dspfgfmqhwh(4) => \dspfgfmqhwh[4]\, dspfgfmqhwh(3)
         => \dspfgfmqhwh[3]\, dspfgfmqhwh(2) => \dspfgfmqhwh[2]\, 
        dspfgfmqhwh(1) => \dspfgfmqhwh[1]\, dspfgfmqhwh(0) => 
        \dspfgfmqhwh[0]\, rdgwgtpkbgc_0(3) => rdgwgtpkbgc(3), 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), rdgwgtpkbgc(3) => 
        rdgwgtpkbgc_0(3), ASSC_RAM_ADDR_B_net_busnet_8 => 
        ASSC_RAM_ADDR_B_net_busnet_8, EV_ASSCADDR_net_busnet_8
         => EV_ASSCADDR_net_busnet_8, 
        ASSC_RAM_ADDR_B_net_busnet_7 => 
        ASSC_RAM_ADDR_B_net_busnet_7, EV_ASSCADDR_net_busnet_7
         => EV_ASSCADDR_net_busnet_7, 
        ASSC_RAM_ADDR_B_net_busnet_6 => 
        ASSC_RAM_ADDR_B_net_busnet_6, EV_ASSCADDR_net_busnet_6
         => EV_ASSCADDR_net_busnet_6, 
        ASSC_RAM_ADDR_B_net_busnet_5 => 
        ASSC_RAM_ADDR_B_net_busnet_5, EV_ASSCADDR_net_busnet_5
         => EV_ASSCADDR_net_busnet_5, 
        ASSC_RAM_ADDR_B_net_busnet_4 => 
        ASSC_RAM_ADDR_B_net_busnet_4, EV_ASSCADDR_net_busnet_4
         => EV_ASSCADDR_net_busnet_4, 
        ASSC_RAM_ADDR_B_net_busnet_3 => 
        ASSC_RAM_ADDR_B_net_busnet_3, EV_ASSCADDR_net_busnet_3
         => EV_ASSCADDR_net_busnet_3, EV_EVFLAG_net => 
        EV_EVFLAG_net, EV_DONE_net => EV_DONE_net, 
        TR_EV_ADDR_net_busnet_0 => TR_EV_ADDR_net_busnet_0, 
        EV_RAM_ADDR_A_net_busnet_0 => EV_RAM_ADDR_A_net_busnet_0, 
        TR_EV_ADDR_net_busnet_6 => TR_EV_ADDR_net_busnet_6, 
        EV_RAM_ADDR_A_net_busnet_6 => EV_RAM_ADDR_A_net_busnet_6, 
        TR_EV_ADDR_net_busnet_1 => TR_EV_ADDR_net_busnet_1, 
        EV_RAM_ADDR_A_net_busnet_1 => EV_RAM_ADDR_A_net_busnet_1, 
        TR_EV_ADDR_net_busnet_2 => TR_EV_ADDR_net_busnet_2, 
        EV_RAM_ADDR_A_net_busnet_2 => EV_RAM_ADDR_A_net_busnet_2, 
        TR_EV_ADDR_net_busnet_5 => TR_EV_ADDR_net_busnet_5, 
        EV_RAM_ADDR_A_net_busnet_5 => EV_RAM_ADDR_A_net_busnet_5, 
        TR_EV_ADDR_net_busnet_8 => TR_EV_ADDR_net_busnet_8, 
        EV_RAM_ADDR_A_net_busnet_8 => EV_RAM_ADDR_A_net_busnet_8, 
        TR_EV_RD_net => TR_EV_RD_net, EV_RAM_CSN_A_net => 
        EV_RAM_CSN_A_net, INIT_EV_WEN_net => INIT_EV_WEN_net, 
        EV_RAM_RW_A_net => EV_RAM_RW_A_net, 
        ASSC_RAM_DO_A_net_busnet_8 => ASSC_RAM_DO_A_net_busnet_8, 
        ASSC_RAM_DO_A_net_busnet_7 => ASSC_RAM_DO_A_net_busnet_7, 
        ASSC_RAM_DO_A_net_busnet_6 => ASSC_RAM_DO_A_net_busnet_6, 
        ASSC_RAM_DO_A_net_busnet_5 => ASSC_RAM_DO_A_net_busnet_5, 
        ASSC_RAM_DO_A_net_busnet_4 => ASSC_RAM_DO_A_net_busnet_4, 
        ASSC_RAM_DO_A_net_busnet_3 => ASSC_RAM_DO_A_net_busnet_3, 
        TR_EV_ADDR_net_busnet_7 => TR_EV_ADDR_net_busnet_7, 
        EV_RAM_ADDR_A_net_busnet_7 => EV_RAM_ADDR_A_net_busnet_7, 
        TR_EV_ADDR_net_busnet_4 => TR_EV_ADDR_net_busnet_4, 
        EV_RAM_ADDR_A_net_busnet_4 => EV_RAM_ADDR_A_net_busnet_4, 
        TR_EV_ADDR_net_busnet_3 => TR_EV_ADDR_net_busnet_3, 
        EV_RAM_ADDR_A_net_busnet_3 => EV_RAM_ADDR_A_net_busnet_3, 
        EV_CHHOLD_net_busnet_3 => EV_CHHOLD_net_busnet_3, 
        un1_Analog_inst_1 => un1_Analog_inst_1, bcmkdjqtngz => 
        bcmkdjqtngz, qvkpfznsfjx => qvkpfznsfjx, 
        EV_RAM_DO_B_net_busnet_7 => EV_RAM_DO_B_net_busnet_7, 
        EV_RAM_DO_B_net_busnet_5 => EV_RAM_DO_B_net_busnet_5, 
        EV_RAM_DO_B_net_busnet_4 => EV_RAM_DO_B_net_busnet_4, 
        EV_RAM_WR_BUSY_B_net => EV_RAM_WR_BUSY_B_net, 
        ASSC_RAM_DO_A_net_busnet_2 => ASSC_RAM_DO_A_net_busnet_2, 
        ASSC_RAM_DO_A_net_busnet_1 => ASSC_RAM_DO_A_net_busnet_1, 
        ASSC_RAM_DO_A_net_busnet_0 => ASSC_RAM_DO_A_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_8 => EV_RAM_ADDR_B_net_busnet_8, 
        EV_RAM_ADDR_B_net_busnet_7 => EV_RAM_ADDR_B_net_busnet_7, 
        EV_RAM_ADDR_B_net_busnet_0 => EV_RAM_ADDR_B_net_busnet_0, 
        EV_RAM_ADDR_B_net_busnet_1 => EV_RAM_ADDR_B_net_busnet_1, 
        EV_RAM_ADDR_B_net_busnet_2 => EV_RAM_ADDR_B_net_busnet_2, 
        EV_RAM_ADDR_B_net_busnet_3 => EV_RAM_ADDR_B_net_busnet_3, 
        EV_RAM_ADDR_B_net_busnet_4 => EV_RAM_ADDR_B_net_busnet_4, 
        EV_RAM_DI_B_net_busnet_8 => EV_RAM_DI_B_net_busnet_8, 
        EV_RAM_DI_B_net_busnet_7 => EV_RAM_DI_B_net_busnet_7, 
        EV_RAM_DI_B_net_busnet_6 => EV_RAM_DI_B_net_busnet_6, 
        EV_RAM_DI_B_net_busnet_5 => EV_RAM_DI_B_net_busnet_5, 
        EV_RAM_DI_B_net_busnet_4 => EV_RAM_DI_B_net_busnet_4, 
        EV_RAM_DI_B_net_busnet_3 => EV_RAM_DI_B_net_busnet_3, 
        EV_RAM_DI_B_net_busnet_2 => EV_RAM_DI_B_net_busnet_2, 
        EV_RAM_DI_B_net_busnet_0 => EV_RAM_DI_B_net_busnet_0, 
        EV_RAM_CSN_B_net => EV_RAM_CSN_B_net, 
        EV_ASSCADDR_net_busnet_2 => EV_ASSCADDR_net_busnet_2, 
        INIT_DONE_net => INIT_DONE_net, EV_CHHOLD_net_busnet_0
         => EV_CHHOLD_net_busnet_0, EV_RAM_ADDR_B_net_busnet_6
         => EV_RAM_ADDR_B_net_busnet_6, 
        EV_RAM_ADDR_B_net_busnet_5 => EV_RAM_ADDR_B_net_busnet_5, 
        EV_CHHOLD_net_busnet_1 => EV_CHHOLD_net_busnet_1, 
        EV_CHHOLD_net_busnet_4 => EV_CHHOLD_net_busnet_4, 
        EV_CHHOLD_net_busnet_2 => EV_CHHOLD_net_busnet_2, 
        EV_RAM_DO_B_net_busnet_3 => EV_RAM_DO_B_net_busnet_3, 
        EV_RAM_DO_B_net_busnet_6 => EV_RAM_DO_B_net_busnet_6, 
        EV_RAM_DO_B_net_busnet_8 => EV_RAM_DO_B_net_busnet_8, 
        fskhwddcbbg_1_sqmuxa => fskhwddcbbg_1_sqmuxa, 
        EV_RAM_DO_B_net_busnet_2 => EV_RAM_DO_B_net_busnet_2, 
        EV_RAM_DO_B_net_busnet_1 => EV_RAM_DO_B_net_busnet_1, 
        EV_RAM_DO_B_net_busnet_0 => EV_RAM_DO_B_net_busnet_0, 
        SYS_RESET_c => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, 
        EV_RAM_DO_B_net_busnet_7_0 => EV_RAM_DO_B_net_busnet_7_0, 
        EV_RAM_DI_B_net_busnet_1 => EV_RAM_DI_B_net_busnet_1);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity jhmkpjjmdkx is

    port( qpkbfhrprrz     : out   std_logic;
          hrgmtcpsdzr     : out   std_logic;
          qdvwjxmzbpf     : in    std_logic;
          bfcqzvtnrcn     : out   std_logic;
          INIT_DONE_net   : in    std_logic;
          INIT_DONE_net_i : out   std_logic;
          INIT_POWER_UP_c : in    std_logic;
          SYS_RESET_c     : in    std_logic;
          SYS_CLK_int     : in    std_logic;
          bfcqzvtnrcn_0   : out   std_logic
        );

end jhmkpjjmdkx;

architecture DEF_ARCH of jhmkpjjmdkx is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component INV
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal \crmctgwbctb\, \qpkbfhrprrz\, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

begin 

    qpkbfhrprrz <= \qpkbfhrprrz\;
    \qpkbfhrprrz\ <= SYS_CLK_int;

    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    crmctgwbctb : DFN1C0
      port map(D => qdvwjxmzbpf, CLK => \qpkbfhrprrz\, CLR => 
        SYS_RESET_c, Q => \crmctgwbctb\);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    \hrgmtcpsdzr\ : DFN1C0
      port map(D => \crmctgwbctb\, CLK => \qpkbfhrprrz\, CLR => 
        SYS_RESET_c, Q => hrgmtcpsdzr);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    qqqjcnjzntg_0 : DFN1C0
      port map(D => INIT_POWER_UP_c, CLK => \qpkbfhrprrz\, CLR
         => SYS_RESET_c, Q => bfcqzvtnrcn_0);
    
    qqqjcnjzntg : DFN1C0
      port map(D => INIT_POWER_UP_c, CLK => \qpkbfhrprrz\, CLR
         => SYS_RESET_c, Q => bfcqzvtnrcn);
    
    \INIT_DONE_net_i\ : INV
      port map(A => INIT_DONE_net, Y => INIT_DONE_net_i);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XF is

    port( bfcqzvtnrcn_0   : out   std_logic;
          SYS_CLK_int     : in    std_logic;
          SYS_RESET_c     : in    std_logic;
          INIT_POWER_UP_c : in    std_logic;
          INIT_DONE_net_i : out   std_logic;
          INIT_DONE_net   : in    std_logic;
          bfcqzvtnrcn     : out   std_logic;
          qdvwjxmzbpf     : in    std_logic;
          hrgmtcpsdzr     : out   std_logic;
          qpkbfhrprrz     : out   std_logic
        );

end INITCFG_XF;

architecture DEF_ARCH of INITCFG_XF is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component jhmkpjjmdkx
    port( qpkbfhrprrz     : out   std_logic;
          hrgmtcpsdzr     : out   std_logic;
          qdvwjxmzbpf     : in    std_logic := 'U';
          bfcqzvtnrcn     : out   std_logic;
          INIT_DONE_net   : in    std_logic := 'U';
          INIT_DONE_net_i : out   std_logic;
          INIT_POWER_UP_c : in    std_logic := 'U';
          SYS_RESET_c     : in    std_logic := 'U';
          SYS_CLK_int     : in    std_logic := 'U';
          bfcqzvtnrcn_0   : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : jhmkpjjmdkx
	Use entity work.jhmkpjjmdkx(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_jhmkpjjmdkx : jhmkpjjmdkx
      port map(qpkbfhrprrz => qpkbfhrprrz, hrgmtcpsdzr => 
        hrgmtcpsdzr, qdvwjxmzbpf => qdvwjxmzbpf, bfcqzvtnrcn => 
        bfcqzvtnrcn, INIT_DONE_net => INIT_DONE_net, 
        INIT_DONE_net_i => INIT_DONE_net_i, INIT_POWER_UP_c => 
        INIT_POWER_UP_c, SYS_RESET_c => SYS_RESET_c, SYS_CLK_int
         => SYS_CLK_int, bfcqzvtnrcn_0 => bfcqzvtnrcn_0);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity stnpfdkggvx is

    port( mwtvnzdkmwm_5 : out   std_logic;
          mwtvnzdkmwm_3 : out   std_logic;
          mwtvnzdkmwm_4 : out   std_logic;
          gpbbjwsprsj   : out   std_logic_vector(1 downto 0);
          SYS_RESET_c   : in    std_logic;
          SYS_CLK_int   : in    std_logic;
          bfcqzvtnrcn   : in    std_logic;
          qdvwjxmzbpf   : out   std_logic;
          mhxwcfnvbgt   : in    std_logic;
          bfcqzvtnrcn_0 : in    std_logic;
          xbkjkgdsbfh   : out   std_logic;
          dxpbcqjpxtw   : out   std_logic;
          NVM_BUSY_net  : in    std_logic
        );

end stnpfdkggvx;

architecture DEF_ARCH of stnpfdkggvx is 

  component AO1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component DFN1P0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          PRE : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal SUM0, \mwtvnzdkmwm[2]_net_1\, 
        \mwtvnzdkmwm_ns[3]_net_1\, \mwtvnzdkmwm_ns[4]_net_1\, 
        N_45, \gpbbjwsprsj[0]\, \mwtvnzdkmwm_ns[6]\, 
        \gpbbjwsprsj[1]\, \mwtvnzdkmwm_ns[1]_net_1\, 
        \mwtvnzdkmwm[7]_net_1\, \mwtvnzdkmwm_ns[5]\, 
        \xbkjkgdsbfh\, \dxpbcqjpxtw\, 
        \mwtvnzdkmwm_ns_i_a2[7]_net_1\, \mwtvnzdkmwm[1]_net_1\, 
        \mwtvnzdkmwm_ns[0]\, \mwtvnzdkmwm_ns[2]_net_1\, 
        \mwtvnzdkmwm[5]_net_1\, SUM1, \mwtvnzdkmwm[6]_net_1\, 
        \mwtvnzdkmwm[4]_net_1\, \qdvwjxmzbpf\, \GND\, \VCC\, 
        GND_net_1, VCC_net_1 : std_logic;

begin 

    mwtvnzdkmwm_5 <= \mwtvnzdkmwm[6]_net_1\;
    mwtvnzdkmwm_3 <= \mwtvnzdkmwm[4]_net_1\;
    mwtvnzdkmwm_4 <= \mwtvnzdkmwm[5]_net_1\;
    gpbbjwsprsj(1) <= \gpbbjwsprsj[1]\;
    gpbbjwsprsj(0) <= \gpbbjwsprsj[0]\;
    qdvwjxmzbpf <= \qdvwjxmzbpf\;
    xbkjkgdsbfh <= \xbkjkgdsbfh\;
    dxpbcqjpxtw <= \dxpbcqjpxtw\;

    \mwtvnzdkmwm_ns[1]\ : AO1B
      port map(A => bfcqzvtnrcn_0, B => \mwtvnzdkmwm[7]_net_1\, C
         => N_45, Y => \mwtvnzdkmwm_ns[1]_net_1\);
    
    \rhjctqnqzsn[0]\ : DFN1C0
      port map(D => SUM0, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        Q => \gpbbjwsprsj[0]\);
    
    \mwtvnzdkmwm[7]\ : DFN1P0
      port map(D => \mwtvnzdkmwm_ns[0]\, CLK => SYS_CLK_int, PRE
         => SYS_RESET_c, Q => \mwtvnzdkmwm[7]_net_1\);
    
    \mwtvnzdkmwm_ns[4]\ : AO1
      port map(A => NVM_BUSY_net, B => \xbkjkgdsbfh\, C => 
        \mwtvnzdkmwm[4]_net_1\, Y => \mwtvnzdkmwm_ns[4]_net_1\);
    
    mwtvnzdkmwm_1_sqmuxa_0_a2 : NOR3A
      port map(A => \xbkjkgdsbfh\, B => NVM_BUSY_net, C => 
        mhxwcfnvbgt, Y => \dxpbcqjpxtw\);
    
    \mwtvnzdkmwm[3]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[4]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \xbkjkgdsbfh\);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    \mwtvnzdkmwm_ns_i_a2[7]\ : OR2
      port map(A => \qdvwjxmzbpf\, B => \mwtvnzdkmwm[1]_net_1\, Y
         => \mwtvnzdkmwm_ns_i_a2[7]_net_1\);
    
    \mwtvnzdkmwm[5]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[2]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \mwtvnzdkmwm[5]_net_1\);
    
    \mwtvnzdkmwm_ns_a2[5]\ : NOR3B
      port map(A => \xbkjkgdsbfh\, B => mhxwcfnvbgt, C => 
        NVM_BUSY_net, Y => \mwtvnzdkmwm_ns[5]\);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    \mwtvnzdkmwm_ns_a2[0]\ : NOR2A
      port map(A => \mwtvnzdkmwm[7]_net_1\, B => bfcqzvtnrcn, Y
         => \mwtvnzdkmwm_ns[0]\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    un1_mwtvnzdkmwm_1_SUM1 : AX1C
      port map(A => \gpbbjwsprsj[0]\, B => \mwtvnzdkmwm[2]_net_1\, 
        C => \gpbbjwsprsj[1]\, Y => SUM1);
    
    \mwtvnzdkmwm[0]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns_i_a2[7]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => \qdvwjxmzbpf\);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    \mwtvnzdkmwm_ns[3]\ : AO1A
      port map(A => NVM_BUSY_net, B => \mwtvnzdkmwm[5]_net_1\, C
         => \dxpbcqjpxtw\, Y => \mwtvnzdkmwm_ns[3]_net_1\);
    
    \mwtvnzdkmwm_ns_a2[1]\ : AO1B
      port map(A => \gpbbjwsprsj[0]\, B => \gpbbjwsprsj[1]\, C
         => \mwtvnzdkmwm[2]_net_1\, Y => N_45);
    
    \mwtvnzdkmwm[4]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[3]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \mwtvnzdkmwm[4]_net_1\);
    
    \mwtvnzdkmwm[1]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \mwtvnzdkmwm[1]_net_1\);
    
    \mwtvnzdkmwm_ns[2]\ : AO1
      port map(A => NVM_BUSY_net, B => \mwtvnzdkmwm[5]_net_1\, C
         => \mwtvnzdkmwm[6]_net_1\, Y => 
        \mwtvnzdkmwm_ns[2]_net_1\);
    
    un1_mwtvnzdkmwm_1_SUM0 : XOR2
      port map(A => \mwtvnzdkmwm[2]_net_1\, B => \gpbbjwsprsj[0]\, 
        Y => SUM0);
    
    \mwtvnzdkmwm[6]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[1]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \mwtvnzdkmwm[6]_net_1\);
    
    \mwtvnzdkmwm[2]\ : DFN1C0
      port map(D => \mwtvnzdkmwm_ns[5]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \mwtvnzdkmwm[2]_net_1\);
    
    \rhjctqnqzsn[1]\ : DFN1C0
      port map(D => SUM1, CLK => SYS_CLK_int, CLR => SYS_RESET_c, 
        Q => \gpbbjwsprsj[1]\);
    
    \mwtvnzdkmwm_ns_a2[6]\ : NOR3C
      port map(A => \gpbbjwsprsj[0]\, B => \gpbbjwsprsj[1]\, C
         => \mwtvnzdkmwm[2]_net_1\, Y => \mwtvnzdkmwm_ns[6]\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XA is

    port( gpbbjwsprsj   : out   std_logic_vector(1 downto 0);
          mwtvnzdkmwm   : out   std_logic_vector(6 downto 4);
          NVM_BUSY_net  : in    std_logic;
          dxpbcqjpxtw   : out   std_logic;
          xbkjkgdsbfh   : out   std_logic;
          bfcqzvtnrcn_0 : in    std_logic;
          mhxwcfnvbgt   : in    std_logic;
          qdvwjxmzbpf   : out   std_logic;
          bfcqzvtnrcn   : in    std_logic;
          SYS_CLK_int   : in    std_logic;
          SYS_RESET_c   : in    std_logic
        );

end INITCFG_XA;

architecture DEF_ARCH of INITCFG_XA is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component stnpfdkggvx
    port( mwtvnzdkmwm_5 : out   std_logic;
          mwtvnzdkmwm_3 : out   std_logic;
          mwtvnzdkmwm_4 : out   std_logic;
          gpbbjwsprsj   : out   std_logic_vector(1 downto 0);
          SYS_RESET_c   : in    std_logic := 'U';
          SYS_CLK_int   : in    std_logic := 'U';
          bfcqzvtnrcn   : in    std_logic := 'U';
          qdvwjxmzbpf   : out   std_logic;
          mhxwcfnvbgt   : in    std_logic := 'U';
          bfcqzvtnrcn_0 : in    std_logic := 'U';
          xbkjkgdsbfh   : out   std_logic;
          dxpbcqjpxtw   : out   std_logic;
          NVM_BUSY_net  : in    std_logic := 'U'
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : stnpfdkggvx
	Use entity work.stnpfdkggvx(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_stnpfdkggvx : stnpfdkggvx
      port map(mwtvnzdkmwm_5 => mwtvnzdkmwm(6), mwtvnzdkmwm_3 => 
        mwtvnzdkmwm(4), mwtvnzdkmwm_4 => mwtvnzdkmwm(5), 
        gpbbjwsprsj(1) => gpbbjwsprsj(1), gpbbjwsprsj(0) => 
        gpbbjwsprsj(0), SYS_RESET_c => SYS_RESET_c, SYS_CLK_int
         => SYS_CLK_int, bfcqzvtnrcn => bfcqzvtnrcn, qdvwjxmzbpf
         => qdvwjxmzbpf, mhxwcfnvbgt => mhxwcfnvbgt, 
        bfcqzvtnrcn_0 => bfcqzvtnrcn_0, xbkjkgdsbfh => 
        xbkjkgdsbfh, dxpbcqjpxtw => dxpbcqjpxtw, NVM_BUSY_net => 
        NVM_BUSY_net);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity dxwqxgdccxc is

    port( bqhrfdzctjc           : out   std_logic_vector(6 downto 1);
          hbqjhzzrbnr_i         : in    std_logic_vector(0 to 0);
          bdhvhfjwtxd_0         : in    std_logic;
          bdhvhfjwtxd_5         : in    std_logic;
          ggfvvjbkdws           : out   std_logic_vector(9 downto 7);
          mmsccbknsvn_3         : in    std_logic;
          mmsccbknsvn_1         : in    std_logic;
          mmsccbknsvn_0         : in    std_logic;
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          SYS_RESET_c           : in    std_logic;
          SYS_CLK_int           : in    std_logic;
          mhxwcfnvbgt           : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          xkvhpkkjhmx_i_i_0     : in    std_logic;
          I2_un1_CO1            : out   std_logic;
          N_382                 : in    std_logic;
          N_383                 : in    std_logic;
          ADD_13x13_slow_I2_S_0 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : out   std_logic
        );

end dxwqxgdccxc;

architecture DEF_ARCH of dxwqxgdccxc is 

  component MX2C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component XNOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO16
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1E
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component MX2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component DFN1E1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          E   : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal ADD_9x9_medium_I8_Y_1, N105, ADD_9x9_medium_I9_Y_0, 
        N107, un10_gnmdxrqrdgs_NE_6, un10_gnmdxrqrdgs_NE_5, 
        un10_gnmdxrqrdgs_NE_3, un10_gnmdxrqrdgs_7_i, 
        un10_gnmdxrqrdgs_6, un10_gnmdxrqrdgs_2_i, 
        un10_gnmdxrqrdgs_NE_1, un10_gnmdxrqrdgs_3, 
        un10_gnmdxrqrdgs_NE_0, \INIT_ADDR_net[4]\, 
        \INIT_ADDR_net[5]\, I0_un1_CO1, N146, N121, N127, N124, 
        \INIT_ADDR_net[0]\, un10_gnmdxrqrdgs_NE, 
        \INIT_ADDR_net[1]\, I16_un1_Y, \INIT_ADDR_net[7]\, 
        I17_un1_Y, I18_un1_Y, \INIT_ADDR_net[3]\, I19_un1_Y, 
        \un1_wpfsqtfqtmx_i[2]\, un2_tnjvgqqhdkd, 
        \gnmdxrqrdgs_3[0]\, \gnmdxrqrdgs_3[1]\, 
        \gnmdxrqrdgs_3[2]\, \INIT_ADDR_net[2]\, 
        \gnmdxrqrdgs_3[3]\, \gnmdxrqrdgs_3[4]\, 
        \gnmdxrqrdgs_3[5]\, \gnmdxrqrdgs_3[6]\, 
        \INIT_ADDR_net[6]\, \gnmdxrqrdgs_3[7]\, 
        \gnmdxrqrdgs_3[8]\, \INIT_ADDR_net[8]\, 
        \ggfvvjbkdws[8]_net_1\, \ggfvvjbkdws[9]_net_1\, 
        \I2_un1_CO1\, \ggfvvjbkdws[7]_net_1\, \GND\, \VCC\, 
        GND_net_1, VCC_net_1 : std_logic;

begin 

    ggfvvjbkdws(9) <= \ggfvvjbkdws[9]_net_1\;
    ggfvvjbkdws(8) <= \ggfvvjbkdws[8]_net_1\;
    ggfvvjbkdws(7) <= \ggfvvjbkdws[7]_net_1\;
    INIT_ADDR_net(8) <= \INIT_ADDR_net[8]\;
    INIT_ADDR_net(7) <= \INIT_ADDR_net[7]\;
    INIT_ADDR_net(6) <= \INIT_ADDR_net[6]\;
    INIT_ADDR_net(5) <= \INIT_ADDR_net[5]\;
    INIT_ADDR_net(4) <= \INIT_ADDR_net[4]\;
    INIT_ADDR_net(3) <= \INIT_ADDR_net[3]\;
    INIT_ADDR_net(2) <= \INIT_ADDR_net[2]\;
    INIT_ADDR_net(1) <= \INIT_ADDR_net[1]\;
    INIT_ADDR_net(0) <= \INIT_ADDR_net[0]\;
    I2_un1_CO1 <= \I2_un1_CO1\;

    \ggfvvjbkdws[4]\ : MX2C
      port map(A => \INIT_ADDR_net[4]\, B => \INIT_ADDR_net[3]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(4));
    
    \gnmdxrqrdgs[2]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[2]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[2]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_7 : XNOR2
      port map(A => bdhvhfjwtxd_5, B => \INIT_ADDR_net[7]\, Y => 
        un10_gnmdxrqrdgs_7_i);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_6 : XOR2
      port map(A => mmsccbknsvn_0, B => \INIT_ADDR_net[6]\, Y => 
        un10_gnmdxrqrdgs_6);
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I2_S_0 : XOR2
      port map(A => N_383, B => N146, Y => ADD_13x13_slow_I2_S_0);
    
    \gnmdxrqrdgs[0]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[0]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[0]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I16_un1_Y : OR2B
      port map(A => N121, B => \INIT_ADDR_net[7]\, Y => I16_un1_Y);
    
    \gnmdxrqrdgs[5]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[5]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[5]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I8_Y : NOR2
      port map(A => ADD_9x9_medium_I8_Y_1, B => N127, Y => N121);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[5]\ : XA1B
      port map(A => \INIT_ADDR_net[5]\, B => N124, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[5]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE_5 : NOR3C
      port map(A => un10_gnmdxrqrdgs_NE_3, B => 
        un10_gnmdxrqrdgs_7_i, C => un10_gnmdxrqrdgs_6, Y => 
        un10_gnmdxrqrdgs_NE_5);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I2_un1_CO1 : AO1
      port map(A => N146, B => N_383, C => \ggfvvjbkdws[9]_net_1\, 
        Y => \I2_un1_CO1\);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[0]\ : XA1B
      port map(A => \INIT_ADDR_net[0]\, B => N_382, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[0]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE_6 : AO16
      port map(A => \INIT_ADDR_net[1]\, B => \INIT_ADDR_net[0]\, 
        C => mmsccbknsvn_0, Y => un10_gnmdxrqrdgs_NE_6);
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I1_S_0 : XOR2
      port map(A => mmsccbknsvn_1, B => I0_un1_CO1, Y => 
        ADD_13x13_slow_I1_S_0);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I19_un1_Y : NOR3C
      port map(A => \INIT_ADDR_net[0]\, B => N_382, C => 
        \INIT_ADDR_net[1]\, Y => I19_un1_Y);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[2]\ : XA1B
      port map(A => \INIT_ADDR_net[2]\, B => I19_un1_Y, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[2]\);
    
    \gnmdxrqrdgs[1]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[1]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[1]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I2_Y : OR2B
      port map(A => \INIT_ADDR_net[2]\, B => \INIT_ADDR_net[1]\, 
        Y => N107);
    
    \ggfvvjbkdws[3]\ : MX2C
      port map(A => \INIT_ADDR_net[3]\, B => \INIT_ADDR_net[2]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(3));
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[6]\ : XA1C
      port map(A => \INIT_ADDR_net[6]\, B => I17_un1_Y, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[6]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE_3 : NOR3C
      port map(A => un10_gnmdxrqrdgs_2_i, B => 
        un10_gnmdxrqrdgs_NE_1, C => un10_gnmdxrqrdgs_3, Y => 
        un10_gnmdxrqrdgs_NE_3);
    
    \gnmdxrqrdgs[6]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[6]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[6]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I6_Y : OR3B
      port map(A => \INIT_ADDR_net[0]\, B => N_382, C => N107, Y
         => N127);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_3 : XOR2
      port map(A => mmsccbknsvn_3, B => \INIT_ADDR_net[3]\, Y => 
        un10_gnmdxrqrdgs_3);
    
    \ggfvvjbkdws[5]\ : MX2C
      port map(A => \INIT_ADDR_net[5]\, B => \INIT_ADDR_net[4]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(5));
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_2 : XNOR2
      port map(A => bdhvhfjwtxd_0, B => \INIT_ADDR_net[2]\, Y => 
        un10_gnmdxrqrdgs_2_i);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I21_Y : AX1E
      port map(A => \INIT_ADDR_net[0]\, B => N_382, C => 
        \INIT_ADDR_net[1]\, Y => \un1_wpfsqtfqtmx_i[2]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE_0 : XA1A
      port map(A => \INIT_ADDR_net[4]\, B => \INIT_ADDR_net[8]\, 
        C => \INIT_ADDR_net[5]\, Y => un10_gnmdxrqrdgs_NE_0);
    
    \gnmdxrqrdgs[4]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[4]\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    \ggfvvjbkdws[7]\ : MX2
      port map(A => \INIT_ADDR_net[6]\, B => \INIT_ADDR_net[7]\, 
        S => mmsccbknsvn_0, Y => \ggfvvjbkdws[7]_net_1\);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[8]\ : XA1C
      port map(A => \INIT_ADDR_net[8]\, B => I16_un1_Y, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[8]\);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[4]\ : XA1B
      port map(A => \INIT_ADDR_net[4]\, B => I18_un1_Y, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[4]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE_1 : XA1A
      port map(A => \INIT_ADDR_net[4]\, B => \INIT_ADDR_net[7]\, 
        C => un10_gnmdxrqrdgs_NE_0, Y => un10_gnmdxrqrdgs_NE_1);
    
    \gnmdxrqrdgs[3]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[3]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[3]\);
    
    \ggfvvjbkdws[2]\ : MX2C
      port map(A => \INIT_ADDR_net[2]\, B => \INIT_ADDR_net[1]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(2));
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I3_CO1 : NOR2A
      port map(A => mmsccbknsvn_3, B => \I2_un1_CO1\, Y => 
        NVM_ADD_net_busnet_16);
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I0_un1_CO1 : OR2B
      port map(A => mmsccbknsvn_0, B => \ggfvvjbkdws[7]_net_1\, Y
         => I0_un1_CO1);
    
    \ggfvvjbkdws[6]\ : MX2C
      port map(A => \INIT_ADDR_net[6]\, B => \INIT_ADDR_net[5]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(6));
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[3]\ : XA1C
      port map(A => \INIT_ADDR_net[3]\, B => N127, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[3]\);
    
    jvbvzqvvxpc_un10_gnmdxrqrdgs_NE : NOR2B
      port map(A => un10_gnmdxrqrdgs_NE_6, B => 
        un10_gnmdxrqrdgs_NE_5, Y => un10_gnmdxrqrdgs_NE);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I9_Y_0 : OR2
      port map(A => N107, B => N105, Y => ADD_9x9_medium_I9_Y_0);
    
    \ggfvvjbkdws[9]\ : OR2B
      port map(A => hbqjhzzrbnr_i(0), B => \INIT_ADDR_net[8]\, Y
         => \ggfvvjbkdws[9]_net_1\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I8_Y_1 : OR3B
      port map(A => \INIT_ADDR_net[5]\, B => \INIT_ADDR_net[6]\, 
        C => N105, Y => ADD_9x9_medium_I8_Y_1);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[7]\ : XA1B
      port map(A => \INIT_ADDR_net[7]\, B => N121, C => 
        xkvhpkkjhmx_i_i_0, Y => \gnmdxrqrdgs_3[7]\);
    
    un1_dkjzqmrkvwb_ADD_13x13_slow_I1_CO1 : AO1
      port map(A => I0_un1_CO1, B => mmsccbknsvn_1, C => 
        \ggfvvjbkdws[8]_net_1\, Y => N146);
    
    \gnmdxrqrdgs[8]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[8]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[8]\);
    
    \gnmdxrqrdgs[7]\ : DFN1C0
      port map(D => \gnmdxrqrdgs_3[7]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \INIT_ADDR_net[7]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I18_un1_Y : NOR2A
      port map(A => \INIT_ADDR_net[3]\, B => N127, Y => I18_un1_Y);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I1_Y : OR2B
      port map(A => \INIT_ADDR_net[4]\, B => \INIT_ADDR_net[3]\, 
        Y => N105);
    
    \jvbvzqvvxpc_gnmdxrqrdgs_3[1]\ : NOR2
      port map(A => xkvhpkkjhmx_i_i_0, B => 
        \un1_wpfsqtfqtmx_i[2]\, Y => \gnmdxrqrdgs_3[1]\);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I17_un1_Y : OR2B
      port map(A => N124, B => \INIT_ADDR_net[5]\, Y => I17_un1_Y);
    
    kftxkfpnstb : DFN1E1C0
      port map(D => un10_gnmdxrqrdgs_NE, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, E => un2_tnjvgqqhdkd, Q => mhxwcfnvbgt);
    
    un1_wpfsqtfqtmx_ADD_9x9_medium_I9_Y : NOR3B
      port map(A => \INIT_ADDR_net[0]\, B => N_382, C => 
        ADD_9x9_medium_I9_Y_0, Y => N124);
    
    jvbvzqvvxpc_un2_tnjvgqqhdkd : OR2
      port map(A => xkvhpkkjhmx_i_i_0, B => un10_gnmdxrqrdgs_NE, 
        Y => un2_tnjvgqqhdkd);
    
    \ggfvvjbkdws[8]\ : MX2C
      port map(A => \INIT_ADDR_net[7]\, B => \INIT_ADDR_net[8]\, 
        S => mmsccbknsvn_0, Y => \ggfvvjbkdws[8]_net_1\);
    
    \ggfvvjbkdws[1]\ : MX2C
      port map(A => \INIT_ADDR_net[1]\, B => \INIT_ADDR_net[0]\, 
        S => hbqjhzzrbnr_i(0), Y => bqhrfdzctjc(1));
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XD is

    port( INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          mmsccbknsvn_0         : in    std_logic;
          mmsccbknsvn_1         : in    std_logic;
          mmsccbknsvn_3         : in    std_logic;
          ggfvvjbkdws           : out   std_logic_vector(9 downto 7);
          bdhvhfjwtxd_5         : in    std_logic;
          bdhvhfjwtxd_0         : in    std_logic;
          hbqjhzzrbnr_i         : in    std_logic_vector(0 to 0);
          bqhrfdzctjc           : out   std_logic_vector(6 downto 1);
          ADD_13x13_slow_I1_S_0 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : out   std_logic;
          N_383                 : in    std_logic;
          N_382                 : in    std_logic;
          I2_un1_CO1            : out   std_logic;
          xkvhpkkjhmx_i_i_0     : in    std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          mhxwcfnvbgt           : out   std_logic;
          SYS_CLK_int           : in    std_logic;
          SYS_RESET_c           : in    std_logic
        );

end INITCFG_XD;

architecture DEF_ARCH of INITCFG_XD is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component dxwqxgdccxc
    port( bqhrfdzctjc           : out   std_logic_vector(6 downto 1);
          hbqjhzzrbnr_i         : in    std_logic_vector(0 to 0) := (others => 'U');
          bdhvhfjwtxd_0         : in    std_logic := 'U';
          bdhvhfjwtxd_5         : in    std_logic := 'U';
          ggfvvjbkdws           : out   std_logic_vector(9 downto 7);
          mmsccbknsvn_3         : in    std_logic := 'U';
          mmsccbknsvn_1         : in    std_logic := 'U';
          mmsccbknsvn_0         : in    std_logic := 'U';
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          SYS_RESET_c           : in    std_logic := 'U';
          SYS_CLK_int           : in    std_logic := 'U';
          mhxwcfnvbgt           : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          xkvhpkkjhmx_i_i_0     : in    std_logic := 'U';
          I2_un1_CO1            : out   std_logic;
          N_382                 : in    std_logic := 'U';
          N_383                 : in    std_logic := 'U';
          ADD_13x13_slow_I2_S_0 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : dxwqxgdccxc
	Use entity work.dxwqxgdccxc(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_dxwqxgdccxc : dxwqxgdccxc
      port map(bqhrfdzctjc(6) => bqhrfdzctjc(6), bqhrfdzctjc(5)
         => bqhrfdzctjc(5), bqhrfdzctjc(4) => bqhrfdzctjc(4), 
        bqhrfdzctjc(3) => bqhrfdzctjc(3), bqhrfdzctjc(2) => 
        bqhrfdzctjc(2), bqhrfdzctjc(1) => bqhrfdzctjc(1), 
        hbqjhzzrbnr_i(0) => hbqjhzzrbnr_i(0), bdhvhfjwtxd_0 => 
        bdhvhfjwtxd_0, bdhvhfjwtxd_5 => bdhvhfjwtxd_5, 
        ggfvvjbkdws(9) => ggfvvjbkdws(9), ggfvvjbkdws(8) => 
        ggfvvjbkdws(8), ggfvvjbkdws(7) => ggfvvjbkdws(7), 
        mmsccbknsvn_3 => mmsccbknsvn_3, mmsccbknsvn_1 => 
        mmsccbknsvn_1, mmsccbknsvn_0 => mmsccbknsvn_0, 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), SYS_RESET_c => 
        SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, mhxwcfnvbgt => 
        mhxwcfnvbgt, NVM_ADD_net_busnet_16 => 
        NVM_ADD_net_busnet_16, xkvhpkkjhmx_i_i_0 => 
        xkvhpkkjhmx_i_i_0, I2_un1_CO1 => I2_un1_CO1, N_382 => 
        N_382, N_383 => N_383, ADD_13x13_slow_I2_S_0 => 
        ADD_13x13_slow_I2_S_0, ADD_13x13_slow_I1_S_0 => 
        ADD_13x13_slow_I1_S_0);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity gpbdjfttbjd is

    port( vvpkfmmpprk       : in    std_logic_vector(1 downto 0);
          gpbbjwsprsj       : in    std_logic_vector(1 downto 0);
          N_399             : in    std_logic;
          N_10              : out   std_logic;
          NVM_BUSY_net      : in    std_logic;
          xbkjkgdsbfh       : in    std_logic;
          INIT_EV_WEN_net   : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          N_4               : out   std_logic;
          INIT_ACM_WEN_net  : out   std_logic;
          npgnwznthhx       : in    std_logic
        );

end gpbdjfttbjd;

architecture DEF_ARCH of gpbdjfttbjd is 

  component OR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AOI1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component OR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal N_19, N_16, N_14, N_15, N_17, \N_4\, N_18, N_21, N_20, 
        \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 

    N_4 <= \N_4\;

    \fpppnnsbksx_0_a3[3]\ : OR3C
      port map(A => vvpkfmmpprk(0), B => vvpkfmmpprk(1), C => 
        npgnwznthhx, Y => N_20);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    \fpppnnsbksx_0_a3[1]\ : OR3B
      port map(A => vvpkfmmpprk(0), B => npgnwznthhx, C => 
        vvpkfmmpprk(1), Y => N_16);
    
    \fpppnnsbksx_r[0]\ : AOI1B
      port map(A => N_14, B => N_15, C => \N_4\, Y => 
        INIT_ACM_WEN_net);
    
    \fpppnnsbksx_0_a3[2]\ : OR3B
      port map(A => npgnwznthhx, B => vvpkfmmpprk(1), C => 
        vvpkfmmpprk(0), Y => N_18);
    
    \fpppnnsbksx_r[2]\ : AOI1B
      port map(A => N_18, B => N_19, C => \N_4\, Y => 
        INIT_EV_WEN_net);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    \fpppnnsbksx_r[1]\ : AOI1B
      port map(A => N_16, B => N_17, C => \N_4\, Y => 
        INIT_ASSC_WEN_net);
    
    \fpppnnsbksx_0_a3_0[3]\ : OR3B
      port map(A => gpbbjwsprsj(0), B => gpbbjwsprsj(1), C => 
        npgnwznthhx, Y => N_21);
    
    \fpppnnsbksx_0_a3[0]\ : OR3A
      port map(A => npgnwznthhx, B => vvpkfmmpprk(0), C => 
        vvpkfmmpprk(1), Y => N_14);
    
    GND_i : GND
      port map(Y => \GND\);
    
    \fpppnnsbksx_0_a3_0[1]\ : OR3A
      port map(A => gpbbjwsprsj(0), B => npgnwznthhx, C => 
        gpbbjwsprsj(1), Y => N_17);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    tdckqkwvkfk_un7_vcktjmvmkfg_i : OA1B
      port map(A => npgnwznthhx, B => xbkjkgdsbfh, C => 
        NVM_BUSY_net, Y => \N_4\);
    
    \fpppnnsbksx_0_a3_0[2]\ : OR3A
      port map(A => gpbbjwsprsj(1), B => gpbbjwsprsj(0), C => 
        npgnwznthhx, Y => N_19);
    
    \fpppnnsbksx_0[3]\ : OR2B
      port map(A => N_21, B => N_20, Y => N_10);
    
    \fpppnnsbksx_0_a3_0[0]\ : OR2A
      port map(A => N_399, B => npgnwznthhx, Y => N_15);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XE is

    port( gpbbjwsprsj       : in    std_logic_vector(1 downto 0);
          vvpkfmmpprk       : in    std_logic_vector(1 downto 0);
          npgnwznthhx       : in    std_logic;
          INIT_ACM_WEN_net  : out   std_logic;
          N_4               : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          INIT_EV_WEN_net   : out   std_logic;
          xbkjkgdsbfh       : in    std_logic;
          NVM_BUSY_net      : in    std_logic;
          N_10              : out   std_logic;
          N_399             : in    std_logic
        );

end INITCFG_XE;

architecture DEF_ARCH of INITCFG_XE is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component gpbdjfttbjd
    port( vvpkfmmpprk       : in    std_logic_vector(1 downto 0) := (others => 'U');
          gpbbjwsprsj       : in    std_logic_vector(1 downto 0) := (others => 'U');
          N_399             : in    std_logic := 'U';
          N_10              : out   std_logic;
          NVM_BUSY_net      : in    std_logic := 'U';
          xbkjkgdsbfh       : in    std_logic := 'U';
          INIT_EV_WEN_net   : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          N_4               : out   std_logic;
          INIT_ACM_WEN_net  : out   std_logic;
          npgnwznthhx       : in    std_logic := 'U'
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : gpbdjfttbjd
	Use entity work.gpbdjfttbjd(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    u_gpbdjfttbjd : gpbdjfttbjd
      port map(vvpkfmmpprk(1) => vvpkfmmpprk(1), vvpkfmmpprk(0)
         => vvpkfmmpprk(0), gpbbjwsprsj(1) => gpbbjwsprsj(1), 
        gpbbjwsprsj(0) => gpbbjwsprsj(0), N_399 => N_399, N_10
         => N_10, NVM_BUSY_net => NVM_BUSY_net, xbkjkgdsbfh => 
        xbkjkgdsbfh, INIT_EV_WEN_net => INIT_EV_WEN_net, 
        INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, N_4 => N_4, 
        INIT_ACM_WEN_net => INIT_ACM_WEN_net, npgnwznthhx => 
        npgnwznthhx);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity ffppvfwnggt is

    port( bqhrfdzctjc           : in    std_logic_vector(6 downto 1);
          ggfvvjbkdws           : in    std_logic_vector(9 downto 7);
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          gpbbjwsprsj           : in    std_logic_vector(1 downto 0);
          INIT_ADDR_net         : in    std_logic_vector(0 to 0);
          vvpkfmmpprk           : in    std_logic_vector(1 downto 0);
          bdhvhfjwtxd_0         : out   std_logic;
          bdhvhfjwtxd_5         : out   std_logic;
          mmsccbknsvn_0         : out   std_logic;
          mmsccbknsvn_3         : out   std_logic;
          mmsccbknsvn_1         : out   std_logic;
          crpwsdfhcqq_0         : in    std_logic;
          crpwsdfhcqq_4         : in    std_logic;
          mwtvnzdkmwm           : in    std_logic_vector(6 downto 4);
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : in    std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : in    std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          I2_un1_CO1            : in    std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          xbkjkgdsbfh           : in    std_logic;
          NVM_REN_net           : out   std_logic;
          xkvhpkkjhmx_i_i_0     : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          N_383                 : out   std_logic;
          bfcqzvtnrcn           : in    std_logic;
          dxpbcqjpxtw           : in    std_logic;
          fhpsqkqvwpw           : in    std_logic;
          N_382                 : out   std_logic;
          N_399                 : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          qdvwjxmzbpf           : in    std_logic;
          bfcqzvtnrcn_0         : in    std_logic
        );

end ffppvfwnggt;

architecture DEF_ARCH of ffppvfwnggt is 

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component OR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component XA1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component NOR3B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OA1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component OR3A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR3
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal N_385_0, \ttkcwbrgmjd_i_a2_0_0\, ttkcwbrgmjd_i_a2_0, 
        N_392, N_393, N_397, N_395, N_396, \mmsccbknsvn[15]\, 
        \bdhvhfjwtxd[7]\, N_398, \N_399\, \un1_wxqqqsndpvg_i_o2\, 
        \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

begin 

    bdhvhfjwtxd_5 <= \bdhvhfjwtxd[7]\;
    mmsccbknsvn_3 <= \mmsccbknsvn[15]\;
    un1_wxqqqsndpvg_i_o2 <= \un1_wxqqqsndpvg_i_o2\;
    N_399 <= \N_399\;

    \hbqjhzzrbnr_i_a2[0]\ : NOR2
      port map(A => gpbbjwsprsj(1), B => gpbbjwsprsj(0), Y => 
        \N_399\);
    
    \hrdbnmzftpn_0_a2[12]\ : OR3
      port map(A => vvpkfmmpprk(0), B => vvpkfmmpprk(1), C => 
        bfcqzvtnrcn_0, Y => N_397);
    
    \srdtcqsfmmm_0_a2[3]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(3), 
        Y => NVM_ADD_net_busnet_3);
    
    \hbqjhzzrbnr_i[0]\ : NOR2A
      port map(A => N_385_0, B => \N_399\, Y => hbqjhzzrbnr_i(0));
    
    \cpqqthwwhvc_i_o2[2]\ : MX2
      port map(A => vvpkfmmpprk(0), B => gpbbjwsprsj(0), S => 
        bfcqzvtnrcn, Y => bdhvhfjwtxd_0);
    
    \srdtcqsfmmm_0_a2[14]\ : XA1A
      port map(A => ggfvvjbkdws(9), B => ADD_13x13_slow_I2_S_0, C
         => N_385_0, Y => NVM_ADD_net_busnet_14);
    
    \cpqqthwwhvc_0_a2_0[4]\ : OR3B
      port map(A => bfcqzvtnrcn, B => gpbbjwsprsj(0), C => 
        gpbbjwsprsj(1), Y => N_396);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    \hrdbnmzftpn_0_a2_0[12]\ : OR2B
      port map(A => \N_399\, B => bfcqzvtnrcn, Y => N_398);
    
    ttkcwbrgmjd_i_a2_0_0_0 : OR2
      port map(A => mwtvnzdkmwm(6), B => mwtvnzdkmwm(5), Y => 
        \ttkcwbrgmjd_i_a2_0_0\);
    
    \srdtcqsfmmm_0_a2[5]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(5), 
        Y => NVM_ADD_net_busnet_5);
    
    \srdtcqsfmmm_0_a2[1]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(1), 
        Y => NVM_ADD_net_busnet_1);
    
    \srdtcqsfmmm_0_a2[12]\ : XA1
      port map(A => \N_399\, B => ggfvvjbkdws(7), C => N_385_0, Y
         => NVM_ADD_net_busnet_12);
    
    \hrdbnmzftpn_i_o2[14]\ : MX2
      port map(A => vvpkfmmpprk(1), B => gpbbjwsprsj(1), S => 
        bfcqzvtnrcn_0, Y => \mmsccbknsvn[15]\);
    
    \srdtcqsfmmm_0_a2[2]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(2), 
        Y => NVM_ADD_net_busnet_2);
    
    \hrdbnmzftpn_i[14]\ : OR3C
      port map(A => bfcqzvtnrcn, B => gpbbjwsprsj(0), C => 
        \mmsccbknsvn[15]\, Y => N_383);
    
    \srdtcqsfmmm_0_a2[15]\ : XA1A
      port map(A => I2_un1_CO1, B => \mmsccbknsvn[15]\, C => 
        N_385_0, Y => NVM_ADD_net_busnet_15);
    
    GND_i : GND
      port map(Y => \GND\);
    
    ttkcwbrgmjd_i : MX2
      port map(A => ttkcwbrgmjd_i_a2_0, B => 
        \ttkcwbrgmjd_i_a2_0_0\, S => N_385_0, Y => 
        xkvhpkkjhmx_i_i_0);
    
    \cpqqthwwhvc_0_o2[4]\ : OR2B
      port map(A => N_396, B => N_395, Y => \bdhvhfjwtxd[7]\);
    
    jsnhqgkgbcr_un1_wxqqqsndpvg_i_o2 : NOR2A
      port map(A => bfcqzvtnrcn, B => qdvwjxmzbpf, Y => 
        \un1_wxqqqsndpvg_i_o2\);
    
    \srdtcqsfmmm_0_a2[13]\ : XA1A
      port map(A => ggfvvjbkdws(8), B => ADD_13x13_slow_I1_S_0, C
         => N_385_0, Y => NVM_ADD_net_busnet_13);
    
    \hrdbnmzftpn_0_o2[12]\ : OR2B
      port map(A => N_398, B => N_397, Y => mmsccbknsvn_0);
    
    \srdtcqsfmmm_0_a2[6]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(6), 
        Y => NVM_ADD_net_busnet_6);
    
    \hrdbnmzftpn_0_a2[13]\ : NOR3B
      port map(A => bfcqzvtnrcn_0, B => gpbbjwsprsj(1), C => 
        gpbbjwsprsj(0), Y => N_392);
    
    ttkcwbrgmjd_i_a2_0_0 : OR2
      port map(A => crpwsdfhcqq_4, B => crpwsdfhcqq_0, Y => 
        ttkcwbrgmjd_i_a2_0);
    
    jsnhqgkgbcr_un1_wxqqqsndpvg_i_o2_0 : NOR2A
      port map(A => bfcqzvtnrcn_0, B => qdvwjxmzbpf, Y => N_385_0);
    
    ttgsznzrpgx_m_0_a2 : OA1
      port map(A => mwtvnzdkmwm(4), B => xbkjkgdsbfh, C => 
        N_385_0, Y => NVM_REN_net);
    
    \srdtcqsfmmm_0_a2[4]\ : NOR2A
      port map(A => \un1_wxqqqsndpvg_i_o2\, B => bqhrfdzctjc(4), 
        Y => NVM_ADD_net_busnet_4);
    
    \hrdbnmzftpn_0_a2_0[13]\ : NOR3A
      port map(A => vvpkfmmpprk(1), B => bfcqzvtnrcn_0, C => 
        vvpkfmmpprk(0), Y => N_393);
    
    cbfkvdxnxdp_i : MX2
      port map(A => fhpsqkqvwpw, B => dxpbcqjpxtw, S => N_385_0, 
        Y => N_382);
    
    \cpqqthwwhvc_0_a2[4]\ : OR3A
      port map(A => vvpkfmmpprk(0), B => bfcqzvtnrcn_0, C => 
        vvpkfmmpprk(1), Y => N_395);
    
    \srdtcqsfmmm_0_a2[0]\ : NOR3C
      port map(A => \N_399\, B => N_385_0, C => INIT_ADDR_net(0), 
        Y => NVM_ADD_net_busnet_0);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    \hrdbnmzftpn_0[13]\ : NOR3
      port map(A => N_392, B => N_393, C => \bdhvhfjwtxd[7]\, Y
         => mmsccbknsvn_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XC is

    port( mwtvnzdkmwm           : in    std_logic_vector(6 downto 4);
          crpwsdfhcqq_4         : in    std_logic;
          crpwsdfhcqq_0         : in    std_logic;
          mmsccbknsvn_1         : out   std_logic;
          mmsccbknsvn_3         : out   std_logic;
          mmsccbknsvn_0         : out   std_logic;
          bdhvhfjwtxd_5         : out   std_logic;
          bdhvhfjwtxd_0         : out   std_logic;
          vvpkfmmpprk           : in    std_logic_vector(1 downto 0);
          INIT_ADDR_net         : in    std_logic_vector(0 to 0);
          gpbbjwsprsj           : in    std_logic_vector(1 downto 0);
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          ggfvvjbkdws           : in    std_logic_vector(9 downto 7);
          bqhrfdzctjc           : in    std_logic_vector(6 downto 1);
          bfcqzvtnrcn_0         : in    std_logic;
          qdvwjxmzbpf           : in    std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          N_399                 : out   std_logic;
          N_382                 : out   std_logic;
          fhpsqkqvwpw           : in    std_logic;
          dxpbcqjpxtw           : in    std_logic;
          bfcqzvtnrcn           : in    std_logic;
          N_383                 : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          xkvhpkkjhmx_i_i_0     : out   std_logic;
          NVM_REN_net           : out   std_logic;
          xbkjkgdsbfh           : in    std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          I2_un1_CO1            : in    std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : in    std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : in    std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic
        );

end INITCFG_XC;

architecture DEF_ARCH of INITCFG_XC is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component ffppvfwnggt
    port( bqhrfdzctjc           : in    std_logic_vector(6 downto 1) := (others => 'U');
          ggfvvjbkdws           : in    std_logic_vector(9 downto 7) := (others => 'U');
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          gpbbjwsprsj           : in    std_logic_vector(1 downto 0) := (others => 'U');
          INIT_ADDR_net         : in    std_logic_vector(0 to 0) := (others => 'U');
          vvpkfmmpprk           : in    std_logic_vector(1 downto 0) := (others => 'U');
          bdhvhfjwtxd_0         : out   std_logic;
          bdhvhfjwtxd_5         : out   std_logic;
          mmsccbknsvn_0         : out   std_logic;
          mmsccbknsvn_3         : out   std_logic;
          mmsccbknsvn_1         : out   std_logic;
          crpwsdfhcqq_0         : in    std_logic := 'U';
          crpwsdfhcqq_4         : in    std_logic := 'U';
          mwtvnzdkmwm           : in    std_logic_vector(6 downto 4) := (others => 'U');
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : in    std_logic := 'U';
          NVM_ADD_net_busnet_13 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : in    std_logic := 'U';
          NVM_ADD_net_busnet_14 : out   std_logic;
          I2_un1_CO1            : in    std_logic := 'U';
          NVM_ADD_net_busnet_15 : out   std_logic;
          xbkjkgdsbfh           : in    std_logic := 'U';
          NVM_REN_net           : out   std_logic;
          xkvhpkkjhmx_i_i_0     : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          N_383                 : out   std_logic;
          bfcqzvtnrcn           : in    std_logic := 'U';
          dxpbcqjpxtw           : in    std_logic := 'U';
          fhpsqkqvwpw           : in    std_logic := 'U';
          N_382                 : out   std_logic;
          N_399                 : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          qdvwjxmzbpf           : in    std_logic := 'U';
          bfcqzvtnrcn_0         : in    std_logic := 'U'
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : ffppvfwnggt
	Use entity work.ffppvfwnggt(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    u_ffppvfwnggt : ffppvfwnggt
      port map(bqhrfdzctjc(6) => bqhrfdzctjc(6), bqhrfdzctjc(5)
         => bqhrfdzctjc(5), bqhrfdzctjc(4) => bqhrfdzctjc(4), 
        bqhrfdzctjc(3) => bqhrfdzctjc(3), bqhrfdzctjc(2) => 
        bqhrfdzctjc(2), bqhrfdzctjc(1) => bqhrfdzctjc(1), 
        ggfvvjbkdws(9) => ggfvvjbkdws(9), ggfvvjbkdws(8) => 
        ggfvvjbkdws(8), ggfvvjbkdws(7) => ggfvvjbkdws(7), 
        hbqjhzzrbnr_i(0) => hbqjhzzrbnr_i(0), gpbbjwsprsj(1) => 
        gpbbjwsprsj(1), gpbbjwsprsj(0) => gpbbjwsprsj(0), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), vvpkfmmpprk(1) => 
        vvpkfmmpprk(1), vvpkfmmpprk(0) => vvpkfmmpprk(0), 
        bdhvhfjwtxd_0 => bdhvhfjwtxd_0, bdhvhfjwtxd_5 => 
        bdhvhfjwtxd_5, mmsccbknsvn_0 => mmsccbknsvn_0, 
        mmsccbknsvn_3 => mmsccbknsvn_3, mmsccbknsvn_1 => 
        mmsccbknsvn_1, crpwsdfhcqq_0 => crpwsdfhcqq_0, 
        crpwsdfhcqq_4 => crpwsdfhcqq_4, mwtvnzdkmwm(6) => 
        mwtvnzdkmwm(6), mwtvnzdkmwm(5) => mwtvnzdkmwm(5), 
        mwtvnzdkmwm(4) => mwtvnzdkmwm(4), NVM_ADD_net_busnet_1
         => NVM_ADD_net_busnet_1, NVM_ADD_net_busnet_2 => 
        NVM_ADD_net_busnet_2, NVM_ADD_net_busnet_3 => 
        NVM_ADD_net_busnet_3, NVM_ADD_net_busnet_4 => 
        NVM_ADD_net_busnet_4, NVM_ADD_net_busnet_5 => 
        NVM_ADD_net_busnet_5, NVM_ADD_net_busnet_6 => 
        NVM_ADD_net_busnet_6, NVM_ADD_net_busnet_12 => 
        NVM_ADD_net_busnet_12, ADD_13x13_slow_I1_S_0 => 
        ADD_13x13_slow_I1_S_0, NVM_ADD_net_busnet_13 => 
        NVM_ADD_net_busnet_13, ADD_13x13_slow_I2_S_0 => 
        ADD_13x13_slow_I2_S_0, NVM_ADD_net_busnet_14 => 
        NVM_ADD_net_busnet_14, I2_un1_CO1 => I2_un1_CO1, 
        NVM_ADD_net_busnet_15 => NVM_ADD_net_busnet_15, 
        xbkjkgdsbfh => xbkjkgdsbfh, NVM_REN_net => NVM_REN_net, 
        xkvhpkkjhmx_i_i_0 => xkvhpkkjhmx_i_i_0, 
        un1_wxqqqsndpvg_i_o2 => un1_wxqqqsndpvg_i_o2, N_383 => 
        N_383, bfcqzvtnrcn => bfcqzvtnrcn, dxpbcqjpxtw => 
        dxpbcqjpxtw, fhpsqkqvwpw => fhpsqkqvwpw, N_382 => N_382, 
        N_399 => N_399, NVM_ADD_net_busnet_0 => 
        NVM_ADD_net_busnet_0, qdvwjxmzbpf => qdvwjxmzbpf, 
        bfcqzvtnrcn_0 => bfcqzvtnrcn_0);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity wbsfnwwctpn is

    port( crpwsdfhcqq_7 : out   std_logic;
          crpwsdfhcqq_3 : out   std_logic;
          vvpkfmmpprk   : out   std_logic_vector(1 downto 0);
          SYS_RESET_c   : in    std_logic;
          SYS_CLK_int   : in    std_logic;
          fhpsqkqvwpw   : out   std_logic;
          NVM_BUSY_net  : in    std_logic;
          npgnwznthhx   : out   std_logic
        );

end wbsfnwwctpn;

architecture DEF_ARCH of wbsfnwwctpn is 

  component DFN1C0
    port( D   : in    std_logic := 'U';
          CLK : in    std_logic := 'U';
          CLR : in    std_logic := 'U';
          Q   : out   std_logic
        );
  end component;

  component OR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component XOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component MX2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          S : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AX1C
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AO1
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component AOI1B
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          C : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NOR2A
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

    signal \crpwsdfhcqq_ns[4]\, \crpwsdfhcqq[0]_net_1\, 
        jspcghhzwmg, \crpwsdfhcqq_ns_i[1]_net_1\, 
        \crpwsdfhcqq_ns[3]_net_1\, \npgnwznthhx\, \fhpsqkqvwpw\, 
        \crpwsdfhcqq_ns_i[7]_net_1\, mfwjfgrqchd, 
        \crpwsdfhcqq[1]_net_1\, \crpwsdfhcqq_ns_i[6]_net_1\, 
        \crpwsdfhcqq_ns[8]\, SUM1_0, \crpwsdfhcqq[3]_net_1\, 
        \vvpkfmmpprk[0]\, \vvpkfmmpprk[1]\, SUM0_0, 
        \crpwsdfhcqq[7]_net_1\, \GND\, \VCC\, GND_net_1, 
        VCC_net_1 : std_logic;

begin 

    crpwsdfhcqq_7 <= \crpwsdfhcqq[7]_net_1\;
    crpwsdfhcqq_3 <= \crpwsdfhcqq[3]_net_1\;
    vvpkfmmpprk(1) <= \vvpkfmmpprk[1]\;
    vvpkfmmpprk(0) <= \vvpkfmmpprk[0]\;
    fhpsqkqvwpw <= \fhpsqkqvwpw\;
    npgnwznthhx <= \npgnwznthhx\;

    \crpwsdfhcqq[0]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns[8]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => \crpwsdfhcqq[0]_net_1\);
    
    \crpwsdfhcqq[3]\ : DFN1C0
      port map(D => \crpwsdfhcqq[7]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \crpwsdfhcqq[3]_net_1\);
    
    un6_zvnnzqsskfv_0 : OR2
      port map(A => \crpwsdfhcqq[0]_net_1\, B => jspcghhzwmg, Y
         => \fhpsqkqvwpw\);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    un1_crpwsdfhcqq_1_SUM0 : XOR2
      port map(A => \vvpkfmmpprk[0]\, B => \crpwsdfhcqq[3]_net_1\, 
        Y => SUM0_0);
    
    \bzcdnkppzhj[0]\ : DFN1C0
      port map(D => SUM0_0, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \vvpkfmmpprk[0]\);
    
    GND_i : GND
      port map(Y => \GND\);
    
    \crpwsdfhcqq[1]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns_i[7]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \crpwsdfhcqq[1]_net_1\);
    
    \crpwsdfhcqq_ns_i[7]\ : MX2
      port map(A => mfwjfgrqchd, B => \crpwsdfhcqq[1]_net_1\, S
         => NVM_BUSY_net, Y => \crpwsdfhcqq_ns_i[7]_net_1\);
    
    \crpwsdfhcqq[4]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns[4]\, CLK => SYS_CLK_int, CLR
         => SYS_RESET_c, Q => jspcghhzwmg);
    
    \crpwsdfhcqq[2]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns_i[6]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => mfwjfgrqchd);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    un1_crpwsdfhcqq_1_SUM1 : AX1C
      port map(A => \crpwsdfhcqq[3]_net_1\, B => \vvpkfmmpprk[0]\, 
        C => \vvpkfmmpprk[1]\, Y => SUM1_0);
    
    \crpwsdfhcqq_ns_i[6]\ : NOR2B
      port map(A => mfwjfgrqchd, B => NVM_BUSY_net, Y => 
        \crpwsdfhcqq_ns_i[6]_net_1\);
    
    \crpwsdfhcqq_ns[3]\ : AO1
      port map(A => NVM_BUSY_net, B => \npgnwznthhx\, C => 
        \fhpsqkqvwpw\, Y => \crpwsdfhcqq_ns[3]_net_1\);
    
    \crpwsdfhcqq[7]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns_i[1]_net_1\, CLK => 
        SYS_CLK_int, CLR => SYS_RESET_c, Q => 
        \crpwsdfhcqq[7]_net_1\);
    
    \crpwsdfhcqq_ns_i[1]\ : AOI1B
      port map(A => \vvpkfmmpprk[0]\, B => \vvpkfmmpprk[1]\, C
         => \crpwsdfhcqq[3]_net_1\, Y => 
        \crpwsdfhcqq_ns_i[1]_net_1\);
    
    \bzcdnkppzhj[1]\ : DFN1C0
      port map(D => SUM1_0, CLK => SYS_CLK_int, CLR => 
        SYS_RESET_c, Q => \vvpkfmmpprk[1]\);
    
    \crpwsdfhcqq_ns_a2[8]\ : NOR2A
      port map(A => \crpwsdfhcqq[1]_net_1\, B => NVM_BUSY_net, Y
         => \crpwsdfhcqq_ns[8]\);
    
    \crpwsdfhcqq_ns_a2[4]\ : NOR2A
      port map(A => \npgnwznthhx\, B => NVM_BUSY_net, Y => 
        \crpwsdfhcqq_ns[4]\);
    
    \crpwsdfhcqq[5]\ : DFN1C0
      port map(D => \crpwsdfhcqq_ns[3]_net_1\, CLK => SYS_CLK_int, 
        CLR => SYS_RESET_c, Q => \npgnwznthhx\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG_XB is

    port( vvpkfmmpprk   : out   std_logic_vector(1 downto 0);
          crpwsdfhcqq_0 : out   std_logic;
          crpwsdfhcqq_4 : out   std_logic;
          npgnwznthhx   : out   std_logic;
          NVM_BUSY_net  : in    std_logic;
          fhpsqkqvwpw   : out   std_logic;
          SYS_CLK_int   : in    std_logic;
          SYS_RESET_c   : in    std_logic
        );

end INITCFG_XB;

architecture DEF_ARCH of INITCFG_XB is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component wbsfnwwctpn
    port( crpwsdfhcqq_7 : out   std_logic;
          crpwsdfhcqq_3 : out   std_logic;
          vvpkfmmpprk   : out   std_logic_vector(1 downto 0);
          SYS_RESET_c   : in    std_logic := 'U';
          SYS_CLK_int   : in    std_logic := 'U';
          fhpsqkqvwpw   : out   std_logic;
          NVM_BUSY_net  : in    std_logic := 'U';
          npgnwznthhx   : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : wbsfnwwctpn
	Use entity work.wbsfnwwctpn(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    u_wbsfnwwctpn : wbsfnwwctpn
      port map(crpwsdfhcqq_7 => crpwsdfhcqq_4, crpwsdfhcqq_3 => 
        crpwsdfhcqq_0, vvpkfmmpprk(1) => vvpkfmmpprk(1), 
        vvpkfmmpprk(0) => vvpkfmmpprk(0), SYS_RESET_c => 
        SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, fhpsqkqvwpw => 
        fhpsqkqvwpw, NVM_BUSY_net => NVM_BUSY_net, npgnwznthhx
         => npgnwznthhx);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity grwzcnqmqzm is

    port( hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          qpkbfhrprrz           : out   std_logic;
          hrgmtcpsdzr           : out   std_logic;
          INIT_DONE_net         : in    std_logic;
          INIT_DONE_net_i       : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic;
          N_10                  : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_REN_net           : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          SYS_RESET_c           : in    std_logic;
          SYS_CLK_int           : in    std_logic;
          NVM_BUSY_net          : in    std_logic
        );

end grwzcnqmqzm;

architecture DEF_ARCH of grwzcnqmqzm is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component INITCFG_XF
    port( bfcqzvtnrcn_0   : out   std_logic;
          SYS_CLK_int     : in    std_logic := 'U';
          SYS_RESET_c     : in    std_logic := 'U';
          INIT_POWER_UP_c : in    std_logic := 'U';
          INIT_DONE_net_i : out   std_logic;
          INIT_DONE_net   : in    std_logic := 'U';
          bfcqzvtnrcn     : out   std_logic;
          qdvwjxmzbpf     : in    std_logic := 'U';
          hrgmtcpsdzr     : out   std_logic;
          qpkbfhrprrz     : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component INITCFG_XA
    port( gpbbjwsprsj   : out   std_logic_vector(1 downto 0);
          mwtvnzdkmwm   : out   std_logic_vector(6 downto 4);
          NVM_BUSY_net  : in    std_logic := 'U';
          dxpbcqjpxtw   : out   std_logic;
          xbkjkgdsbfh   : out   std_logic;
          bfcqzvtnrcn_0 : in    std_logic := 'U';
          mhxwcfnvbgt   : in    std_logic := 'U';
          qdvwjxmzbpf   : out   std_logic;
          bfcqzvtnrcn   : in    std_logic := 'U';
          SYS_CLK_int   : in    std_logic := 'U';
          SYS_RESET_c   : in    std_logic := 'U'
        );
  end component;

  component INITCFG_XD
    port( INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          mmsccbknsvn_0         : in    std_logic := 'U';
          mmsccbknsvn_1         : in    std_logic := 'U';
          mmsccbknsvn_3         : in    std_logic := 'U';
          ggfvvjbkdws           : out   std_logic_vector(9 downto 7);
          bdhvhfjwtxd_5         : in    std_logic := 'U';
          bdhvhfjwtxd_0         : in    std_logic := 'U';
          hbqjhzzrbnr_i         : in    std_logic_vector(0 to 0) := (others => 'U');
          bqhrfdzctjc           : out   std_logic_vector(6 downto 1);
          ADD_13x13_slow_I1_S_0 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : out   std_logic;
          N_383                 : in    std_logic := 'U';
          N_382                 : in    std_logic := 'U';
          I2_un1_CO1            : out   std_logic;
          xkvhpkkjhmx_i_i_0     : in    std_logic := 'U';
          NVM_ADD_net_busnet_16 : out   std_logic;
          mhxwcfnvbgt           : out   std_logic;
          SYS_CLK_int           : in    std_logic := 'U';
          SYS_RESET_c           : in    std_logic := 'U'
        );
  end component;

  component INITCFG_XE
    port( gpbbjwsprsj       : in    std_logic_vector(1 downto 0) := (others => 'U');
          vvpkfmmpprk       : in    std_logic_vector(1 downto 0) := (others => 'U');
          npgnwznthhx       : in    std_logic := 'U';
          INIT_ACM_WEN_net  : out   std_logic;
          N_4               : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          INIT_EV_WEN_net   : out   std_logic;
          xbkjkgdsbfh       : in    std_logic := 'U';
          NVM_BUSY_net      : in    std_logic := 'U';
          N_10              : out   std_logic;
          N_399             : in    std_logic := 'U'
        );
  end component;

  component INITCFG_XC
    port( mwtvnzdkmwm           : in    std_logic_vector(6 downto 4) := (others => 'U');
          crpwsdfhcqq_4         : in    std_logic := 'U';
          crpwsdfhcqq_0         : in    std_logic := 'U';
          mmsccbknsvn_1         : out   std_logic;
          mmsccbknsvn_3         : out   std_logic;
          mmsccbknsvn_0         : out   std_logic;
          bdhvhfjwtxd_5         : out   std_logic;
          bdhvhfjwtxd_0         : out   std_logic;
          vvpkfmmpprk           : in    std_logic_vector(1 downto 0) := (others => 'U');
          INIT_ADDR_net         : in    std_logic_vector(0 to 0) := (others => 'U');
          gpbbjwsprsj           : in    std_logic_vector(1 downto 0) := (others => 'U');
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          ggfvvjbkdws           : in    std_logic_vector(9 downto 7) := (others => 'U');
          bqhrfdzctjc           : in    std_logic_vector(6 downto 1) := (others => 'U');
          bfcqzvtnrcn_0         : in    std_logic := 'U';
          qdvwjxmzbpf           : in    std_logic := 'U';
          NVM_ADD_net_busnet_0  : out   std_logic;
          N_399                 : out   std_logic;
          N_382                 : out   std_logic;
          fhpsqkqvwpw           : in    std_logic := 'U';
          dxpbcqjpxtw           : in    std_logic := 'U';
          bfcqzvtnrcn           : in    std_logic := 'U';
          N_383                 : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          xkvhpkkjhmx_i_i_0     : out   std_logic;
          NVM_REN_net           : out   std_logic;
          xbkjkgdsbfh           : in    std_logic := 'U';
          NVM_ADD_net_busnet_15 : out   std_logic;
          I2_un1_CO1            : in    std_logic := 'U';
          NVM_ADD_net_busnet_14 : out   std_logic;
          ADD_13x13_slow_I2_S_0 : in    std_logic := 'U';
          NVM_ADD_net_busnet_13 : out   std_logic;
          ADD_13x13_slow_I1_S_0 : in    std_logic := 'U';
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic
        );
  end component;

  component INITCFG_XB
    port( vvpkfmmpprk   : out   std_logic_vector(1 downto 0);
          crpwsdfhcqq_0 : out   std_logic;
          crpwsdfhcqq_4 : out   std_logic;
          npgnwznthhx   : out   std_logic;
          NVM_BUSY_net  : in    std_logic := 'U';
          fhpsqkqvwpw   : out   std_logic;
          SYS_CLK_int   : in    std_logic := 'U';
          SYS_RESET_c   : in    std_logic := 'U'
        );
  end component;

    signal \gpbbjwsprsj[0]\, \gpbbjwsprsj[1]\, \mwtvnzdkmwm[4]\, 
        \mwtvnzdkmwm[5]\, \mwtvnzdkmwm[6]\, dxpbcqjpxtw, 
        xbkjkgdsbfh, bfcqzvtnrcn_0, mhxwcfnvbgt, qdvwjxmzbpf, 
        bfcqzvtnrcn, \vvpkfmmpprk[0]\, \vvpkfmmpprk[1]\, 
        \crpwsdfhcqq[3]\, \crpwsdfhcqq[7]\, npgnwznthhx, 
        fhpsqkqvwpw, \mmsccbknsvn[13]\, \mmsccbknsvn[15]\, 
        \mmsccbknsvn[12]\, \bdhvhfjwtxd[7]\, \bdhvhfjwtxd[2]\, 
        \ggfvvjbkdws[7]\, \ggfvvjbkdws[8]\, \ggfvvjbkdws[9]\, 
        \bqhrfdzctjc[1]\, \bqhrfdzctjc[2]\, \bqhrfdzctjc[3]\, 
        \bqhrfdzctjc[4]\, \bqhrfdzctjc[5]\, \bqhrfdzctjc[6]\, 
        N_399, N_382, N_383, xkvhpkkjhmx_i_i_0, I2_un1_CO1, 
        ADD_13x13_slow_I2_S_0, ADD_13x13_slow_I1_S_0, 
        \INIT_ADDR_net[0]\, \hbqjhzzrbnr_i[0]\, \GND\, \VCC\, 
        GND_net_1, VCC_net_1 : std_logic;

    for all : INITCFG_XF
	Use entity work.INITCFG_XF(DEF_ARCH);
    for all : INITCFG_XA
	Use entity work.INITCFG_XA(DEF_ARCH);
    for all : INITCFG_XD
	Use entity work.INITCFG_XD(DEF_ARCH);
    for all : INITCFG_XE
	Use entity work.INITCFG_XE(DEF_ARCH);
    for all : INITCFG_XC
	Use entity work.INITCFG_XC(DEF_ARCH);
    for all : INITCFG_XB
	Use entity work.INITCFG_XB(DEF_ARCH);
begin 

    hbqjhzzrbnr_i(0) <= \hbqjhzzrbnr_i[0]\;
    INIT_ADDR_net(0) <= \INIT_ADDR_net[0]\;

    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    user_clk_sel : INITCFG_XF
      port map(bfcqzvtnrcn_0 => bfcqzvtnrcn_0, SYS_CLK_int => 
        SYS_CLK_int, SYS_RESET_c => SYS_RESET_c, INIT_POWER_UP_c
         => INIT_POWER_UP_c, INIT_DONE_net_i => INIT_DONE_net_i, 
        INIT_DONE_net => INIT_DONE_net, bfcqzvtnrcn => 
        bfcqzvtnrcn, qdvwjxmzbpf => qdvwjxmzbpf, hrgmtcpsdzr => 
        hrgmtcpsdzr, qpkbfhrprrz => qpkbfhrprrz);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    init_fsm : INITCFG_XA
      port map(gpbbjwsprsj(1) => \gpbbjwsprsj[1]\, gpbbjwsprsj(0)
         => \gpbbjwsprsj[0]\, mwtvnzdkmwm(6) => \mwtvnzdkmwm[6]\, 
        mwtvnzdkmwm(5) => \mwtvnzdkmwm[5]\, mwtvnzdkmwm(4) => 
        \mwtvnzdkmwm[4]\, NVM_BUSY_net => NVM_BUSY_net, 
        dxpbcqjpxtw => dxpbcqjpxtw, xbkjkgdsbfh => xbkjkgdsbfh, 
        bfcqzvtnrcn_0 => bfcqzvtnrcn_0, mhxwcfnvbgt => 
        mhxwcfnvbgt, qdvwjxmzbpf => qdvwjxmzbpf, bfcqzvtnrcn => 
        bfcqzvtnrcn, SYS_CLK_int => SYS_CLK_int, SYS_RESET_c => 
        SYS_RESET_c);
    
    address_gen : INITCFG_XD
      port map(INIT_ADDR_net(8) => INIT_ADDR_net(8), 
        INIT_ADDR_net(7) => INIT_ADDR_net(7), INIT_ADDR_net(6)
         => INIT_ADDR_net(6), INIT_ADDR_net(5) => 
        INIT_ADDR_net(5), INIT_ADDR_net(4) => INIT_ADDR_net(4), 
        INIT_ADDR_net(3) => INIT_ADDR_net(3), INIT_ADDR_net(2)
         => INIT_ADDR_net(2), INIT_ADDR_net(1) => 
        INIT_ADDR_net(1), INIT_ADDR_net(0) => \INIT_ADDR_net[0]\, 
        mmsccbknsvn_0 => \mmsccbknsvn[12]\, mmsccbknsvn_1 => 
        \mmsccbknsvn[13]\, mmsccbknsvn_3 => \mmsccbknsvn[15]\, 
        ggfvvjbkdws(9) => \ggfvvjbkdws[9]\, ggfvvjbkdws(8) => 
        \ggfvvjbkdws[8]\, ggfvvjbkdws(7) => \ggfvvjbkdws[7]\, 
        bdhvhfjwtxd_5 => \bdhvhfjwtxd[7]\, bdhvhfjwtxd_0 => 
        \bdhvhfjwtxd[2]\, hbqjhzzrbnr_i(0) => \hbqjhzzrbnr_i[0]\, 
        bqhrfdzctjc(6) => \bqhrfdzctjc[6]\, bqhrfdzctjc(5) => 
        \bqhrfdzctjc[5]\, bqhrfdzctjc(4) => \bqhrfdzctjc[4]\, 
        bqhrfdzctjc(3) => \bqhrfdzctjc[3]\, bqhrfdzctjc(2) => 
        \bqhrfdzctjc[2]\, bqhrfdzctjc(1) => \bqhrfdzctjc[1]\, 
        ADD_13x13_slow_I1_S_0 => ADD_13x13_slow_I1_S_0, 
        ADD_13x13_slow_I2_S_0 => ADD_13x13_slow_I2_S_0, N_383 => 
        N_383, N_382 => N_382, I2_un1_CO1 => I2_un1_CO1, 
        xkvhpkkjhmx_i_i_0 => xkvhpkkjhmx_i_i_0, 
        NVM_ADD_net_busnet_16 => NVM_ADD_net_busnet_16, 
        mhxwcfnvbgt => mhxwcfnvbgt, SYS_CLK_int => SYS_CLK_int, 
        SYS_RESET_c => SYS_RESET_c);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    valid_client : INITCFG_XE
      port map(gpbbjwsprsj(1) => \gpbbjwsprsj[1]\, gpbbjwsprsj(0)
         => \gpbbjwsprsj[0]\, vvpkfmmpprk(1) => \vvpkfmmpprk[1]\, 
        vvpkfmmpprk(0) => \vvpkfmmpprk[0]\, npgnwznthhx => 
        npgnwznthhx, INIT_ACM_WEN_net => INIT_ACM_WEN_net, N_4
         => N_4, INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, 
        INIT_EV_WEN_net => INIT_EV_WEN_net, xbkjkgdsbfh => 
        xbkjkgdsbfh, NVM_BUSY_net => NVM_BUSY_net, N_10 => N_10, 
        N_399 => N_399);
    
    user_control : INITCFG_XC
      port map(mwtvnzdkmwm(6) => \mwtvnzdkmwm[6]\, mwtvnzdkmwm(5)
         => \mwtvnzdkmwm[5]\, mwtvnzdkmwm(4) => \mwtvnzdkmwm[4]\, 
        crpwsdfhcqq_4 => \crpwsdfhcqq[7]\, crpwsdfhcqq_0 => 
        \crpwsdfhcqq[3]\, mmsccbknsvn_1 => \mmsccbknsvn[13]\, 
        mmsccbknsvn_3 => \mmsccbknsvn[15]\, mmsccbknsvn_0 => 
        \mmsccbknsvn[12]\, bdhvhfjwtxd_5 => \bdhvhfjwtxd[7]\, 
        bdhvhfjwtxd_0 => \bdhvhfjwtxd[2]\, vvpkfmmpprk(1) => 
        \vvpkfmmpprk[1]\, vvpkfmmpprk(0) => \vvpkfmmpprk[0]\, 
        INIT_ADDR_net(0) => \INIT_ADDR_net[0]\, gpbbjwsprsj(1)
         => \gpbbjwsprsj[1]\, gpbbjwsprsj(0) => \gpbbjwsprsj[0]\, 
        hbqjhzzrbnr_i(0) => \hbqjhzzrbnr_i[0]\, ggfvvjbkdws(9)
         => \ggfvvjbkdws[9]\, ggfvvjbkdws(8) => \ggfvvjbkdws[8]\, 
        ggfvvjbkdws(7) => \ggfvvjbkdws[7]\, bqhrfdzctjc(6) => 
        \bqhrfdzctjc[6]\, bqhrfdzctjc(5) => \bqhrfdzctjc[5]\, 
        bqhrfdzctjc(4) => \bqhrfdzctjc[4]\, bqhrfdzctjc(3) => 
        \bqhrfdzctjc[3]\, bqhrfdzctjc(2) => \bqhrfdzctjc[2]\, 
        bqhrfdzctjc(1) => \bqhrfdzctjc[1]\, bfcqzvtnrcn_0 => 
        bfcqzvtnrcn_0, qdvwjxmzbpf => qdvwjxmzbpf, 
        NVM_ADD_net_busnet_0 => NVM_ADD_net_busnet_0, N_399 => 
        N_399, N_382 => N_382, fhpsqkqvwpw => fhpsqkqvwpw, 
        dxpbcqjpxtw => dxpbcqjpxtw, bfcqzvtnrcn => bfcqzvtnrcn, 
        N_383 => N_383, un1_wxqqqsndpvg_i_o2 => 
        un1_wxqqqsndpvg_i_o2, xkvhpkkjhmx_i_i_0 => 
        xkvhpkkjhmx_i_i_0, NVM_REN_net => NVM_REN_net, 
        xbkjkgdsbfh => xbkjkgdsbfh, NVM_ADD_net_busnet_15 => 
        NVM_ADD_net_busnet_15, I2_un1_CO1 => I2_un1_CO1, 
        NVM_ADD_net_busnet_14 => NVM_ADD_net_busnet_14, 
        ADD_13x13_slow_I2_S_0 => ADD_13x13_slow_I2_S_0, 
        NVM_ADD_net_busnet_13 => NVM_ADD_net_busnet_13, 
        ADD_13x13_slow_I1_S_0 => ADD_13x13_slow_I1_S_0, 
        NVM_ADD_net_busnet_12 => NVM_ADD_net_busnet_12, 
        NVM_ADD_net_busnet_6 => NVM_ADD_net_busnet_6, 
        NVM_ADD_net_busnet_5 => NVM_ADD_net_busnet_5, 
        NVM_ADD_net_busnet_4 => NVM_ADD_net_busnet_4, 
        NVM_ADD_net_busnet_3 => NVM_ADD_net_busnet_3, 
        NVM_ADD_net_busnet_2 => NVM_ADD_net_busnet_2, 
        NVM_ADD_net_busnet_1 => NVM_ADD_net_busnet_1);
    
    save_fsm : INITCFG_XB
      port map(vvpkfmmpprk(1) => \vvpkfmmpprk[1]\, vvpkfmmpprk(0)
         => \vvpkfmmpprk[0]\, crpwsdfhcqq_0 => \crpwsdfhcqq[3]\, 
        crpwsdfhcqq_4 => \crpwsdfhcqq[7]\, npgnwznthhx => 
        npgnwznthhx, NVM_BUSY_net => NVM_BUSY_net, fhpsqkqvwpw
         => fhpsqkqvwpw, SYS_CLK_int => SYS_CLK_int, SYS_RESET_c
         => SYS_RESET_c);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity INITCFG is

    port( INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          NVM_BUSY_net          : in    std_logic;
          SYS_CLK_int           : in    std_logic;
          SYS_RESET_c           : in    std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_REN_net           : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          N_10                  : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic;
          INIT_DONE_net_i       : out   std_logic;
          INIT_DONE_net         : in    std_logic;
          hrgmtcpsdzr           : out   std_logic;
          qpkbfhrprrz           : out   std_logic
        );

end INITCFG;

architecture DEF_ARCH of INITCFG is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component grwzcnqmqzm
    port( hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          qpkbfhrprrz           : out   std_logic;
          hrgmtcpsdzr           : out   std_logic;
          INIT_DONE_net         : in    std_logic := 'U';
          INIT_DONE_net_i       : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic := 'U';
          N_10                  : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_REN_net           : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          SYS_RESET_c           : in    std_logic := 'U';
          SYS_CLK_int           : in    std_logic := 'U';
          NVM_BUSY_net          : in    std_logic := 'U'
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : grwzcnqmqzm
	Use entity work.grwzcnqmqzm(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    u_grwzcnqmqzm : grwzcnqmqzm
      port map(hbqjhzzrbnr_i(0) => hbqjhzzrbnr_i(0), 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), qpkbfhrprrz => 
        qpkbfhrprrz, hrgmtcpsdzr => hrgmtcpsdzr, INIT_DONE_net
         => INIT_DONE_net, INIT_DONE_net_i => INIT_DONE_net_i, 
        INIT_POWER_UP_c => INIT_POWER_UP_c, N_10 => N_10, 
        INIT_EV_WEN_net => INIT_EV_WEN_net, INIT_ASSC_WEN_net => 
        INIT_ASSC_WEN_net, N_4 => N_4, INIT_ACM_WEN_net => 
        INIT_ACM_WEN_net, NVM_ADD_net_busnet_16 => 
        NVM_ADD_net_busnet_16, NVM_ADD_net_busnet_1 => 
        NVM_ADD_net_busnet_1, NVM_ADD_net_busnet_2 => 
        NVM_ADD_net_busnet_2, NVM_ADD_net_busnet_3 => 
        NVM_ADD_net_busnet_3, NVM_ADD_net_busnet_4 => 
        NVM_ADD_net_busnet_4, NVM_ADD_net_busnet_5 => 
        NVM_ADD_net_busnet_5, NVM_ADD_net_busnet_6 => 
        NVM_ADD_net_busnet_6, NVM_ADD_net_busnet_12 => 
        NVM_ADD_net_busnet_12, NVM_ADD_net_busnet_13 => 
        NVM_ADD_net_busnet_13, NVM_ADD_net_busnet_14 => 
        NVM_ADD_net_busnet_14, NVM_ADD_net_busnet_15 => 
        NVM_ADD_net_busnet_15, NVM_REN_net => NVM_REN_net, 
        un1_wxqqqsndpvg_i_o2 => un1_wxqqqsndpvg_i_o2, 
        NVM_ADD_net_busnet_0 => NVM_ADD_net_busnet_0, SYS_RESET_c
         => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, NVM_BUSY_net
         => NVM_BUSY_net);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity NVM_sys_init_wrapper is

    port( hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          qpkbfhrprrz           : out   std_logic;
          hrgmtcpsdzr           : out   std_logic;
          INIT_DONE_net         : in    std_logic;
          INIT_DONE_net_i       : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic;
          N_10                  : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_REN_net           : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          SYS_RESET_c           : in    std_logic;
          SYS_CLK_int           : in    std_logic;
          NVM_BUSY_net          : in    std_logic
        );

end NVM_sys_init_wrapper;

architecture DEF_ARCH of NVM_sys_init_wrapper is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component INITCFG
    port( INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          NVM_BUSY_net          : in    std_logic := 'U';
          SYS_CLK_int           : in    std_logic := 'U';
          SYS_RESET_c           : in    std_logic := 'U';
          NVM_ADD_net_busnet_0  : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_REN_net           : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          N_10                  : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic := 'U';
          INIT_DONE_net_i       : out   std_logic;
          INIT_DONE_net         : in    std_logic := 'U';
          hrgmtcpsdzr           : out   std_logic;
          qpkbfhrprrz           : out   std_logic
        );
  end component;

    signal \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : INITCFG
	Use entity work.INITCFG(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    U0 : INITCFG
      port map(INIT_ADDR_net(8) => INIT_ADDR_net(8), 
        INIT_ADDR_net(7) => INIT_ADDR_net(7), INIT_ADDR_net(6)
         => INIT_ADDR_net(6), INIT_ADDR_net(5) => 
        INIT_ADDR_net(5), INIT_ADDR_net(4) => INIT_ADDR_net(4), 
        INIT_ADDR_net(3) => INIT_ADDR_net(3), INIT_ADDR_net(2)
         => INIT_ADDR_net(2), INIT_ADDR_net(1) => 
        INIT_ADDR_net(1), INIT_ADDR_net(0) => INIT_ADDR_net(0), 
        hbqjhzzrbnr_i(0) => hbqjhzzrbnr_i(0), NVM_BUSY_net => 
        NVM_BUSY_net, SYS_CLK_int => SYS_CLK_int, SYS_RESET_c => 
        SYS_RESET_c, NVM_ADD_net_busnet_0 => NVM_ADD_net_busnet_0, 
        un1_wxqqqsndpvg_i_o2 => un1_wxqqqsndpvg_i_o2, NVM_REN_net
         => NVM_REN_net, NVM_ADD_net_busnet_15 => 
        NVM_ADD_net_busnet_15, NVM_ADD_net_busnet_14 => 
        NVM_ADD_net_busnet_14, NVM_ADD_net_busnet_13 => 
        NVM_ADD_net_busnet_13, NVM_ADD_net_busnet_12 => 
        NVM_ADD_net_busnet_12, NVM_ADD_net_busnet_6 => 
        NVM_ADD_net_busnet_6, NVM_ADD_net_busnet_5 => 
        NVM_ADD_net_busnet_5, NVM_ADD_net_busnet_4 => 
        NVM_ADD_net_busnet_4, NVM_ADD_net_busnet_3 => 
        NVM_ADD_net_busnet_3, NVM_ADD_net_busnet_2 => 
        NVM_ADD_net_busnet_2, NVM_ADD_net_busnet_1 => 
        NVM_ADD_net_busnet_1, NVM_ADD_net_busnet_16 => 
        NVM_ADD_net_busnet_16, INIT_ACM_WEN_net => 
        INIT_ACM_WEN_net, N_4 => N_4, INIT_ASSC_WEN_net => 
        INIT_ASSC_WEN_net, INIT_EV_WEN_net => INIT_EV_WEN_net, 
        N_10 => N_10, INIT_POWER_UP_c => INIT_POWER_UP_c, 
        INIT_DONE_net_i => INIT_DONE_net_i, INIT_DONE_net => 
        INIT_DONE_net, hrgmtcpsdzr => hrgmtcpsdzr, qpkbfhrprrz
         => qpkbfhrprrz);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity NVM_sys is

    port( INIT_ADDR_net     : out   std_logic_vector(8 downto 0);
          INIT_DATA_net     : out   std_logic_vector(8 downto 0);
          SYS_CLK_int       : in    std_logic;
          INIT_ACM_WEN_net  : out   std_logic;
          N_4               : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          INIT_EV_WEN_net   : out   std_logic;
          N_10              : out   std_logic;
          INIT_POWER_UP_c   : in    std_logic;
          INIT_DONE_net_i   : out   std_logic;
          INIT_DONE_net     : in    std_logic;
          hrgmtcpsdzr       : out   std_logic;
          SYS_RESET_c       : in    std_logic;
          NVM_sys_GND       : in    std_logic
        );

end NVM_sys;

architecture DEF_ARCH of NVM_sys is 

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component NVM
    generic (MEMORYFILE:string := "");

    port( RD               : out   std_logic_vector(31 downto 0);
          BUSY             : out   std_logic;
          STATUS           : out   std_logic_vector(1 downto 0);
          ADDR             : in    std_logic_vector(17 downto 0) := (others => 'U');
          WD               : in    std_logic_vector(31 downto 0) := (others => 'U');
          DATAWIDTH        : in    std_logic_vector(1 downto 0) := (others => 'U');
          REN              : in    std_logic := 'U';
          WEN              : in    std_logic := 'U';
          PROGRAM          : in    std_logic := 'U';
          SPAREPAGE        : in    std_logic := 'U';
          AUXBLOCK         : in    std_logic := 'U';
          READNEXT         : in    std_logic := 'U';
          ERASEPAGE        : in    std_logic := 'U';
          UNPROTECTPAGE    : in    std_logic := 'U';
          DISCARDPAGE      : in    std_logic := 'U';
          OVERWRITEPROTECT : in    std_logic := 'U';
          PAGELOSSPROTECT  : in    std_logic := 'U';
          CLK              : in    std_logic := 'U';
          RESET            : in    std_logic := 'U';
          PAGESTATUS       : in    std_logic := 'U';
          OVERWRITEPAGE    : in    std_logic := 'U';
          PIPE             : in    std_logic := 'U';
          LOCKREQUEST      : in    std_logic := 'U'
        );
  end component;

  component NVM_sys_init_wrapper
    port( hbqjhzzrbnr_i         : out   std_logic_vector(0 to 0);
          INIT_ADDR_net         : out   std_logic_vector(8 downto 0);
          qpkbfhrprrz           : out   std_logic;
          hrgmtcpsdzr           : out   std_logic;
          INIT_DONE_net         : in    std_logic := 'U';
          INIT_DONE_net_i       : out   std_logic;
          INIT_POWER_UP_c       : in    std_logic := 'U';
          N_10                  : out   std_logic;
          INIT_EV_WEN_net       : out   std_logic;
          INIT_ASSC_WEN_net     : out   std_logic;
          N_4                   : out   std_logic;
          INIT_ACM_WEN_net      : out   std_logic;
          NVM_ADD_net_busnet_16 : out   std_logic;
          NVM_ADD_net_busnet_1  : out   std_logic;
          NVM_ADD_net_busnet_2  : out   std_logic;
          NVM_ADD_net_busnet_3  : out   std_logic;
          NVM_ADD_net_busnet_4  : out   std_logic;
          NVM_ADD_net_busnet_5  : out   std_logic;
          NVM_ADD_net_busnet_6  : out   std_logic;
          NVM_ADD_net_busnet_12 : out   std_logic;
          NVM_ADD_net_busnet_13 : out   std_logic;
          NVM_ADD_net_busnet_14 : out   std_logic;
          NVM_ADD_net_busnet_15 : out   std_logic;
          NVM_REN_net           : out   std_logic;
          un1_wxqqqsndpvg_i_o2  : out   std_logic;
          NVM_ADD_net_busnet_0  : out   std_logic;
          SYS_RESET_c           : in    std_logic := 'U';
          SYS_CLK_int           : in    std_logic := 'U';
          NVM_BUSY_net          : in    std_logic := 'U'
        );
  end component;

    signal NVM_BUSY_net, NVM_DAT_FROM_net_busnet_9, 
        NVM_DAT_FROM_net_busnet_10, NVM_DAT_FROM_net_busnet_11, 
        NVM_DAT_FROM_net_busnet_12, NVM_DAT_FROM_net_busnet_13, 
        NVM_DAT_FROM_net_busnet_14, NVM_DAT_FROM_net_busnet_15, 
        NVM_DAT_FROM_net_busnet_16, NVM_DAT_FROM_net_busnet_17, 
        NVM_DAT_FROM_net_busnet_18, NVM_DAT_FROM_net_busnet_19, 
        NVM_DAT_FROM_net_busnet_20, NVM_DAT_FROM_net_busnet_21, 
        NVM_DAT_FROM_net_busnet_22, NVM_DAT_FROM_net_busnet_23, 
        NVM_DAT_FROM_net_busnet_24, NVM_DAT_FROM_net_busnet_25, 
        NVM_DAT_FROM_net_busnet_26, NVM_DAT_FROM_net_busnet_27, 
        NVM_DAT_FROM_net_busnet_28, NVM_DAT_FROM_net_busnet_29, 
        NVM_DAT_FROM_net_busnet_30, NVM_DAT_FROM_net_busnet_31, 
        NVM_STATUS_net_busnet_0, NVM_STATUS_net_busnet_1, 
        NVM_ADD_net_busnet_0, NVM_ADD_net_busnet_1, 
        NVM_ADD_net_busnet_2, NVM_ADD_net_busnet_3, 
        NVM_ADD_net_busnet_4, NVM_ADD_net_busnet_5, 
        NVM_ADD_net_busnet_6, NVM_ADD_net_busnet_12, 
        NVM_ADD_net_busnet_13, NVM_ADD_net_busnet_14, 
        NVM_ADD_net_busnet_15, NVM_ADD_net_busnet_16, qpkbfhrprrz, 
        \hbqjhzzrbnr_i[0]\, un1_wxqqqsndpvg_i_o2, NVM_REN_net, 
        \GND\, \VCC\, GND_net_1, VCC_net_1 : std_logic;

    for all : NVM_sys_init_wrapper
	Use entity work.NVM_sys_init_wrapper(DEF_ARCH);
begin 


    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    NVM_INST : NVM
      generic map(MEMORYFILE => "NVM_sys.mem")

      port map(RD(31) => NVM_DAT_FROM_net_busnet_31, RD(30) => 
        NVM_DAT_FROM_net_busnet_30, RD(29) => 
        NVM_DAT_FROM_net_busnet_29, RD(28) => 
        NVM_DAT_FROM_net_busnet_28, RD(27) => 
        NVM_DAT_FROM_net_busnet_27, RD(26) => 
        NVM_DAT_FROM_net_busnet_26, RD(25) => 
        NVM_DAT_FROM_net_busnet_25, RD(24) => 
        NVM_DAT_FROM_net_busnet_24, RD(23) => 
        NVM_DAT_FROM_net_busnet_23, RD(22) => 
        NVM_DAT_FROM_net_busnet_22, RD(21) => 
        NVM_DAT_FROM_net_busnet_21, RD(20) => 
        NVM_DAT_FROM_net_busnet_20, RD(19) => 
        NVM_DAT_FROM_net_busnet_19, RD(18) => 
        NVM_DAT_FROM_net_busnet_18, RD(17) => 
        NVM_DAT_FROM_net_busnet_17, RD(16) => 
        NVM_DAT_FROM_net_busnet_16, RD(15) => 
        NVM_DAT_FROM_net_busnet_15, RD(14) => 
        NVM_DAT_FROM_net_busnet_14, RD(13) => 
        NVM_DAT_FROM_net_busnet_13, RD(12) => 
        NVM_DAT_FROM_net_busnet_12, RD(11) => 
        NVM_DAT_FROM_net_busnet_11, RD(10) => 
        NVM_DAT_FROM_net_busnet_10, RD(9) => 
        NVM_DAT_FROM_net_busnet_9, RD(8) => INIT_DATA_net(8), 
        RD(7) => INIT_DATA_net(7), RD(6) => INIT_DATA_net(6), 
        RD(5) => INIT_DATA_net(5), RD(4) => INIT_DATA_net(4), 
        RD(3) => INIT_DATA_net(3), RD(2) => INIT_DATA_net(2), 
        RD(1) => INIT_DATA_net(1), RD(0) => INIT_DATA_net(0), 
        BUSY => NVM_BUSY_net, STATUS(1) => 
        NVM_STATUS_net_busnet_1, STATUS(0) => 
        NVM_STATUS_net_busnet_0, ADDR(17) => NVM_sys_GND, 
        ADDR(16) => NVM_ADD_net_busnet_16, ADDR(15) => 
        NVM_ADD_net_busnet_15, ADDR(14) => NVM_ADD_net_busnet_14, 
        ADDR(13) => NVM_ADD_net_busnet_13, ADDR(12) => 
        NVM_ADD_net_busnet_12, ADDR(11) => NVM_sys_GND, ADDR(10)
         => NVM_sys_GND, ADDR(9) => NVM_sys_GND, ADDR(8) => 
        NVM_sys_GND, ADDR(7) => NVM_sys_GND, ADDR(6) => 
        NVM_ADD_net_busnet_6, ADDR(5) => NVM_ADD_net_busnet_5, 
        ADDR(4) => NVM_ADD_net_busnet_4, ADDR(3) => 
        NVM_ADD_net_busnet_3, ADDR(2) => NVM_ADD_net_busnet_2, 
        ADDR(1) => NVM_ADD_net_busnet_1, ADDR(0) => 
        NVM_ADD_net_busnet_0, WD(31) => NVM_sys_GND, WD(30) => 
        NVM_sys_GND, WD(29) => NVM_sys_GND, WD(28) => NVM_sys_GND, 
        WD(27) => NVM_sys_GND, WD(26) => NVM_sys_GND, WD(25) => 
        NVM_sys_GND, WD(24) => NVM_sys_GND, WD(23) => NVM_sys_GND, 
        WD(22) => NVM_sys_GND, WD(21) => NVM_sys_GND, WD(20) => 
        NVM_sys_GND, WD(19) => NVM_sys_GND, WD(18) => NVM_sys_GND, 
        WD(17) => NVM_sys_GND, WD(16) => NVM_sys_GND, WD(15) => 
        NVM_sys_GND, WD(14) => NVM_sys_GND, WD(13) => NVM_sys_GND, 
        WD(12) => NVM_sys_GND, WD(11) => NVM_sys_GND, WD(10) => 
        NVM_sys_GND, WD(9) => NVM_sys_GND, WD(8) => NVM_sys_GND, 
        WD(7) => NVM_sys_GND, WD(6) => NVM_sys_GND, WD(5) => 
        NVM_sys_GND, WD(4) => NVM_sys_GND, WD(3) => NVM_sys_GND, 
        WD(2) => NVM_sys_GND, WD(1) => NVM_sys_GND, WD(0) => 
        NVM_sys_GND, DATAWIDTH(1) => NVM_sys_GND, DATAWIDTH(0)
         => \hbqjhzzrbnr_i[0]\, REN => NVM_REN_net, WEN => 
        NVM_sys_GND, PROGRAM => NVM_sys_GND, SPAREPAGE => 
        un1_wxqqqsndpvg_i_o2, AUXBLOCK => NVM_sys_GND, READNEXT
         => NVM_REN_net, ERASEPAGE => NVM_sys_GND, UNPROTECTPAGE
         => NVM_sys_GND, DISCARDPAGE => NVM_sys_GND, 
        OVERWRITEPROTECT => NVM_sys_GND, PAGELOSSPROTECT => 
        NVM_sys_GND, CLK => qpkbfhrprrz, RESET => SYS_RESET_c, 
        PAGESTATUS => NVM_sys_GND, OVERWRITEPAGE => NVM_sys_GND, 
        PIPE => NVM_sys_GND, LOCKREQUEST => un1_wxqqqsndpvg_i_o2);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    NVM_sys_init_wrapper_inst : NVM_sys_init_wrapper
      port map(hbqjhzzrbnr_i(0) => \hbqjhzzrbnr_i[0]\, 
        INIT_ADDR_net(8) => INIT_ADDR_net(8), INIT_ADDR_net(7)
         => INIT_ADDR_net(7), INIT_ADDR_net(6) => 
        INIT_ADDR_net(6), INIT_ADDR_net(5) => INIT_ADDR_net(5), 
        INIT_ADDR_net(4) => INIT_ADDR_net(4), INIT_ADDR_net(3)
         => INIT_ADDR_net(3), INIT_ADDR_net(2) => 
        INIT_ADDR_net(2), INIT_ADDR_net(1) => INIT_ADDR_net(1), 
        INIT_ADDR_net(0) => INIT_ADDR_net(0), qpkbfhrprrz => 
        qpkbfhrprrz, hrgmtcpsdzr => hrgmtcpsdzr, INIT_DONE_net
         => INIT_DONE_net, INIT_DONE_net_i => INIT_DONE_net_i, 
        INIT_POWER_UP_c => INIT_POWER_UP_c, N_10 => N_10, 
        INIT_EV_WEN_net => INIT_EV_WEN_net, INIT_ASSC_WEN_net => 
        INIT_ASSC_WEN_net, N_4 => N_4, INIT_ACM_WEN_net => 
        INIT_ACM_WEN_net, NVM_ADD_net_busnet_16 => 
        NVM_ADD_net_busnet_16, NVM_ADD_net_busnet_1 => 
        NVM_ADD_net_busnet_1, NVM_ADD_net_busnet_2 => 
        NVM_ADD_net_busnet_2, NVM_ADD_net_busnet_3 => 
        NVM_ADD_net_busnet_3, NVM_ADD_net_busnet_4 => 
        NVM_ADD_net_busnet_4, NVM_ADD_net_busnet_5 => 
        NVM_ADD_net_busnet_5, NVM_ADD_net_busnet_6 => 
        NVM_ADD_net_busnet_6, NVM_ADD_net_busnet_12 => 
        NVM_ADD_net_busnet_12, NVM_ADD_net_busnet_13 => 
        NVM_ADD_net_busnet_13, NVM_ADD_net_busnet_14 => 
        NVM_ADD_net_busnet_14, NVM_ADD_net_busnet_15 => 
        NVM_ADD_net_busnet_15, NVM_REN_net => NVM_REN_net, 
        un1_wxqqqsndpvg_i_o2 => un1_wxqqqsndpvg_i_o2, 
        NVM_ADD_net_busnet_0 => NVM_ADD_net_busnet_0, SYS_RESET_c
         => SYS_RESET_c, SYS_CLK_int => SYS_CLK_int, NVM_BUSY_net
         => NVM_BUSY_net);
    
    GND_i : GND
      port map(Y => \GND\);
    

end DEF_ARCH; 

library ieee;
use ieee.std_logic_1164.all;
library fusion;
use fusion.all;

entity VT_Mon is

    port( CLK40M        : in    std_logic;
          SYS_RESET     : in    std_logic;
          INIT_POWER_UP : in    std_logic;
          ATRETURN01    : in    std_logic;
          AV5V          : in    std_logic;
          Temp          : in    std_logic;
          VAREF         : in    std_logic;
          Supply_good   : out   std_logic;
          Over_temp     : out   std_logic
        );

end VT_Mon;

architecture DEF_ARCH of VT_Mon is 

  component CLKINT
    port( A : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component VCC
    port( Y : out   std_logic
        );
  end component;

  component NOR2
    port( A : in    std_logic := 'U';
          B : in    std_logic := 'U';
          Y : out   std_logic
        );
  end component;

  component NGM
    port( INIT_DONE_net_i : in    std_logic := 'U';
          CLK10M          : in    std_logic := 'U';
          PLL_CLK40M      : in    std_logic := 'U';
          SYS_CLK_int     : out   std_logic
        );
  end component;

  component INBUF
    port( PAD : in    std_logic := 'U';
          Y   : out   std_logic
        );
  end component;

  component PLL_40_10
    port( PLL_40_10_VCC : in    std_logic := 'U';
          PLL_40_10_GND : in    std_logic := 'U';
          PLL_CLK40M    : out   std_logic;
          CLK40M_c      : in    std_logic := 'U';
          CLK10M        : out   std_logic
        );
  end component;

  component GND
    port( Y : out   std_logic
        );
  end component;

  component Analog
    port( rdgwgtpkbgc_0      : in    std_logic_vector(3 to 3) := (others => 'U');
          rdgwgtpkbgc        : out   std_logic_vector(3 to 3);
          INIT_DATA_net      : in    std_logic_vector(8 downto 0) := (others => 'U');
          INIT_ADDR_net      : in    std_logic_vector(8 downto 0) := (others => 'U');
          INIT_ASSC_WEN_net  : in    std_logic := 'U';
          INIT_EV_WEN_net    : in    std_logic := 'U';
          INIT_DONE_net      : in    std_logic := 'U';
          AV5V_over5p25_net  : out   std_logic;
          AV5V_under4p75_net : out   std_logic;
          N_4                : in    std_logic := 'U';
          N_10               : in    std_logic := 'U';
          Analog_VCC         : in    std_logic := 'U';
          SYS_CLK_int        : in    std_logic := 'U';
          Supply_good_en_net : in    std_logic := 'U';
          SYS_RESET_c        : in    std_logic := 'U';
          CLK10M             : in    std_logic := 'U';
          VAREF              : inout   std_logic;
          AV5V               : in    std_logic := 'U';
          Analog_GND         : in    std_logic := 'U';
          INIT_ACM_WEN_net   : in    std_logic := 'U';
          Over_temp          : out   std_logic;
          Supply_good        : out   std_logic;
          ATRETURN01         : in    std_logic := 'U';
          Temp               : in    std_logic := 'U'
        );
  end component;

  component CLKBUF
    port( PAD : in    std_logic := 'U';
          Y   : out   std_logic
        );
  end component;

  component NVM_sys
    port( INIT_ADDR_net     : out   std_logic_vector(8 downto 0);
          INIT_DATA_net     : out   std_logic_vector(8 downto 0);
          SYS_CLK_int       : in    std_logic := 'U';
          INIT_ACM_WEN_net  : out   std_logic;
          N_4               : out   std_logic;
          INIT_ASSC_WEN_net : out   std_logic;
          INIT_EV_WEN_net   : out   std_logic;
          N_10              : out   std_logic;
          INIT_POWER_UP_c   : in    std_logic := 'U';
          INIT_DONE_net_i   : out   std_logic;
          INIT_DONE_net     : in    std_logic := 'U';
          hrgmtcpsdzr       : out   std_logic;
          SYS_RESET_c       : in    std_logic := 'U';
          NVM_sys_GND       : in    std_logic := 'U'
        );
  end component;

    signal \VAREF\, PLL_CLK40M, CLK10M, SYS_CLK_int, 
        AV5V_over5p25_net, AV5V_under4p75_net, \GND\, 
        \INIT_ADDR_net[0]\, \INIT_ADDR_net[1]\, 
        \INIT_ADDR_net[2]\, \INIT_ADDR_net[3]\, 
        \INIT_ADDR_net[4]\, \INIT_ADDR_net[5]\, 
        \INIT_ADDR_net[6]\, \INIT_ADDR_net[7]\, 
        \INIT_ADDR_net[8]\, \INIT_DATA_net[0]\, 
        \INIT_DATA_net[1]\, \INIT_DATA_net[2]\, 
        \INIT_DATA_net[3]\, \INIT_DATA_net[4]\, 
        \INIT_DATA_net[5]\, \INIT_DATA_net[6]\, 
        \INIT_DATA_net[7]\, \INIT_DATA_net[8]\, INIT_ACM_WEN_net, 
        INIT_DONE_net, \VCC\, \Supply_good_en_net\, 
        \Analog_inst.Analog_smev_wrapper_inst.U0.u_nbnjbfrkqwq.rdgwgtpkbgc[3]\, 
        CLK40M_c, SYS_RESET_c, INIT_POWER_UP_c, INIT_EV_WEN_net, 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_10\, 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_4\, 
        INIT_ASSC_WEN_net, INIT_DONE_net_i, hrgmtcpsdzr, 
        \rdgwgtpkbgc[3]\, GND_net_1, VCC_net_1 : std_logic;

    for all : NGM
	Use entity work.NGM(DEF_ARCH);
    for all : PLL_40_10
	Use entity work.PLL_40_10(DEF_ARCH);
    for all : Analog
	Use entity work.Analog(DEF_ARCH);
    for all : NVM_sys
	Use entity work.NVM_sys(DEF_ARCH);
begin 

    \VAREF\ <= VAREF;

    I_70 : CLKINT
      port map(A => \rdgwgtpkbgc[3]\, Y => 
        \Analog_inst.Analog_smev_wrapper_inst.U0.u_nbnjbfrkqwq.rdgwgtpkbgc[3]\);
    
    VCC_i_0 : VCC
      port map(Y => VCC_net_1);
    
    Supply_good_en_net : NOR2
      port map(A => AV5V_under4p75_net, B => AV5V_over5p25_net, Y
         => \Supply_good_en_net\);
    
    I_69 : CLKINT
      port map(A => hrgmtcpsdzr, Y => INIT_DONE_net);
    
    VCC_i : VCC
      port map(Y => \VCC\);
    
    NGMUX_inst : NGM
      port map(INIT_DONE_net_i => INIT_DONE_net_i, CLK10M => 
        CLK10M, PLL_CLK40M => PLL_CLK40M, SYS_CLK_int => 
        SYS_CLK_int);
    
    INIT_POWER_UP_pad : INBUF
      port map(PAD => INIT_POWER_UP, Y => INIT_POWER_UP_c);
    
    PLL_inst : PLL_40_10
      port map(PLL_40_10_VCC => \VCC\, PLL_40_10_GND => \GND\, 
        PLL_CLK40M => PLL_CLK40M, CLK40M_c => CLK40M_c, CLK10M
         => CLK10M);
    
    GND_i_0 : GND
      port map(Y => GND_net_1);
    
    GND_i : GND
      port map(Y => \GND\);
    
    CLK40M_pad : INBUF
      port map(PAD => CLK40M, Y => CLK40M_c);
    
    Analog_inst : Analog
      port map(rdgwgtpkbgc_0(3) => 
        \Analog_inst.Analog_smev_wrapper_inst.U0.u_nbnjbfrkqwq.rdgwgtpkbgc[3]\, 
        rdgwgtpkbgc(3) => \rdgwgtpkbgc[3]\, INIT_DATA_net(8) => 
        \INIT_DATA_net[8]\, INIT_DATA_net(7) => 
        \INIT_DATA_net[7]\, INIT_DATA_net(6) => 
        \INIT_DATA_net[6]\, INIT_DATA_net(5) => 
        \INIT_DATA_net[5]\, INIT_DATA_net(4) => 
        \INIT_DATA_net[4]\, INIT_DATA_net(3) => 
        \INIT_DATA_net[3]\, INIT_DATA_net(2) => 
        \INIT_DATA_net[2]\, INIT_DATA_net(1) => 
        \INIT_DATA_net[1]\, INIT_DATA_net(0) => 
        \INIT_DATA_net[0]\, INIT_ADDR_net(8) => 
        \INIT_ADDR_net[8]\, INIT_ADDR_net(7) => 
        \INIT_ADDR_net[7]\, INIT_ADDR_net(6) => 
        \INIT_ADDR_net[6]\, INIT_ADDR_net(5) => 
        \INIT_ADDR_net[5]\, INIT_ADDR_net(4) => 
        \INIT_ADDR_net[4]\, INIT_ADDR_net(3) => 
        \INIT_ADDR_net[3]\, INIT_ADDR_net(2) => 
        \INIT_ADDR_net[2]\, INIT_ADDR_net(1) => 
        \INIT_ADDR_net[1]\, INIT_ADDR_net(0) => 
        \INIT_ADDR_net[0]\, INIT_ASSC_WEN_net => 
        INIT_ASSC_WEN_net, INIT_EV_WEN_net => INIT_EV_WEN_net, 
        INIT_DONE_net => INIT_DONE_net, AV5V_over5p25_net => 
        AV5V_over5p25_net, AV5V_under4p75_net => 
        AV5V_under4p75_net, N_4 => 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_4\, 
        N_10 => 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_10\, 
        Analog_VCC => \VCC\, SYS_CLK_int => SYS_CLK_int, 
        Supply_good_en_net => \Supply_good_en_net\, SYS_RESET_c
         => SYS_RESET_c, CLK10M => CLK10M, VAREF => \VAREF\, AV5V
         => AV5V, Analog_GND => \GND\, INIT_ACM_WEN_net => 
        INIT_ACM_WEN_net, Over_temp => Over_temp, Supply_good => 
        Supply_good, ATRETURN01 => ATRETURN01, Temp => Temp);
    
    SYS_RESET_pad : CLKBUF
      port map(PAD => SYS_RESET, Y => SYS_RESET_c);
    
    NVM_inst : NVM_sys
      port map(INIT_ADDR_net(8) => \INIT_ADDR_net[8]\, 
        INIT_ADDR_net(7) => \INIT_ADDR_net[7]\, INIT_ADDR_net(6)
         => \INIT_ADDR_net[6]\, INIT_ADDR_net(5) => 
        \INIT_ADDR_net[5]\, INIT_ADDR_net(4) => 
        \INIT_ADDR_net[4]\, INIT_ADDR_net(3) => 
        \INIT_ADDR_net[3]\, INIT_ADDR_net(2) => 
        \INIT_ADDR_net[2]\, INIT_ADDR_net(1) => 
        \INIT_ADDR_net[1]\, INIT_ADDR_net(0) => 
        \INIT_ADDR_net[0]\, INIT_DATA_net(8) => 
        \INIT_DATA_net[8]\, INIT_DATA_net(7) => 
        \INIT_DATA_net[7]\, INIT_DATA_net(6) => 
        \INIT_DATA_net[6]\, INIT_DATA_net(5) => 
        \INIT_DATA_net[5]\, INIT_DATA_net(4) => 
        \INIT_DATA_net[4]\, INIT_DATA_net(3) => 
        \INIT_DATA_net[3]\, INIT_DATA_net(2) => 
        \INIT_DATA_net[2]\, INIT_DATA_net(1) => 
        \INIT_DATA_net[1]\, INIT_DATA_net(0) => 
        \INIT_DATA_net[0]\, SYS_CLK_int => SYS_CLK_int, 
        INIT_ACM_WEN_net => INIT_ACM_WEN_net, N_4 => 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_4\, 
        INIT_ASSC_WEN_net => INIT_ASSC_WEN_net, INIT_EV_WEN_net
         => INIT_EV_WEN_net, N_10 => 
        \NVM_inst.NVM_sys_init_wrapper_inst.U0.u_grwzcnqmqzm.valid_client.u_gpbdjfttbjd.N_10\, 
        INIT_POWER_UP_c => INIT_POWER_UP_c, INIT_DONE_net_i => 
        INIT_DONE_net_i, INIT_DONE_net => INIT_DONE_net, 
        hrgmtcpsdzr => hrgmtcpsdzr, SYS_RESET_c => SYS_RESET_c, 
        NVM_sys_GND => \GND\);
    

end DEF_ARCH; 
